Class: Google::Apis::ContainerV1::AdditionalNodeNetworkConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

AdditionalNodeNetworkConfig is the configuration for additional node networks within the NodeNetworkConfig message

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AdditionalNodeNetworkConfig

Returns a new instance of AdditionalNodeNetworkConfig.



144
145
146
# File 'lib/google/apis/container_v1/classes.rb', line 144

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#networkString

Name of the VPC where the additional interface belongs Corresponds to the JSON property network

Returns:

  • (String)


137
138
139
# File 'lib/google/apis/container_v1/classes.rb', line 137

def network
  @network
end

#subnetworkString

Name of the subnetwork where the additional interface belongs Corresponds to the JSON property subnetwork

Returns:

  • (String)


142
143
144
# File 'lib/google/apis/container_v1/classes.rb', line 142

def subnetwork
  @subnetwork
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



149
150
151
152
# File 'lib/google/apis/container_v1/classes.rb', line 149

def update!(**args)
  @network = args[:network] if args.key?(:network)
  @subnetwork = args[:subnetwork] if args.key?(:subnetwork)
end