Class: Google::Apis::ContainerV1::AutopilotConfig
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1::AutopilotConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb
Overview
AutopilotConfig contains configuration of autopilot feature for this nodepool.
Instance Attribute Summary collapse
-
#enabled ⇒ Boolean
(also: #enabled?)
Denotes that nodes belonging to this node pool are Autopilot nodes.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AutopilotConfig
constructor
A new instance of AutopilotConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AutopilotConfig
Returns a new instance of AutopilotConfig.
600 601 602 |
# File 'lib/google/apis/container_v1/classes.rb', line 600 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enabled ⇒ Boolean Also known as: enabled?
Denotes that nodes belonging to this node pool are Autopilot nodes.
Corresponds to the JSON property enabled
597 598 599 |
# File 'lib/google/apis/container_v1/classes.rb', line 597 def enabled @enabled end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
605 606 607 |
# File 'lib/google/apis/container_v1/classes.rb', line 605 def update!(**args) @enabled = args[:enabled] if args.key?(:enabled) end |