Class: Google::Apis::ContainerV1::BestEffortProvisioning

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

Best effort provisioning.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BestEffortProvisioning

Returns a new instance of BestEffortProvisioning.



848
849
850
# File 'lib/google/apis/container_v1/classes.rb', line 848

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enabledBoolean Also known as: enabled?

When this is enabled, cluster/node pool creations will ignore non-fatal errors like stockout to best provision as many nodes as possible right now and eventually bring up all target number of nodes Corresponds to the JSON property enabled

Returns:

  • (Boolean)


838
839
840
# File 'lib/google/apis/container_v1/classes.rb', line 838

def enabled
  @enabled
end

#min_provision_nodesFixnum

Minimum number of nodes to be provisioned to be considered as succeeded, and the rest of nodes will be provisioned gradually and eventually when stockout issue has been resolved. Corresponds to the JSON property minProvisionNodes

Returns:

  • (Fixnum)


846
847
848
# File 'lib/google/apis/container_v1/classes.rb', line 846

def min_provision_nodes
  @min_provision_nodes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



853
854
855
856
# File 'lib/google/apis/container_v1/classes.rb', line 853

def update!(**args)
  @enabled = args[:enabled] if args.key?(:enabled)
  @min_provision_nodes = args[:min_provision_nodes] if args.key?(:min_provision_nodes)
end