Class: Google::Apis::ContainerV1::BlueGreenSettings

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

Settings for blue-green upgrade.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BlueGreenSettings

Returns a new instance of BlueGreenSettings.



974
975
976
# File 'lib/google/apis/container_v1/classes.rb', line 974

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#autoscaled_rollout_policyGoogle::Apis::ContainerV1::AutoscaledRolloutPolicy

Autoscaled rollout policy utilizes the cluster autoscaler during blue-green upgrade to scale both the blue and green pools. Corresponds to the JSON property autoscaledRolloutPolicy



961
962
963
# File 'lib/google/apis/container_v1/classes.rb', line 961

def autoscaled_rollout_policy
  @autoscaled_rollout_policy
end

#node_pool_soak_durationString

Time needed after draining entire blue pool. After this period, blue pool will be cleaned up. Corresponds to the JSON property nodePoolSoakDuration

Returns:

  • (String)


967
968
969
# File 'lib/google/apis/container_v1/classes.rb', line 967

def node_pool_soak_duration
  @node_pool_soak_duration
end

#standard_rollout_policyGoogle::Apis::ContainerV1::StandardRolloutPolicy

Standard rollout policy is the default policy for blue-green. Corresponds to the JSON property standardRolloutPolicy



972
973
974
# File 'lib/google/apis/container_v1/classes.rb', line 972

def standard_rollout_policy
  @standard_rollout_policy
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



979
980
981
982
983
# File 'lib/google/apis/container_v1/classes.rb', line 979

def update!(**args)
  @autoscaled_rollout_policy = args[:autoscaled_rollout_policy] if args.key?(:autoscaled_rollout_policy)
  @node_pool_soak_duration = args[:node_pool_soak_duration] if args.key?(:node_pool_soak_duration)
  @standard_rollout_policy = args[:standard_rollout_policy] if args.key?(:standard_rollout_policy)
end