Class: Google::Apis::ContainerV1::CancelOperationRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

CancelOperationRequest cancels a single operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CancelOperationRequest

Returns a new instance of CancelOperationRequest.



1078
1079
1080
# File 'lib/google/apis/container_v1/classes.rb', line 1078

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

The name (project, location, operation id) of the operation to cancel. Specified in the format projects/*/locations/*/operations/*. Corresponds to the JSON property name

Returns:

  • (String)


1056
1057
1058
# File 'lib/google/apis/container_v1/classes.rb', line 1056

def name
  @name
end

#operation_idString

Deprecated. The server-assigned name of the operation. This field has been deprecated and replaced by the name field. Corresponds to the JSON property operationId

Returns:

  • (String)


1062
1063
1064
# File 'lib/google/apis/container_v1/classes.rb', line 1062

def operation_id
  @operation_id
end

#project_idString

Deprecated. The Google Developers Console project ID or project number. This field has been deprecated and replaced by the name field. Corresponds to the JSON property projectId

Returns:

  • (String)


1069
1070
1071
# File 'lib/google/apis/container_v1/classes.rb', line 1069

def project_id
  @project_id
end

#zoneString

Deprecated. The name of the Google Compute Engine zone in which the operation resides. This field has been deprecated and replaced by the name field. Corresponds to the JSON property zone

Returns:

  • (String)


1076
1077
1078
# File 'lib/google/apis/container_v1/classes.rb', line 1076

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1083
1084
1085
1086
1087
1088
# File 'lib/google/apis/container_v1/classes.rb', line 1083

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @operation_id = args[:operation_id] if args.key?(:operation_id)
  @project_id = args[:project_id] if args.key?(:project_id)
  @zone = args[:zone] if args.key?(:zone)
end