Class: Google::Apis::ContainerV1::CertificateConfigPair

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

CertificateConfigPair configures pairs of certificates, which is used for client certificate and key pairs under a registry.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CertificateConfigPair

Returns a new instance of CertificateConfigPair.



1158
1159
1160
# File 'lib/google/apis/container_v1/classes.rb', line 1158

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#certGoogle::Apis::ContainerV1::CertificateConfig

CertificateConfig configures certificate for the registry. Corresponds to the JSON property cert



1151
1152
1153
# File 'lib/google/apis/container_v1/classes.rb', line 1151

def cert
  @cert
end

#keyGoogle::Apis::ContainerV1::CertificateConfig

CertificateConfig configures certificate for the registry. Corresponds to the JSON property key



1156
1157
1158
# File 'lib/google/apis/container_v1/classes.rb', line 1156

def key
  @key
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1163
1164
1165
1166
# File 'lib/google/apis/container_v1/classes.rb', line 1163

def update!(**args)
  @cert = args[:cert] if args.key?(:cert)
  @key = args[:key] if args.key?(:key)
end