Class: Google::Apis::ContainerV1::ClusterAutoscaling

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

ClusterAutoscaling contains global, per-cluster information required by Cluster Autoscaler to automatically adjust the size of the cluster and create/ delete node pools based on the current needs.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ClusterAutoscaling

Returns a new instance of ClusterAutoscaling.



1964
1965
1966
# File 'lib/google/apis/container_v1/classes.rb', line 1964

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#autopilot_general_profileString

Autopilot general profile for the cluster, which defines the configuration for the cluster. Corresponds to the JSON property autopilotGeneralProfile

Returns:

  • (String)


1928
1929
1930
# File 'lib/google/apis/container_v1/classes.rb', line 1928

def autopilot_general_profile
  @autopilot_general_profile
end

#autoprovisioning_locationsArray<String>

The list of Google Compute Engine zones in which the NodePool's nodes can be created by NAP. Corresponds to the JSON property autoprovisioningLocations

Returns:

  • (Array<String>)


1934
1935
1936
# File 'lib/google/apis/container_v1/classes.rb', line 1934

def autoprovisioning_locations
  @autoprovisioning_locations
end

#autoprovisioning_node_pool_defaultsGoogle::Apis::ContainerV1::AutoprovisioningNodePoolDefaults

AutoprovisioningNodePoolDefaults contains defaults for a node pool created by NAP. Corresponds to the JSON property autoprovisioningNodePoolDefaults



1940
1941
1942
# File 'lib/google/apis/container_v1/classes.rb', line 1940

def autoprovisioning_node_pool_defaults
  @autoprovisioning_node_pool_defaults
end

#autoscaling_profileString

Defines autoscaling behaviour. Corresponds to the JSON property autoscalingProfile

Returns:

  • (String)


1945
1946
1947
# File 'lib/google/apis/container_v1/classes.rb', line 1945

def autoscaling_profile
  @autoscaling_profile
end

#default_compute_class_configGoogle::Apis::ContainerV1::DefaultComputeClassConfig

DefaultComputeClassConfig defines default compute class configuration. Corresponds to the JSON property defaultComputeClassConfig



1950
1951
1952
# File 'lib/google/apis/container_v1/classes.rb', line 1950

def default_compute_class_config
  @default_compute_class_config
end

#enable_node_autoprovisioningBoolean Also known as: enable_node_autoprovisioning?

Enables automatic node pool creation and deletion. Corresponds to the JSON property enableNodeAutoprovisioning

Returns:

  • (Boolean)


1955
1956
1957
# File 'lib/google/apis/container_v1/classes.rb', line 1955

def enable_node_autoprovisioning
  @enable_node_autoprovisioning
end

#resource_limitsArray<Google::Apis::ContainerV1::ResourceLimit>

Contains global constraints regarding minimum and maximum amount of resources in the cluster. Corresponds to the JSON property resourceLimits



1962
1963
1964
# File 'lib/google/apis/container_v1/classes.rb', line 1962

def resource_limits
  @resource_limits
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1969
1970
1971
1972
1973
1974
1975
1976
1977
# File 'lib/google/apis/container_v1/classes.rb', line 1969

def update!(**args)
  @autopilot_general_profile = args[:autopilot_general_profile] if args.key?(:autopilot_general_profile)
  @autoprovisioning_locations = args[:autoprovisioning_locations] if args.key?(:autoprovisioning_locations)
  @autoprovisioning_node_pool_defaults = args[:autoprovisioning_node_pool_defaults] if args.key?(:autoprovisioning_node_pool_defaults)
  @autoscaling_profile = args[:autoscaling_profile] if args.key?(:autoscaling_profile)
  @default_compute_class_config = args[:default_compute_class_config] if args.key?(:default_compute_class_config)
  @enable_node_autoprovisioning = args[:enable_node_autoprovisioning] if args.key?(:enable_node_autoprovisioning)
  @resource_limits = args[:resource_limits] if args.key?(:resource_limits)
end