Class: Google::Apis::ContainerV1::ClusterPolicyConfig
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1::ClusterPolicyConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb
Overview
ClusterPolicyConfig stores the configuration for cluster wide policies.
Instance Attribute Summary collapse
-
#no_standard_node_pools ⇒ Boolean
(also: #no_standard_node_pools?)
Denotes preventing standard node pools and requiring only autopilot node pools.
-
#no_system_impersonation ⇒ Boolean
(also: #no_system_impersonation?)
Denotes preventing impersonation and CSRs for GKE System users.
-
#no_system_mutation ⇒ Boolean
(also: #no_system_mutation?)
Denotes that preventing creation and mutation of resources in GKE managed namespaces and cluster-scoped GKE managed resources .
-
#no_unsafe_webhooks ⇒ Boolean
(also: #no_unsafe_webhooks?)
Denotes preventing unsafe webhooks.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ClusterPolicyConfig
constructor
A new instance of ClusterPolicyConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ClusterPolicyConfig
Returns a new instance of ClusterPolicyConfig.
2014 2015 2016 |
# File 'lib/google/apis/container_v1/classes.rb', line 2014 def initialize(**args) update!(**args) end |
Instance Attribute Details
#no_standard_node_pools ⇒ Boolean Also known as: no_standard_node_pools?
Denotes preventing standard node pools and requiring only autopilot node pools.
Corresponds to the JSON property noStandardNodePools
1992 1993 1994 |
# File 'lib/google/apis/container_v1/classes.rb', line 1992 def no_standard_node_pools @no_standard_node_pools end |
#no_system_impersonation ⇒ Boolean Also known as: no_system_impersonation?
Denotes preventing impersonation and CSRs for GKE System users.
Corresponds to the JSON property noSystemImpersonation
1998 1999 2000 |
# File 'lib/google/apis/container_v1/classes.rb', line 1998 def no_system_impersonation @no_system_impersonation end |
#no_system_mutation ⇒ Boolean Also known as: no_system_mutation?
Denotes that preventing creation and mutation of resources in GKE managed
namespaces and cluster-scoped GKE managed resources .
Corresponds to the JSON property noSystemMutation
2005 2006 2007 |
# File 'lib/google/apis/container_v1/classes.rb', line 2005 def no_system_mutation @no_system_mutation end |
#no_unsafe_webhooks ⇒ Boolean Also known as: no_unsafe_webhooks?
Denotes preventing unsafe webhooks.
Corresponds to the JSON property noUnsafeWebhooks
2011 2012 2013 |
# File 'lib/google/apis/container_v1/classes.rb', line 2011 def no_unsafe_webhooks @no_unsafe_webhooks end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2019 2020 2021 2022 2023 2024 |
# File 'lib/google/apis/container_v1/classes.rb', line 2019 def update!(**args) @no_standard_node_pools = args[:no_standard_node_pools] if args.key?(:no_standard_node_pools) @no_system_impersonation = args[:no_system_impersonation] if args.key?(:no_system_impersonation) @no_system_mutation = args[:no_system_mutation] if args.key?(:no_system_mutation) @no_unsafe_webhooks = args[:no_unsafe_webhooks] if args.key?(:no_unsafe_webhooks) end |