Class: Google::Apis::ContainerV1::CompleteIpRotationRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

CompleteIPRotationRequest moves the cluster master back into single-IP mode.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CompleteIpRotationRequest

Returns a new instance of CompleteIpRotationRequest.



2762
2763
2764
# File 'lib/google/apis/container_v1/classes.rb', line 2762

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cluster_idString

Deprecated. The name of the cluster. This field has been deprecated and replaced by the name field. Corresponds to the JSON property clusterId

Returns:

  • (String)


2740
2741
2742
# File 'lib/google/apis/container_v1/classes.rb', line 2740

def cluster_id
  @cluster_id
end

#nameString

The name (project, location, cluster name) of the cluster to complete IP rotation. Specified in the format projects/*/locations/*/clusters/*. Corresponds to the JSON property name

Returns:

  • (String)


2746
2747
2748
# File 'lib/google/apis/container_v1/classes.rb', line 2746

def name
  @name
end

#project_idString

Deprecated. The Google Developers Console project ID or project number. This field has been deprecated and replaced by the name field. Corresponds to the JSON property projectId

Returns:

  • (String)


2753
2754
2755
# File 'lib/google/apis/container_v1/classes.rb', line 2753

def project_id
  @project_id
end

#zoneString

Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has been deprecated and replaced by the name field. Corresponds to the JSON property zone

Returns:

  • (String)


2760
2761
2762
# File 'lib/google/apis/container_v1/classes.rb', line 2760

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2767
2768
2769
2770
2771
2772
# File 'lib/google/apis/container_v1/classes.rb', line 2767

def update!(**args)
  @cluster_id = args[:cluster_id] if args.key?(:cluster_id)
  @name = args[:name] if args.key?(:name)
  @project_id = args[:project_id] if args.key?(:project_id)
  @zone = args[:zone] if args.key?(:zone)
end