Class: Google::Apis::ContainerV1::CrashLoopBackOffConfig
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1::CrashLoopBackOffConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb
Overview
Contains config to modify node-level parameters for container restart behavior.
Instance Attribute Summary collapse
-
#max_container_restart_period ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CrashLoopBackOffConfig
constructor
A new instance of CrashLoopBackOffConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CrashLoopBackOffConfig
Returns a new instance of CrashLoopBackOffConfig.
2752 2753 2754 |
# File 'lib/google/apis/container_v1/classes.rb', line 2752 def initialize(**args) update!(**args) end |
Instance Attribute Details
#max_container_restart_period ⇒ String
Optional. The maximum duration the backoff delay can accrue to for container
restarts, minimum 1 second, maximum 300 seconds. If not set, defaults to the
internal crashloopbackoff maximum. The string must be a sequence of decimal
numbers, each with optional fraction and a unit suffix, such as "300ms". Valid
time units are "ns", "us" (or "µs"), "ms", "s", "m", "h". See https://
kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle/#configurable-
container-restart-delay for more details.
Corresponds to the JSON property maxContainerRestartPeriod
2750 2751 2752 |
# File 'lib/google/apis/container_v1/classes.rb', line 2750 def max_container_restart_period @max_container_restart_period end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2757 2758 2759 |
# File 'lib/google/apis/container_v1/classes.rb', line 2757 def update!(**args) @max_container_restart_period = args[:max_container_restart_period] if args.key?(:max_container_restart_period) end |