Class: Google::Apis::ContainerV1::CreateClusterRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

CreateClusterRequest creates a cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CreateClusterRequest

Returns a new instance of CreateClusterRequest.



3057
3058
3059
# File 'lib/google/apis/container_v1/classes.rb', line 3057

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#clusterGoogle::Apis::ContainerV1::Cluster

A Google Kubernetes Engine cluster. Corresponds to the JSON property cluster



3035
3036
3037
# File 'lib/google/apis/container_v1/classes.rb', line 3035

def cluster
  @cluster
end

#parentString

The parent (project and location) where the cluster will be created. Specified in the format projects/*/locations/*. Corresponds to the JSON property parent

Returns:

  • (String)


3041
3042
3043
# File 'lib/google/apis/container_v1/classes.rb', line 3041

def parent
  @parent
end

#project_idString

Deprecated. The Google Developers Console project ID or project number. This field has been deprecated and replaced by the parent field. Corresponds to the JSON property projectId

Returns:

  • (String)


3048
3049
3050
# File 'lib/google/apis/container_v1/classes.rb', line 3048

def project_id
  @project_id
end

#zoneString

Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has been deprecated and replaced by the parent field. Corresponds to the JSON property zone

Returns:

  • (String)


3055
3056
3057
# File 'lib/google/apis/container_v1/classes.rb', line 3055

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3062
3063
3064
3065
3066
3067
# File 'lib/google/apis/container_v1/classes.rb', line 3062

def update!(**args)
  @cluster = args[:cluster] if args.key?(:cluster)
  @parent = args[:parent] if args.key?(:parent)
  @project_id = args[:project_id] if args.key?(:project_id)
  @zone = args[:zone] if args.key?(:zone)
end