Class: Google::Apis::ContainerV1::CustomImageConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

CustomImageConfig contains the information r

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CustomImageConfig

Returns a new instance of CustomImageConfig.



3138
3139
3140
# File 'lib/google/apis/container_v1/classes.rb', line 3138

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#imageString

The name of the image to use for this node. Corresponds to the JSON property image

Returns:

  • (String)


3131
3132
3133
# File 'lib/google/apis/container_v1/classes.rb', line 3131

def image
  @image
end

#image_projectString

The project containing the image to use for this node. Corresponds to the JSON property imageProject

Returns:

  • (String)


3136
3137
3138
# File 'lib/google/apis/container_v1/classes.rb', line 3136

def image_project
  @image_project
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3143
3144
3145
3146
# File 'lib/google/apis/container_v1/classes.rb', line 3143

def update!(**args)
  @image = args[:image] if args.key?(:image)
  @image_project = args[:image_project] if args.key?(:image_project)
end