Class: Google::Apis::ContainerV1::CustomNodeInit
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1::CustomNodeInit
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb
Overview
Support for running custom init code while bootstrapping nodes.
Instance Attribute Summary collapse
-
#init_script ⇒ Google::Apis::ContainerV1::InitScript
InitScript provide a simply bash script to be executed on the node.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CustomNodeInit
constructor
A new instance of CustomNodeInit.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CustomNodeInit
Returns a new instance of CustomNodeInit.
3111 3112 3113 |
# File 'lib/google/apis/container_v1/classes.rb', line 3111 def initialize(**args) update!(**args) end |
Instance Attribute Details
#init_script ⇒ Google::Apis::ContainerV1::InitScript
InitScript provide a simply bash script to be executed on the node.
Corresponds to the JSON property initScript
3109 3110 3111 |
# File 'lib/google/apis/container_v1/classes.rb', line 3109 def init_script @init_script end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3116 3117 3118 |
# File 'lib/google/apis/container_v1/classes.rb', line 3116 def update!(**args) @init_script = args[:init_script] if args.key?(:init_script) end |