Class: Google::Apis::ContainerV1::DailyMaintenanceWindow

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

Time window specified for daily maintenance operations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DailyMaintenanceWindow

Returns a new instance of DailyMaintenanceWindow.



3286
3287
3288
# File 'lib/google/apis/container_v1/classes.rb', line 3286

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#durationString

Output only. Duration of the time window, automatically chosen to be smallest possible in the given scenario. Duration will be in RFC3339 format "PTnHnMnS". Corresponds to the JSON property duration

Returns:

  • (String)


3277
3278
3279
# File 'lib/google/apis/container_v1/classes.rb', line 3277

def duration
  @duration
end

#start_timeString

Time within the maintenance window to start the maintenance operations. Time format should be in RFC3339 format "HH: MM", where HH : [00-23] and MM : [00-59] GMT. Corresponds to the JSON property startTime

Returns:

  • (String)


3284
3285
3286
# File 'lib/google/apis/container_v1/classes.rb', line 3284

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3291
3292
3293
3294
# File 'lib/google/apis/container_v1/classes.rb', line 3291

def update!(**args)
  @duration = args[:duration] if args.key?(:duration)
  @start_time = args[:start_time] if args.key?(:start_time)
end