Class: Google::Apis::ContainerV1::DnsConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

DNSConfig contains the desired set of options for configuring clusterDNS.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DnsConfig

Returns a new instance of DnsConfig.



3211
3212
3213
# File 'lib/google/apis/container_v1/classes.rb', line 3211

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#additive_vpc_scope_dns_domainString

Optional. The domain used in Additive VPC scope. Corresponds to the JSON property additiveVpcScopeDnsDomain

Returns:

  • (String)


3194
3195
3196
# File 'lib/google/apis/container_v1/classes.rb', line 3194

def additive_vpc_scope_dns_domain
  @additive_vpc_scope_dns_domain
end

#cluster_dnsString

cluster_dns indicates which in-cluster DNS provider should be used. Corresponds to the JSON property clusterDns

Returns:

  • (String)


3199
3200
3201
# File 'lib/google/apis/container_v1/classes.rb', line 3199

def cluster_dns
  @cluster_dns
end

#cluster_dns_domainString

cluster_dns_domain is the suffix used for all cluster service records. Corresponds to the JSON property clusterDnsDomain

Returns:

  • (String)


3204
3205
3206
# File 'lib/google/apis/container_v1/classes.rb', line 3204

def cluster_dns_domain
  @cluster_dns_domain
end

#cluster_dns_scopeString

cluster_dns_scope indicates the scope of access to cluster DNS records. Corresponds to the JSON property clusterDnsScope

Returns:

  • (String)


3209
3210
3211
# File 'lib/google/apis/container_v1/classes.rb', line 3209

def cluster_dns_scope
  @cluster_dns_scope
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3216
3217
3218
3219
3220
3221
# File 'lib/google/apis/container_v1/classes.rb', line 3216

def update!(**args)
  @additive_vpc_scope_dns_domain = args[:additive_vpc_scope_dns_domain] if args.key?(:additive_vpc_scope_dns_domain)
  @cluster_dns = args[:cluster_dns] if args.key?(:cluster_dns)
  @cluster_dns_domain = args[:cluster_dns_domain] if args.key?(:cluster_dns_domain)
  @cluster_dns_scope = args[:cluster_dns_scope] if args.key?(:cluster_dns_scope)
end