Class: Google::Apis::ContainerV1::DnsEndpointConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

Describes the configuration of a DNS endpoint.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DnsEndpointConfig

Returns a new instance of DnsEndpointConfig.



3189
3190
3191
# File 'lib/google/apis/container_v1/classes.rb', line 3189

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allow_external_trafficBoolean Also known as: allow_external_traffic?

Controls whether user traffic is allowed over this endpoint. Note that Google- managed services may still use the endpoint even if this is false. Corresponds to the JSON property allowExternalTraffic

Returns:

  • (Boolean)


3166
3167
3168
# File 'lib/google/apis/container_v1/classes.rb', line 3166

def allow_external_traffic
  @allow_external_traffic
end

#enable_k8s_certs_via_dnsBoolean Also known as: enable_k8s_certs_via_dns?

Controls whether the k8s certs auth is allowed via DNS. Corresponds to the JSON property enableK8sCertsViaDns

Returns:

  • (Boolean)


3172
3173
3174
# File 'lib/google/apis/container_v1/classes.rb', line 3172

def enable_k8s_certs_via_dns
  @enable_k8s_certs_via_dns
end

#enable_k8s_tokens_via_dnsBoolean Also known as: enable_k8s_tokens_via_dns?

Controls whether the k8s token auth is allowed via DNS. Corresponds to the JSON property enableK8sTokensViaDns

Returns:

  • (Boolean)


3178
3179
3180
# File 'lib/google/apis/container_v1/classes.rb', line 3178

def enable_k8s_tokens_via_dns
  @enable_k8s_tokens_via_dns
end

#endpointString

Output only. The cluster's DNS endpoint configuration. A DNS format address. This is accessible from the public internet. Ex: uid.us-central1.gke.goog. Always present, but the behavior may change according to the value of DNSEndpointConfig.allow_external_traffic. Corresponds to the JSON property endpoint

Returns:

  • (String)


3187
3188
3189
# File 'lib/google/apis/container_v1/classes.rb', line 3187

def endpoint
  @endpoint
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3194
3195
3196
3197
3198
3199
# File 'lib/google/apis/container_v1/classes.rb', line 3194

def update!(**args)
  @allow_external_traffic = args[:allow_external_traffic] if args.key?(:allow_external_traffic)
  @enable_k8s_certs_via_dns = args[:enable_k8s_certs_via_dns] if args.key?(:enable_k8s_certs_via_dns)
  @enable_k8s_tokens_via_dns = args[:enable_k8s_tokens_via_dns] if args.key?(:enable_k8s_tokens_via_dns)
  @endpoint = args[:endpoint] if args.key?(:endpoint)
end