Class: Google::Apis::ContainerV1::EvictionGracePeriod
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1::EvictionGracePeriod
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb
Overview
Eviction grace periods are grace periods for each eviction signal.
Instance Attribute Summary collapse
-
#imagefs_available ⇒ String
Optional.
-
#imagefs_inodes_free ⇒ String
Optional.
-
#memory_available ⇒ String
Optional.
-
#nodefs_available ⇒ String
Optional.
-
#nodefs_inodes_free ⇒ String
Optional.
-
#pid_available ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ EvictionGracePeriod
constructor
A new instance of EvictionGracePeriod.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EvictionGracePeriod
Returns a new instance of EvictionGracePeriod.
3807 3808 3809 |
# File 'lib/google/apis/container_v1/classes.rb', line 3807 def initialize(**args) update!(**args) end |
Instance Attribute Details
#imagefs_available ⇒ String
Optional. Grace period for eviction due to imagefs available signal. Sample
format: "10s". Must be >= 0. See https://kubernetes.io/docs/concepts/
scheduling-eviction/node-pressure-eviction/#eviction-signals
Corresponds to the JSON property imagefsAvailable
3770 3771 3772 |
# File 'lib/google/apis/container_v1/classes.rb', line 3770 def imagefs_available @imagefs_available end |
#imagefs_inodes_free ⇒ String
Optional. Grace period for eviction due to imagefs inodes free signal. Sample
format: "10s". Must be >= 0. See https://kubernetes.io/docs/concepts/
scheduling-eviction/node-pressure-eviction/#eviction-signals
Corresponds to the JSON property imagefsInodesFree
3777 3778 3779 |
# File 'lib/google/apis/container_v1/classes.rb', line 3777 def imagefs_inodes_free @imagefs_inodes_free end |
#memory_available ⇒ String
Optional. Grace period for eviction due to memory available signal. Sample
format: "10s". Must be >= 0. See https://kubernetes.io/docs/concepts/
scheduling-eviction/node-pressure-eviction/#eviction-signals
Corresponds to the JSON property memoryAvailable
3784 3785 3786 |
# File 'lib/google/apis/container_v1/classes.rb', line 3784 def memory_available @memory_available end |
#nodefs_available ⇒ String
Optional. Grace period for eviction due to nodefs available signal. Sample
format: "10s". Must be >= 0. See https://kubernetes.io/docs/concepts/
scheduling-eviction/node-pressure-eviction/#eviction-signals
Corresponds to the JSON property nodefsAvailable
3791 3792 3793 |
# File 'lib/google/apis/container_v1/classes.rb', line 3791 def nodefs_available @nodefs_available end |
#nodefs_inodes_free ⇒ String
Optional. Grace period for eviction due to nodefs inodes free signal. Sample
format: "10s". Must be >= 0. See https://kubernetes.io/docs/concepts/
scheduling-eviction/node-pressure-eviction/#eviction-signals
Corresponds to the JSON property nodefsInodesFree
3798 3799 3800 |
# File 'lib/google/apis/container_v1/classes.rb', line 3798 def nodefs_inodes_free @nodefs_inodes_free end |
#pid_available ⇒ String
Optional. Grace period for eviction due to pid available signal. Sample format:
"10s". Must be >= 0. See https://kubernetes.io/docs/concepts/scheduling-
eviction/node-pressure-eviction/#eviction-signals
Corresponds to the JSON property pidAvailable
3805 3806 3807 |
# File 'lib/google/apis/container_v1/classes.rb', line 3805 def pid_available @pid_available end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3812 3813 3814 3815 3816 3817 3818 3819 |
# File 'lib/google/apis/container_v1/classes.rb', line 3812 def update!(**args) @imagefs_available = args[:imagefs_available] if args.key?(:imagefs_available) @imagefs_inodes_free = args[:imagefs_inodes_free] if args.key?(:imagefs_inodes_free) @memory_available = args[:memory_available] if args.key?(:memory_available) @nodefs_available = args[:nodefs_available] if args.key?(:nodefs_available) @nodefs_inodes_free = args[:nodefs_inodes_free] if args.key?(:nodefs_inodes_free) @pid_available = args[:pid_available] if args.key?(:pid_available) end |