Class: Google::Apis::ContainerV1::EvictionMinimumReclaim
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1::EvictionMinimumReclaim
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb
Overview
Eviction minimum reclaims are the resource amounts of minimum reclaims for each eviction signal.
Instance Attribute Summary collapse
-
#imagefs_available ⇒ String
Optional.
-
#imagefs_inodes_free ⇒ String
Optional.
-
#memory_available ⇒ String
Optional.
-
#nodefs_available ⇒ String
Optional.
-
#nodefs_inodes_free ⇒ String
Optional.
-
#pid_available ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ EvictionMinimumReclaim
constructor
A new instance of EvictionMinimumReclaim.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EvictionMinimumReclaim
Returns a new instance of EvictionMinimumReclaim.
3794 3795 3796 |
# File 'lib/google/apis/container_v1/classes.rb', line 3794 def initialize(**args) update!(**args) end |
Instance Attribute Details
#imagefs_available ⇒ String
Optional. Minimum reclaim for eviction due to imagefs available signal. Only
take percentage value for now. Sample format: "10%". Must be <=10%. See https:/
/kubernetes.io/docs/concepts/scheduling-eviction/node-pressure-eviction/#
eviction-signals
Corresponds to the JSON property imagefsAvailable
3752 3753 3754 |
# File 'lib/google/apis/container_v1/classes.rb', line 3752 def imagefs_available @imagefs_available end |
#imagefs_inodes_free ⇒ String
Optional. Minimum reclaim for eviction due to imagefs inodes free signal. Only
take percentage value for now. Sample format: "10%". Must be <=10%. See https:/
/kubernetes.io/docs/concepts/scheduling-eviction/node-pressure-eviction/#
eviction-signals
Corresponds to the JSON property imagefsInodesFree
3760 3761 3762 |
# File 'lib/google/apis/container_v1/classes.rb', line 3760 def imagefs_inodes_free @imagefs_inodes_free end |
#memory_available ⇒ String
Optional. Minimum reclaim for eviction due to memory available signal. Only
take percentage value for now. Sample format: "10%". Must be <=10%. See https:/
/kubernetes.io/docs/concepts/scheduling-eviction/node-pressure-eviction/#
eviction-signals
Corresponds to the JSON property memoryAvailable
3768 3769 3770 |
# File 'lib/google/apis/container_v1/classes.rb', line 3768 def memory_available @memory_available end |
#nodefs_available ⇒ String
Optional. Minimum reclaim for eviction due to nodefs available signal. Only
take percentage value for now. Sample format: "10%". Must be <=10%. See https:/
/kubernetes.io/docs/concepts/scheduling-eviction/node-pressure-eviction/#
eviction-signals
Corresponds to the JSON property nodefsAvailable
3776 3777 3778 |
# File 'lib/google/apis/container_v1/classes.rb', line 3776 def nodefs_available @nodefs_available end |
#nodefs_inodes_free ⇒ String
Optional. Minimum reclaim for eviction due to nodefs inodes free signal. Only
take percentage value for now. Sample format: "10%". Must be <=10%. See https:/
/kubernetes.io/docs/concepts/scheduling-eviction/node-pressure-eviction/#
eviction-signals
Corresponds to the JSON property nodefsInodesFree
3784 3785 3786 |
# File 'lib/google/apis/container_v1/classes.rb', line 3784 def nodefs_inodes_free @nodefs_inodes_free end |
#pid_available ⇒ String
Optional. Minimum reclaim for eviction due to pid available signal. Only take
percentage value for now. Sample format: "10%". Must be <=10%. See https://
kubernetes.io/docs/concepts/scheduling-eviction/node-pressure-eviction/#
eviction-signals
Corresponds to the JSON property pidAvailable
3792 3793 3794 |
# File 'lib/google/apis/container_v1/classes.rb', line 3792 def pid_available @pid_available end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3799 3800 3801 3802 3803 3804 3805 3806 |
# File 'lib/google/apis/container_v1/classes.rb', line 3799 def update!(**args) @imagefs_available = args[:imagefs_available] if args.key?(:imagefs_available) @imagefs_inodes_free = args[:imagefs_inodes_free] if args.key?(:imagefs_inodes_free) @memory_available = args[:memory_available] if args.key?(:memory_available) @nodefs_available = args[:nodefs_available] if args.key?(:nodefs_available) @nodefs_inodes_free = args[:nodefs_inodes_free] if args.key?(:nodefs_inodes_free) @pid_available = args[:pid_available] if args.key?(:pid_available) end |