Class: Google::Apis::ContainerV1::GetJsonWebKeysResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

GetJSONWebKeysResponse is a valid JSON Web Key Set as specified in rfc 7517

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GetJsonWebKeysResponse

Returns a new instance of GetJsonWebKeysResponse.



4292
4293
4294
# File 'lib/google/apis/container_v1/classes.rb', line 4292

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cache_headerGoogle::Apis::ContainerV1::HttpCacheControlResponseHeader

RFC-2616: cache control support Corresponds to the JSON property cacheHeader



4285
4286
4287
# File 'lib/google/apis/container_v1/classes.rb', line 4285

def cache_header
  @cache_header
end

#keysArray<Google::Apis::ContainerV1::Jwk>

The public component of the keys used by the cluster to sign token requests. Corresponds to the JSON property keys

Returns:



4290
4291
4292
# File 'lib/google/apis/container_v1/classes.rb', line 4290

def keys
  @keys
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4297
4298
4299
4300
# File 'lib/google/apis/container_v1/classes.rb', line 4297

def update!(**args)
  @cache_header = args[:cache_header] if args.key?(:cache_header)
  @keys = args[:keys] if args.key?(:keys)
end