Class: Google::Apis::ContainerV1::GpuDirectConfig
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1::GpuDirectConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb
Overview
GPUDirectConfig specifies the GPU direct strategy on the node pool.
Instance Attribute Summary collapse
-
#gpu_direct_strategy ⇒ String
The type of GPU direct strategy to enable on the node pool.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GpuDirectConfig
constructor
A new instance of GpuDirectConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GpuDirectConfig
Returns a new instance of GpuDirectConfig.
3670 3671 3672 |
# File 'lib/google/apis/container_v1/classes.rb', line 3670 def initialize(**args) update!(**args) end |
Instance Attribute Details
#gpu_direct_strategy ⇒ String
The type of GPU direct strategy to enable on the node pool.
Corresponds to the JSON property gpuDirectStrategy
3668 3669 3670 |
# File 'lib/google/apis/container_v1/classes.rb', line 3668 def gpu_direct_strategy @gpu_direct_strategy end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3675 3676 3677 |
# File 'lib/google/apis/container_v1/classes.rb', line 3675 def update!(**args) @gpu_direct_strategy = args[:gpu_direct_strategy] if args.key?(:gpu_direct_strategy) end |