Class: Google::Apis::ContainerV1::GpuSharingConfig
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1::GpuSharingConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb
Overview
GPUSharingConfig represents the GPU sharing configuration for Hardware Accelerators.
Instance Attribute Summary collapse
-
#gpu_sharing_strategy ⇒ String
The type of GPU sharing strategy to enable on the GPU node.
-
#max_shared_clients_per_gpu ⇒ Fixnum
The max number of containers that can share a physical GPU.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GpuSharingConfig
constructor
A new instance of GpuSharingConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GpuSharingConfig
Returns a new instance of GpuSharingConfig.
3715 3716 3717 |
# File 'lib/google/apis/container_v1/classes.rb', line 3715 def initialize(**args) update!(**args) end |
Instance Attribute Details
#gpu_sharing_strategy ⇒ String
The type of GPU sharing strategy to enable on the GPU node.
Corresponds to the JSON property gpuSharingStrategy
3708 3709 3710 |
# File 'lib/google/apis/container_v1/classes.rb', line 3708 def gpu_sharing_strategy @gpu_sharing_strategy end |
#max_shared_clients_per_gpu ⇒ Fixnum
The max number of containers that can share a physical GPU.
Corresponds to the JSON property maxSharedClientsPerGpu
3713 3714 3715 |
# File 'lib/google/apis/container_v1/classes.rb', line 3713 def max_shared_clients_per_gpu @max_shared_clients_per_gpu end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3720 3721 3722 3723 |
# File 'lib/google/apis/container_v1/classes.rb', line 3720 def update!(**args) @gpu_sharing_strategy = args[:gpu_sharing_strategy] if args.key?(:gpu_sharing_strategy) @max_shared_clients_per_gpu = args[:max_shared_clients_per_gpu] if args.key?(:max_shared_clients_per_gpu) end |