Class: Google::Apis::ContainerV1::HorizontalPodAutoscaling
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1::HorizontalPodAutoscaling
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb
Overview
Configuration options for the horizontal pod autoscaling feature, which increases or decreases the number of replica pods a replication controller has based on the resource usage of the existing pods.
Instance Attribute Summary collapse
-
#disabled ⇒ Boolean
(also: #disabled?)
Whether the Horizontal Pod Autoscaling feature is enabled in the cluster.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HorizontalPodAutoscaling
constructor
A new instance of HorizontalPodAutoscaling.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HorizontalPodAutoscaling
Returns a new instance of HorizontalPodAutoscaling.
3985 3986 3987 |
# File 'lib/google/apis/container_v1/classes.rb', line 3985 def initialize(**args) update!(**args) end |
Instance Attribute Details
#disabled ⇒ Boolean Also known as: disabled?
Whether the Horizontal Pod Autoscaling feature is enabled in the cluster. When
enabled, it ensures that metrics are collected into Stackdriver Monitoring.
Corresponds to the JSON property disabled
3982 3983 3984 |
# File 'lib/google/apis/container_v1/classes.rb', line 3982 def disabled @disabled end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3990 3991 3992 |
# File 'lib/google/apis/container_v1/classes.rb', line 3990 def update!(**args) @disabled = args[:disabled] if args.key?(:disabled) end |