Class: Google::Apis::ContainerV1::InitScript
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1::InitScript
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb
Overview
InitScript provide a simply bash script to be executed on the node.
Instance Attribute Summary collapse
-
#args ⇒ Array<String>
Optional.
-
#gcp_secret_manager_secret_uri ⇒ String
The resource name of the secret manager secret hosting the init script.
-
#gcs_generation ⇒ Fixnum
The generation of the init script stored in Gloud Storage.
-
#gcs_uri ⇒ String
The Cloud Storage URI for storing the init script.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InitScript
constructor
A new instance of InitScript.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InitScript
Returns a new instance of InitScript.
4943 4944 4945 |
# File 'lib/google/apis/container_v1/classes.rb', line 4943 def initialize(**args) update!(**args) end |
Instance Attribute Details
#args ⇒ Array<String>
Optional. The optional arguments line to be passed to the init script.
Corresponds to the JSON property args
4914 4915 4916 |
# File 'lib/google/apis/container_v1/classes.rb', line 4914 def args @args end |
#gcp_secret_manager_secret_uri ⇒ String
The resource name of the secret manager secret hosting the init script. Both
global and regional secrets are supported with format below: Global secret:
projects/project/secrets/secret/versions/version Regional secret:
projects/project/locations/location/secrets/secret/versions/version
Example: projects/1234567890/secrets/script_1/versions/1. Accept version
number only, not support version alias. User can't configure both
gcp_secret_manager_secret_uri and gcs_uri.
Corresponds to the JSON property gcpSecretManagerSecretUri
4925 4926 4927 |
# File 'lib/google/apis/container_v1/classes.rb', line 4925 def gcp_secret_manager_secret_uri @gcp_secret_manager_secret_uri end |
#gcs_generation ⇒ Fixnum
The generation of the init script stored in Gloud Storage. This is the
required field to identify the version of the init script. User can get the
genetaion from gcloud storage objects describe gs://BUCKET_NAME/OBJECT_NAME --
format="value(generation)" or from the "Version history" tab of the object in
the Cloud Console UI.
Corresponds to the JSON property gcsGeneration
4934 4935 4936 |
# File 'lib/google/apis/container_v1/classes.rb', line 4934 def gcs_generation @gcs_generation end |
#gcs_uri ⇒ String
The Cloud Storage URI for storing the init script. Format: gs://BUCKET_NAME/
OBJECT_NAME The service account on the node pool must have read access to the
object. User can't configure both gcs_uri and gcp_secret_manager_secret_uri.
Corresponds to the JSON property gcsUri
4941 4942 4943 |
# File 'lib/google/apis/container_v1/classes.rb', line 4941 def gcs_uri @gcs_uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4948 4949 4950 4951 4952 4953 |
# File 'lib/google/apis/container_v1/classes.rb', line 4948 def update!(**args) @args = args[:args] if args.key?(:args) @gcp_secret_manager_secret_uri = args[:gcp_secret_manager_secret_uri] if args.key?(:gcp_secret_manager_secret_uri) @gcs_generation = args[:gcs_generation] if args.key?(:gcs_generation) @gcs_uri = args[:gcs_uri] if args.key?(:gcs_uri) end |