Class: Google::Apis::ContainerV1::IpAllocationPolicy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

Configuration for controlling how IPs are allocated in the cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IpAllocationPolicy

Returns a new instance of IpAllocationPolicy.



4784
4785
4786
# File 'lib/google/apis/container_v1/classes.rb', line 4784

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#additional_ip_ranges_configsArray<Google::Apis::ContainerV1::AdditionalIpRangesConfig>

Output only. The additional IP ranges that are added to the cluster. These IP ranges can be used by new node pools to allocate node and pod IPs automatically. Each AdditionalIPRangesConfig corresponds to a single subnetwork. Once a range is removed it will not show up in IPAllocationPolicy. Corresponds to the JSON property additionalIpRangesConfigs



4624
4625
4626
# File 'lib/google/apis/container_v1/classes.rb', line 4624

def additional_ip_ranges_configs
  @additional_ip_ranges_configs
end

#additional_pod_ranges_configGoogle::Apis::ContainerV1::AdditionalPodRangesConfig

AdditionalPodRangesConfig is the configuration for additional pod secondary ranges supporting the ClusterUpdate message. Corresponds to the JSON property additionalPodRangesConfig



4630
4631
4632
# File 'lib/google/apis/container_v1/classes.rb', line 4630

def additional_pod_ranges_config
  @additional_pod_ranges_config
end

#auto_ipam_configGoogle::Apis::ContainerV1::AutoIpamConfig

AutoIpamConfig contains all information related to Auto IPAM Corresponds to the JSON property autoIpamConfig



4635
4636
4637
# File 'lib/google/apis/container_v1/classes.rb', line 4635

def auto_ipam_config
  @auto_ipam_config
end

#cluster_ipv4_cidrString

This field is deprecated, use cluster_ipv4_cidr_block. Corresponds to the JSON property clusterIpv4Cidr

Returns:

  • (String)


4640
4641
4642
# File 'lib/google/apis/container_v1/classes.rb', line 4640

def cluster_ipv4_cidr
  @cluster_ipv4_cidr
end

#cluster_ipv4_cidr_blockString

The IP address range for the cluster pod IPs. If this field is set, then cluster.cluster_ipv4_cidr must be left blank. This field is only applicable when use_ip_aliases is true. Set to blank to have a range chosen with the default size. Set to /netmask (e.g. /14) to have a range chosen with a specific netmask. Set to a CIDR notation (e.g. 10.96.0.0/14) from the RFC- 1918 private networks (e.g. 10.0.0.0/8, 172.16.0.0/12, 192.168.0.0/16) to pick a specific range to use. Corresponds to the JSON property clusterIpv4CidrBlock

Returns:

  • (String)


4652
4653
4654
# File 'lib/google/apis/container_v1/classes.rb', line 4652

def cluster_ipv4_cidr_block
  @cluster_ipv4_cidr_block
end

#cluster_secondary_range_nameString

The name of the secondary range to be used for the cluster CIDR block. The secondary range will be used for pod IP addresses. This must be an existing secondary range associated with the cluster subnetwork. This field is only applicable with use_ip_aliases is true and create_subnetwork is false. Corresponds to the JSON property clusterSecondaryRangeName

Returns:

  • (String)


4660
4661
4662
# File 'lib/google/apis/container_v1/classes.rb', line 4660

def cluster_secondary_range_name
  @cluster_secondary_range_name
end

#create_subnetworkBoolean Also known as: create_subnetwork?

Whether a new subnetwork will be created automatically for the cluster. This field is only applicable when use_ip_aliases is true. Corresponds to the JSON property createSubnetwork

Returns:

  • (Boolean)


4666
4667
4668
# File 'lib/google/apis/container_v1/classes.rb', line 4666

def create_subnetwork
  @create_subnetwork
end

#default_pod_ipv4_range_utilizationFloat

Output only. The utilization of the cluster default IPv4 range for the pod. The ratio is Usage/[Total number of IPs in the secondary range], Usage= numNodes*numZones*podIPsPerNode. Corresponds to the JSON property defaultPodIpv4RangeUtilization

Returns:

  • (Float)


4674
4675
4676
# File 'lib/google/apis/container_v1/classes.rb', line 4674

def default_pod_ipv4_range_utilization
  @default_pod_ipv4_range_utilization
end

#ipv6_access_typeString

The ipv6 access type (internal or external) when create_subnetwork is true Corresponds to the JSON property ipv6AccessType

Returns:

  • (String)


4679
4680
4681
# File 'lib/google/apis/container_v1/classes.rb', line 4679

def ipv6_access_type
  @ipv6_access_type
end

#network_tier_configGoogle::Apis::ContainerV1::NetworkTierConfig

NetworkTierConfig contains network tier information. Corresponds to the JSON property networkTierConfig



4684
4685
4686
# File 'lib/google/apis/container_v1/classes.rb', line 4684

def network_tier_config
  @network_tier_config
end

#node_ipv4_cidrString

This field is deprecated, use node_ipv4_cidr_block. Corresponds to the JSON property nodeIpv4Cidr

Returns:

  • (String)


4689
4690
4691
# File 'lib/google/apis/container_v1/classes.rb', line 4689

def node_ipv4_cidr
  @node_ipv4_cidr
end

#node_ipv4_cidr_blockString

The IP address range of the instance IPs in this cluster. This is applicable only if create_subnetwork is true. Set to blank to have a range chosen with the default size. Set to /netmask (e.g. /14) to have a range chosen with a specific netmask. Set to a CIDR notation (e.g. 10.96.0.0/14) from the RFC- 1918 private networks (e.g. 10.0.0.0/8, 172.16.0.0/12, 192.168.0.0/16) to pick a specific range to use. Corresponds to the JSON property nodeIpv4CidrBlock

Returns:

  • (String)


4700
4701
4702
# File 'lib/google/apis/container_v1/classes.rb', line 4700

def node_ipv4_cidr_block
  @node_ipv4_cidr_block
end

#pod_cidr_overprovision_configGoogle::Apis::ContainerV1::PodCidrOverprovisionConfig

[PRIVATE FIELD] Config for pod CIDR size overprovisioning. Corresponds to the JSON property podCidrOverprovisionConfig



4705
4706
4707
# File 'lib/google/apis/container_v1/classes.rb', line 4705

def pod_cidr_overprovision_config
  @pod_cidr_overprovision_config
end

#services_ipv4_cidrString

This field is deprecated, use services_ipv4_cidr_block. Corresponds to the JSON property servicesIpv4Cidr

Returns:

  • (String)


4710
4711
4712
# File 'lib/google/apis/container_v1/classes.rb', line 4710

def services_ipv4_cidr
  @services_ipv4_cidr
end

#services_ipv4_cidr_blockString

The IP address range of the services IPs in this cluster. If blank, a range will be automatically chosen with the default size. This field is only applicable when use_ip_aliases is true. Set to blank to have a range chosen with the default size. Set to /netmask (e.g. /14) to have a range chosen with a specific netmask. Set to a CIDR notation (e.g. 10.96.0.0/14) from the RFC- 1918 private networks (e.g. 10.0.0.0/8, 172.16.0.0/12, 192.168.0.0/16) to pick a specific range to use. Corresponds to the JSON property servicesIpv4CidrBlock

Returns:

  • (String)


4722
4723
4724
# File 'lib/google/apis/container_v1/classes.rb', line 4722

def services_ipv4_cidr_block
  @services_ipv4_cidr_block
end

#services_ipv6_cidr_blockString

Output only. The services IPv6 CIDR block for the cluster. Corresponds to the JSON property servicesIpv6CidrBlock

Returns:

  • (String)


4727
4728
4729
# File 'lib/google/apis/container_v1/classes.rb', line 4727

def services_ipv6_cidr_block
  @services_ipv6_cidr_block
end

#services_secondary_range_nameString

The name of the secondary range to be used as for the services CIDR block. The secondary range will be used for service ClusterIPs. This must be an existing secondary range associated with the cluster subnetwork. This field is only applicable with use_ip_aliases is true and create_subnetwork is false. Corresponds to the JSON property servicesSecondaryRangeName

Returns:

  • (String)


4735
4736
4737
# File 'lib/google/apis/container_v1/classes.rb', line 4735

def services_secondary_range_name
  @services_secondary_range_name
end

#stack_typeString

The IP stack type of the cluster Corresponds to the JSON property stackType

Returns:

  • (String)


4740
4741
4742
# File 'lib/google/apis/container_v1/classes.rb', line 4740

def stack_type
  @stack_type
end

#subnet_ipv6_cidr_blockString

Output only. The subnet's IPv6 CIDR block used by nodes and pods. Corresponds to the JSON property subnetIpv6CidrBlock

Returns:

  • (String)


4745
4746
4747
# File 'lib/google/apis/container_v1/classes.rb', line 4745

def subnet_ipv6_cidr_block
  @subnet_ipv6_cidr_block
end

#subnetwork_nameString

A custom subnetwork name to be used if create_subnetwork is true. If this field is empty, then an automatic name will be chosen for the new subnetwork. Corresponds to the JSON property subnetworkName

Returns:

  • (String)


4751
4752
4753
# File 'lib/google/apis/container_v1/classes.rb', line 4751

def subnetwork_name
  @subnetwork_name
end

#tpu_ipv4_cidr_blockString

The IP address range of the Cloud TPUs in this cluster. If unspecified, a range will be automatically chosen with the default size. This field is only applicable when use_ip_aliases is true. If unspecified, the range will use the default size. Set to /netmask (e.g. /14) to have a range chosen with a specific netmask. Set to a CIDR notation (e.g. 10.96.0.0/14) from the RFC- 1918 private networks (e.g. 10.0.0.0/8, 172.16.0.0/12, 192.168.0.0/16) to pick a specific range to use. This field is deprecated due to the deprecation of 2VM TPU. The end of life date for 2VM TPU is 2025-04-25. Corresponds to the JSON property tpuIpv4CidrBlock

Returns:

  • (String)


4764
4765
4766
# File 'lib/google/apis/container_v1/classes.rb', line 4764

def tpu_ipv4_cidr_block
  @tpu_ipv4_cidr_block
end

#use_ip_aliasesBoolean Also known as: use_ip_aliases?

Whether alias IPs will be used for pod IPs in the cluster. This is used in conjunction with use_routes. It cannot be true if use_routes is true. If both use_ip_aliases and use_routes are false, then the server picks the default IP allocation mode Corresponds to the JSON property useIpAliases

Returns:

  • (Boolean)


4772
4773
4774
# File 'lib/google/apis/container_v1/classes.rb', line 4772

def use_ip_aliases
  @use_ip_aliases
end

#use_routesBoolean Also known as: use_routes?

Whether routes will be used for pod IPs in the cluster. This is used in conjunction with use_ip_aliases. It cannot be true if use_ip_aliases is true. If both use_ip_aliases and use_routes are false, then the server picks the default IP allocation mode Corresponds to the JSON property useRoutes

Returns:

  • (Boolean)


4781
4782
4783
# File 'lib/google/apis/container_v1/classes.rb', line 4781

def use_routes
  @use_routes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4789
4790
4791
4792
4793
4794
4795
4796
4797
4798
4799
4800
4801
4802
4803
4804
4805
4806
4807
4808
4809
4810
4811
4812
4813
# File 'lib/google/apis/container_v1/classes.rb', line 4789

def update!(**args)
  @additional_ip_ranges_configs = args[:additional_ip_ranges_configs] if args.key?(:additional_ip_ranges_configs)
  @additional_pod_ranges_config = args[:additional_pod_ranges_config] if args.key?(:additional_pod_ranges_config)
  @auto_ipam_config = args[:auto_ipam_config] if args.key?(:auto_ipam_config)
  @cluster_ipv4_cidr = args[:cluster_ipv4_cidr] if args.key?(:cluster_ipv4_cidr)
  @cluster_ipv4_cidr_block = args[:cluster_ipv4_cidr_block] if args.key?(:cluster_ipv4_cidr_block)
  @cluster_secondary_range_name = args[:cluster_secondary_range_name] if args.key?(:cluster_secondary_range_name)
  @create_subnetwork = args[:create_subnetwork] if args.key?(:create_subnetwork)
  @default_pod_ipv4_range_utilization = args[:default_pod_ipv4_range_utilization] if args.key?(:default_pod_ipv4_range_utilization)
  @ipv6_access_type = args[:ipv6_access_type] if args.key?(:ipv6_access_type)
  @network_tier_config = args[:network_tier_config] if args.key?(:network_tier_config)
  @node_ipv4_cidr = args[:node_ipv4_cidr] if args.key?(:node_ipv4_cidr)
  @node_ipv4_cidr_block = args[:node_ipv4_cidr_block] if args.key?(:node_ipv4_cidr_block)
  @pod_cidr_overprovision_config = args[:pod_cidr_overprovision_config] if args.key?(:pod_cidr_overprovision_config)
  @services_ipv4_cidr = args[:services_ipv4_cidr] if args.key?(:services_ipv4_cidr)
  @services_ipv4_cidr_block = args[:services_ipv4_cidr_block] if args.key?(:services_ipv4_cidr_block)
  @services_ipv6_cidr_block = args[:services_ipv6_cidr_block] if args.key?(:services_ipv6_cidr_block)
  @services_secondary_range_name = args[:services_secondary_range_name] if args.key?(:services_secondary_range_name)
  @stack_type = args[:stack_type] if args.key?(:stack_type)
  @subnet_ipv6_cidr_block = args[:subnet_ipv6_cidr_block] if args.key?(:subnet_ipv6_cidr_block)
  @subnetwork_name = args[:subnetwork_name] if args.key?(:subnetwork_name)
  @tpu_ipv4_cidr_block = args[:tpu_ipv4_cidr_block] if args.key?(:tpu_ipv4_cidr_block)
  @use_ip_aliases = args[:use_ip_aliases] if args.key?(:use_ip_aliases)
  @use_routes = args[:use_routes] if args.key?(:use_routes)
end