Class: Google::Apis::ContainerV1::ListOperationsResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

ListOperationsResponse is the result of ListOperationsRequest.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListOperationsResponse

Returns a new instance of ListOperationsResponse.



5180
5181
5182
# File 'lib/google/apis/container_v1/classes.rb', line 5180

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#missing_zonesArray<String>

If any zones are listed here, the list of operations returned may be missing the operations from those zones. Corresponds to the JSON property missingZones

Returns:

  • (Array<String>)


5173
5174
5175
# File 'lib/google/apis/container_v1/classes.rb', line 5173

def missing_zones
  @missing_zones
end

#operationsArray<Google::Apis::ContainerV1::Operation>

A list of operations in the project in the specified zone. Corresponds to the JSON property operations



5178
5179
5180
# File 'lib/google/apis/container_v1/classes.rb', line 5178

def operations
  @operations
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5185
5186
5187
5188
# File 'lib/google/apis/container_v1/classes.rb', line 5185

def update!(**args)
  @missing_zones = args[:missing_zones] if args.key?(:missing_zones)
  @operations = args[:operations] if args.key?(:operations)
end