Class: Google::Apis::ContainerV1::MaintenanceExclusionOptions

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

Represents the Maintenance exclusion option.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MaintenanceExclusionOptions

Returns a new instance of MaintenanceExclusionOptions.



5352
5353
5354
# File 'lib/google/apis/container_v1/classes.rb', line 5352

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_time_behaviorString

EndTimeBehavior specifies the behavior of the exclusion end time. Corresponds to the JSON property endTimeBehavior

Returns:

  • (String)


5345
5346
5347
# File 'lib/google/apis/container_v1/classes.rb', line 5345

def end_time_behavior
  @end_time_behavior
end

#scopeString

Scope specifies the upgrade scope which upgrades are blocked by the exclusion. Corresponds to the JSON property scope

Returns:

  • (String)


5350
5351
5352
# File 'lib/google/apis/container_v1/classes.rb', line 5350

def scope
  @scope
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5357
5358
5359
5360
# File 'lib/google/apis/container_v1/classes.rb', line 5357

def update!(**args)
  @end_time_behavior = args[:end_time_behavior] if args.key?(:end_time_behavior)
  @scope = args[:scope] if args.key?(:scope)
end