Class: Google::Apis::ContainerV1::MaintenancePolicy
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1::MaintenancePolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb
Overview
MaintenancePolicy defines the maintenance policy to be used for the cluster.
Instance Attribute Summary collapse
-
#disruption_budget ⇒ Google::Apis::ContainerV1::DisruptionBudget
DisruptionBudget defines the upgrade disruption budget for the cluster control plane.
-
#resource_version ⇒ String
A hash identifying the version of this policy, so that updates to fields of the policy won't accidentally undo intermediate changes (and so that users of the API unaware of some fields won't accidentally remove other fields).
-
#window ⇒ Google::Apis::ContainerV1::MaintenanceWindow
MaintenanceWindow defines the maintenance window to be used for the cluster.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MaintenancePolicy
constructor
A new instance of MaintenancePolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MaintenancePolicy
Returns a new instance of MaintenancePolicy.
5519 5520 5521 |
# File 'lib/google/apis/container_v1/classes.rb', line 5519 def initialize(**args) update!(**args) end |
Instance Attribute Details
#disruption_budget ⇒ Google::Apis::ContainerV1::DisruptionBudget
DisruptionBudget defines the upgrade disruption budget for the cluster control
plane.
Corresponds to the JSON property disruptionBudget
5503 5504 5505 |
# File 'lib/google/apis/container_v1/classes.rb', line 5503 def disruption_budget @disruption_budget end |
#resource_version ⇒ String
A hash identifying the version of this policy, so that updates to fields of
the policy won't accidentally undo intermediate changes (and so that users of
the API unaware of some fields won't accidentally remove other fields). Make a
get() request to the cluster to get the current resource version and include
it with requests to set the policy.
Corresponds to the JSON property resourceVersion
5512 5513 5514 |
# File 'lib/google/apis/container_v1/classes.rb', line 5512 def resource_version @resource_version end |
#window ⇒ Google::Apis::ContainerV1::MaintenanceWindow
MaintenanceWindow defines the maintenance window to be used for the cluster.
Corresponds to the JSON property window
5517 5518 5519 |
# File 'lib/google/apis/container_v1/classes.rb', line 5517 def window @window end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5524 5525 5526 5527 5528 |
# File 'lib/google/apis/container_v1/classes.rb', line 5524 def update!(**args) @disruption_budget = args[:disruption_budget] if args.key?(:disruption_budget) @resource_version = args[:resource_version] if args.key?(:resource_version) @window = args[:window] if args.key?(:window) end |