Class: Google::Apis::ContainerV1::MasterAuth

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

The authentication information for accessing the master endpoint. Authentication can be done using HTTP basic auth or using client certificates.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MasterAuth

Returns a new instance of MasterAuth.



5570
5571
5572
# File 'lib/google/apis/container_v1/classes.rb', line 5570

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#client_certificateString

Output only. Base64-encoded public certificate used by clients to authenticate to the cluster endpoint. Issued only if client_certificate_config is set. Corresponds to the JSON property clientCertificate

Returns:

  • (String)


5529
5530
5531
# File 'lib/google/apis/container_v1/classes.rb', line 5529

def client_certificate
  @client_certificate
end

#client_certificate_configGoogle::Apis::ContainerV1::ClientCertificateConfig

Configuration for client certificates on the cluster. Corresponds to the JSON property clientCertificateConfig



5534
5535
5536
# File 'lib/google/apis/container_v1/classes.rb', line 5534

def client_certificate_config
  @client_certificate_config
end

#client_keyString

Output only. Base64-encoded private key used by clients to authenticate to the cluster endpoint. Corresponds to the JSON property clientKey

Returns:

  • (String)


5540
5541
5542
# File 'lib/google/apis/container_v1/classes.rb', line 5540

def client_key
  @client_key
end

#cluster_ca_certificateString

Output only. Base64-encoded public certificate that is the root of trust for the cluster. Corresponds to the JSON property clusterCaCertificate

Returns:

  • (String)


5546
5547
5548
# File 'lib/google/apis/container_v1/classes.rb', line 5546

def cluster_ca_certificate
  @cluster_ca_certificate
end

#passwordString

The password to use for HTTP basic authentication to the master endpoint. Because the master endpoint is open to the Internet, you should create a strong password. If a password is provided for cluster creation, username must be non-empty. Warning: basic authentication is deprecated, and will be removed in GKE control plane versions 1.19 and newer. For a list of recommended authentication methods, see: https://cloud.google.com/kubernetes-engine/docs/ how-to/api-server-authentication Corresponds to the JSON property password

Returns:

  • (String)


5557
5558
5559
# File 'lib/google/apis/container_v1/classes.rb', line 5557

def password
  @password
end

#usernameString

The username to use for HTTP basic authentication to the master endpoint. For clusters v1.6.0 and later, basic authentication can be disabled by leaving username unspecified (or setting it to the empty string). Warning: basic authentication is deprecated, and will be removed in GKE control plane versions 1.19 and newer. For a list of recommended authentication methods, see: https://cloud.google.com/kubernetes-engine/docs/how-to/api-server- authentication Corresponds to the JSON property username

Returns:

  • (String)


5568
5569
5570
# File 'lib/google/apis/container_v1/classes.rb', line 5568

def username
  @username
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5575
5576
5577
5578
5579
5580
5581
5582
# File 'lib/google/apis/container_v1/classes.rb', line 5575

def update!(**args)
  @client_certificate = args[:client_certificate] if args.key?(:client_certificate)
  @client_certificate_config = args[:client_certificate_config] if args.key?(:client_certificate_config)
  @client_key = args[:client_key] if args.key?(:client_key)
  @cluster_ca_certificate = args[:cluster_ca_certificate] if args.key?(:cluster_ca_certificate)
  @password = args[:password] if args.key?(:password)
  @username = args[:username] if args.key?(:username)
end