Class: Google::Apis::ContainerV1::MonitoringConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

MonitoringConfig is cluster monitoring configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MonitoringConfig

Returns a new instance of MonitoringConfig.



5892
5893
5894
# File 'lib/google/apis/container_v1/classes.rb', line 5892

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advanced_datapath_observability_configGoogle::Apis::ContainerV1::AdvancedDatapathObservabilityConfig

AdvancedDatapathObservabilityConfig specifies configuration of observability features of advanced datapath. Corresponds to the JSON property advancedDatapathObservabilityConfig



5879
5880
5881
# File 'lib/google/apis/container_v1/classes.rb', line 5879

def advanced_datapath_observability_config
  @advanced_datapath_observability_config
end

#component_configGoogle::Apis::ContainerV1::MonitoringComponentConfig

MonitoringComponentConfig is cluster monitoring component configuration. Corresponds to the JSON property componentConfig



5884
5885
5886
# File 'lib/google/apis/container_v1/classes.rb', line 5884

def component_config
  @component_config
end

#managed_prometheus_configGoogle::Apis::ContainerV1::ManagedPrometheusConfig

ManagedPrometheusConfig defines the configuration for Google Cloud Managed Service for Prometheus. Corresponds to the JSON property managedPrometheusConfig



5890
5891
5892
# File 'lib/google/apis/container_v1/classes.rb', line 5890

def managed_prometheus_config
  @managed_prometheus_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5897
5898
5899
5900
5901
# File 'lib/google/apis/container_v1/classes.rb', line 5897

def update!(**args)
  @advanced_datapath_observability_config = args[:advanced_datapath_observability_config] if args.key?(:advanced_datapath_observability_config)
  @component_config = args[:component_config] if args.key?(:component_config)
  @managed_prometheus_config = args[:managed_prometheus_config] if args.key?(:managed_prometheus_config)
end