Class: Google::Apis::ContainerV1::NetworkConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

NetworkConfig reports the relative names of network & subnetwork.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkConfig

Returns a new instance of NetworkConfig.



6017
6018
6019
# File 'lib/google/apis/container_v1/classes.rb', line 6017

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#datapath_providerString

The desired datapath provider for this cluster. By default, uses the IPTables- based kube-proxy implementation. Corresponds to the JSON property datapathProvider

Returns:

  • (String)


5912
5913
5914
# File 'lib/google/apis/container_v1/classes.rb', line 5912

def datapath_provider
  @datapath_provider
end

#dataplane_v2_configGoogle::Apis::ContainerV1::DataplaneV2Config

DataplaneV2Config is the configuration for DPv2. Corresponds to the JSON property dataplaneV2Config



5917
5918
5919
# File 'lib/google/apis/container_v1/classes.rb', line 5917

def dataplane_v2_config
  @dataplane_v2_config
end

#default_enable_private_nodesBoolean Also known as: default_enable_private_nodes?

Controls whether by default nodes have private IP addresses only. It is invalid to specify both PrivateClusterConfig.enablePrivateNodes and this field at the same time. To update the default setting, use ClusterUpdate. desired_default_enable_private_nodes Corresponds to the JSON property defaultEnablePrivateNodes

Returns:

  • (Boolean)


5925
5926
5927
# File 'lib/google/apis/container_v1/classes.rb', line 5925

def default_enable_private_nodes
  @default_enable_private_nodes
end

#default_snat_statusGoogle::Apis::ContainerV1::DefaultSnatStatus

DefaultSnatStatus contains the desired state of whether default sNAT should be disabled on the cluster. Corresponds to the JSON property defaultSnatStatus



5932
5933
5934
# File 'lib/google/apis/container_v1/classes.rb', line 5932

def default_snat_status
  @default_snat_status
end

#disable_l4_lb_firewall_reconciliationBoolean Also known as: disable_l4_lb_firewall_reconciliation?

Disable L4 load balancer VPC firewalls to enable firewall policies. Corresponds to the JSON property disableL4LbFirewallReconciliation

Returns:

  • (Boolean)


5937
5938
5939
# File 'lib/google/apis/container_v1/classes.rb', line 5937

def disable_l4_lb_firewall_reconciliation
  @disable_l4_lb_firewall_reconciliation
end

#dns_configGoogle::Apis::ContainerV1::DnsConfig

DNSConfig contains the desired set of options for configuring clusterDNS. Corresponds to the JSON property dnsConfig



5943
5944
5945
# File 'lib/google/apis/container_v1/classes.rb', line 5943

def dns_config
  @dns_config
end

#enable_cilium_clusterwide_network_policyBoolean Also known as: enable_cilium_clusterwide_network_policy?

Whether CiliumClusterwideNetworkPolicy is enabled on this cluster. Corresponds to the JSON property enableCiliumClusterwideNetworkPolicy

Returns:

  • (Boolean)


5948
5949
5950
# File 'lib/google/apis/container_v1/classes.rb', line 5948

def enable_cilium_clusterwide_network_policy
  @enable_cilium_clusterwide_network_policy
end

#enable_fqdn_network_policyBoolean Also known as: enable_fqdn_network_policy?

Whether FQDN Network Policy is enabled on this cluster. Corresponds to the JSON property enableFqdnNetworkPolicy

Returns:

  • (Boolean)


5954
5955
5956
# File 'lib/google/apis/container_v1/classes.rb', line 5954

def enable_fqdn_network_policy
  @enable_fqdn_network_policy
end

#enable_intra_node_visibilityBoolean Also known as: enable_intra_node_visibility?

Whether Intra-node visibility is enabled for this cluster. This makes same node pod to pod traffic visible for VPC network. Corresponds to the JSON property enableIntraNodeVisibility

Returns:

  • (Boolean)


5961
5962
5963
# File 'lib/google/apis/container_v1/classes.rb', line 5961

def enable_intra_node_visibility
  @enable_intra_node_visibility
end

#enable_l4ilb_subsettingBoolean Also known as: enable_l4ilb_subsetting?

Whether L4ILB Subsetting is enabled for this cluster. Corresponds to the JSON property enableL4ilbSubsetting

Returns:

  • (Boolean)


5967
5968
5969
# File 'lib/google/apis/container_v1/classes.rb', line 5967

def enable_l4ilb_subsetting
  @enable_l4ilb_subsetting
end

#enable_multi_networkingBoolean Also known as: enable_multi_networking?

Whether multi-networking is enabled for this cluster. Corresponds to the JSON property enableMultiNetworking

Returns:

  • (Boolean)


5973
5974
5975
# File 'lib/google/apis/container_v1/classes.rb', line 5973

def enable_multi_networking
  @enable_multi_networking
end

#gateway_api_configGoogle::Apis::ContainerV1::GatewayApiConfig

GatewayAPIConfig contains the desired config of Gateway API on this cluster. Corresponds to the JSON property gatewayApiConfig



5979
5980
5981
# File 'lib/google/apis/container_v1/classes.rb', line 5979

def gateway_api_config
  @gateway_api_config
end

#in_transit_encryption_configString

Specify the details of in-transit encryption. Now named inter-node transparent encryption. Corresponds to the JSON property inTransitEncryptionConfig

Returns:

  • (String)


5985
5986
5987
# File 'lib/google/apis/container_v1/classes.rb', line 5985

def in_transit_encryption_config
  @in_transit_encryption_config
end

#networkString

Output only. The relative name of the Google Compute Engine network to which the cluster is connected. Example: projects/my-project/global/networks/my-network Corresponds to the JSON property network

Returns:

  • (String)


5992
5993
5994
# File 'lib/google/apis/container_v1/classes.rb', line 5992

def network
  @network
end

#network_performance_configGoogle::Apis::ContainerV1::ClusterNetworkPerformanceConfig

Configuration of network bandwidth tiers Corresponds to the JSON property networkPerformanceConfig



5997
5998
5999
# File 'lib/google/apis/container_v1/classes.rb', line 5997

def network_performance_config
  @network_performance_config
end

#private_ipv6_google_accessString

The desired state of IPv6 connectivity to Google Services. By default, no private IPv6 access to or from Google Services (all access will be via IPv4) Corresponds to the JSON property privateIpv6GoogleAccess

Returns:

  • (String)


6003
6004
6005
# File 'lib/google/apis/container_v1/classes.rb', line 6003

def private_ipv6_google_access
  @private_ipv6_google_access
end

#service_external_ips_configGoogle::Apis::ContainerV1::ServiceExternalIPsConfig

Config to block services with externalIPs field. Corresponds to the JSON property serviceExternalIpsConfig



6008
6009
6010
# File 'lib/google/apis/container_v1/classes.rb', line 6008

def service_external_ips_config
  @service_external_ips_config
end

#subnetworkString

Output only. The relative name of the Google Compute Engine subnetwork to which the cluster is connected. Example: projects/my-project/regions/us-central1/subnetworks/my-subnet Corresponds to the JSON property subnetwork

Returns:

  • (String)


6015
6016
6017
# File 'lib/google/apis/container_v1/classes.rb', line 6015

def subnetwork
  @subnetwork
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6022
6023
6024
6025
6026
6027
6028
6029
6030
6031
6032
6033
6034
6035
6036
6037
6038
6039
6040
6041
# File 'lib/google/apis/container_v1/classes.rb', line 6022

def update!(**args)
  @datapath_provider = args[:datapath_provider] if args.key?(:datapath_provider)
  @dataplane_v2_config = args[:dataplane_v2_config] if args.key?(:dataplane_v2_config)
  @default_enable_private_nodes = args[:default_enable_private_nodes] if args.key?(:default_enable_private_nodes)
  @default_snat_status = args[:default_snat_status] if args.key?(:default_snat_status)
  @disable_l4_lb_firewall_reconciliation = args[:disable_l4_lb_firewall_reconciliation] if args.key?(:disable_l4_lb_firewall_reconciliation)
  @dns_config = args[:dns_config] if args.key?(:dns_config)
  @enable_cilium_clusterwide_network_policy = args[:enable_cilium_clusterwide_network_policy] if args.key?(:enable_cilium_clusterwide_network_policy)
  @enable_fqdn_network_policy = args[:enable_fqdn_network_policy] if args.key?(:enable_fqdn_network_policy)
  @enable_intra_node_visibility = args[:enable_intra_node_visibility] if args.key?(:enable_intra_node_visibility)
  @enable_l4ilb_subsetting = args[:enable_l4ilb_subsetting] if args.key?(:enable_l4ilb_subsetting)
  @enable_multi_networking = args[:enable_multi_networking] if args.key?(:enable_multi_networking)
  @gateway_api_config = args[:gateway_api_config] if args.key?(:gateway_api_config)
  @in_transit_encryption_config = args[:in_transit_encryption_config] if args.key?(:in_transit_encryption_config)
  @network = args[:network] if args.key?(:network)
  @network_performance_config = args[:network_performance_config] if args.key?(:network_performance_config)
  @private_ipv6_google_access = args[:private_ipv6_google_access] if args.key?(:private_ipv6_google_access)
  @service_external_ips_config = args[:service_external_ips_config] if args.key?(:service_external_ips_config)
  @subnetwork = args[:subnetwork] if args.key?(:subnetwork)
end