Class: Google::Apis::ContainerV1::NodeKubeletConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

Node kubelet configs.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NodeKubeletConfig

Returns a new instance of NodeKubeletConfig.



6895
6896
6897
# File 'lib/google/apis/container_v1/classes.rb', line 6895

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allowed_unsafe_sysctlsArray<String>

Optional. Defines a comma-separated allowlist of unsafe sysctls or sysctl patterns (ending in *). The unsafe namespaced sysctl groups are kernel.shm* , kernel.msg*, kernel.sem, fs.mqueue.*, and net.*. Leaving this allowlist empty means they cannot be set on Pods. To allow certain sysctls or sysctl patterns to be set on Pods, list them separated by commas. For example: kernel.msg*,net.ipv4.route.min_pmtu. See https://kubernetes.io/docs/tasks/ administer-cluster/sysctl-cluster/ for more details. Corresponds to the JSON property allowedUnsafeSysctls

Returns:

  • (Array<String>)


6704
6705
6706
# File 'lib/google/apis/container_v1/classes.rb', line 6704

def allowed_unsafe_sysctls
  @allowed_unsafe_sysctls
end

#container_log_max_filesFixnum

Optional. Defines the maximum number of container log files that can be present for a container. See https://kubernetes.io/docs/concepts/cluster- administration/logging/#log-rotation The value must be an integer between 2 and 10, inclusive. The default value is 5 if unspecified. Corresponds to the JSON property containerLogMaxFiles

Returns:

  • (Fixnum)


6712
6713
6714
# File 'lib/google/apis/container_v1/classes.rb', line 6712

def container_log_max_files
  @container_log_max_files
end

#container_log_max_sizeString

Optional. Defines the maximum size of the container log file before it is rotated. See https://kubernetes.io/docs/concepts/cluster-administration/ logging/#log-rotation Valid format is positive number + unit, e.g. 100Ki, 10Mi. Valid units are Ki, Mi, Gi. The value must be between 10Mi and 500Mi, inclusive. Note that the total container log size (container_log_max_size * container_log_max_files) cannot exceed 1% of the total storage of the node, to avoid disk pressure caused by log files. The default value is 10Mi if unspecified. Corresponds to the JSON property containerLogMaxSize

Returns:

  • (String)


6724
6725
6726
# File 'lib/google/apis/container_v1/classes.rb', line 6724

def container_log_max_size
  @container_log_max_size
end

#cpu_cfs_quotaBoolean Also known as: cpu_cfs_quota?

Enable CPU CFS quota enforcement for containers that specify CPU limits. This option is enabled by default which makes kubelet use CFS quota (https://www. kernel.org/doc/Documentation/scheduler/sched-bwc.txt) to enforce container CPU limits. Otherwise, CPU limits will not be enforced at all. Disable this option to mitigate CPU throttling problems while still having your pods to be in Guaranteed QoS class by specifying the CPU limits. The default value is 'true' if unspecified. Corresponds to the JSON property cpuCfsQuota

Returns:

  • (Boolean)


6735
6736
6737
# File 'lib/google/apis/container_v1/classes.rb', line 6735

def cpu_cfs_quota
  @cpu_cfs_quota
end

#cpu_cfs_quota_periodString

Set the CPU CFS quota period value 'cpu.cfs_period_us'. The string must be a sequence of decimal numbers, each with optional fraction and a unit suffix, such as "300ms". Valid time units are "ns", "us" (or "µs"), "ms", "s", "m", "h" . The value must be a positive duration between 1ms and 1 second, inclusive. Corresponds to the JSON property cpuCfsQuotaPeriod

Returns:

  • (String)


6744
6745
6746
# File 'lib/google/apis/container_v1/classes.rb', line 6744

def cpu_cfs_quota_period
  @cpu_cfs_quota_period
end

#cpu_manager_policyString

Control the CPU management policy on the node. See https://kubernetes.io/docs/ tasks/administer-cluster/cpu-management-policies/ The following values are allowed. * "none": the default, which represents the existing scheduling behavior. * "static": allows pods with certain resource characteristics to be granted increased CPU affinity and exclusivity on the node. The default value is 'none' if unspecified. Corresponds to the JSON property cpuManagerPolicy

Returns:

  • (String)


6754
6755
6756
# File 'lib/google/apis/container_v1/classes.rb', line 6754

def cpu_manager_policy
  @cpu_manager_policy
end

#crash_loop_back_offGoogle::Apis::ContainerV1::CrashLoopBackOffConfig

Contains config to modify node-level parameters for container restart behavior. Corresponds to the JSON property crashLoopBackOff



6759
6760
6761
# File 'lib/google/apis/container_v1/classes.rb', line 6759

def crash_loop_back_off
  @crash_loop_back_off
end

#eviction_max_pod_grace_period_secondsFixnum

Optional. eviction_max_pod_grace_period_seconds is the maximum allowed grace period (in seconds) to use when terminating pods in response to a soft eviction threshold being met. This value effectively caps the Pod's terminationGracePeriodSeconds value during soft evictions. Default: 0. Range: [ 0, 300]. Corresponds to the JSON property evictionMaxPodGracePeriodSeconds

Returns:

  • (Fixnum)


6768
6769
6770
# File 'lib/google/apis/container_v1/classes.rb', line 6768

def eviction_max_pod_grace_period_seconds
  @eviction_max_pod_grace_period_seconds
end

#eviction_minimum_reclaimGoogle::Apis::ContainerV1::EvictionMinimumReclaim

Eviction minimum reclaims are the resource amounts of minimum reclaims for each eviction signal. Corresponds to the JSON property evictionMinimumReclaim



6774
6775
6776
# File 'lib/google/apis/container_v1/classes.rb', line 6774

def eviction_minimum_reclaim
  @eviction_minimum_reclaim
end

#eviction_softGoogle::Apis::ContainerV1::EvictionSignals

Eviction signals are the current state of a particular resource at a specific point in time. The kubelet uses eviction signals to make eviction decisions by comparing the signals to eviction thresholds, which are the minimum amount of the resource that should be available on the node. Corresponds to the JSON property evictionSoft



6782
6783
6784
# File 'lib/google/apis/container_v1/classes.rb', line 6782

def eviction_soft
  @eviction_soft
end

#eviction_soft_grace_periodGoogle::Apis::ContainerV1::EvictionGracePeriod

Eviction grace periods are grace periods for each eviction signal. Corresponds to the JSON property evictionSoftGracePeriod



6787
6788
6789
# File 'lib/google/apis/container_v1/classes.rb', line 6787

def eviction_soft_grace_period
  @eviction_soft_grace_period
end

#image_gc_high_threshold_percentFixnum

Optional. Defines the percent of disk usage after which image garbage collection is always run. The percent is calculated as this field value out of

  1. The value must be between 10 and 85, inclusive and greater than image_gc_low_threshold_percent. The default value is 85 if unspecified. Corresponds to the JSON property imageGcHighThresholdPercent

Returns:

  • (Fixnum)


6795
6796
6797
# File 'lib/google/apis/container_v1/classes.rb', line 6795

def image_gc_high_threshold_percent
  @image_gc_high_threshold_percent
end

#image_gc_low_threshold_percentFixnum

Optional. Defines the percent of disk usage before which image garbage collection is never run. Lowest disk usage to garbage collect to. The percent is calculated as this field value out of 100. The value must be between 10 and 85, inclusive and smaller than image_gc_high_threshold_percent. The default value is 80 if unspecified. Corresponds to the JSON property imageGcLowThresholdPercent

Returns:

  • (Fixnum)


6804
6805
6806
# File 'lib/google/apis/container_v1/classes.rb', line 6804

def image_gc_low_threshold_percent
  @image_gc_low_threshold_percent
end

#image_maximum_gc_ageString

Optional. Defines the maximum age an image can be unused before it is garbage collected. The string must be a sequence of decimal numbers, each with optional fraction and a unit suffix, such as "300s", "1.5h", and "2h45m". Valid time units are "ns", "us" (or "µs"), "ms", "s", "m", "h". The value must be a positive duration greater than image_minimum_gc_age or "0s". The default value is "0s" if unspecified, which disables this field, meaning images won't be garbage collected based on being unused for too long. Corresponds to the JSON property imageMaximumGcAge

Returns:

  • (String)


6815
6816
6817
# File 'lib/google/apis/container_v1/classes.rb', line 6815

def image_maximum_gc_age
  @image_maximum_gc_age
end

#image_minimum_gc_ageString

Optional. Defines the minimum age for an unused image before it is garbage collected. The string must be a sequence of decimal numbers, each with optional fraction and a unit suffix, such as "300s", "1.5h", and "2h45m". Valid time units are "ns", "us" (or "µs"), "ms", "s", "m", "h". The value must be a positive duration less than or equal to 2 minutes. The default value is " 2m0s" if unspecified. Corresponds to the JSON property imageMinimumGcAge

Returns:

  • (String)


6825
6826
6827
# File 'lib/google/apis/container_v1/classes.rb', line 6825

def image_minimum_gc_age
  @image_minimum_gc_age
end

#insecure_kubelet_readonly_port_enabledBoolean Also known as: insecure_kubelet_readonly_port_enabled?

Enable or disable Kubelet read only port. Corresponds to the JSON property insecureKubeletReadonlyPortEnabled

Returns:

  • (Boolean)


6830
6831
6832
# File 'lib/google/apis/container_v1/classes.rb', line 6830

def insecure_kubelet_readonly_port_enabled
  @insecure_kubelet_readonly_port_enabled
end

#max_parallel_image_pullsFixnum

Optional. Defines the maximum number of image pulls in parallel. The range is 2 to 5, inclusive. The default value is 2 or 3 depending on the disk type. See https://kubernetes.io/docs/concepts/containers/images/#maximum-parallel-image- pulls for more details. Corresponds to the JSON property maxParallelImagePulls

Returns:

  • (Fixnum)


6839
6840
6841
# File 'lib/google/apis/container_v1/classes.rb', line 6839

def max_parallel_image_pulls
  @max_parallel_image_pulls
end

#memory_managerGoogle::Apis::ContainerV1::MemoryManager

The option enables the Kubernetes NUMA-aware Memory Manager feature. Detailed description about the feature can be found here. Corresponds to the JSON property memoryManager



6846
6847
6848
# File 'lib/google/apis/container_v1/classes.rb', line 6846

def memory_manager
  @memory_manager
end

#pod_pids_limitFixnum

Set the Pod PID limits. See https://kubernetes.io/docs/concepts/policy/pid- limiting/#pod-pid-limits Controls the maximum number of processes allowed to run in a pod. The value must be greater than or equal to 1024 and less than 4194304. Corresponds to the JSON property podPidsLimit

Returns:

  • (Fixnum)


6854
6855
6856
# File 'lib/google/apis/container_v1/classes.rb', line 6854

def pod_pids_limit
  @pod_pids_limit
end

#shutdown_grace_period_critical_pods_secondsFixnum

Optional. shutdown_grace_period_critical_pods_seconds is the maximum allowed grace period (in seconds) used to terminate critical pods during a node shutdown. This value should be <= shutdown_grace_period_seconds, and is only valid if shutdown_grace_period_seconds is set. https://kubernetes.io/docs/ concepts/cluster-administration/node-shutdown/ Range: [0, 120]. Corresponds to the JSON property shutdownGracePeriodCriticalPodsSeconds

Returns:

  • (Fixnum)


6863
6864
6865
# File 'lib/google/apis/container_v1/classes.rb', line 6863

def shutdown_grace_period_critical_pods_seconds
  @shutdown_grace_period_critical_pods_seconds
end

#shutdown_grace_period_secondsFixnum

Optional. shutdown_grace_period_seconds is the maximum allowed grace period ( in seconds) the total duration that the node should delay the shutdown during a graceful shutdown. This is the total grace period for pod termination for both regular and critical pods. https://kubernetes.io/docs/concepts/cluster- administration/node-shutdown/ If set to 0, node will not enable the graceful node shutdown functionality. This field is only valid for Spot VMs. Allowed values: 0, 30, 120. Corresponds to the JSON property shutdownGracePeriodSeconds

Returns:

  • (Fixnum)


6874
6875
6876
# File 'lib/google/apis/container_v1/classes.rb', line 6874

def shutdown_grace_period_seconds
  @shutdown_grace_period_seconds
end

#single_process_oom_killBoolean Also known as: single_process_oom_kill?

Optional. Defines whether to enable single process OOM killer. If true, will prevent the memory.oom.group flag from being set for container cgroups in cgroups v2. This causes processes in the container to be OOM killed individually instead of as a group. Corresponds to the JSON property singleProcessOomKill

Returns:

  • (Boolean)


6882
6883
6884
# File 'lib/google/apis/container_v1/classes.rb', line 6882

def single_process_oom_kill
  @single_process_oom_kill
end

#topology_managerGoogle::Apis::ContainerV1::TopologyManager

TopologyManager defines the configuration options for the kubelet Topology Manager component. For more information about the supported machine types and versions for the Topology Manager in GKE, see Customizing node system configuration. Corresponds to the JSON property topologyManager



6893
6894
6895
# File 'lib/google/apis/container_v1/classes.rb', line 6893

def topology_manager
  @topology_manager
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6900
6901
6902
6903
6904
6905
6906
6907
6908
6909
6910
6911
6912
6913
6914
6915
6916
6917
6918
6919
6920
6921
6922
6923
6924
# File 'lib/google/apis/container_v1/classes.rb', line 6900

def update!(**args)
  @allowed_unsafe_sysctls = args[:allowed_unsafe_sysctls] if args.key?(:allowed_unsafe_sysctls)
  @container_log_max_files = args[:container_log_max_files] if args.key?(:container_log_max_files)
  @container_log_max_size = args[:container_log_max_size] if args.key?(:container_log_max_size)
  @cpu_cfs_quota = args[:cpu_cfs_quota] if args.key?(:cpu_cfs_quota)
  @cpu_cfs_quota_period = args[:cpu_cfs_quota_period] if args.key?(:cpu_cfs_quota_period)
  @cpu_manager_policy = args[:cpu_manager_policy] if args.key?(:cpu_manager_policy)
  @crash_loop_back_off = args[:crash_loop_back_off] if args.key?(:crash_loop_back_off)
  @eviction_max_pod_grace_period_seconds = args[:eviction_max_pod_grace_period_seconds] if args.key?(:eviction_max_pod_grace_period_seconds)
  @eviction_minimum_reclaim = args[:eviction_minimum_reclaim] if args.key?(:eviction_minimum_reclaim)
  @eviction_soft = args[:eviction_soft] if args.key?(:eviction_soft)
  @eviction_soft_grace_period = args[:eviction_soft_grace_period] if args.key?(:eviction_soft_grace_period)
  @image_gc_high_threshold_percent = args[:image_gc_high_threshold_percent] if args.key?(:image_gc_high_threshold_percent)
  @image_gc_low_threshold_percent = args[:image_gc_low_threshold_percent] if args.key?(:image_gc_low_threshold_percent)
  @image_maximum_gc_age = args[:image_maximum_gc_age] if args.key?(:image_maximum_gc_age)
  @image_minimum_gc_age = args[:image_minimum_gc_age] if args.key?(:image_minimum_gc_age)
  @insecure_kubelet_readonly_port_enabled = args[:insecure_kubelet_readonly_port_enabled] if args.key?(:insecure_kubelet_readonly_port_enabled)
  @max_parallel_image_pulls = args[:max_parallel_image_pulls] if args.key?(:max_parallel_image_pulls)
  @memory_manager = args[:memory_manager] if args.key?(:memory_manager)
  @pod_pids_limit = args[:pod_pids_limit] if args.key?(:pod_pids_limit)
  @shutdown_grace_period_critical_pods_seconds = args[:shutdown_grace_period_critical_pods_seconds] if args.key?(:shutdown_grace_period_critical_pods_seconds)
  @shutdown_grace_period_seconds = args[:shutdown_grace_period_seconds] if args.key?(:shutdown_grace_period_seconds)
  @single_process_oom_kill = args[:single_process_oom_kill] if args.key?(:single_process_oom_kill)
  @topology_manager = args[:topology_manager] if args.key?(:topology_manager)
end