Class: Google::Apis::ContainerV1::NodeManagement
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1::NodeManagement
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb
Overview
NodeManagement defines the set of node management services turned on for the node pool.
Instance Attribute Summary collapse
-
#auto_repair ⇒ Boolean
(also: #auto_repair?)
A flag that specifies whether the node auto-repair is enabled for the node pool.
-
#auto_upgrade ⇒ Boolean
(also: #auto_upgrade?)
A flag that specifies whether node auto-upgrade is enabled for the node pool.
-
#upgrade_options ⇒ Google::Apis::ContainerV1::AutoUpgradeOptions
AutoUpgradeOptions defines the set of options for the user to control how the Auto Upgrades will proceed.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NodeManagement
constructor
A new instance of NodeManagement.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NodeManagement
Returns a new instance of NodeManagement.
6975 6976 6977 |
# File 'lib/google/apis/container_v1/classes.rb', line 6975 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auto_repair ⇒ Boolean Also known as: auto_repair?
A flag that specifies whether the node auto-repair is enabled for the node
pool. If enabled, the nodes in this node pool will be monitored and, if they
fail health checks too many times, an automatic repair action will be
triggered.
Corresponds to the JSON property autoRepair
6958 6959 6960 |
# File 'lib/google/apis/container_v1/classes.rb', line 6958 def auto_repair @auto_repair end |
#auto_upgrade ⇒ Boolean Also known as: auto_upgrade?
A flag that specifies whether node auto-upgrade is enabled for the node pool.
If enabled, node auto-upgrade helps keep the nodes in your node pool up to
date with the latest release version of Kubernetes.
Corresponds to the JSON property autoUpgrade
6966 6967 6968 |
# File 'lib/google/apis/container_v1/classes.rb', line 6966 def auto_upgrade @auto_upgrade end |
#upgrade_options ⇒ Google::Apis::ContainerV1::AutoUpgradeOptions
AutoUpgradeOptions defines the set of options for the user to control how the
Auto Upgrades will proceed.
Corresponds to the JSON property upgradeOptions
6973 6974 6975 |
# File 'lib/google/apis/container_v1/classes.rb', line 6973 def @upgrade_options end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6980 6981 6982 6983 6984 |
# File 'lib/google/apis/container_v1/classes.rb', line 6980 def update!(**args) @auto_repair = args[:auto_repair] if args.key?(:auto_repair) @auto_upgrade = args[:auto_upgrade] if args.key?(:auto_upgrade) @upgrade_options = args[:upgrade_options] if args.key?(:upgrade_options) end |