Class: Google::Apis::ContainerV1::ReleaseChannelConfig
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1::ReleaseChannelConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb
Overview
ReleaseChannelConfig exposes configuration for a release channel.
Instance Attribute Summary collapse
-
#channel ⇒ String
The release channel this configuration applies to.
-
#default_version ⇒ String
The default version for newly created clusters on the channel.
-
#upgrade_target_version ⇒ String
The auto upgrade target version for clusters on the channel.
-
#valid_versions ⇒ Array<String>
List of valid versions for the channel.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReleaseChannelConfig
constructor
A new instance of ReleaseChannelConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReleaseChannelConfig
Returns a new instance of ReleaseChannelConfig.
8575 8576 8577 |
# File 'lib/google/apis/container_v1/classes.rb', line 8575 def initialize(**args) update!(**args) end |
Instance Attribute Details
#channel ⇒ String
The release channel this configuration applies to.
Corresponds to the JSON property channel
8558 8559 8560 |
# File 'lib/google/apis/container_v1/classes.rb', line 8558 def channel @channel end |
#default_version ⇒ String
The default version for newly created clusters on the channel.
Corresponds to the JSON property defaultVersion
8563 8564 8565 |
# File 'lib/google/apis/container_v1/classes.rb', line 8563 def default_version @default_version end |
#upgrade_target_version ⇒ String
The auto upgrade target version for clusters on the channel.
Corresponds to the JSON property upgradeTargetVersion
8568 8569 8570 |
# File 'lib/google/apis/container_v1/classes.rb', line 8568 def upgrade_target_version @upgrade_target_version end |
#valid_versions ⇒ Array<String>
List of valid versions for the channel.
Corresponds to the JSON property validVersions
8573 8574 8575 |
# File 'lib/google/apis/container_v1/classes.rb', line 8573 def valid_versions @valid_versions end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8580 8581 8582 8583 8584 8585 |
# File 'lib/google/apis/container_v1/classes.rb', line 8580 def update!(**args) @channel = args[:channel] if args.key?(:channel) @default_version = args[:default_version] if args.key?(:default_version) @upgrade_target_version = args[:upgrade_target_version] if args.key?(:upgrade_target_version) @valid_versions = args[:valid_versions] if args.key?(:valid_versions) end |