Class: Google::Apis::ContainerV1::ReservationAffinity

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

ReservationAffinity is the configuration of desired reservation which instances could take capacity from.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationAffinity

Returns a new instance of ReservationAffinity.



7527
7528
7529
# File 'lib/google/apis/container_v1/classes.rb', line 7527

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#consume_reservation_typeString

Corresponds to the type of reservation consumption. Corresponds to the JSON property consumeReservationType

Returns:

  • (String)


7513
7514
7515
# File 'lib/google/apis/container_v1/classes.rb', line 7513

def consume_reservation_type
  @consume_reservation_type
end

#keyString

Corresponds to the label key of a reservation resource. To target a SPECIFIC_RESERVATION by name, specify "compute.googleapis.com/reservation-name" as the key and specify the name of your reservation as its value. Corresponds to the JSON property key

Returns:

  • (String)


7520
7521
7522
# File 'lib/google/apis/container_v1/classes.rb', line 7520

def key
  @key
end

#valuesArray<String>

Corresponds to the label value(s) of reservation resource(s). Corresponds to the JSON property values

Returns:

  • (Array<String>)


7525
7526
7527
# File 'lib/google/apis/container_v1/classes.rb', line 7525

def values
  @values
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7532
7533
7534
7535
7536
# File 'lib/google/apis/container_v1/classes.rb', line 7532

def update!(**args)
  @consume_reservation_type = args[:consume_reservation_type] if args.key?(:consume_reservation_type)
  @key = args[:key] if args.key?(:key)
  @values = args[:values] if args.key?(:values)
end