Class: Google::Apis::ContainerV1::RollbackSafeUpgrade

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

RollbackSafeUpgrade is the configuration for the rollback safe upgrade.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RollbackSafeUpgrade

Returns a new instance of RollbackSafeUpgrade.



8803
8804
8805
# File 'lib/google/apis/container_v1/classes.rb', line 8803

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#control_plane_soak_durationString

Optional. A user-defined period for the cluster remains in the rollbackable state. ex: seconds: 21600. Corresponds to the JSON property controlPlaneSoakDuration

Returns:

  • (String)


8801
8802
8803
# File 'lib/google/apis/container_v1/classes.rb', line 8801

def control_plane_soak_duration
  @control_plane_soak_duration
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8808
8809
8810
# File 'lib/google/apis/container_v1/classes.rb', line 8808

def update!(**args)
  @control_plane_soak_duration = args[:control_plane_soak_duration] if args.key?(:control_plane_soak_duration)
end