Class: Google::Apis::ContainerV1::SetMaintenancePolicyRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

SetMaintenancePolicyRequest sets the maintenance policy for a cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SetMaintenancePolicyRequest

Returns a new instance of SetMaintenancePolicyRequest.



9491
9492
9493
# File 'lib/google/apis/container_v1/classes.rb', line 9491

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cluster_idString

Required. The name of the cluster to update. Corresponds to the JSON property clusterId

Returns:

  • (String)


9466
9467
9468
# File 'lib/google/apis/container_v1/classes.rb', line 9466

def cluster_id
  @cluster_id
end

#maintenance_policyGoogle::Apis::ContainerV1::MaintenancePolicy

MaintenancePolicy defines the maintenance policy to be used for the cluster. Corresponds to the JSON property maintenancePolicy



9471
9472
9473
# File 'lib/google/apis/container_v1/classes.rb', line 9471

def maintenance_policy
  @maintenance_policy
end

#nameString

The name (project, location, cluster name) of the cluster to set maintenance policy. Specified in the format projects/*/locations/*/clusters/*. Corresponds to the JSON property name

Returns:

  • (String)


9477
9478
9479
# File 'lib/google/apis/container_v1/classes.rb', line 9477

def name
  @name
end

#project_idString

Required. The Google Developers Console project ID or project number. Corresponds to the JSON property projectId

Returns:

  • (String)


9483
9484
9485
# File 'lib/google/apis/container_v1/classes.rb', line 9483

def project_id
  @project_id
end

#zoneString

Required. The name of the Google Compute Engine zone in which the cluster resides. Corresponds to the JSON property zone

Returns:

  • (String)


9489
9490
9491
# File 'lib/google/apis/container_v1/classes.rb', line 9489

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9496
9497
9498
9499
9500
9501
9502
# File 'lib/google/apis/container_v1/classes.rb', line 9496

def update!(**args)
  @cluster_id = args[:cluster_id] if args.key?(:cluster_id)
  @maintenance_policy = args[:maintenance_policy] if args.key?(:maintenance_policy)
  @name = args[:name] if args.key?(:name)
  @project_id = args[:project_id] if args.key?(:project_id)
  @zone = args[:zone] if args.key?(:zone)
end