Class: Google::Apis::ContainerV1::SetMasterAuthRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

SetMasterAuthRequest updates the admin password of a cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SetMasterAuthRequest

Returns a new instance of SetMasterAuthRequest.



9552
9553
9554
# File 'lib/google/apis/container_v1/classes.rb', line 9552

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actionString

Required. The exact form of action to be taken on the master auth. Corresponds to the JSON property action

Returns:

  • (String)


9518
9519
9520
# File 'lib/google/apis/container_v1/classes.rb', line 9518

def action
  @action
end

#cluster_idString

Deprecated. The name of the cluster to upgrade. This field has been deprecated and replaced by the name field. Corresponds to the JSON property clusterId

Returns:

  • (String)


9524
9525
9526
# File 'lib/google/apis/container_v1/classes.rb', line 9524

def cluster_id
  @cluster_id
end

#nameString

The name (project, location, cluster) of the cluster to set auth. Specified in the format projects/*/locations/*/clusters/*. Corresponds to the JSON property name

Returns:

  • (String)


9530
9531
9532
# File 'lib/google/apis/container_v1/classes.rb', line 9530

def name
  @name
end

#project_idString

Deprecated. The Google Developers Console project ID or project number. This field has been deprecated and replaced by the name field. Corresponds to the JSON property projectId

Returns:

  • (String)


9537
9538
9539
# File 'lib/google/apis/container_v1/classes.rb', line 9537

def project_id
  @project_id
end

#updateGoogle::Apis::ContainerV1::MasterAuth

The authentication information for accessing the master endpoint. Authentication can be done using HTTP basic auth or using client certificates. Corresponds to the JSON property update



9543
9544
9545
# File 'lib/google/apis/container_v1/classes.rb', line 9543

def update
  @update
end

#zoneString

Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has been deprecated and replaced by the name field. Corresponds to the JSON property zone

Returns:

  • (String)


9550
9551
9552
# File 'lib/google/apis/container_v1/classes.rb', line 9550

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9557
9558
9559
9560
9561
9562
9563
9564
# File 'lib/google/apis/container_v1/classes.rb', line 9557

def update!(**args)
  @action = args[:action] if args.key?(:action)
  @cluster_id = args[:cluster_id] if args.key?(:cluster_id)
  @name = args[:name] if args.key?(:name)
  @project_id = args[:project_id] if args.key?(:project_id)
  @update = args[:update] if args.key?(:update)
  @zone = args[:zone] if args.key?(:zone)
end