Class: Google::Apis::ContainerV1::SetNodePoolManagementRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

SetNodePoolManagementRequest sets the node management properties of a node pool.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SetNodePoolManagementRequest

Returns a new instance of SetNodePoolManagementRequest.



9774
9775
9776
# File 'lib/google/apis/container_v1/classes.rb', line 9774

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cluster_idString

Deprecated. The name of the cluster to update. This field has been deprecated and replaced by the name field. Corresponds to the JSON property clusterId

Returns:

  • (String)


9739
9740
9741
# File 'lib/google/apis/container_v1/classes.rb', line 9739

def cluster_id
  @cluster_id
end

#managementGoogle::Apis::ContainerV1::NodeManagement

NodeManagement defines the set of node management services turned on for the node pool. Corresponds to the JSON property management



9745
9746
9747
# File 'lib/google/apis/container_v1/classes.rb', line 9745

def management
  @management
end

#nameString

The name (project, location, cluster, node pool id) of the node pool to set management properties. Specified in the format projects/*/locations/*/ clusters/*/nodePools/*. Corresponds to the JSON property name

Returns:

  • (String)


9752
9753
9754
# File 'lib/google/apis/container_v1/classes.rb', line 9752

def name
  @name
end

#node_pool_idString

Deprecated. The name of the node pool to update. This field has been deprecated and replaced by the name field. Corresponds to the JSON property nodePoolId

Returns:

  • (String)


9758
9759
9760
# File 'lib/google/apis/container_v1/classes.rb', line 9758

def node_pool_id
  @node_pool_id
end

#project_idString

Deprecated. The Google Developers Console project ID or project number. This field has been deprecated and replaced by the name field. Corresponds to the JSON property projectId

Returns:

  • (String)


9765
9766
9767
# File 'lib/google/apis/container_v1/classes.rb', line 9765

def project_id
  @project_id
end

#zoneString

Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has been deprecated and replaced by the name field. Corresponds to the JSON property zone

Returns:

  • (String)


9772
9773
9774
# File 'lib/google/apis/container_v1/classes.rb', line 9772

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9779
9780
9781
9782
9783
9784
9785
9786
# File 'lib/google/apis/container_v1/classes.rb', line 9779

def update!(**args)
  @cluster_id = args[:cluster_id] if args.key?(:cluster_id)
  @management = args[:management] if args.key?(:management)
  @name = args[:name] if args.key?(:name)
  @node_pool_id = args[:node_pool_id] if args.key?(:node_pool_id)
  @project_id = args[:project_id] if args.key?(:project_id)
  @zone = args[:zone] if args.key?(:zone)
end