Class: Google::Apis::ContainerV1::SlurmOperatorConfig
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1::SlurmOperatorConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb
Overview
Configuration for the Slurm Operator.
Instance Attribute Summary collapse
-
#enabled ⇒ Boolean
(also: #enabled?)
When enabled, it runs a Slurm Operator that manages the set of compute pods for Slurm Cluster.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SlurmOperatorConfig
constructor
A new instance of SlurmOperatorConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SlurmOperatorConfig
Returns a new instance of SlurmOperatorConfig.
9715 9716 9717 |
# File 'lib/google/apis/container_v1/classes.rb', line 9715 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enabled ⇒ Boolean Also known as: enabled?
When enabled, it runs a Slurm Operator that manages the set of compute pods
for Slurm Cluster.
Corresponds to the JSON property enabled
9712 9713 9714 |
# File 'lib/google/apis/container_v1/classes.rb', line 9712 def enabled @enabled end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9720 9721 9722 |
# File 'lib/google/apis/container_v1/classes.rb', line 9720 def update!(**args) @enabled = args[:enabled] if args.key?(:enabled) end |