Class: Google::Apis::ContainerV1::SoleTenantConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

SoleTenantConfig contains the NodeAffinities to specify what shared sole tenant node groups should back the node pool.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SoleTenantConfig

Returns a new instance of SoleTenantConfig.



9723
9724
9725
# File 'lib/google/apis/container_v1/classes.rb', line 9723

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#min_node_cpusFixnum

Optional. The minimum number of virtual CPUs this instance will consume when running on a sole-tenant node. This field can only be set if the node pool is created in a shared sole-tenant node group. Corresponds to the JSON property minNodeCpus

Returns:

  • (Fixnum)


9716
9717
9718
# File 'lib/google/apis/container_v1/classes.rb', line 9716

def min_node_cpus
  @min_node_cpus
end

#node_affinitiesArray<Google::Apis::ContainerV1::NodeAffinity>

NodeAffinities used to match to a shared sole tenant node group. Corresponds to the JSON property nodeAffinities



9721
9722
9723
# File 'lib/google/apis/container_v1/classes.rb', line 9721

def node_affinities
  @node_affinities
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9728
9729
9730
9731
# File 'lib/google/apis/container_v1/classes.rb', line 9728

def update!(**args)
  @min_node_cpus = args[:min_node_cpus] if args.key?(:min_node_cpus)
  @node_affinities = args[:node_affinities] if args.key?(:node_affinities)
end