Class: Google::Apis::ContainerV1::UpgradeEvent

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

UpgradeEvent is a notification sent to customers by the cluster server when a resource is upgrading.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UpgradeEvent

Returns a new instance of UpgradeEvent.



10735
10736
10737
# File 'lib/google/apis/container_v1/classes.rb', line 10735

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#current_versionString

The current version before the upgrade. Corresponds to the JSON property currentVersion

Returns:

  • (String)


10707
10708
10709
# File 'lib/google/apis/container_v1/classes.rb', line 10707

def current_version
  @current_version
end

#operationString

The operation associated with this upgrade. Corresponds to the JSON property operation

Returns:

  • (String)


10712
10713
10714
# File 'lib/google/apis/container_v1/classes.rb', line 10712

def operation
  @operation
end

#operation_start_timeString

The time when the operation was started. Corresponds to the JSON property operationStartTime

Returns:

  • (String)


10717
10718
10719
# File 'lib/google/apis/container_v1/classes.rb', line 10717

def operation_start_time
  @operation_start_time
end

#resourceString

Optional relative path to the resource. For example in node pool upgrades, the relative path of the node pool. Corresponds to the JSON property resource

Returns:

  • (String)


10723
10724
10725
# File 'lib/google/apis/container_v1/classes.rb', line 10723

def resource
  @resource
end

#resource_typeString

The resource type that is upgrading. Corresponds to the JSON property resourceType

Returns:

  • (String)


10728
10729
10730
# File 'lib/google/apis/container_v1/classes.rb', line 10728

def resource_type
  @resource_type
end

#target_versionString

The target version for the upgrade. Corresponds to the JSON property targetVersion

Returns:

  • (String)


10733
10734
10735
# File 'lib/google/apis/container_v1/classes.rb', line 10733

def target_version
  @target_version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10740
10741
10742
10743
10744
10745
10746
10747
# File 'lib/google/apis/container_v1/classes.rb', line 10740

def update!(**args)
  @current_version = args[:current_version] if args.key?(:current_version)
  @operation = args[:operation] if args.key?(:operation)
  @operation_start_time = args[:operation_start_time] if args.key?(:operation_start_time)
  @resource = args[:resource] if args.key?(:resource)
  @resource_type = args[:resource_type] if args.key?(:resource_type)
  @target_version = args[:target_version] if args.key?(:target_version)
end