Class: Google::Apis::ContainerV1::WindowsNodeConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

Parameters that can be configured on Windows nodes. Windows Node Config that define the parameters that will be used to configure the Windows node pool settings.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WindowsNodeConfig

Returns a new instance of WindowsNodeConfig.



11374
11375
11376
# File 'lib/google/apis/container_v1/classes.rb', line 11374

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#os_versionString

OSVersion specifies the Windows node config to be used on the node. Corresponds to the JSON property osVersion

Returns:

  • (String)


11372
11373
11374
# File 'lib/google/apis/container_v1/classes.rb', line 11372

def os_version
  @os_version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11379
11380
11381
# File 'lib/google/apis/container_v1/classes.rb', line 11379

def update!(**args)
  @os_version = args[:os_version] if args.key?(:os_version)
end