Class: Google::Apis::ContainerV1::WorkloadIdentityConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

Configuration for the use of Kubernetes Service Accounts in IAM policies.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WorkloadIdentityConfig

Returns a new instance of WorkloadIdentityConfig.



9960
9961
9962
# File 'lib/google/apis/container_v1/classes.rb', line 9960

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#workload_poolString

The workload pool to attach all Kubernetes service accounts to. Corresponds to the JSON property workloadPool

Returns:

  • (String)


9958
9959
9960
# File 'lib/google/apis/container_v1/classes.rb', line 9958

def workload_pool
  @workload_pool
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9965
9966
9967
# File 'lib/google/apis/container_v1/classes.rb', line 9965

def update!(**args)
  @workload_pool = args[:workload_pool] if args.key?(:workload_pool)
end