Class: Google::Apis::ContainerV1::AddonsConfig
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1::AddonsConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb
Overview
Configuration for the addons that can be automatically spun up in the cluster, enabling additional functionality.
Instance Attribute Summary collapse
-
#agent_sandbox_config ⇒ Google::Apis::ContainerV1::AgentSandboxConfig
Configuration for the AgentSandbox addon.
-
#cloud_run_config ⇒ Google::Apis::ContainerV1::CloudRunConfig
Configuration options for the Cloud Run feature.
-
#config_connector_config ⇒ Google::Apis::ContainerV1::ConfigConnectorConfig
Configuration options for the Config Connector add-on.
-
#dns_cache_config ⇒ Google::Apis::ContainerV1::DnsCacheConfig
Configuration for NodeLocal DNSCache Corresponds to the JSON property
dnsCacheConfig. -
#gce_persistent_disk_csi_driver_config ⇒ Google::Apis::ContainerV1::GcePersistentDiskCsiDriverConfig
Configuration for the Compute Engine PD CSI driver.
-
#gcp_filestore_csi_driver_config ⇒ Google::Apis::ContainerV1::GcpFilestoreCsiDriverConfig
Configuration for the Filestore CSI driver.
-
#gcs_fuse_csi_driver_config ⇒ Google::Apis::ContainerV1::GcsFuseCsiDriverConfig
Configuration for the Cloud Storage Fuse CSI driver.
-
#gke_backup_agent_config ⇒ Google::Apis::ContainerV1::GkeBackupAgentConfig
Configuration for the Backup for GKE Agent.
-
#high_scale_checkpointing_config ⇒ Google::Apis::ContainerV1::HighScaleCheckpointingConfig
Configuration for the High Scale Checkpointing.
-
#horizontal_pod_autoscaling ⇒ Google::Apis::ContainerV1::HorizontalPodAutoscaling
Configuration options for the horizontal pod autoscaling feature, which increases or decreases the number of replica pods a replication controller has based on the resource usage of the existing pods.
-
#http_load_balancing ⇒ Google::Apis::ContainerV1::HttpLoadBalancing
Configuration options for the HTTP (L7) load balancing controller addon, which makes it easy to set up HTTP load balancers for services in a cluster.
-
#kubernetes_dashboard ⇒ Google::Apis::ContainerV1::KubernetesDashboard
Configuration for the Kubernetes Dashboard.
-
#lustre_csi_driver_config ⇒ Google::Apis::ContainerV1::LustreCsiDriverConfig
Configuration for the Lustre CSI driver.
-
#network_policy_config ⇒ Google::Apis::ContainerV1::NetworkPolicyConfig
Configuration for NetworkPolicy.
-
#node_readiness_config ⇒ Google::Apis::ContainerV1::NodeReadinessConfig
Configuration for the GKE Node Readiness Controller.
-
#parallelstore_csi_driver_config ⇒ Google::Apis::ContainerV1::ParallelstoreCsiDriverConfig
Configuration for the Cloud Storage Parallelstore CSI driver.
-
#pod_snapshot_config ⇒ Google::Apis::ContainerV1::PodSnapshotConfig
PodSnapshotConfig is the configuration for GKE Pod Snapshots feature.
-
#ray_operator_config ⇒ Google::Apis::ContainerV1::RayOperatorConfig
Configuration options for the Ray Operator add-on.
-
#slice_controller_config ⇒ Google::Apis::ContainerV1::SliceControllerConfig
Configuration for the Slice Controller.
-
#slurm_operator_config ⇒ Google::Apis::ContainerV1::SlurmOperatorConfig
Configuration for the Slurm Operator.
-
#stateful_ha_config ⇒ Google::Apis::ContainerV1::StatefulHaConfig
Configuration for the Stateful HA add-on.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AddonsConfig
constructor
A new instance of AddonsConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AddonsConfig
Returns a new instance of AddonsConfig.
336 337 338 |
# File 'lib/google/apis/container_v1/classes.rb', line 336 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_sandbox_config ⇒ Google::Apis::ContainerV1::AgentSandboxConfig
Configuration for the AgentSandbox addon.
Corresponds to the JSON property agentSandboxConfig
229 230 231 |
# File 'lib/google/apis/container_v1/classes.rb', line 229 def agent_sandbox_config @agent_sandbox_config end |
#cloud_run_config ⇒ Google::Apis::ContainerV1::CloudRunConfig
Configuration options for the Cloud Run feature.
Corresponds to the JSON property cloudRunConfig
234 235 236 |
# File 'lib/google/apis/container_v1/classes.rb', line 234 def cloud_run_config @cloud_run_config end |
#config_connector_config ⇒ Google::Apis::ContainerV1::ConfigConnectorConfig
Configuration options for the Config Connector add-on.
Corresponds to the JSON property configConnectorConfig
239 240 241 |
# File 'lib/google/apis/container_v1/classes.rb', line 239 def config_connector_config @config_connector_config end |
#dns_cache_config ⇒ Google::Apis::ContainerV1::DnsCacheConfig
Configuration for NodeLocal DNSCache
Corresponds to the JSON property dnsCacheConfig
244 245 246 |
# File 'lib/google/apis/container_v1/classes.rb', line 244 def dns_cache_config @dns_cache_config end |
#gce_persistent_disk_csi_driver_config ⇒ Google::Apis::ContainerV1::GcePersistentDiskCsiDriverConfig
Configuration for the Compute Engine PD CSI driver.
Corresponds to the JSON property gcePersistentDiskCsiDriverConfig
249 250 251 |
# File 'lib/google/apis/container_v1/classes.rb', line 249 def gce_persistent_disk_csi_driver_config @gce_persistent_disk_csi_driver_config end |
#gcp_filestore_csi_driver_config ⇒ Google::Apis::ContainerV1::GcpFilestoreCsiDriverConfig
Configuration for the Filestore CSI driver.
Corresponds to the JSON property gcpFilestoreCsiDriverConfig
254 255 256 |
# File 'lib/google/apis/container_v1/classes.rb', line 254 def gcp_filestore_csi_driver_config @gcp_filestore_csi_driver_config end |
#gcs_fuse_csi_driver_config ⇒ Google::Apis::ContainerV1::GcsFuseCsiDriverConfig
Configuration for the Cloud Storage Fuse CSI driver.
Corresponds to the JSON property gcsFuseCsiDriverConfig
259 260 261 |
# File 'lib/google/apis/container_v1/classes.rb', line 259 def gcs_fuse_csi_driver_config @gcs_fuse_csi_driver_config end |
#gke_backup_agent_config ⇒ Google::Apis::ContainerV1::GkeBackupAgentConfig
Configuration for the Backup for GKE Agent.
Corresponds to the JSON property gkeBackupAgentConfig
264 265 266 |
# File 'lib/google/apis/container_v1/classes.rb', line 264 def gke_backup_agent_config @gke_backup_agent_config end |
#high_scale_checkpointing_config ⇒ Google::Apis::ContainerV1::HighScaleCheckpointingConfig
Configuration for the High Scale Checkpointing.
Corresponds to the JSON property highScaleCheckpointingConfig
269 270 271 |
# File 'lib/google/apis/container_v1/classes.rb', line 269 def high_scale_checkpointing_config @high_scale_checkpointing_config end |
#horizontal_pod_autoscaling ⇒ Google::Apis::ContainerV1::HorizontalPodAutoscaling
Configuration options for the horizontal pod autoscaling feature, which
increases or decreases the number of replica pods a replication controller has
based on the resource usage of the existing pods.
Corresponds to the JSON property horizontalPodAutoscaling
276 277 278 |
# File 'lib/google/apis/container_v1/classes.rb', line 276 def horizontal_pod_autoscaling @horizontal_pod_autoscaling end |
#http_load_balancing ⇒ Google::Apis::ContainerV1::HttpLoadBalancing
Configuration options for the HTTP (L7) load balancing controller addon, which
makes it easy to set up HTTP load balancers for services in a cluster.
Corresponds to the JSON property httpLoadBalancing
282 283 284 |
# File 'lib/google/apis/container_v1/classes.rb', line 282 def http_load_balancing @http_load_balancing end |
#kubernetes_dashboard ⇒ Google::Apis::ContainerV1::KubernetesDashboard
Configuration for the Kubernetes Dashboard.
Corresponds to the JSON property kubernetesDashboard
287 288 289 |
# File 'lib/google/apis/container_v1/classes.rb', line 287 def kubernetes_dashboard @kubernetes_dashboard end |
#lustre_csi_driver_config ⇒ Google::Apis::ContainerV1::LustreCsiDriverConfig
Configuration for the Lustre CSI driver.
Corresponds to the JSON property lustreCsiDriverConfig
292 293 294 |
# File 'lib/google/apis/container_v1/classes.rb', line 292 def lustre_csi_driver_config @lustre_csi_driver_config end |
#network_policy_config ⇒ Google::Apis::ContainerV1::NetworkPolicyConfig
Configuration for NetworkPolicy. This only tracks whether the addon is enabled
or not on the Master, it does not track whether network policy is enabled for
the nodes.
Corresponds to the JSON property networkPolicyConfig
299 300 301 |
# File 'lib/google/apis/container_v1/classes.rb', line 299 def network_policy_config @network_policy_config end |
#node_readiness_config ⇒ Google::Apis::ContainerV1::NodeReadinessConfig
Configuration for the GKE Node Readiness Controller.
Corresponds to the JSON property nodeReadinessConfig
304 305 306 |
# File 'lib/google/apis/container_v1/classes.rb', line 304 def node_readiness_config @node_readiness_config end |
#parallelstore_csi_driver_config ⇒ Google::Apis::ContainerV1::ParallelstoreCsiDriverConfig
Configuration for the Cloud Storage Parallelstore CSI driver.
Corresponds to the JSON property parallelstoreCsiDriverConfig
309 310 311 |
# File 'lib/google/apis/container_v1/classes.rb', line 309 def parallelstore_csi_driver_config @parallelstore_csi_driver_config end |
#pod_snapshot_config ⇒ Google::Apis::ContainerV1::PodSnapshotConfig
PodSnapshotConfig is the configuration for GKE Pod Snapshots feature.
Corresponds to the JSON property podSnapshotConfig
314 315 316 |
# File 'lib/google/apis/container_v1/classes.rb', line 314 def pod_snapshot_config @pod_snapshot_config end |
#ray_operator_config ⇒ Google::Apis::ContainerV1::RayOperatorConfig
Configuration options for the Ray Operator add-on.
Corresponds to the JSON property rayOperatorConfig
319 320 321 |
# File 'lib/google/apis/container_v1/classes.rb', line 319 def ray_operator_config @ray_operator_config end |
#slice_controller_config ⇒ Google::Apis::ContainerV1::SliceControllerConfig
Configuration for the Slice Controller.
Corresponds to the JSON property sliceControllerConfig
324 325 326 |
# File 'lib/google/apis/container_v1/classes.rb', line 324 def slice_controller_config @slice_controller_config end |
#slurm_operator_config ⇒ Google::Apis::ContainerV1::SlurmOperatorConfig
Configuration for the Slurm Operator.
Corresponds to the JSON property slurmOperatorConfig
329 330 331 |
# File 'lib/google/apis/container_v1/classes.rb', line 329 def slurm_operator_config @slurm_operator_config end |
#stateful_ha_config ⇒ Google::Apis::ContainerV1::StatefulHaConfig
Configuration for the Stateful HA add-on.
Corresponds to the JSON property statefulHaConfig
334 335 336 |
# File 'lib/google/apis/container_v1/classes.rb', line 334 def stateful_ha_config @stateful_ha_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 |
# File 'lib/google/apis/container_v1/classes.rb', line 341 def update!(**args) @agent_sandbox_config = args[:agent_sandbox_config] if args.key?(:agent_sandbox_config) @cloud_run_config = args[:cloud_run_config] if args.key?(:cloud_run_config) @config_connector_config = args[:config_connector_config] if args.key?(:config_connector_config) @dns_cache_config = args[:dns_cache_config] if args.key?(:dns_cache_config) @gce_persistent_disk_csi_driver_config = args[:gce_persistent_disk_csi_driver_config] if args.key?(:gce_persistent_disk_csi_driver_config) @gcp_filestore_csi_driver_config = args[:gcp_filestore_csi_driver_config] if args.key?(:gcp_filestore_csi_driver_config) @gcs_fuse_csi_driver_config = args[:gcs_fuse_csi_driver_config] if args.key?(:gcs_fuse_csi_driver_config) @gke_backup_agent_config = args[:gke_backup_agent_config] if args.key?(:gke_backup_agent_config) @high_scale_checkpointing_config = args[:high_scale_checkpointing_config] if args.key?(:high_scale_checkpointing_config) @horizontal_pod_autoscaling = args[:horizontal_pod_autoscaling] if args.key?(:horizontal_pod_autoscaling) @http_load_balancing = args[:http_load_balancing] if args.key?(:http_load_balancing) @kubernetes_dashboard = args[:kubernetes_dashboard] if args.key?(:kubernetes_dashboard) @lustre_csi_driver_config = args[:lustre_csi_driver_config] if args.key?(:lustre_csi_driver_config) @network_policy_config = args[:network_policy_config] if args.key?(:network_policy_config) @node_readiness_config = args[:node_readiness_config] if args.key?(:node_readiness_config) @parallelstore_csi_driver_config = args[:parallelstore_csi_driver_config] if args.key?(:parallelstore_csi_driver_config) @pod_snapshot_config = args[:pod_snapshot_config] if args.key?(:pod_snapshot_config) @ray_operator_config = args[:ray_operator_config] if args.key?(:ray_operator_config) @slice_controller_config = args[:slice_controller_config] if args.key?(:slice_controller_config) @slurm_operator_config = args[:slurm_operator_config] if args.key?(:slurm_operator_config) @stateful_ha_config = args[:stateful_ha_config] if args.key?(:stateful_ha_config) end |