Class: Google::Apis::ContainerV1::AddonsConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

Configuration for the addons that can be automatically spun up in the cluster, enabling additional functionality.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AddonsConfig

Returns a new instance of AddonsConfig.



295
296
297
# File 'lib/google/apis/container_v1/classes.rb', line 295

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cloud_run_configGoogle::Apis::ContainerV1::CloudRunConfig

Configuration options for the Cloud Run feature. Corresponds to the JSON property cloudRunConfig



208
209
210
# File 'lib/google/apis/container_v1/classes.rb', line 208

def cloud_run_config
  @cloud_run_config
end

#config_connector_configGoogle::Apis::ContainerV1::ConfigConnectorConfig

Configuration options for the Config Connector add-on. Corresponds to the JSON property configConnectorConfig



213
214
215
# File 'lib/google/apis/container_v1/classes.rb', line 213

def config_connector_config
  @config_connector_config
end

#dns_cache_configGoogle::Apis::ContainerV1::DnsCacheConfig

Configuration for NodeLocal DNSCache Corresponds to the JSON property dnsCacheConfig



218
219
220
# File 'lib/google/apis/container_v1/classes.rb', line 218

def dns_cache_config
  @dns_cache_config
end

#gce_persistent_disk_csi_driver_configGoogle::Apis::ContainerV1::GcePersistentDiskCsiDriverConfig

Configuration for the Compute Engine PD CSI driver. Corresponds to the JSON property gcePersistentDiskCsiDriverConfig



223
224
225
# File 'lib/google/apis/container_v1/classes.rb', line 223

def gce_persistent_disk_csi_driver_config
  @gce_persistent_disk_csi_driver_config
end

#gcp_filestore_csi_driver_configGoogle::Apis::ContainerV1::GcpFilestoreCsiDriverConfig

Configuration for the Filestore CSI driver. Corresponds to the JSON property gcpFilestoreCsiDriverConfig



228
229
230
# File 'lib/google/apis/container_v1/classes.rb', line 228

def gcp_filestore_csi_driver_config
  @gcp_filestore_csi_driver_config
end

#gcs_fuse_csi_driver_configGoogle::Apis::ContainerV1::GcsFuseCsiDriverConfig

Configuration for the Cloud Storage Fuse CSI driver. Corresponds to the JSON property gcsFuseCsiDriverConfig



233
234
235
# File 'lib/google/apis/container_v1/classes.rb', line 233

def gcs_fuse_csi_driver_config
  @gcs_fuse_csi_driver_config
end

#gke_backup_agent_configGoogle::Apis::ContainerV1::GkeBackupAgentConfig

Configuration for the Backup for GKE Agent. Corresponds to the JSON property gkeBackupAgentConfig



238
239
240
# File 'lib/google/apis/container_v1/classes.rb', line 238

def gke_backup_agent_config
  @gke_backup_agent_config
end

#high_scale_checkpointing_configGoogle::Apis::ContainerV1::HighScaleCheckpointingConfig

Configuration for the High Scale Checkpointing. Corresponds to the JSON property highScaleCheckpointingConfig



243
244
245
# File 'lib/google/apis/container_v1/classes.rb', line 243

def high_scale_checkpointing_config
  @high_scale_checkpointing_config
end

#horizontal_pod_autoscalingGoogle::Apis::ContainerV1::HorizontalPodAutoscaling

Configuration options for the horizontal pod autoscaling feature, which increases or decreases the number of replica pods a replication controller has based on the resource usage of the existing pods. Corresponds to the JSON property horizontalPodAutoscaling



250
251
252
# File 'lib/google/apis/container_v1/classes.rb', line 250

def horizontal_pod_autoscaling
  @horizontal_pod_autoscaling
end

#http_load_balancingGoogle::Apis::ContainerV1::HttpLoadBalancing

Configuration options for the HTTP (L7) load balancing controller addon, which makes it easy to set up HTTP load balancers for services in a cluster. Corresponds to the JSON property httpLoadBalancing



256
257
258
# File 'lib/google/apis/container_v1/classes.rb', line 256

def http_load_balancing
  @http_load_balancing
end

#kubernetes_dashboardGoogle::Apis::ContainerV1::KubernetesDashboard

Configuration for the Kubernetes Dashboard. Corresponds to the JSON property kubernetesDashboard



261
262
263
# File 'lib/google/apis/container_v1/classes.rb', line 261

def kubernetes_dashboard
  @kubernetes_dashboard
end

#lustre_csi_driver_configGoogle::Apis::ContainerV1::LustreCsiDriverConfig

Configuration for the Lustre CSI driver. Corresponds to the JSON property lustreCsiDriverConfig



266
267
268
# File 'lib/google/apis/container_v1/classes.rb', line 266

def lustre_csi_driver_config
  @lustre_csi_driver_config
end

#network_policy_configGoogle::Apis::ContainerV1::NetworkPolicyConfig

Configuration for NetworkPolicy. This only tracks whether the addon is enabled or not on the Master, it does not track whether network policy is enabled for the nodes. Corresponds to the JSON property networkPolicyConfig



273
274
275
# File 'lib/google/apis/container_v1/classes.rb', line 273

def network_policy_config
  @network_policy_config
end

#parallelstore_csi_driver_configGoogle::Apis::ContainerV1::ParallelstoreCsiDriverConfig

Configuration for the Cloud Storage Parallelstore CSI driver. Corresponds to the JSON property parallelstoreCsiDriverConfig



278
279
280
# File 'lib/google/apis/container_v1/classes.rb', line 278

def parallelstore_csi_driver_config
  @parallelstore_csi_driver_config
end

#ray_operator_configGoogle::Apis::ContainerV1::RayOperatorConfig

Configuration options for the Ray Operator add-on. Corresponds to the JSON property rayOperatorConfig



283
284
285
# File 'lib/google/apis/container_v1/classes.rb', line 283

def ray_operator_config
  @ray_operator_config
end

#slice_controller_configGoogle::Apis::ContainerV1::SliceControllerConfig

Configuration for the Slice Controller. Corresponds to the JSON property sliceControllerConfig



288
289
290
# File 'lib/google/apis/container_v1/classes.rb', line 288

def slice_controller_config
  @slice_controller_config
end

#stateful_ha_configGoogle::Apis::ContainerV1::StatefulHaConfig

Configuration for the Stateful HA add-on. Corresponds to the JSON property statefulHaConfig



293
294
295
# File 'lib/google/apis/container_v1/classes.rb', line 293

def stateful_ha_config
  @stateful_ha_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
# File 'lib/google/apis/container_v1/classes.rb', line 300

def update!(**args)
  @cloud_run_config = args[:cloud_run_config] if args.key?(:cloud_run_config)
  @config_connector_config = args[:config_connector_config] if args.key?(:config_connector_config)
  @dns_cache_config = args[:dns_cache_config] if args.key?(:dns_cache_config)
  @gce_persistent_disk_csi_driver_config = args[:gce_persistent_disk_csi_driver_config] if args.key?(:gce_persistent_disk_csi_driver_config)
  @gcp_filestore_csi_driver_config = args[:gcp_filestore_csi_driver_config] if args.key?(:gcp_filestore_csi_driver_config)
  @gcs_fuse_csi_driver_config = args[:gcs_fuse_csi_driver_config] if args.key?(:gcs_fuse_csi_driver_config)
  @gke_backup_agent_config = args[:gke_backup_agent_config] if args.key?(:gke_backup_agent_config)
  @high_scale_checkpointing_config = args[:high_scale_checkpointing_config] if args.key?(:high_scale_checkpointing_config)
  @horizontal_pod_autoscaling = args[:horizontal_pod_autoscaling] if args.key?(:horizontal_pod_autoscaling)
  @http_load_balancing = args[:http_load_balancing] if args.key?(:http_load_balancing)
  @kubernetes_dashboard = args[:kubernetes_dashboard] if args.key?(:kubernetes_dashboard)
  @lustre_csi_driver_config = args[:lustre_csi_driver_config] if args.key?(:lustre_csi_driver_config)
  @network_policy_config = args[:network_policy_config] if args.key?(:network_policy_config)
  @parallelstore_csi_driver_config = args[:parallelstore_csi_driver_config] if args.key?(:parallelstore_csi_driver_config)
  @ray_operator_config = args[:ray_operator_config] if args.key?(:ray_operator_config)
  @slice_controller_config = args[:slice_controller_config] if args.key?(:slice_controller_config)
  @stateful_ha_config = args[:stateful_ha_config] if args.key?(:stateful_ha_config)
end