Class: Google::Apis::ContainerV1::AutoUpgradeOptions

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

AutoUpgradeOptions defines the set of options for the user to control how the Auto Upgrades will proceed.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AutoUpgradeOptions

Returns a new instance of AutoUpgradeOptions.



496
497
498
# File 'lib/google/apis/container_v1/classes.rb', line 496

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auto_upgrade_start_timeString

Output only. This field is set when upgrades are about to commence with the approximate start time for the upgrades, in RFC3339 text format. Corresponds to the JSON property autoUpgradeStartTime

Returns:

  • (String)


488
489
490
# File 'lib/google/apis/container_v1/classes.rb', line 488

def auto_upgrade_start_time
  @auto_upgrade_start_time
end

#descriptionString

Output only. This field is set when upgrades are about to commence with the description of the upgrade. Corresponds to the JSON property description

Returns:

  • (String)


494
495
496
# File 'lib/google/apis/container_v1/classes.rb', line 494

def description
  @description
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



501
502
503
504
# File 'lib/google/apis/container_v1/classes.rb', line 501

def update!(**args)
  @auto_upgrade_start_time = args[:auto_upgrade_start_time] if args.key?(:auto_upgrade_start_time)
  @description = args[:description] if args.key?(:description)
end