Class: Google::Apis::ContainerV1::AutoscaledRolloutPolicy
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1::AutoscaledRolloutPolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb
Overview
Autoscaled rollout policy utilizes the cluster autoscaler during blue-green upgrade to scale both the blue and green pools.
Instance Attribute Summary collapse
-
#wait_for_drain_duration ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AutoscaledRolloutPolicy
constructor
A new instance of AutoscaledRolloutPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AutoscaledRolloutPolicy
Returns a new instance of AutoscaledRolloutPolicy.
736 737 738 |
# File 'lib/google/apis/container_v1/classes.rb', line 736 def initialize(**args) update!(**args) end |
Instance Attribute Details
#wait_for_drain_duration ⇒ String
Optional. Time to wait after cordoning the blue pool before draining the nodes.
Defaults to 3 days. The value can be set between 0 and 7 days, inclusive.
Corresponds to the JSON property waitForDrainDuration
734 735 736 |
# File 'lib/google/apis/container_v1/classes.rb', line 734 def wait_for_drain_duration @wait_for_drain_duration end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
741 742 743 |
# File 'lib/google/apis/container_v1/classes.rb', line 741 def update!(**args) @wait_for_drain_duration = args[:wait_for_drain_duration] if args.key?(:wait_for_drain_duration) end |