Class: Google::Apis::ContainerV1::BlueGreenInfo
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1::BlueGreenInfo
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb
Overview
Information relevant to blue-green upgrade.
Instance Attribute Summary collapse
-
#blue_instance_group_urls ⇒ Array<String>
The resource URLs of the managed instance groups associated with blue pool.
-
#blue_pool_deletion_start_time ⇒ String
Time to start deleting blue pool to complete blue-green upgrade, in RFC3339 text format.
-
#green_instance_group_urls ⇒ Array<String>
The resource URLs of the managed instance groups associated with green pool.
-
#green_pool_version ⇒ String
Version of green pool.
-
#phase ⇒ String
Current blue-green upgrade phase.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BlueGreenInfo
constructor
A new instance of BlueGreenInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BlueGreenInfo
Returns a new instance of BlueGreenInfo.
939 940 941 |
# File 'lib/google/apis/container_v1/classes.rb', line 939 def initialize(**args) update!(**args) end |
Instance Attribute Details
#blue_instance_group_urls ⇒ Array<String>
The resource URLs of the managed instance groups associated with blue pool.
Corresponds to the JSON property blueInstanceGroupUrls
915 916 917 |
# File 'lib/google/apis/container_v1/classes.rb', line 915 def blue_instance_group_urls @blue_instance_group_urls end |
#blue_pool_deletion_start_time ⇒ String
Time to start deleting blue pool to complete blue-green upgrade, in RFC3339 text format.
Corresponds to the JSON property bluePoolDeletionStartTime
921 922 923 |
# File 'lib/google/apis/container_v1/classes.rb', line 921 def blue_pool_deletion_start_time @blue_pool_deletion_start_time end |
#green_instance_group_urls ⇒ Array<String>
The resource URLs of the managed instance groups associated with green pool.
Corresponds to the JSON property greenInstanceGroupUrls
927 928 929 |
# File 'lib/google/apis/container_v1/classes.rb', line 927 def green_instance_group_urls @green_instance_group_urls end |
#green_pool_version ⇒ String
Version of green pool.
Corresponds to the JSON property greenPoolVersion
932 933 934 |
# File 'lib/google/apis/container_v1/classes.rb', line 932 def green_pool_version @green_pool_version end |
#phase ⇒ String
Current blue-green upgrade phase.
Corresponds to the JSON property phase
937 938 939 |
# File 'lib/google/apis/container_v1/classes.rb', line 937 def phase @phase end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
944 945 946 947 948 949 950 |
# File 'lib/google/apis/container_v1/classes.rb', line 944 def update!(**args) @blue_instance_group_urls = args[:blue_instance_group_urls] if args.key?(:blue_instance_group_urls) @blue_pool_deletion_start_time = args[:blue_pool_deletion_start_time] if args.key?(:blue_pool_deletion_start_time) @green_instance_group_urls = args[:green_instance_group_urls] if args.key?(:green_instance_group_urls) @green_pool_version = args[:green_pool_version] if args.key?(:green_pool_version) @phase = args[:phase] if args.key?(:phase) end |