Class: Google::Apis::ContainerV1::CertificateConfigPair
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1::CertificateConfigPair
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb
Overview
CertificateConfigPair configures pairs of certificates, which is used for client certificate and key pairs under a registry.
Instance Attribute Summary collapse
-
#cert ⇒ Google::Apis::ContainerV1::CertificateConfig
CertificateConfig configures certificate for the registry.
-
#key ⇒ Google::Apis::ContainerV1::CertificateConfig
CertificateConfig configures certificate for the registry.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CertificateConfigPair
constructor
A new instance of CertificateConfigPair.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CertificateConfigPair
Returns a new instance of CertificateConfigPair.
1086 1087 1088 |
# File 'lib/google/apis/container_v1/classes.rb', line 1086 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cert ⇒ Google::Apis::ContainerV1::CertificateConfig
CertificateConfig configures certificate for the registry.
Corresponds to the JSON property cert
1079 1080 1081 |
# File 'lib/google/apis/container_v1/classes.rb', line 1079 def cert @cert end |
#key ⇒ Google::Apis::ContainerV1::CertificateConfig
CertificateConfig configures certificate for the registry.
Corresponds to the JSON property key
1084 1085 1086 |
# File 'lib/google/apis/container_v1/classes.rb', line 1084 def key @key end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1091 1092 1093 1094 |
# File 'lib/google/apis/container_v1/classes.rb', line 1091 def update!(**args) @cert = args[:cert] if args.key?(:cert) @key = args[:key] if args.key?(:key) end |