Class: Google::Apis::ContainerV1::ClusterAutoscaling

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

ClusterAutoscaling contains global, per-cluster information required by Cluster Autoscaler to automatically adjust the size of the cluster and create/ delete node pools based on the current needs.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ClusterAutoscaling

Returns a new instance of ClusterAutoscaling.



1801
1802
1803
# File 'lib/google/apis/container_v1/classes.rb', line 1801

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#autoprovisioning_locationsArray<String>

The list of Google Compute Engine zones in which the NodePool's nodes can be created by NAP. Corresponds to the JSON property autoprovisioningLocations

Returns:

  • (Array<String>)


1771
1772
1773
# File 'lib/google/apis/container_v1/classes.rb', line 1771

def autoprovisioning_locations
  @autoprovisioning_locations
end

#autoprovisioning_node_pool_defaultsGoogle::Apis::ContainerV1::AutoprovisioningNodePoolDefaults

AutoprovisioningNodePoolDefaults contains defaults for a node pool created by NAP. Corresponds to the JSON property autoprovisioningNodePoolDefaults



1777
1778
1779
# File 'lib/google/apis/container_v1/classes.rb', line 1777

def autoprovisioning_node_pool_defaults
  @autoprovisioning_node_pool_defaults
end

#autoscaling_profileString

Defines autoscaling behaviour. Corresponds to the JSON property autoscalingProfile

Returns:

  • (String)


1782
1783
1784
# File 'lib/google/apis/container_v1/classes.rb', line 1782

def autoscaling_profile
  @autoscaling_profile
end

#default_compute_class_configGoogle::Apis::ContainerV1::DefaultComputeClassConfig

DefaultComputeClassConfig defines default compute class configuration. Corresponds to the JSON property defaultComputeClassConfig



1787
1788
1789
# File 'lib/google/apis/container_v1/classes.rb', line 1787

def default_compute_class_config
  @default_compute_class_config
end

#enable_node_autoprovisioningBoolean Also known as: enable_node_autoprovisioning?

Enables automatic node pool creation and deletion. Corresponds to the JSON property enableNodeAutoprovisioning

Returns:

  • (Boolean)


1792
1793
1794
# File 'lib/google/apis/container_v1/classes.rb', line 1792

def enable_node_autoprovisioning
  @enable_node_autoprovisioning
end

#resource_limitsArray<Google::Apis::ContainerV1::ResourceLimit>

Contains global constraints regarding minimum and maximum amount of resources in the cluster. Corresponds to the JSON property resourceLimits



1799
1800
1801
# File 'lib/google/apis/container_v1/classes.rb', line 1799

def resource_limits
  @resource_limits
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1806
1807
1808
1809
1810
1811
1812
1813
# File 'lib/google/apis/container_v1/classes.rb', line 1806

def update!(**args)
  @autoprovisioning_locations = args[:autoprovisioning_locations] if args.key?(:autoprovisioning_locations)
  @autoprovisioning_node_pool_defaults = args[:autoprovisioning_node_pool_defaults] if args.key?(:autoprovisioning_node_pool_defaults)
  @autoscaling_profile = args[:autoscaling_profile] if args.key?(:autoscaling_profile)
  @default_compute_class_config = args[:default_compute_class_config] if args.key?(:default_compute_class_config)
  @enable_node_autoprovisioning = args[:enable_node_autoprovisioning] if args.key?(:enable_node_autoprovisioning)
  @resource_limits = args[:resource_limits] if args.key?(:resource_limits)
end