Class: Google::Apis::ContainerV1::ClusterUpdate
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1::ClusterUpdate
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb
Overview
ClusterUpdate describes an update to the cluster. Exactly one update can be applied to a cluster with each request, so at most one field can be provided.
Instance Attribute Summary collapse
-
#additional_pod_ranges_config ⇒ Google::Apis::ContainerV1::AdditionalPodRangesConfig
AdditionalPodRangesConfig is the configuration for additional pod secondary ranges supporting the ClusterUpdate message.
-
#desired_additional_ip_ranges_config ⇒ Google::Apis::ContainerV1::DesiredAdditionalIpRangesConfig
DesiredAdditionalIPRangesConfig is a wrapper used for cluster update operation and contains multiple AdditionalIPRangesConfigs.
-
#desired_addons_config ⇒ Google::Apis::ContainerV1::AddonsConfig
Configuration for the addons that can be automatically spun up in the cluster, enabling additional functionality.
-
#desired_anonymous_authentication_config ⇒ Google::Apis::ContainerV1::AnonymousAuthenticationConfig
AnonymousAuthenticationConfig defines the settings needed to limit endpoints that allow anonymous authentication.
-
#desired_authenticator_groups_config ⇒ Google::Apis::ContainerV1::AuthenticatorGroupsConfig
Configuration for returning group information from authenticators.
-
#desired_auto_ipam_config ⇒ Google::Apis::ContainerV1::AutoIpamConfig
AutoIpamConfig contains all information related to Auto IPAM Corresponds to the JSON property
desiredAutoIpamConfig. -
#desired_autopilot_cluster_policy_config ⇒ Google::Apis::ContainerV1::ClusterPolicyConfig
ClusterPolicyConfig stores the configuration for cluster wide policies.
-
#desired_autopilot_workload_policy_config ⇒ Google::Apis::ContainerV1::WorkloadPolicyConfig
WorkloadPolicyConfig is the configuration related to GCW workload policy Corresponds to the JSON property
desiredAutopilotWorkloadPolicyConfig. -
#desired_binary_authorization ⇒ Google::Apis::ContainerV1::BinaryAuthorization
Configuration for Binary Authorization.
-
#desired_cluster_autoscaling ⇒ Google::Apis::ContainerV1::ClusterAutoscaling
ClusterAutoscaling contains global, per-cluster information required by Cluster Autoscaler to automatically adjust the size of the cluster and create/ delete node pools based on the current needs.
-
#desired_compliance_posture_config ⇒ Google::Apis::ContainerV1::CompliancePostureConfig
Deprecated: Compliance Posture is no longer supported.
-
#desired_containerd_config ⇒ Google::Apis::ContainerV1::ContainerdConfig
ContainerdConfig contains configuration to customize containerd.
-
#desired_control_plane_egress ⇒ Google::Apis::ContainerV1::ControlPlaneEgress
ControlPlaneEgress defines the settings needed to enable control plane egress control.
-
#desired_control_plane_endpoints_config ⇒ Google::Apis::ContainerV1::ControlPlaneEndpointsConfig
Configuration for all of the cluster's control plane endpoints.
-
#desired_cost_management_config ⇒ Google::Apis::ContainerV1::CostManagementConfig
Configuration for fine-grained cost management feature.
-
#desired_database_encryption ⇒ Google::Apis::ContainerV1::DatabaseEncryption
Configuration of etcd encryption.
-
#desired_datapath_provider ⇒ String
The desired datapath provider for the cluster.
-
#desired_default_enable_private_nodes ⇒ Boolean
(also: #desired_default_enable_private_nodes?)
Override the default setting of whether future created nodes have private IP addresses only, namely NetworkConfig.default_enable_private_nodes Corresponds to the JSON property
desiredDefaultEnablePrivateNodes. -
#desired_default_snat_status ⇒ Google::Apis::ContainerV1::DefaultSnatStatus
DefaultSnatStatus contains the desired state of whether default sNAT should be disabled on the cluster.
-
#desired_disable_l4_lb_firewall_reconciliation ⇒ Boolean
(also: #desired_disable_l4_lb_firewall_reconciliation?)
Enable/Disable L4 LB VPC firewall reconciliation for the cluster.
-
#desired_dns_config ⇒ Google::Apis::ContainerV1::DnsConfig
DNSConfig contains the desired set of options for configuring clusterDNS.
-
#desired_enable_cilium_clusterwide_network_policy ⇒ Boolean
(also: #desired_enable_cilium_clusterwide_network_policy?)
Enable/Disable Cilium Clusterwide Network Policy for the cluster.
-
#desired_enable_fqdn_network_policy ⇒ Boolean
(also: #desired_enable_fqdn_network_policy?)
Enable/Disable FQDN Network Policy for the cluster.
-
#desired_enable_multi_networking ⇒ Boolean
(also: #desired_enable_multi_networking?)
Enable/Disable Multi-Networking for the cluster Corresponds to the JSON property
desiredEnableMultiNetworking. -
#desired_enable_private_endpoint ⇒ Boolean
(also: #desired_enable_private_endpoint?)
Enable/Disable private endpoint for the cluster's master.
-
#desired_enterprise_config ⇒ Google::Apis::ContainerV1::DesiredEnterpriseConfig
DesiredEnterpriseConfig is a wrapper used for updating enterprise_config.
-
#desired_fleet ⇒ Google::Apis::ContainerV1::Fleet
Fleet is the fleet configuration for the cluster.
-
#desired_gateway_api_config ⇒ Google::Apis::ContainerV1::GatewayApiConfig
GatewayAPIConfig contains the desired config of Gateway API on this cluster.
-
#desired_gcfs_config ⇒ Google::Apis::ContainerV1::GcfsConfig
GcfsConfig contains configurations of Google Container File System (image streaming).
-
#desired_identity_service_config ⇒ Google::Apis::ContainerV1::IdentityServiceConfig
IdentityServiceConfig is configuration for Identity Service which allows customers to use external identity providers with the K8S API Corresponds to the JSON property
desiredIdentityServiceConfig. -
#desired_image ⇒ String
The desired name of the image to use for this node.
-
#desired_image_project ⇒ String
The project containing the desired image to use for this node.
-
#desired_image_type ⇒ String
The desired image type for the node pool.
-
#desired_in_transit_encryption_config ⇒ String
Specify the details of in-transit encryption.
-
#desired_intra_node_visibility_config ⇒ Google::Apis::ContainerV1::IntraNodeVisibilityConfig
IntraNodeVisibilityConfig contains the desired config of the intra-node visibility on this cluster.
-
#desired_k8s_beta_apis ⇒ Google::Apis::ContainerV1::K8sBetaApiConfig
K8sBetaAPIConfig , configuration for beta APIs Corresponds to the JSON property
desiredK8sBetaApis. -
#desired_l4ilb_subsetting_config ⇒ Google::Apis::ContainerV1::IlbSubsettingConfig
ILBSubsettingConfig contains the desired config of L4 Internal LoadBalancer subsetting on this cluster.
-
#desired_locations ⇒ Array<String>
The desired list of Google Compute Engine zones in which the cluster's nodes should be located.
-
#desired_logging_config ⇒ Google::Apis::ContainerV1::LoggingConfig
LoggingConfig is cluster logging configuration.
-
#desired_logging_service ⇒ String
The logging service the cluster should use to write logs.
-
#desired_managed_machine_learning_diagnostics_config ⇒ Google::Apis::ContainerV1::ManagedMachineLearningDiagnosticsConfig
ManagedMachineLearningDiagnosticsConfig is the configuration for the GKE Managed Machine Learning Diagnostics pipeline.
-
#desired_managed_opentelemetry_config ⇒ Google::Apis::ContainerV1::ManagedOpenTelemetryConfig
ManagedOpenTelemetryConfig is the configuration for the GKE Managed OpenTelemetry pipeline.
-
#desired_master_authorized_networks_config ⇒ Google::Apis::ContainerV1::MasterAuthorizedNetworksConfig
Configuration options for the master authorized networks feature.
-
#desired_master_version ⇒ String
The Kubernetes version to change the master to.
-
#desired_mesh_certificates ⇒ Google::Apis::ContainerV1::MeshCertificates
Configuration for issuance of mTLS keys and certificates to Kubernetes pods.
-
#desired_monitoring_config ⇒ Google::Apis::ContainerV1::MonitoringConfig
MonitoringConfig is cluster monitoring configuration.
-
#desired_monitoring_service ⇒ String
The monitoring service the cluster should use to write metrics.
-
#desired_network_performance_config ⇒ Google::Apis::ContainerV1::ClusterNetworkPerformanceConfig
Configuration of network bandwidth tiers Corresponds to the JSON property
desiredNetworkPerformanceConfig. -
#desired_network_tier_config ⇒ Google::Apis::ContainerV1::NetworkTierConfig
NetworkTierConfig contains network tier information.
-
#desired_node_creation_config ⇒ Google::Apis::ContainerV1::NodeCreationConfig
NodeCreationConfig defines the settings of node creation mode.
-
#desired_node_kubelet_config ⇒ Google::Apis::ContainerV1::NodeKubeletConfig
Node kubelet configs.
-
#desired_node_pool_auto_config_kubelet_config ⇒ Google::Apis::ContainerV1::NodeKubeletConfig
Node kubelet configs.
-
#desired_node_pool_auto_config_linux_node_config ⇒ Google::Apis::ContainerV1::LinuxNodeConfig
Parameters that can be configured on Linux nodes.
-
#desired_node_pool_auto_config_network_tags ⇒ Google::Apis::ContainerV1::NetworkTags
Collection of Compute Engine network tags that can be applied to a node's underlying VM instance.
-
#desired_node_pool_auto_config_resource_manager_tags ⇒ Google::Apis::ContainerV1::ResourceManagerTags
A map of resource manager tag keys and values to be attached to the nodes for managing Compute Engine firewalls using Network Firewall Policies.
-
#desired_node_pool_autoscaling ⇒ Google::Apis::ContainerV1::NodePoolAutoscaling
NodePoolAutoscaling contains information required by cluster autoscaler to adjust the size of the node pool to the current cluster usage.
-
#desired_node_pool_id ⇒ String
The node pool to be upgraded.
-
#desired_node_pool_logging_config ⇒ Google::Apis::ContainerV1::NodePoolLoggingConfig
NodePoolLoggingConfig specifies logging configuration for node pools.
-
#desired_node_version ⇒ String
The Kubernetes version to change the nodes to (typically an upgrade).
-
#desired_notification_config ⇒ Google::Apis::ContainerV1::NotificationConfig
NotificationConfig is the configuration of notifications.
-
#desired_parent_product_config ⇒ Google::Apis::ContainerV1::ParentProductConfig
ParentProductConfig is the configuration of the parent product of the cluster.
-
#desired_pod_autoscaling ⇒ Google::Apis::ContainerV1::PodAutoscaling
PodAutoscaling is used for configuration of parameters for workload autoscaling.
-
#desired_private_cluster_config ⇒ Google::Apis::ContainerV1::PrivateClusterConfig
Configuration options for private clusters.
-
#desired_private_ipv6_google_access ⇒ String
The desired state of IPv6 connectivity to Google Services.
-
#desired_privileged_admission_config ⇒ Google::Apis::ContainerV1::PrivilegedAdmissionConfig
PrivilegedAdmissionConfig stores the list of authorized allowlist paths for the cluster.
-
#desired_rbac_binding_config ⇒ Google::Apis::ContainerV1::RbacBindingConfig
RBACBindingConfig allows user to restrict ClusterRoleBindings an RoleBindings that can be created.
-
#desired_release_channel ⇒ Google::Apis::ContainerV1::ReleaseChannel
ReleaseChannel indicates which release channel a cluster is subscribed to.
-
#desired_resource_usage_export_config ⇒ Google::Apis::ContainerV1::ResourceUsageExportConfig
Configuration for exporting cluster resource usages.
-
#desired_secret_manager_config ⇒ Google::Apis::ContainerV1::SecretManagerConfig
SecretManagerConfig is config for secret manager enablement.
-
#desired_secret_sync_config ⇒ Google::Apis::ContainerV1::SecretSyncConfig
Configuration for sync Secret Manager secrets as k8s secrets.
-
#desired_security_posture_config ⇒ Google::Apis::ContainerV1::SecurityPostureConfig
SecurityPostureConfig defines the flags needed to enable/disable features for the Security Posture API.
-
#desired_service_external_ips_config ⇒ Google::Apis::ContainerV1::ServiceExternalIPsConfig
Config to block services with externalIPs field.
-
#desired_shielded_nodes ⇒ Google::Apis::ContainerV1::ShieldedNodes
Configuration of Shielded Nodes feature.
-
#desired_stack_type ⇒ String
The desired stack type of the cluster.
-
#desired_user_managed_keys_config ⇒ Google::Apis::ContainerV1::UserManagedKeysConfig
UserManagedKeysConfig holds the resource address to Keys which are used for signing certs and token that are used for communication within cluster.
-
#desired_vertical_pod_autoscaling ⇒ Google::Apis::ContainerV1::VerticalPodAutoscaling
VerticalPodAutoscaling contains global, per-cluster information required by Vertical Pod Autoscaler to automatically adjust the resources of pods controlled by it.
-
#desired_workload_identity_config ⇒ Google::Apis::ContainerV1::WorkloadIdentityConfig
Configuration for the use of Kubernetes Service Accounts in IAM policies.
-
#enable_k8s_beta_apis ⇒ Google::Apis::ContainerV1::K8sBetaApiConfig
K8sBetaAPIConfig , configuration for beta APIs Corresponds to the JSON property
enableK8sBetaApis. -
#etag ⇒ String
The current etag of the cluster.
-
#gke_auto_upgrade_config ⇒ Google::Apis::ContainerV1::GkeAutoUpgradeConfig
GkeAutoUpgradeConfig is the configuration for GKE auto upgrades.
-
#removed_additional_pod_ranges_config ⇒ Google::Apis::ContainerV1::AdditionalPodRangesConfig
AdditionalPodRangesConfig is the configuration for additional pod secondary ranges supporting the ClusterUpdate message.
-
#user_managed_keys_config ⇒ Google::Apis::ContainerV1::UserManagedKeysConfig
UserManagedKeysConfig holds the resource address to Keys which are used for signing certs and token that are used for communication within cluster.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ClusterUpdate
constructor
A new instance of ClusterUpdate.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ClusterUpdate
Returns a new instance of ClusterUpdate.
2533 2534 2535 |
# File 'lib/google/apis/container_v1/classes.rb', line 2533 def initialize(**args) update!(**args) end |
Instance Attribute Details
#additional_pod_ranges_config ⇒ Google::Apis::ContainerV1::AdditionalPodRangesConfig
AdditionalPodRangesConfig is the configuration for additional pod secondary
ranges supporting the ClusterUpdate message.
Corresponds to the JSON property additionalPodRangesConfig
2036 2037 2038 |
# File 'lib/google/apis/container_v1/classes.rb', line 2036 def additional_pod_ranges_config @additional_pod_ranges_config end |
#desired_additional_ip_ranges_config ⇒ Google::Apis::ContainerV1::DesiredAdditionalIpRangesConfig
DesiredAdditionalIPRangesConfig is a wrapper used for cluster update operation
and contains multiple AdditionalIPRangesConfigs.
Corresponds to the JSON property desiredAdditionalIpRangesConfig
2042 2043 2044 |
# File 'lib/google/apis/container_v1/classes.rb', line 2042 def desired_additional_ip_ranges_config @desired_additional_ip_ranges_config end |
#desired_addons_config ⇒ Google::Apis::ContainerV1::AddonsConfig
Configuration for the addons that can be automatically spun up in the cluster,
enabling additional functionality.
Corresponds to the JSON property desiredAddonsConfig
2048 2049 2050 |
# File 'lib/google/apis/container_v1/classes.rb', line 2048 def desired_addons_config @desired_addons_config end |
#desired_anonymous_authentication_config ⇒ Google::Apis::ContainerV1::AnonymousAuthenticationConfig
AnonymousAuthenticationConfig defines the settings needed to limit endpoints
that allow anonymous authentication.
Corresponds to the JSON property desiredAnonymousAuthenticationConfig
2054 2055 2056 |
# File 'lib/google/apis/container_v1/classes.rb', line 2054 def desired_anonymous_authentication_config @desired_anonymous_authentication_config end |
#desired_authenticator_groups_config ⇒ Google::Apis::ContainerV1::AuthenticatorGroupsConfig
Configuration for returning group information from authenticators.
Corresponds to the JSON property desiredAuthenticatorGroupsConfig
2059 2060 2061 |
# File 'lib/google/apis/container_v1/classes.rb', line 2059 def desired_authenticator_groups_config @desired_authenticator_groups_config end |
#desired_auto_ipam_config ⇒ Google::Apis::ContainerV1::AutoIpamConfig
AutoIpamConfig contains all information related to Auto IPAM
Corresponds to the JSON property desiredAutoIpamConfig
2064 2065 2066 |
# File 'lib/google/apis/container_v1/classes.rb', line 2064 def desired_auto_ipam_config @desired_auto_ipam_config end |
#desired_autopilot_cluster_policy_config ⇒ Google::Apis::ContainerV1::ClusterPolicyConfig
ClusterPolicyConfig stores the configuration for cluster wide policies.
Corresponds to the JSON property desiredAutopilotClusterPolicyConfig
2069 2070 2071 |
# File 'lib/google/apis/container_v1/classes.rb', line 2069 def desired_autopilot_cluster_policy_config @desired_autopilot_cluster_policy_config end |
#desired_autopilot_workload_policy_config ⇒ Google::Apis::ContainerV1::WorkloadPolicyConfig
WorkloadPolicyConfig is the configuration related to GCW workload policy
Corresponds to the JSON property desiredAutopilotWorkloadPolicyConfig
2074 2075 2076 |
# File 'lib/google/apis/container_v1/classes.rb', line 2074 def desired_autopilot_workload_policy_config @desired_autopilot_workload_policy_config end |
#desired_binary_authorization ⇒ Google::Apis::ContainerV1::BinaryAuthorization
Configuration for Binary Authorization.
Corresponds to the JSON property desiredBinaryAuthorization
2079 2080 2081 |
# File 'lib/google/apis/container_v1/classes.rb', line 2079 def @desired_binary_authorization end |
#desired_cluster_autoscaling ⇒ Google::Apis::ContainerV1::ClusterAutoscaling
ClusterAutoscaling contains global, per-cluster information required by
Cluster Autoscaler to automatically adjust the size of the cluster and create/
delete node pools based on the current needs.
Corresponds to the JSON property desiredClusterAutoscaling
2086 2087 2088 |
# File 'lib/google/apis/container_v1/classes.rb', line 2086 def desired_cluster_autoscaling @desired_cluster_autoscaling end |
#desired_compliance_posture_config ⇒ Google::Apis::ContainerV1::CompliancePostureConfig
Deprecated: Compliance Posture is no longer supported. For more details, see
https://cloud.google.com/kubernetes-engine/docs/deprecations/posture-
management-deprecation. CompliancePostureConfig defines the settings needed to
enable/disable features for the Compliance Posture.
Corresponds to the JSON property desiredCompliancePostureConfig
2094 2095 2096 |
# File 'lib/google/apis/container_v1/classes.rb', line 2094 def desired_compliance_posture_config @desired_compliance_posture_config end |
#desired_containerd_config ⇒ Google::Apis::ContainerV1::ContainerdConfig
ContainerdConfig contains configuration to customize containerd.
Corresponds to the JSON property desiredContainerdConfig
2099 2100 2101 |
# File 'lib/google/apis/container_v1/classes.rb', line 2099 def desired_containerd_config @desired_containerd_config end |
#desired_control_plane_egress ⇒ Google::Apis::ContainerV1::ControlPlaneEgress
ControlPlaneEgress defines the settings needed to enable control plane egress
control.
Corresponds to the JSON property desiredControlPlaneEgress
2105 2106 2107 |
# File 'lib/google/apis/container_v1/classes.rb', line 2105 def desired_control_plane_egress @desired_control_plane_egress end |
#desired_control_plane_endpoints_config ⇒ Google::Apis::ContainerV1::ControlPlaneEndpointsConfig
Configuration for all of the cluster's control plane endpoints.
Corresponds to the JSON property desiredControlPlaneEndpointsConfig
2110 2111 2112 |
# File 'lib/google/apis/container_v1/classes.rb', line 2110 def desired_control_plane_endpoints_config @desired_control_plane_endpoints_config end |
#desired_cost_management_config ⇒ Google::Apis::ContainerV1::CostManagementConfig
Configuration for fine-grained cost management feature.
Corresponds to the JSON property desiredCostManagementConfig
2115 2116 2117 |
# File 'lib/google/apis/container_v1/classes.rb', line 2115 def desired_cost_management_config @desired_cost_management_config end |
#desired_database_encryption ⇒ Google::Apis::ContainerV1::DatabaseEncryption
Configuration of etcd encryption.
Corresponds to the JSON property desiredDatabaseEncryption
2120 2121 2122 |
# File 'lib/google/apis/container_v1/classes.rb', line 2120 def desired_database_encryption @desired_database_encryption end |
#desired_datapath_provider ⇒ String
The desired datapath provider for the cluster.
Corresponds to the JSON property desiredDatapathProvider
2125 2126 2127 |
# File 'lib/google/apis/container_v1/classes.rb', line 2125 def desired_datapath_provider @desired_datapath_provider end |
#desired_default_enable_private_nodes ⇒ Boolean Also known as: desired_default_enable_private_nodes?
Override the default setting of whether future created nodes have private IP
addresses only, namely NetworkConfig.default_enable_private_nodes
Corresponds to the JSON property desiredDefaultEnablePrivateNodes
2131 2132 2133 |
# File 'lib/google/apis/container_v1/classes.rb', line 2131 def desired_default_enable_private_nodes @desired_default_enable_private_nodes end |
#desired_default_snat_status ⇒ Google::Apis::ContainerV1::DefaultSnatStatus
DefaultSnatStatus contains the desired state of whether default sNAT should be
disabled on the cluster.
Corresponds to the JSON property desiredDefaultSnatStatus
2138 2139 2140 |
# File 'lib/google/apis/container_v1/classes.rb', line 2138 def desired_default_snat_status @desired_default_snat_status end |
#desired_disable_l4_lb_firewall_reconciliation ⇒ Boolean Also known as: desired_disable_l4_lb_firewall_reconciliation?
Enable/Disable L4 LB VPC firewall reconciliation for the cluster.
Corresponds to the JSON property desiredDisableL4LbFirewallReconciliation
2143 2144 2145 |
# File 'lib/google/apis/container_v1/classes.rb', line 2143 def desired_disable_l4_lb_firewall_reconciliation @desired_disable_l4_lb_firewall_reconciliation end |
#desired_dns_config ⇒ Google::Apis::ContainerV1::DnsConfig
DNSConfig contains the desired set of options for configuring clusterDNS.
Corresponds to the JSON property desiredDnsConfig
2149 2150 2151 |
# File 'lib/google/apis/container_v1/classes.rb', line 2149 def desired_dns_config @desired_dns_config end |
#desired_enable_cilium_clusterwide_network_policy ⇒ Boolean Also known as: desired_enable_cilium_clusterwide_network_policy?
Enable/Disable Cilium Clusterwide Network Policy for the cluster.
Corresponds to the JSON property desiredEnableCiliumClusterwideNetworkPolicy
2154 2155 2156 |
# File 'lib/google/apis/container_v1/classes.rb', line 2154 def desired_enable_cilium_clusterwide_network_policy @desired_enable_cilium_clusterwide_network_policy end |
#desired_enable_fqdn_network_policy ⇒ Boolean Also known as: desired_enable_fqdn_network_policy?
Enable/Disable FQDN Network Policy for the cluster.
Corresponds to the JSON property desiredEnableFqdnNetworkPolicy
2160 2161 2162 |
# File 'lib/google/apis/container_v1/classes.rb', line 2160 def desired_enable_fqdn_network_policy @desired_enable_fqdn_network_policy end |
#desired_enable_multi_networking ⇒ Boolean Also known as: desired_enable_multi_networking?
Enable/Disable Multi-Networking for the cluster
Corresponds to the JSON property desiredEnableMultiNetworking
2166 2167 2168 |
# File 'lib/google/apis/container_v1/classes.rb', line 2166 def desired_enable_multi_networking @desired_enable_multi_networking end |
#desired_enable_private_endpoint ⇒ Boolean Also known as: desired_enable_private_endpoint?
Enable/Disable private endpoint for the cluster's master. Deprecated: Use
desired_control_plane_endpoints_config.ip_endpoints_config.
enable_public_endpoint instead. Note that the value of enable_public_endpoint
is reversed: if enable_private_endpoint is false, then enable_public_endpoint
will be true.
Corresponds to the JSON property desiredEnablePrivateEndpoint
2176 2177 2178 |
# File 'lib/google/apis/container_v1/classes.rb', line 2176 def desired_enable_private_endpoint @desired_enable_private_endpoint end |
#desired_enterprise_config ⇒ Google::Apis::ContainerV1::DesiredEnterpriseConfig
DesiredEnterpriseConfig is a wrapper used for updating enterprise_config.
Deprecated: GKE Enterprise features are now available without an Enterprise
tier.
Corresponds to the JSON property desiredEnterpriseConfig
2184 2185 2186 |
# File 'lib/google/apis/container_v1/classes.rb', line 2184 def desired_enterprise_config @desired_enterprise_config end |
#desired_fleet ⇒ Google::Apis::ContainerV1::Fleet
Fleet is the fleet configuration for the cluster.
Corresponds to the JSON property desiredFleet
2189 2190 2191 |
# File 'lib/google/apis/container_v1/classes.rb', line 2189 def desired_fleet @desired_fleet end |
#desired_gateway_api_config ⇒ Google::Apis::ContainerV1::GatewayApiConfig
GatewayAPIConfig contains the desired config of Gateway API on this cluster.
Corresponds to the JSON property desiredGatewayApiConfig
2194 2195 2196 |
# File 'lib/google/apis/container_v1/classes.rb', line 2194 def desired_gateway_api_config @desired_gateway_api_config end |
#desired_gcfs_config ⇒ Google::Apis::ContainerV1::GcfsConfig
GcfsConfig contains configurations of Google Container File System (image
streaming).
Corresponds to the JSON property desiredGcfsConfig
2200 2201 2202 |
# File 'lib/google/apis/container_v1/classes.rb', line 2200 def desired_gcfs_config @desired_gcfs_config end |
#desired_identity_service_config ⇒ Google::Apis::ContainerV1::IdentityServiceConfig
IdentityServiceConfig is configuration for Identity Service which allows
customers to use external identity providers with the K8S API
Corresponds to the JSON property desiredIdentityServiceConfig
2206 2207 2208 |
# File 'lib/google/apis/container_v1/classes.rb', line 2206 def desired_identity_service_config @desired_identity_service_config end |
#desired_image ⇒ String
The desired name of the image to use for this node. This is used to create
clusters using a custom image. NOTE: Set the "desired_node_pool" field as well.
Corresponds to the JSON property desiredImage
2212 2213 2214 |
# File 'lib/google/apis/container_v1/classes.rb', line 2212 def desired_image @desired_image end |
#desired_image_project ⇒ String
The project containing the desired image to use for this node. This is used to
create clusters using a custom image. NOTE: Set the "desired_node_pool" field
as well.
Corresponds to the JSON property desiredImageProject
2219 2220 2221 |
# File 'lib/google/apis/container_v1/classes.rb', line 2219 def desired_image_project @desired_image_project end |
#desired_image_type ⇒ String
The desired image type for the node pool. NOTE: Set the "desired_node_pool"
field as well.
Corresponds to the JSON property desiredImageType
2225 2226 2227 |
# File 'lib/google/apis/container_v1/classes.rb', line 2225 def desired_image_type @desired_image_type end |
#desired_in_transit_encryption_config ⇒ String
Specify the details of in-transit encryption.
Corresponds to the JSON property desiredInTransitEncryptionConfig
2230 2231 2232 |
# File 'lib/google/apis/container_v1/classes.rb', line 2230 def desired_in_transit_encryption_config @desired_in_transit_encryption_config end |
#desired_intra_node_visibility_config ⇒ Google::Apis::ContainerV1::IntraNodeVisibilityConfig
IntraNodeVisibilityConfig contains the desired config of the intra-node
visibility on this cluster.
Corresponds to the JSON property desiredIntraNodeVisibilityConfig
2236 2237 2238 |
# File 'lib/google/apis/container_v1/classes.rb', line 2236 def desired_intra_node_visibility_config @desired_intra_node_visibility_config end |
#desired_k8s_beta_apis ⇒ Google::Apis::ContainerV1::K8sBetaApiConfig
K8sBetaAPIConfig , configuration for beta APIs
Corresponds to the JSON property desiredK8sBetaApis
2241 2242 2243 |
# File 'lib/google/apis/container_v1/classes.rb', line 2241 def desired_k8s_beta_apis @desired_k8s_beta_apis end |
#desired_l4ilb_subsetting_config ⇒ Google::Apis::ContainerV1::IlbSubsettingConfig
ILBSubsettingConfig contains the desired config of L4 Internal LoadBalancer
subsetting on this cluster.
Corresponds to the JSON property desiredL4ilbSubsettingConfig
2247 2248 2249 |
# File 'lib/google/apis/container_v1/classes.rb', line 2247 def desired_l4ilb_subsetting_config @desired_l4ilb_subsetting_config end |
#desired_locations ⇒ Array<String>
The desired list of Google Compute Engine zones in which the cluster's nodes should be located.
This list must always include the cluster's primary zone. Warning: changing
cluster locations will update the locations of all node pools and will result
in nodes being added and/or removed.
Corresponds to the JSON property desiredLocations
2256 2257 2258 |
# File 'lib/google/apis/container_v1/classes.rb', line 2256 def desired_locations @desired_locations end |
#desired_logging_config ⇒ Google::Apis::ContainerV1::LoggingConfig
LoggingConfig is cluster logging configuration.
Corresponds to the JSON property desiredLoggingConfig
2261 2262 2263 |
# File 'lib/google/apis/container_v1/classes.rb', line 2261 def desired_logging_config @desired_logging_config end |
#desired_logging_service ⇒ String
The logging service the cluster should use to write logs. Currently available
options: * logging.googleapis.com/kubernetes - The Cloud Logging service
with a Kubernetes-native resource model * logging.googleapis.com - The
legacy Cloud Logging service (no longer available as of GKE 1.15). * none -
no logs will be exported from the cluster. If left as an empty string,logging.
googleapis.com/kubernetes will be used for GKE 1.14+ or logging.googleapis.
com for earlier versions.
Corresponds to the JSON property desiredLoggingService
2272 2273 2274 |
# File 'lib/google/apis/container_v1/classes.rb', line 2272 def desired_logging_service @desired_logging_service end |
#desired_managed_machine_learning_diagnostics_config ⇒ Google::Apis::ContainerV1::ManagedMachineLearningDiagnosticsConfig
ManagedMachineLearningDiagnosticsConfig is the configuration for the GKE
Managed Machine Learning Diagnostics pipeline.
Corresponds to the JSON property desiredManagedMachineLearningDiagnosticsConfig
2278 2279 2280 |
# File 'lib/google/apis/container_v1/classes.rb', line 2278 def desired_managed_machine_learning_diagnostics_config @desired_managed_machine_learning_diagnostics_config end |
#desired_managed_opentelemetry_config ⇒ Google::Apis::ContainerV1::ManagedOpenTelemetryConfig
ManagedOpenTelemetryConfig is the configuration for the GKE Managed
OpenTelemetry pipeline.
Corresponds to the JSON property desiredManagedOpentelemetryConfig
2284 2285 2286 |
# File 'lib/google/apis/container_v1/classes.rb', line 2284 def desired_managed_opentelemetry_config @desired_managed_opentelemetry_config end |
#desired_master_authorized_networks_config ⇒ Google::Apis::ContainerV1::MasterAuthorizedNetworksConfig
Configuration options for the master authorized networks feature. Enabled
master authorized networks will disallow all external traffic to access
Kubernetes master through HTTPS except traffic from the given CIDR blocks,
Google Compute Engine Public IPs and Google Prod IPs.
Corresponds to the JSON property desiredMasterAuthorizedNetworksConfig
2292 2293 2294 |
# File 'lib/google/apis/container_v1/classes.rb', line 2292 def @desired_master_authorized_networks_config end |
#desired_master_version ⇒ String
The Kubernetes version to change the master to. Users may specify either explicit versions offered by Kubernetes Engine or version aliases, which have the following behavior: - "latest": picks the highest valid Kubernetes version
- "1.X": picks the highest valid patch+gke.N patch in the 1.X version - "1.X.Y"
: picks the highest valid gke.N patch in the 1.X.Y version - "1.X.Y-gke.N":
picks an explicit Kubernetes version - "-": picks the default Kubernetes
version
Corresponds to the JSON property
desiredMasterVersion
2303 2304 2305 |
# File 'lib/google/apis/container_v1/classes.rb', line 2303 def desired_master_version @desired_master_version end |
#desired_mesh_certificates ⇒ Google::Apis::ContainerV1::MeshCertificates
Configuration for issuance of mTLS keys and certificates to Kubernetes pods.
Corresponds to the JSON property desiredMeshCertificates
2308 2309 2310 |
# File 'lib/google/apis/container_v1/classes.rb', line 2308 def desired_mesh_certificates @desired_mesh_certificates end |
#desired_monitoring_config ⇒ Google::Apis::ContainerV1::MonitoringConfig
MonitoringConfig is cluster monitoring configuration.
Corresponds to the JSON property desiredMonitoringConfig
2313 2314 2315 |
# File 'lib/google/apis/container_v1/classes.rb', line 2313 def desired_monitoring_config @desired_monitoring_config end |
#desired_monitoring_service ⇒ String
The monitoring service the cluster should use to write metrics. Currently
available options: * monitoring.googleapis.com/kubernetes - The Cloud
Monitoring service with a Kubernetes-native resource model * monitoring.
googleapis.com - The legacy Cloud Monitoring service (no longer available as
of GKE 1.15). * none - No metrics will be exported from the cluster. If left
as an empty string,monitoring.googleapis.com/kubernetes will be used for GKE
1.14+ or monitoring.googleapis.com for earlier versions.
Corresponds to the JSON property desiredMonitoringService
2324 2325 2326 |
# File 'lib/google/apis/container_v1/classes.rb', line 2324 def desired_monitoring_service @desired_monitoring_service end |
#desired_network_performance_config ⇒ Google::Apis::ContainerV1::ClusterNetworkPerformanceConfig
Configuration of network bandwidth tiers
Corresponds to the JSON property desiredNetworkPerformanceConfig
2329 2330 2331 |
# File 'lib/google/apis/container_v1/classes.rb', line 2329 def desired_network_performance_config @desired_network_performance_config end |
#desired_network_tier_config ⇒ Google::Apis::ContainerV1::NetworkTierConfig
NetworkTierConfig contains network tier information.
Corresponds to the JSON property desiredNetworkTierConfig
2334 2335 2336 |
# File 'lib/google/apis/container_v1/classes.rb', line 2334 def desired_network_tier_config @desired_network_tier_config end |
#desired_node_creation_config ⇒ Google::Apis::ContainerV1::NodeCreationConfig
NodeCreationConfig defines the settings of node creation mode.
Corresponds to the JSON property desiredNodeCreationConfig
2339 2340 2341 |
# File 'lib/google/apis/container_v1/classes.rb', line 2339 def desired_node_creation_config @desired_node_creation_config end |
#desired_node_kubelet_config ⇒ Google::Apis::ContainerV1::NodeKubeletConfig
Node kubelet configs.
Corresponds to the JSON property desiredNodeKubeletConfig
2344 2345 2346 |
# File 'lib/google/apis/container_v1/classes.rb', line 2344 def desired_node_kubelet_config @desired_node_kubelet_config end |
#desired_node_pool_auto_config_kubelet_config ⇒ Google::Apis::ContainerV1::NodeKubeletConfig
Node kubelet configs.
Corresponds to the JSON property desiredNodePoolAutoConfigKubeletConfig
2349 2350 2351 |
# File 'lib/google/apis/container_v1/classes.rb', line 2349 def desired_node_pool_auto_config_kubelet_config @desired_node_pool_auto_config_kubelet_config end |
#desired_node_pool_auto_config_linux_node_config ⇒ Google::Apis::ContainerV1::LinuxNodeConfig
Parameters that can be configured on Linux nodes.
Corresponds to the JSON property desiredNodePoolAutoConfigLinuxNodeConfig
2354 2355 2356 |
# File 'lib/google/apis/container_v1/classes.rb', line 2354 def desired_node_pool_auto_config_linux_node_config @desired_node_pool_auto_config_linux_node_config end |
#desired_node_pool_auto_config_network_tags ⇒ Google::Apis::ContainerV1::NetworkTags
Collection of Compute Engine network tags that can be applied to a node's
underlying VM instance.
Corresponds to the JSON property desiredNodePoolAutoConfigNetworkTags
2360 2361 2362 |
# File 'lib/google/apis/container_v1/classes.rb', line 2360 def @desired_node_pool_auto_config_network_tags end |
#desired_node_pool_auto_config_resource_manager_tags ⇒ Google::Apis::ContainerV1::ResourceManagerTags
A map of resource manager tag keys and values to be attached to the nodes for
managing Compute Engine firewalls using Network Firewall Policies. Tags must
be according to specifications in https://cloud.google.com/vpc/docs/tags-
firewalls-overview#specifications. A maximum of 5 tag key-value pairs can be
specified. Existing tags will be replaced with new values.
Corresponds to the JSON property desiredNodePoolAutoConfigResourceManagerTags
2369 2370 2371 |
# File 'lib/google/apis/container_v1/classes.rb', line 2369 def @desired_node_pool_auto_config_resource_manager_tags end |
#desired_node_pool_autoscaling ⇒ Google::Apis::ContainerV1::NodePoolAutoscaling
NodePoolAutoscaling contains information required by cluster autoscaler to
adjust the size of the node pool to the current cluster usage.
Corresponds to the JSON property desiredNodePoolAutoscaling
2375 2376 2377 |
# File 'lib/google/apis/container_v1/classes.rb', line 2375 def desired_node_pool_autoscaling @desired_node_pool_autoscaling end |
#desired_node_pool_id ⇒ String
The node pool to be upgraded. This field is mandatory if "desired_node_version"
, "desired_image_family" or "desired_node_pool_autoscaling" is specified and
there is more than one node pool on the cluster.
Corresponds to the JSON property desiredNodePoolId
2382 2383 2384 |
# File 'lib/google/apis/container_v1/classes.rb', line 2382 def desired_node_pool_id @desired_node_pool_id end |
#desired_node_pool_logging_config ⇒ Google::Apis::ContainerV1::NodePoolLoggingConfig
NodePoolLoggingConfig specifies logging configuration for node pools.
Corresponds to the JSON property desiredNodePoolLoggingConfig
2387 2388 2389 |
# File 'lib/google/apis/container_v1/classes.rb', line 2387 def desired_node_pool_logging_config @desired_node_pool_logging_config end |
#desired_node_version ⇒ String
The Kubernetes version to change the nodes to (typically an upgrade). Users
may specify either explicit versions offered by Kubernetes Engine or version
aliases, which have the following behavior: - "latest": picks the highest
valid Kubernetes version - "1.X": picks the highest valid patch+gke.N patch in
the 1.X version - "1.X.Y": picks the highest valid gke.N patch in the 1.X.Y
version - "1.X.Y-gke.N": picks an explicit Kubernetes version - "-": picks the
Kubernetes master version
Corresponds to the JSON property desiredNodeVersion
2398 2399 2400 |
# File 'lib/google/apis/container_v1/classes.rb', line 2398 def desired_node_version @desired_node_version end |
#desired_notification_config ⇒ Google::Apis::ContainerV1::NotificationConfig
NotificationConfig is the configuration of notifications.
Corresponds to the JSON property desiredNotificationConfig
2403 2404 2405 |
# File 'lib/google/apis/container_v1/classes.rb', line 2403 def desired_notification_config @desired_notification_config end |
#desired_parent_product_config ⇒ Google::Apis::ContainerV1::ParentProductConfig
ParentProductConfig is the configuration of the parent product of the cluster.
This field is used by Google internal products that are built on top of a GKE
cluster and take the ownership of the cluster.
Corresponds to the JSON property desiredParentProductConfig
2410 2411 2412 |
# File 'lib/google/apis/container_v1/classes.rb', line 2410 def desired_parent_product_config @desired_parent_product_config end |
#desired_pod_autoscaling ⇒ Google::Apis::ContainerV1::PodAutoscaling
PodAutoscaling is used for configuration of parameters for workload
autoscaling.
Corresponds to the JSON property desiredPodAutoscaling
2416 2417 2418 |
# File 'lib/google/apis/container_v1/classes.rb', line 2416 def desired_pod_autoscaling @desired_pod_autoscaling end |
#desired_private_cluster_config ⇒ Google::Apis::ContainerV1::PrivateClusterConfig
Configuration options for private clusters.
Corresponds to the JSON property desiredPrivateClusterConfig
2421 2422 2423 |
# File 'lib/google/apis/container_v1/classes.rb', line 2421 def desired_private_cluster_config @desired_private_cluster_config end |
#desired_private_ipv6_google_access ⇒ String
The desired state of IPv6 connectivity to Google Services.
Corresponds to the JSON property desiredPrivateIpv6GoogleAccess
2426 2427 2428 |
# File 'lib/google/apis/container_v1/classes.rb', line 2426 def desired_private_ipv6_google_access @desired_private_ipv6_google_access end |
#desired_privileged_admission_config ⇒ Google::Apis::ContainerV1::PrivilegedAdmissionConfig
PrivilegedAdmissionConfig stores the list of authorized allowlist paths for
the cluster.
Corresponds to the JSON property desiredPrivilegedAdmissionConfig
2432 2433 2434 |
# File 'lib/google/apis/container_v1/classes.rb', line 2432 def desired_privileged_admission_config @desired_privileged_admission_config end |
#desired_rbac_binding_config ⇒ Google::Apis::ContainerV1::RbacBindingConfig
RBACBindingConfig allows user to restrict ClusterRoleBindings an RoleBindings
that can be created.
Corresponds to the JSON property desiredRbacBindingConfig
2438 2439 2440 |
# File 'lib/google/apis/container_v1/classes.rb', line 2438 def desired_rbac_binding_config @desired_rbac_binding_config end |
#desired_release_channel ⇒ Google::Apis::ContainerV1::ReleaseChannel
ReleaseChannel indicates which release channel a cluster is subscribed to.
Release channels are arranged in order of risk. When a cluster is subscribed
to a release channel, Google maintains both the master version and the node
version. Node auto-upgrade defaults to true and cannot be disabled.
Corresponds to the JSON property desiredReleaseChannel
2446 2447 2448 |
# File 'lib/google/apis/container_v1/classes.rb', line 2446 def desired_release_channel @desired_release_channel end |
#desired_resource_usage_export_config ⇒ Google::Apis::ContainerV1::ResourceUsageExportConfig
Configuration for exporting cluster resource usages.
Corresponds to the JSON property desiredResourceUsageExportConfig
2451 2452 2453 |
# File 'lib/google/apis/container_v1/classes.rb', line 2451 def desired_resource_usage_export_config @desired_resource_usage_export_config end |
#desired_secret_manager_config ⇒ Google::Apis::ContainerV1::SecretManagerConfig
SecretManagerConfig is config for secret manager enablement.
Corresponds to the JSON property desiredSecretManagerConfig
2456 2457 2458 |
# File 'lib/google/apis/container_v1/classes.rb', line 2456 def desired_secret_manager_config @desired_secret_manager_config end |
#desired_secret_sync_config ⇒ Google::Apis::ContainerV1::SecretSyncConfig
Configuration for sync Secret Manager secrets as k8s secrets.
Corresponds to the JSON property desiredSecretSyncConfig
2461 2462 2463 |
# File 'lib/google/apis/container_v1/classes.rb', line 2461 def desired_secret_sync_config @desired_secret_sync_config end |
#desired_security_posture_config ⇒ Google::Apis::ContainerV1::SecurityPostureConfig
SecurityPostureConfig defines the flags needed to enable/disable features for
the Security Posture API.
Corresponds to the JSON property desiredSecurityPostureConfig
2467 2468 2469 |
# File 'lib/google/apis/container_v1/classes.rb', line 2467 def desired_security_posture_config @desired_security_posture_config end |
#desired_service_external_ips_config ⇒ Google::Apis::ContainerV1::ServiceExternalIPsConfig
Config to block services with externalIPs field.
Corresponds to the JSON property desiredServiceExternalIpsConfig
2472 2473 2474 |
# File 'lib/google/apis/container_v1/classes.rb', line 2472 def desired_service_external_ips_config @desired_service_external_ips_config end |
#desired_shielded_nodes ⇒ Google::Apis::ContainerV1::ShieldedNodes
Configuration of Shielded Nodes feature.
Corresponds to the JSON property desiredShieldedNodes
2477 2478 2479 |
# File 'lib/google/apis/container_v1/classes.rb', line 2477 def desired_shielded_nodes @desired_shielded_nodes end |
#desired_stack_type ⇒ String
The desired stack type of the cluster. If a stack type is provided and does
not match the current stack type of the cluster, update will attempt to change
the stack type to the new type.
Corresponds to the JSON property desiredStackType
2484 2485 2486 |
# File 'lib/google/apis/container_v1/classes.rb', line 2484 def desired_stack_type @desired_stack_type end |
#desired_user_managed_keys_config ⇒ Google::Apis::ContainerV1::UserManagedKeysConfig
UserManagedKeysConfig holds the resource address to Keys which are used for
signing certs and token that are used for communication within cluster.
Corresponds to the JSON property desiredUserManagedKeysConfig
2490 2491 2492 |
# File 'lib/google/apis/container_v1/classes.rb', line 2490 def desired_user_managed_keys_config @desired_user_managed_keys_config end |
#desired_vertical_pod_autoscaling ⇒ Google::Apis::ContainerV1::VerticalPodAutoscaling
VerticalPodAutoscaling contains global, per-cluster information required by
Vertical Pod Autoscaler to automatically adjust the resources of pods
controlled by it.
Corresponds to the JSON property desiredVerticalPodAutoscaling
2497 2498 2499 |
# File 'lib/google/apis/container_v1/classes.rb', line 2497 def desired_vertical_pod_autoscaling @desired_vertical_pod_autoscaling end |
#desired_workload_identity_config ⇒ Google::Apis::ContainerV1::WorkloadIdentityConfig
Configuration for the use of Kubernetes Service Accounts in IAM policies.
Corresponds to the JSON property desiredWorkloadIdentityConfig
2502 2503 2504 |
# File 'lib/google/apis/container_v1/classes.rb', line 2502 def desired_workload_identity_config @desired_workload_identity_config end |
#enable_k8s_beta_apis ⇒ Google::Apis::ContainerV1::K8sBetaApiConfig
K8sBetaAPIConfig , configuration for beta APIs
Corresponds to the JSON property enableK8sBetaApis
2507 2508 2509 |
# File 'lib/google/apis/container_v1/classes.rb', line 2507 def enable_k8s_beta_apis @enable_k8s_beta_apis end |
#etag ⇒ String
The current etag of the cluster. If an etag is provided and does not match the
current etag of the cluster, update will be blocked and an ABORTED error will
be returned.
Corresponds to the JSON property etag
2514 2515 2516 |
# File 'lib/google/apis/container_v1/classes.rb', line 2514 def etag @etag end |
#gke_auto_upgrade_config ⇒ Google::Apis::ContainerV1::GkeAutoUpgradeConfig
GkeAutoUpgradeConfig is the configuration for GKE auto upgrades.
Corresponds to the JSON property gkeAutoUpgradeConfig
2519 2520 2521 |
# File 'lib/google/apis/container_v1/classes.rb', line 2519 def gke_auto_upgrade_config @gke_auto_upgrade_config end |
#removed_additional_pod_ranges_config ⇒ Google::Apis::ContainerV1::AdditionalPodRangesConfig
AdditionalPodRangesConfig is the configuration for additional pod secondary
ranges supporting the ClusterUpdate message.
Corresponds to the JSON property removedAdditionalPodRangesConfig
2525 2526 2527 |
# File 'lib/google/apis/container_v1/classes.rb', line 2525 def removed_additional_pod_ranges_config @removed_additional_pod_ranges_config end |
#user_managed_keys_config ⇒ Google::Apis::ContainerV1::UserManagedKeysConfig
UserManagedKeysConfig holds the resource address to Keys which are used for
signing certs and token that are used for communication within cluster.
Corresponds to the JSON property userManagedKeysConfig
2531 2532 2533 |
# File 'lib/google/apis/container_v1/classes.rb', line 2531 def user_managed_keys_config @user_managed_keys_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2538 2539 2540 2541 2542 2543 2544 2545 2546 2547 2548 2549 2550 2551 2552 2553 2554 2555 2556 2557 2558 2559 2560 2561 2562 2563 2564 2565 2566 2567 2568 2569 2570 2571 2572 2573 2574 2575 2576 2577 2578 2579 2580 2581 2582 2583 2584 2585 2586 2587 2588 2589 2590 2591 2592 2593 2594 2595 2596 2597 2598 2599 2600 2601 2602 2603 2604 2605 2606 2607 2608 2609 2610 2611 2612 2613 2614 2615 2616 2617 2618 2619 2620 2621 |
# File 'lib/google/apis/container_v1/classes.rb', line 2538 def update!(**args) @additional_pod_ranges_config = args[:additional_pod_ranges_config] if args.key?(:additional_pod_ranges_config) @desired_additional_ip_ranges_config = args[:desired_additional_ip_ranges_config] if args.key?(:desired_additional_ip_ranges_config) @desired_addons_config = args[:desired_addons_config] if args.key?(:desired_addons_config) @desired_anonymous_authentication_config = args[:desired_anonymous_authentication_config] if args.key?(:desired_anonymous_authentication_config) @desired_authenticator_groups_config = args[:desired_authenticator_groups_config] if args.key?(:desired_authenticator_groups_config) @desired_auto_ipam_config = args[:desired_auto_ipam_config] if args.key?(:desired_auto_ipam_config) @desired_autopilot_cluster_policy_config = args[:desired_autopilot_cluster_policy_config] if args.key?(:desired_autopilot_cluster_policy_config) @desired_autopilot_workload_policy_config = args[:desired_autopilot_workload_policy_config] if args.key?(:desired_autopilot_workload_policy_config) @desired_binary_authorization = args[:desired_binary_authorization] if args.key?(:desired_binary_authorization) @desired_cluster_autoscaling = args[:desired_cluster_autoscaling] if args.key?(:desired_cluster_autoscaling) @desired_compliance_posture_config = args[:desired_compliance_posture_config] if args.key?(:desired_compliance_posture_config) @desired_containerd_config = args[:desired_containerd_config] if args.key?(:desired_containerd_config) @desired_control_plane_egress = args[:desired_control_plane_egress] if args.key?(:desired_control_plane_egress) @desired_control_plane_endpoints_config = args[:desired_control_plane_endpoints_config] if args.key?(:desired_control_plane_endpoints_config) @desired_cost_management_config = args[:desired_cost_management_config] if args.key?(:desired_cost_management_config) @desired_database_encryption = args[:desired_database_encryption] if args.key?(:desired_database_encryption) @desired_datapath_provider = args[:desired_datapath_provider] if args.key?(:desired_datapath_provider) @desired_default_enable_private_nodes = args[:desired_default_enable_private_nodes] if args.key?(:desired_default_enable_private_nodes) @desired_default_snat_status = args[:desired_default_snat_status] if args.key?(:desired_default_snat_status) @desired_disable_l4_lb_firewall_reconciliation = args[:desired_disable_l4_lb_firewall_reconciliation] if args.key?(:desired_disable_l4_lb_firewall_reconciliation) @desired_dns_config = args[:desired_dns_config] if args.key?(:desired_dns_config) @desired_enable_cilium_clusterwide_network_policy = args[:desired_enable_cilium_clusterwide_network_policy] if args.key?(:desired_enable_cilium_clusterwide_network_policy) @desired_enable_fqdn_network_policy = args[:desired_enable_fqdn_network_policy] if args.key?(:desired_enable_fqdn_network_policy) @desired_enable_multi_networking = args[:desired_enable_multi_networking] if args.key?(:desired_enable_multi_networking) @desired_enable_private_endpoint = args[:desired_enable_private_endpoint] if args.key?(:desired_enable_private_endpoint) @desired_enterprise_config = args[:desired_enterprise_config] if args.key?(:desired_enterprise_config) @desired_fleet = args[:desired_fleet] if args.key?(:desired_fleet) @desired_gateway_api_config = args[:desired_gateway_api_config] if args.key?(:desired_gateway_api_config) @desired_gcfs_config = args[:desired_gcfs_config] if args.key?(:desired_gcfs_config) @desired_identity_service_config = args[:desired_identity_service_config] if args.key?(:desired_identity_service_config) @desired_image = args[:desired_image] if args.key?(:desired_image) @desired_image_project = args[:desired_image_project] if args.key?(:desired_image_project) @desired_image_type = args[:desired_image_type] if args.key?(:desired_image_type) @desired_in_transit_encryption_config = args[:desired_in_transit_encryption_config] if args.key?(:desired_in_transit_encryption_config) @desired_intra_node_visibility_config = args[:desired_intra_node_visibility_config] if args.key?(:desired_intra_node_visibility_config) @desired_k8s_beta_apis = args[:desired_k8s_beta_apis] if args.key?(:desired_k8s_beta_apis) @desired_l4ilb_subsetting_config = args[:desired_l4ilb_subsetting_config] if args.key?(:desired_l4ilb_subsetting_config) @desired_locations = args[:desired_locations] if args.key?(:desired_locations) @desired_logging_config = args[:desired_logging_config] if args.key?(:desired_logging_config) @desired_logging_service = args[:desired_logging_service] if args.key?(:desired_logging_service) @desired_managed_machine_learning_diagnostics_config = args[:desired_managed_machine_learning_diagnostics_config] if args.key?(:desired_managed_machine_learning_diagnostics_config) @desired_managed_opentelemetry_config = args[:desired_managed_opentelemetry_config] if args.key?(:desired_managed_opentelemetry_config) @desired_master_authorized_networks_config = args[:desired_master_authorized_networks_config] if args.key?(:desired_master_authorized_networks_config) @desired_master_version = args[:desired_master_version] if args.key?(:desired_master_version) @desired_mesh_certificates = args[:desired_mesh_certificates] if args.key?(:desired_mesh_certificates) @desired_monitoring_config = args[:desired_monitoring_config] if args.key?(:desired_monitoring_config) @desired_monitoring_service = args[:desired_monitoring_service] if args.key?(:desired_monitoring_service) @desired_network_performance_config = args[:desired_network_performance_config] if args.key?(:desired_network_performance_config) @desired_network_tier_config = args[:desired_network_tier_config] if args.key?(:desired_network_tier_config) @desired_node_creation_config = args[:desired_node_creation_config] if args.key?(:desired_node_creation_config) @desired_node_kubelet_config = args[:desired_node_kubelet_config] if args.key?(:desired_node_kubelet_config) @desired_node_pool_auto_config_kubelet_config = args[:desired_node_pool_auto_config_kubelet_config] if args.key?(:desired_node_pool_auto_config_kubelet_config) @desired_node_pool_auto_config_linux_node_config = args[:desired_node_pool_auto_config_linux_node_config] if args.key?(:desired_node_pool_auto_config_linux_node_config) @desired_node_pool_auto_config_network_tags = args[:desired_node_pool_auto_config_network_tags] if args.key?(:desired_node_pool_auto_config_network_tags) @desired_node_pool_auto_config_resource_manager_tags = args[:desired_node_pool_auto_config_resource_manager_tags] if args.key?(:desired_node_pool_auto_config_resource_manager_tags) @desired_node_pool_autoscaling = args[:desired_node_pool_autoscaling] if args.key?(:desired_node_pool_autoscaling) @desired_node_pool_id = args[:desired_node_pool_id] if args.key?(:desired_node_pool_id) @desired_node_pool_logging_config = args[:desired_node_pool_logging_config] if args.key?(:desired_node_pool_logging_config) @desired_node_version = args[:desired_node_version] if args.key?(:desired_node_version) @desired_notification_config = args[:desired_notification_config] if args.key?(:desired_notification_config) @desired_parent_product_config = args[:desired_parent_product_config] if args.key?(:desired_parent_product_config) @desired_pod_autoscaling = args[:desired_pod_autoscaling] if args.key?(:desired_pod_autoscaling) @desired_private_cluster_config = args[:desired_private_cluster_config] if args.key?(:desired_private_cluster_config) @desired_private_ipv6_google_access = args[:desired_private_ipv6_google_access] if args.key?(:desired_private_ipv6_google_access) @desired_privileged_admission_config = args[:desired_privileged_admission_config] if args.key?(:desired_privileged_admission_config) @desired_rbac_binding_config = args[:desired_rbac_binding_config] if args.key?(:desired_rbac_binding_config) @desired_release_channel = args[:desired_release_channel] if args.key?(:desired_release_channel) @desired_resource_usage_export_config = args[:desired_resource_usage_export_config] if args.key?(:desired_resource_usage_export_config) @desired_secret_manager_config = args[:desired_secret_manager_config] if args.key?(:desired_secret_manager_config) @desired_secret_sync_config = args[:desired_secret_sync_config] if args.key?(:desired_secret_sync_config) @desired_security_posture_config = args[:desired_security_posture_config] if args.key?(:desired_security_posture_config) @desired_service_external_ips_config = args[:desired_service_external_ips_config] if args.key?(:desired_service_external_ips_config) @desired_shielded_nodes = args[:desired_shielded_nodes] if args.key?(:desired_shielded_nodes) @desired_stack_type = args[:desired_stack_type] if args.key?(:desired_stack_type) @desired_user_managed_keys_config = args[:desired_user_managed_keys_config] if args.key?(:desired_user_managed_keys_config) @desired_vertical_pod_autoscaling = args[:desired_vertical_pod_autoscaling] if args.key?(:desired_vertical_pod_autoscaling) @desired_workload_identity_config = args[:desired_workload_identity_config] if args.key?(:desired_workload_identity_config) @enable_k8s_beta_apis = args[:enable_k8s_beta_apis] if args.key?(:enable_k8s_beta_apis) @etag = args[:etag] if args.key?(:etag) @gke_auto_upgrade_config = args[:gke_auto_upgrade_config] if args.key?(:gke_auto_upgrade_config) @removed_additional_pod_ranges_config = args[:removed_additional_pod_ranges_config] if args.key?(:removed_additional_pod_ranges_config) @user_managed_keys_config = args[:user_managed_keys_config] if args.key?(:user_managed_keys_config) end |