Class: Google::Apis::ContainerV1::ClusterUpdate

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

ClusterUpdate describes an update to the cluster. Exactly one update can be applied to a cluster with each request, so at most one field can be provided.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ClusterUpdate

Returns a new instance of ClusterUpdate.



2299
2300
2301
# File 'lib/google/apis/container_v1/classes.rb', line 2299

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#additional_pod_ranges_configGoogle::Apis::ContainerV1::AdditionalPodRangesConfig

AdditionalPodRangesConfig is the configuration for additional pod secondary ranges supporting the ClusterUpdate message. Corresponds to the JSON property additionalPodRangesConfig



1844
1845
1846
# File 'lib/google/apis/container_v1/classes.rb', line 1844

def additional_pod_ranges_config
  @additional_pod_ranges_config
end

#desired_additional_ip_ranges_configGoogle::Apis::ContainerV1::DesiredAdditionalIpRangesConfig

DesiredAdditionalIPRangesConfig is a wrapper used for cluster update operation and contains multiple AdditionalIPRangesConfigs. Corresponds to the JSON property desiredAdditionalIpRangesConfig



1850
1851
1852
# File 'lib/google/apis/container_v1/classes.rb', line 1850

def desired_additional_ip_ranges_config
  @desired_additional_ip_ranges_config
end

#desired_addons_configGoogle::Apis::ContainerV1::AddonsConfig

Configuration for the addons that can be automatically spun up in the cluster, enabling additional functionality. Corresponds to the JSON property desiredAddonsConfig



1856
1857
1858
# File 'lib/google/apis/container_v1/classes.rb', line 1856

def desired_addons_config
  @desired_addons_config
end

#desired_anonymous_authentication_configGoogle::Apis::ContainerV1::AnonymousAuthenticationConfig

AnonymousAuthenticationConfig defines the settings needed to limit endpoints that allow anonymous authentication. Corresponds to the JSON property desiredAnonymousAuthenticationConfig



1862
1863
1864
# File 'lib/google/apis/container_v1/classes.rb', line 1862

def desired_anonymous_authentication_config
  @desired_anonymous_authentication_config
end

#desired_authenticator_groups_configGoogle::Apis::ContainerV1::AuthenticatorGroupsConfig

Configuration for returning group information from authenticators. Corresponds to the JSON property desiredAuthenticatorGroupsConfig



1867
1868
1869
# File 'lib/google/apis/container_v1/classes.rb', line 1867

def desired_authenticator_groups_config
  @desired_authenticator_groups_config
end

#desired_auto_ipam_configGoogle::Apis::ContainerV1::AutoIpamConfig

AutoIpamConfig contains all information related to Auto IPAM Corresponds to the JSON property desiredAutoIpamConfig



1872
1873
1874
# File 'lib/google/apis/container_v1/classes.rb', line 1872

def desired_auto_ipam_config
  @desired_auto_ipam_config
end

#desired_autopilot_workload_policy_configGoogle::Apis::ContainerV1::WorkloadPolicyConfig

WorkloadPolicyConfig is the configuration related to GCW workload policy Corresponds to the JSON property desiredAutopilotWorkloadPolicyConfig



1877
1878
1879
# File 'lib/google/apis/container_v1/classes.rb', line 1877

def desired_autopilot_workload_policy_config
  @desired_autopilot_workload_policy_config
end

#desired_binary_authorizationGoogle::Apis::ContainerV1::BinaryAuthorization

Configuration for Binary Authorization. Corresponds to the JSON property desiredBinaryAuthorization



1882
1883
1884
# File 'lib/google/apis/container_v1/classes.rb', line 1882

def desired_binary_authorization
  @desired_binary_authorization
end

#desired_cluster_autoscalingGoogle::Apis::ContainerV1::ClusterAutoscaling

ClusterAutoscaling contains global, per-cluster information required by Cluster Autoscaler to automatically adjust the size of the cluster and create/ delete node pools based on the current needs. Corresponds to the JSON property desiredClusterAutoscaling



1889
1890
1891
# File 'lib/google/apis/container_v1/classes.rb', line 1889

def desired_cluster_autoscaling
  @desired_cluster_autoscaling
end

#desired_compliance_posture_configGoogle::Apis::ContainerV1::CompliancePostureConfig

CompliancePostureConfig defines the settings needed to enable/disable features for the Compliance Posture. Corresponds to the JSON property desiredCompliancePostureConfig



1895
1896
1897
# File 'lib/google/apis/container_v1/classes.rb', line 1895

def desired_compliance_posture_config
  @desired_compliance_posture_config
end

#desired_containerd_configGoogle::Apis::ContainerV1::ContainerdConfig

ContainerdConfig contains configuration to customize containerd. Corresponds to the JSON property desiredContainerdConfig



1900
1901
1902
# File 'lib/google/apis/container_v1/classes.rb', line 1900

def desired_containerd_config
  @desired_containerd_config
end

#desired_control_plane_endpoints_configGoogle::Apis::ContainerV1::ControlPlaneEndpointsConfig

Configuration for all of the cluster's control plane endpoints. Corresponds to the JSON property desiredControlPlaneEndpointsConfig



1905
1906
1907
# File 'lib/google/apis/container_v1/classes.rb', line 1905

def desired_control_plane_endpoints_config
  @desired_control_plane_endpoints_config
end

#desired_cost_management_configGoogle::Apis::ContainerV1::CostManagementConfig

Configuration for fine-grained cost management feature. Corresponds to the JSON property desiredCostManagementConfig



1910
1911
1912
# File 'lib/google/apis/container_v1/classes.rb', line 1910

def desired_cost_management_config
  @desired_cost_management_config
end

#desired_database_encryptionGoogle::Apis::ContainerV1::DatabaseEncryption

Configuration of etcd encryption. Corresponds to the JSON property desiredDatabaseEncryption



1915
1916
1917
# File 'lib/google/apis/container_v1/classes.rb', line 1915

def desired_database_encryption
  @desired_database_encryption
end

#desired_datapath_providerString

The desired datapath provider for the cluster. Corresponds to the JSON property desiredDatapathProvider

Returns:

  • (String)


1920
1921
1922
# File 'lib/google/apis/container_v1/classes.rb', line 1920

def desired_datapath_provider
  @desired_datapath_provider
end

#desired_default_enable_private_nodesBoolean Also known as: desired_default_enable_private_nodes?

Override the default setting of whether future created nodes have private IP addresses only, namely NetworkConfig.default_enable_private_nodes Corresponds to the JSON property desiredDefaultEnablePrivateNodes

Returns:

  • (Boolean)


1926
1927
1928
# File 'lib/google/apis/container_v1/classes.rb', line 1926

def desired_default_enable_private_nodes
  @desired_default_enable_private_nodes
end

#desired_default_snat_statusGoogle::Apis::ContainerV1::DefaultSnatStatus

DefaultSnatStatus contains the desired state of whether default sNAT should be disabled on the cluster. Corresponds to the JSON property desiredDefaultSnatStatus



1933
1934
1935
# File 'lib/google/apis/container_v1/classes.rb', line 1933

def desired_default_snat_status
  @desired_default_snat_status
end

#desired_disable_l4_lb_firewall_reconciliationBoolean Also known as: desired_disable_l4_lb_firewall_reconciliation?

Enable/Disable L4 LB VPC firewall reconciliation for the cluster. Corresponds to the JSON property desiredDisableL4LbFirewallReconciliation

Returns:

  • (Boolean)


1938
1939
1940
# File 'lib/google/apis/container_v1/classes.rb', line 1938

def desired_disable_l4_lb_firewall_reconciliation
  @desired_disable_l4_lb_firewall_reconciliation
end

#desired_dns_configGoogle::Apis::ContainerV1::DnsConfig

DNSConfig contains the desired set of options for configuring clusterDNS. Corresponds to the JSON property desiredDnsConfig



1944
1945
1946
# File 'lib/google/apis/container_v1/classes.rb', line 1944

def desired_dns_config
  @desired_dns_config
end

#desired_enable_cilium_clusterwide_network_policyBoolean Also known as: desired_enable_cilium_clusterwide_network_policy?

Enable/Disable Cilium Clusterwide Network Policy for the cluster. Corresponds to the JSON property desiredEnableCiliumClusterwideNetworkPolicy

Returns:

  • (Boolean)


1949
1950
1951
# File 'lib/google/apis/container_v1/classes.rb', line 1949

def desired_enable_cilium_clusterwide_network_policy
  @desired_enable_cilium_clusterwide_network_policy
end

#desired_enable_fqdn_network_policyBoolean Also known as: desired_enable_fqdn_network_policy?

Enable/Disable FQDN Network Policy for the cluster. Corresponds to the JSON property desiredEnableFqdnNetworkPolicy

Returns:

  • (Boolean)


1955
1956
1957
# File 'lib/google/apis/container_v1/classes.rb', line 1955

def desired_enable_fqdn_network_policy
  @desired_enable_fqdn_network_policy
end

#desired_enable_multi_networkingBoolean Also known as: desired_enable_multi_networking?

Enable/Disable Multi-Networking for the cluster Corresponds to the JSON property desiredEnableMultiNetworking

Returns:

  • (Boolean)


1961
1962
1963
# File 'lib/google/apis/container_v1/classes.rb', line 1961

def desired_enable_multi_networking
  @desired_enable_multi_networking
end

#desired_enable_private_endpointBoolean Also known as: desired_enable_private_endpoint?

Enable/Disable private endpoint for the cluster's master. Deprecated: Use desired_control_plane_endpoints_config.ip_endpoints_config. enable_public_endpoint instead. Note that the value of enable_public_endpoint is reversed: if enable_private_endpoint is false, then enable_public_endpoint will be true. Corresponds to the JSON property desiredEnablePrivateEndpoint

Returns:

  • (Boolean)


1971
1972
1973
# File 'lib/google/apis/container_v1/classes.rb', line 1971

def desired_enable_private_endpoint
  @desired_enable_private_endpoint
end

#desired_enterprise_configGoogle::Apis::ContainerV1::DesiredEnterpriseConfig

DesiredEnterpriseConfig is a wrapper used for updating enterprise_config. Deprecated: GKE Enterprise features are now available without an Enterprise tier. Corresponds to the JSON property desiredEnterpriseConfig



1979
1980
1981
# File 'lib/google/apis/container_v1/classes.rb', line 1979

def desired_enterprise_config
  @desired_enterprise_config
end

#desired_fleetGoogle::Apis::ContainerV1::Fleet

Fleet is the fleet configuration for the cluster. Corresponds to the JSON property desiredFleet



1984
1985
1986
# File 'lib/google/apis/container_v1/classes.rb', line 1984

def desired_fleet
  @desired_fleet
end

#desired_gateway_api_configGoogle::Apis::ContainerV1::GatewayApiConfig

GatewayAPIConfig contains the desired config of Gateway API on this cluster. Corresponds to the JSON property desiredGatewayApiConfig



1989
1990
1991
# File 'lib/google/apis/container_v1/classes.rb', line 1989

def desired_gateway_api_config
  @desired_gateway_api_config
end

#desired_gcfs_configGoogle::Apis::ContainerV1::GcfsConfig

GcfsConfig contains configurations of Google Container File System (image streaming). Corresponds to the JSON property desiredGcfsConfig



1995
1996
1997
# File 'lib/google/apis/container_v1/classes.rb', line 1995

def desired_gcfs_config
  @desired_gcfs_config
end

#desired_identity_service_configGoogle::Apis::ContainerV1::IdentityServiceConfig

IdentityServiceConfig is configuration for Identity Service which allows customers to use external identity providers with the K8S API Corresponds to the JSON property desiredIdentityServiceConfig



2001
2002
2003
# File 'lib/google/apis/container_v1/classes.rb', line 2001

def desired_identity_service_config
  @desired_identity_service_config
end

#desired_image_typeString

The desired image type for the node pool. NOTE: Set the "desired_node_pool" field as well. Corresponds to the JSON property desiredImageType

Returns:

  • (String)


2007
2008
2009
# File 'lib/google/apis/container_v1/classes.rb', line 2007

def desired_image_type
  @desired_image_type
end

#desired_in_transit_encryption_configString

Specify the details of in-transit encryption. Corresponds to the JSON property desiredInTransitEncryptionConfig

Returns:

  • (String)


2012
2013
2014
# File 'lib/google/apis/container_v1/classes.rb', line 2012

def desired_in_transit_encryption_config
  @desired_in_transit_encryption_config
end

#desired_intra_node_visibility_configGoogle::Apis::ContainerV1::IntraNodeVisibilityConfig

IntraNodeVisibilityConfig contains the desired config of the intra-node visibility on this cluster. Corresponds to the JSON property desiredIntraNodeVisibilityConfig



2018
2019
2020
# File 'lib/google/apis/container_v1/classes.rb', line 2018

def desired_intra_node_visibility_config
  @desired_intra_node_visibility_config
end

#desired_k8s_beta_apisGoogle::Apis::ContainerV1::K8sBetaApiConfig

K8sBetaAPIConfig , configuration for beta APIs Corresponds to the JSON property desiredK8sBetaApis



2023
2024
2025
# File 'lib/google/apis/container_v1/classes.rb', line 2023

def desired_k8s_beta_apis
  @desired_k8s_beta_apis
end

#desired_l4ilb_subsetting_configGoogle::Apis::ContainerV1::IlbSubsettingConfig

ILBSubsettingConfig contains the desired config of L4 Internal LoadBalancer subsetting on this cluster. Corresponds to the JSON property desiredL4ilbSubsettingConfig



2029
2030
2031
# File 'lib/google/apis/container_v1/classes.rb', line 2029

def desired_l4ilb_subsetting_config
  @desired_l4ilb_subsetting_config
end

#desired_locationsArray<String>

The desired list of Google Compute Engine zones in which the cluster's nodes should be located. This list must always include the cluster's primary zone. Warning: changing cluster locations will update the locations of all node pools and will result in nodes being added and/or removed. Corresponds to the JSON property desiredLocations

Returns:

  • (Array<String>)


2038
2039
2040
# File 'lib/google/apis/container_v1/classes.rb', line 2038

def desired_locations
  @desired_locations
end

#desired_logging_configGoogle::Apis::ContainerV1::LoggingConfig

LoggingConfig is cluster logging configuration. Corresponds to the JSON property desiredLoggingConfig



2043
2044
2045
# File 'lib/google/apis/container_v1/classes.rb', line 2043

def desired_logging_config
  @desired_logging_config
end

#desired_logging_serviceString

The logging service the cluster should use to write logs. Currently available options: * logging.googleapis.com/kubernetes - The Cloud Logging service with a Kubernetes-native resource model * logging.googleapis.com - The legacy Cloud Logging service (no longer available as of GKE 1.15). * none - no logs will be exported from the cluster. If left as an empty string,logging. googleapis.com/kubernetes will be used for GKE 1.14+ or logging.googleapis. com for earlier versions. Corresponds to the JSON property desiredLoggingService

Returns:

  • (String)


2054
2055
2056
# File 'lib/google/apis/container_v1/classes.rb', line 2054

def desired_logging_service
  @desired_logging_service
end

#desired_managed_opentelemetry_configGoogle::Apis::ContainerV1::ManagedOpenTelemetryConfig

ManagedOpenTelemetryConfig is the configuration for the GKE Managed OpenTelemetry pipeline. Corresponds to the JSON property desiredManagedOpentelemetryConfig



2060
2061
2062
# File 'lib/google/apis/container_v1/classes.rb', line 2060

def desired_managed_opentelemetry_config
  @desired_managed_opentelemetry_config
end

#desired_master_authorized_networks_configGoogle::Apis::ContainerV1::MasterAuthorizedNetworksConfig

Configuration options for the master authorized networks feature. Enabled master authorized networks will disallow all external traffic to access Kubernetes master through HTTPS except traffic from the given CIDR blocks, Google Compute Engine Public IPs and Google Prod IPs. Corresponds to the JSON property desiredMasterAuthorizedNetworksConfig



2068
2069
2070
# File 'lib/google/apis/container_v1/classes.rb', line 2068

def desired_master_authorized_networks_config
  @desired_master_authorized_networks_config
end

#desired_master_versionString

The Kubernetes version to change the master to. Users may specify either explicit versions offered by Kubernetes Engine or version aliases, which have the following behavior: - "latest": picks the highest valid Kubernetes version

  • "1.X": picks the highest valid patch+gke.N patch in the 1.X version - "1.X.Y" : picks the highest valid gke.N patch in the 1.X.Y version - "1.X.Y-gke.N": picks an explicit Kubernetes version - "-": picks the default Kubernetes version Corresponds to the JSON property desiredMasterVersion

Returns:

  • (String)


2079
2080
2081
# File 'lib/google/apis/container_v1/classes.rb', line 2079

def desired_master_version
  @desired_master_version
end

#desired_mesh_certificatesGoogle::Apis::ContainerV1::MeshCertificates

Configuration for issuance of mTLS keys and certificates to Kubernetes pods. Corresponds to the JSON property desiredMeshCertificates



2084
2085
2086
# File 'lib/google/apis/container_v1/classes.rb', line 2084

def desired_mesh_certificates
  @desired_mesh_certificates
end

#desired_monitoring_configGoogle::Apis::ContainerV1::MonitoringConfig

MonitoringConfig is cluster monitoring configuration. Corresponds to the JSON property desiredMonitoringConfig



2089
2090
2091
# File 'lib/google/apis/container_v1/classes.rb', line 2089

def desired_monitoring_config
  @desired_monitoring_config
end

#desired_monitoring_serviceString

The monitoring service the cluster should use to write metrics. Currently available options: * monitoring.googleapis.com/kubernetes - The Cloud Monitoring service with a Kubernetes-native resource model * monitoring. googleapis.com - The legacy Cloud Monitoring service (no longer available as of GKE 1.15). * none - No metrics will be exported from the cluster. If left as an empty string,monitoring.googleapis.com/kubernetes will be used for GKE 1.14+ or monitoring.googleapis.com for earlier versions. Corresponds to the JSON property desiredMonitoringService

Returns:

  • (String)


2100
2101
2102
# File 'lib/google/apis/container_v1/classes.rb', line 2100

def desired_monitoring_service
  @desired_monitoring_service
end

#desired_network_performance_configGoogle::Apis::ContainerV1::ClusterNetworkPerformanceConfig

Configuration of network bandwidth tiers Corresponds to the JSON property desiredNetworkPerformanceConfig



2105
2106
2107
# File 'lib/google/apis/container_v1/classes.rb', line 2105

def desired_network_performance_config
  @desired_network_performance_config
end

#desired_network_tier_configGoogle::Apis::ContainerV1::NetworkTierConfig

NetworkTierConfig contains network tier information. Corresponds to the JSON property desiredNetworkTierConfig



2110
2111
2112
# File 'lib/google/apis/container_v1/classes.rb', line 2110

def desired_network_tier_config
  @desired_network_tier_config
end

#desired_node_kubelet_configGoogle::Apis::ContainerV1::NodeKubeletConfig

Node kubelet configs. Corresponds to the JSON property desiredNodeKubeletConfig



2115
2116
2117
# File 'lib/google/apis/container_v1/classes.rb', line 2115

def desired_node_kubelet_config
  @desired_node_kubelet_config
end

#desired_node_pool_auto_config_kubelet_configGoogle::Apis::ContainerV1::NodeKubeletConfig

Node kubelet configs. Corresponds to the JSON property desiredNodePoolAutoConfigKubeletConfig



2120
2121
2122
# File 'lib/google/apis/container_v1/classes.rb', line 2120

def desired_node_pool_auto_config_kubelet_config
  @desired_node_pool_auto_config_kubelet_config
end

#desired_node_pool_auto_config_linux_node_configGoogle::Apis::ContainerV1::LinuxNodeConfig

Parameters that can be configured on Linux nodes. Corresponds to the JSON property desiredNodePoolAutoConfigLinuxNodeConfig



2125
2126
2127
# File 'lib/google/apis/container_v1/classes.rb', line 2125

def desired_node_pool_auto_config_linux_node_config
  @desired_node_pool_auto_config_linux_node_config
end

#desired_node_pool_auto_config_network_tagsGoogle::Apis::ContainerV1::NetworkTags

Collection of Compute Engine network tags that can be applied to a node's underlying VM instance. Corresponds to the JSON property desiredNodePoolAutoConfigNetworkTags



2131
2132
2133
# File 'lib/google/apis/container_v1/classes.rb', line 2131

def desired_node_pool_auto_config_network_tags
  @desired_node_pool_auto_config_network_tags
end

#desired_node_pool_auto_config_resource_manager_tagsGoogle::Apis::ContainerV1::ResourceManagerTags

A map of resource manager tag keys and values to be attached to the nodes for managing Compute Engine firewalls using Network Firewall Policies. Tags must be according to specifications in https://cloud.google.com/vpc/docs/tags- firewalls-overview#specifications. A maximum of 5 tag key-value pairs can be specified. Existing tags will be replaced with new values. Corresponds to the JSON property desiredNodePoolAutoConfigResourceManagerTags



2140
2141
2142
# File 'lib/google/apis/container_v1/classes.rb', line 2140

def desired_node_pool_auto_config_resource_manager_tags
  @desired_node_pool_auto_config_resource_manager_tags
end

#desired_node_pool_autoscalingGoogle::Apis::ContainerV1::NodePoolAutoscaling

NodePoolAutoscaling contains information required by cluster autoscaler to adjust the size of the node pool to the current cluster usage. Corresponds to the JSON property desiredNodePoolAutoscaling



2146
2147
2148
# File 'lib/google/apis/container_v1/classes.rb', line 2146

def desired_node_pool_autoscaling
  @desired_node_pool_autoscaling
end

#desired_node_pool_idString

The node pool to be upgraded. This field is mandatory if "desired_node_version" , "desired_image_family" or "desired_node_pool_autoscaling" is specified and there is more than one node pool on the cluster. Corresponds to the JSON property desiredNodePoolId

Returns:

  • (String)


2153
2154
2155
# File 'lib/google/apis/container_v1/classes.rb', line 2153

def desired_node_pool_id
  @desired_node_pool_id
end

#desired_node_pool_logging_configGoogle::Apis::ContainerV1::NodePoolLoggingConfig

NodePoolLoggingConfig specifies logging configuration for nodepools. Corresponds to the JSON property desiredNodePoolLoggingConfig



2158
2159
2160
# File 'lib/google/apis/container_v1/classes.rb', line 2158

def desired_node_pool_logging_config
  @desired_node_pool_logging_config
end

#desired_node_versionString

The Kubernetes version to change the nodes to (typically an upgrade). Users may specify either explicit versions offered by Kubernetes Engine or version aliases, which have the following behavior: - "latest": picks the highest valid Kubernetes version - "1.X": picks the highest valid patch+gke.N patch in the 1.X version - "1.X.Y": picks the highest valid gke.N patch in the 1.X.Y version - "1.X.Y-gke.N": picks an explicit Kubernetes version - "-": picks the Kubernetes master version Corresponds to the JSON property desiredNodeVersion

Returns:

  • (String)


2169
2170
2171
# File 'lib/google/apis/container_v1/classes.rb', line 2169

def desired_node_version
  @desired_node_version
end

#desired_notification_configGoogle::Apis::ContainerV1::NotificationConfig

NotificationConfig is the configuration of notifications. Corresponds to the JSON property desiredNotificationConfig



2174
2175
2176
# File 'lib/google/apis/container_v1/classes.rb', line 2174

def desired_notification_config
  @desired_notification_config
end

#desired_parent_product_configGoogle::Apis::ContainerV1::ParentProductConfig

ParentProductConfig is the configuration of the parent product of the cluster. This field is used by Google internal products that are built on top of a GKE cluster and take the ownership of the cluster. Corresponds to the JSON property desiredParentProductConfig



2181
2182
2183
# File 'lib/google/apis/container_v1/classes.rb', line 2181

def desired_parent_product_config
  @desired_parent_product_config
end

#desired_pod_autoscalingGoogle::Apis::ContainerV1::PodAutoscaling

PodAutoscaling is used for configuration of parameters for workload autoscaling. Corresponds to the JSON property desiredPodAutoscaling



2187
2188
2189
# File 'lib/google/apis/container_v1/classes.rb', line 2187

def desired_pod_autoscaling
  @desired_pod_autoscaling
end

#desired_private_cluster_configGoogle::Apis::ContainerV1::PrivateClusterConfig

Configuration options for private clusters. Corresponds to the JSON property desiredPrivateClusterConfig



2192
2193
2194
# File 'lib/google/apis/container_v1/classes.rb', line 2192

def desired_private_cluster_config
  @desired_private_cluster_config
end

#desired_private_ipv6_google_accessString

The desired state of IPv6 connectivity to Google Services. Corresponds to the JSON property desiredPrivateIpv6GoogleAccess

Returns:

  • (String)


2197
2198
2199
# File 'lib/google/apis/container_v1/classes.rb', line 2197

def desired_private_ipv6_google_access
  @desired_private_ipv6_google_access
end

#desired_privileged_admission_configGoogle::Apis::ContainerV1::PrivilegedAdmissionConfig

PrivilegedAdmissionConfig stores the list of authorized allowlist paths for the cluster. Corresponds to the JSON property desiredPrivilegedAdmissionConfig



2203
2204
2205
# File 'lib/google/apis/container_v1/classes.rb', line 2203

def desired_privileged_admission_config
  @desired_privileged_admission_config
end

#desired_rbac_binding_configGoogle::Apis::ContainerV1::RbacBindingConfig

RBACBindingConfig allows user to restrict ClusterRoleBindings an RoleBindings that can be created. Corresponds to the JSON property desiredRbacBindingConfig



2209
2210
2211
# File 'lib/google/apis/container_v1/classes.rb', line 2209

def desired_rbac_binding_config
  @desired_rbac_binding_config
end

#desired_release_channelGoogle::Apis::ContainerV1::ReleaseChannel

ReleaseChannel indicates which release channel a cluster is subscribed to. Release channels are arranged in order of risk. When a cluster is subscribed to a release channel, Google maintains both the master version and the node version. Node auto-upgrade defaults to true and cannot be disabled. Corresponds to the JSON property desiredReleaseChannel



2217
2218
2219
# File 'lib/google/apis/container_v1/classes.rb', line 2217

def desired_release_channel
  @desired_release_channel
end

#desired_resource_usage_export_configGoogle::Apis::ContainerV1::ResourceUsageExportConfig

Configuration for exporting cluster resource usages. Corresponds to the JSON property desiredResourceUsageExportConfig



2222
2223
2224
# File 'lib/google/apis/container_v1/classes.rb', line 2222

def desired_resource_usage_export_config
  @desired_resource_usage_export_config
end

#desired_secret_manager_configGoogle::Apis::ContainerV1::SecretManagerConfig

SecretManagerConfig is config for secret manager enablement. Corresponds to the JSON property desiredSecretManagerConfig



2227
2228
2229
# File 'lib/google/apis/container_v1/classes.rb', line 2227

def desired_secret_manager_config
  @desired_secret_manager_config
end

#desired_security_posture_configGoogle::Apis::ContainerV1::SecurityPostureConfig

SecurityPostureConfig defines the flags needed to enable/disable features for the Security Posture API. Corresponds to the JSON property desiredSecurityPostureConfig



2233
2234
2235
# File 'lib/google/apis/container_v1/classes.rb', line 2233

def desired_security_posture_config
  @desired_security_posture_config
end

#desired_service_external_ips_configGoogle::Apis::ContainerV1::ServiceExternalIPsConfig

Config to block services with externalIPs field. Corresponds to the JSON property desiredServiceExternalIpsConfig



2238
2239
2240
# File 'lib/google/apis/container_v1/classes.rb', line 2238

def desired_service_external_ips_config
  @desired_service_external_ips_config
end

#desired_shielded_nodesGoogle::Apis::ContainerV1::ShieldedNodes

Configuration of Shielded Nodes feature. Corresponds to the JSON property desiredShieldedNodes



2243
2244
2245
# File 'lib/google/apis/container_v1/classes.rb', line 2243

def desired_shielded_nodes
  @desired_shielded_nodes
end

#desired_stack_typeString

The desired stack type of the cluster. If a stack type is provided and does not match the current stack type of the cluster, update will attempt to change the stack type to the new type. Corresponds to the JSON property desiredStackType

Returns:

  • (String)


2250
2251
2252
# File 'lib/google/apis/container_v1/classes.rb', line 2250

def desired_stack_type
  @desired_stack_type
end

#desired_user_managed_keys_configGoogle::Apis::ContainerV1::UserManagedKeysConfig

UserManagedKeysConfig holds the resource address to Keys which are used for signing certs and token that are used for communication within cluster. Corresponds to the JSON property desiredUserManagedKeysConfig



2256
2257
2258
# File 'lib/google/apis/container_v1/classes.rb', line 2256

def desired_user_managed_keys_config
  @desired_user_managed_keys_config
end

#desired_vertical_pod_autoscalingGoogle::Apis::ContainerV1::VerticalPodAutoscaling

VerticalPodAutoscaling contains global, per-cluster information required by Vertical Pod Autoscaler to automatically adjust the resources of pods controlled by it. Corresponds to the JSON property desiredVerticalPodAutoscaling



2263
2264
2265
# File 'lib/google/apis/container_v1/classes.rb', line 2263

def desired_vertical_pod_autoscaling
  @desired_vertical_pod_autoscaling
end

#desired_workload_identity_configGoogle::Apis::ContainerV1::WorkloadIdentityConfig

Configuration for the use of Kubernetes Service Accounts in IAM policies. Corresponds to the JSON property desiredWorkloadIdentityConfig



2268
2269
2270
# File 'lib/google/apis/container_v1/classes.rb', line 2268

def desired_workload_identity_config
  @desired_workload_identity_config
end

#enable_k8s_beta_apisGoogle::Apis::ContainerV1::K8sBetaApiConfig

K8sBetaAPIConfig , configuration for beta APIs Corresponds to the JSON property enableK8sBetaApis



2273
2274
2275
# File 'lib/google/apis/container_v1/classes.rb', line 2273

def enable_k8s_beta_apis
  @enable_k8s_beta_apis
end

#etagString

The current etag of the cluster. If an etag is provided and does not match the current etag of the cluster, update will be blocked and an ABORTED error will be returned. Corresponds to the JSON property etag

Returns:

  • (String)


2280
2281
2282
# File 'lib/google/apis/container_v1/classes.rb', line 2280

def etag
  @etag
end

#gke_auto_upgrade_configGoogle::Apis::ContainerV1::GkeAutoUpgradeConfig

GkeAutoUpgradeConfig is the configuration for GKE auto upgrades. Corresponds to the JSON property gkeAutoUpgradeConfig



2285
2286
2287
# File 'lib/google/apis/container_v1/classes.rb', line 2285

def gke_auto_upgrade_config
  @gke_auto_upgrade_config
end

#removed_additional_pod_ranges_configGoogle::Apis::ContainerV1::AdditionalPodRangesConfig

AdditionalPodRangesConfig is the configuration for additional pod secondary ranges supporting the ClusterUpdate message. Corresponds to the JSON property removedAdditionalPodRangesConfig



2291
2292
2293
# File 'lib/google/apis/container_v1/classes.rb', line 2291

def removed_additional_pod_ranges_config
  @removed_additional_pod_ranges_config
end

#user_managed_keys_configGoogle::Apis::ContainerV1::UserManagedKeysConfig

UserManagedKeysConfig holds the resource address to Keys which are used for signing certs and token that are used for communication within cluster. Corresponds to the JSON property userManagedKeysConfig



2297
2298
2299
# File 'lib/google/apis/container_v1/classes.rb', line 2297

def user_managed_keys_config
  @user_managed_keys_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2304
2305
2306
2307
2308
2309
2310
2311
2312
2313
2314
2315
2316
2317
2318
2319
2320
2321
2322
2323
2324
2325
2326
2327
2328
2329
2330
2331
2332
2333
2334
2335
2336
2337
2338
2339
2340
2341
2342
2343
2344
2345
2346
2347
2348
2349
2350
2351
2352
2353
2354
2355
2356
2357
2358
2359
2360
2361
2362
2363
2364
2365
2366
2367
2368
2369
2370
2371
2372
2373
2374
2375
2376
2377
2378
2379
2380
# File 'lib/google/apis/container_v1/classes.rb', line 2304

def update!(**args)
  @additional_pod_ranges_config = args[:additional_pod_ranges_config] if args.key?(:additional_pod_ranges_config)
  @desired_additional_ip_ranges_config = args[:desired_additional_ip_ranges_config] if args.key?(:desired_additional_ip_ranges_config)
  @desired_addons_config = args[:desired_addons_config] if args.key?(:desired_addons_config)
  @desired_anonymous_authentication_config = args[:desired_anonymous_authentication_config] if args.key?(:desired_anonymous_authentication_config)
  @desired_authenticator_groups_config = args[:desired_authenticator_groups_config] if args.key?(:desired_authenticator_groups_config)
  @desired_auto_ipam_config = args[:desired_auto_ipam_config] if args.key?(:desired_auto_ipam_config)
  @desired_autopilot_workload_policy_config = args[:desired_autopilot_workload_policy_config] if args.key?(:desired_autopilot_workload_policy_config)
  @desired_binary_authorization = args[:desired_binary_authorization] if args.key?(:desired_binary_authorization)
  @desired_cluster_autoscaling = args[:desired_cluster_autoscaling] if args.key?(:desired_cluster_autoscaling)
  @desired_compliance_posture_config = args[:desired_compliance_posture_config] if args.key?(:desired_compliance_posture_config)
  @desired_containerd_config = args[:desired_containerd_config] if args.key?(:desired_containerd_config)
  @desired_control_plane_endpoints_config = args[:desired_control_plane_endpoints_config] if args.key?(:desired_control_plane_endpoints_config)
  @desired_cost_management_config = args[:desired_cost_management_config] if args.key?(:desired_cost_management_config)
  @desired_database_encryption = args[:desired_database_encryption] if args.key?(:desired_database_encryption)
  @desired_datapath_provider = args[:desired_datapath_provider] if args.key?(:desired_datapath_provider)
  @desired_default_enable_private_nodes = args[:desired_default_enable_private_nodes] if args.key?(:desired_default_enable_private_nodes)
  @desired_default_snat_status = args[:desired_default_snat_status] if args.key?(:desired_default_snat_status)
  @desired_disable_l4_lb_firewall_reconciliation = args[:desired_disable_l4_lb_firewall_reconciliation] if args.key?(:desired_disable_l4_lb_firewall_reconciliation)
  @desired_dns_config = args[:desired_dns_config] if args.key?(:desired_dns_config)
  @desired_enable_cilium_clusterwide_network_policy = args[:desired_enable_cilium_clusterwide_network_policy] if args.key?(:desired_enable_cilium_clusterwide_network_policy)
  @desired_enable_fqdn_network_policy = args[:desired_enable_fqdn_network_policy] if args.key?(:desired_enable_fqdn_network_policy)
  @desired_enable_multi_networking = args[:desired_enable_multi_networking] if args.key?(:desired_enable_multi_networking)
  @desired_enable_private_endpoint = args[:desired_enable_private_endpoint] if args.key?(:desired_enable_private_endpoint)
  @desired_enterprise_config = args[:desired_enterprise_config] if args.key?(:desired_enterprise_config)
  @desired_fleet = args[:desired_fleet] if args.key?(:desired_fleet)
  @desired_gateway_api_config = args[:desired_gateway_api_config] if args.key?(:desired_gateway_api_config)
  @desired_gcfs_config = args[:desired_gcfs_config] if args.key?(:desired_gcfs_config)
  @desired_identity_service_config = args[:desired_identity_service_config] if args.key?(:desired_identity_service_config)
  @desired_image_type = args[:desired_image_type] if args.key?(:desired_image_type)
  @desired_in_transit_encryption_config = args[:desired_in_transit_encryption_config] if args.key?(:desired_in_transit_encryption_config)
  @desired_intra_node_visibility_config = args[:desired_intra_node_visibility_config] if args.key?(:desired_intra_node_visibility_config)
  @desired_k8s_beta_apis = args[:desired_k8s_beta_apis] if args.key?(:desired_k8s_beta_apis)
  @desired_l4ilb_subsetting_config = args[:desired_l4ilb_subsetting_config] if args.key?(:desired_l4ilb_subsetting_config)
  @desired_locations = args[:desired_locations] if args.key?(:desired_locations)
  @desired_logging_config = args[:desired_logging_config] if args.key?(:desired_logging_config)
  @desired_logging_service = args[:desired_logging_service] if args.key?(:desired_logging_service)
  @desired_managed_opentelemetry_config = args[:desired_managed_opentelemetry_config] if args.key?(:desired_managed_opentelemetry_config)
  @desired_master_authorized_networks_config = args[:desired_master_authorized_networks_config] if args.key?(:desired_master_authorized_networks_config)
  @desired_master_version = args[:desired_master_version] if args.key?(:desired_master_version)
  @desired_mesh_certificates = args[:desired_mesh_certificates] if args.key?(:desired_mesh_certificates)
  @desired_monitoring_config = args[:desired_monitoring_config] if args.key?(:desired_monitoring_config)
  @desired_monitoring_service = args[:desired_monitoring_service] if args.key?(:desired_monitoring_service)
  @desired_network_performance_config = args[:desired_network_performance_config] if args.key?(:desired_network_performance_config)
  @desired_network_tier_config = args[:desired_network_tier_config] if args.key?(:desired_network_tier_config)
  @desired_node_kubelet_config = args[:desired_node_kubelet_config] if args.key?(:desired_node_kubelet_config)
  @desired_node_pool_auto_config_kubelet_config = args[:desired_node_pool_auto_config_kubelet_config] if args.key?(:desired_node_pool_auto_config_kubelet_config)
  @desired_node_pool_auto_config_linux_node_config = args[:desired_node_pool_auto_config_linux_node_config] if args.key?(:desired_node_pool_auto_config_linux_node_config)
  @desired_node_pool_auto_config_network_tags = args[:desired_node_pool_auto_config_network_tags] if args.key?(:desired_node_pool_auto_config_network_tags)
  @desired_node_pool_auto_config_resource_manager_tags = args[:desired_node_pool_auto_config_resource_manager_tags] if args.key?(:desired_node_pool_auto_config_resource_manager_tags)
  @desired_node_pool_autoscaling = args[:desired_node_pool_autoscaling] if args.key?(:desired_node_pool_autoscaling)
  @desired_node_pool_id = args[:desired_node_pool_id] if args.key?(:desired_node_pool_id)
  @desired_node_pool_logging_config = args[:desired_node_pool_logging_config] if args.key?(:desired_node_pool_logging_config)
  @desired_node_version = args[:desired_node_version] if args.key?(:desired_node_version)
  @desired_notification_config = args[:desired_notification_config] if args.key?(:desired_notification_config)
  @desired_parent_product_config = args[:desired_parent_product_config] if args.key?(:desired_parent_product_config)
  @desired_pod_autoscaling = args[:desired_pod_autoscaling] if args.key?(:desired_pod_autoscaling)
  @desired_private_cluster_config = args[:desired_private_cluster_config] if args.key?(:desired_private_cluster_config)
  @desired_private_ipv6_google_access = args[:desired_private_ipv6_google_access] if args.key?(:desired_private_ipv6_google_access)
  @desired_privileged_admission_config = args[:desired_privileged_admission_config] if args.key?(:desired_privileged_admission_config)
  @desired_rbac_binding_config = args[:desired_rbac_binding_config] if args.key?(:desired_rbac_binding_config)
  @desired_release_channel = args[:desired_release_channel] if args.key?(:desired_release_channel)
  @desired_resource_usage_export_config = args[:desired_resource_usage_export_config] if args.key?(:desired_resource_usage_export_config)
  @desired_secret_manager_config = args[:desired_secret_manager_config] if args.key?(:desired_secret_manager_config)
  @desired_security_posture_config = args[:desired_security_posture_config] if args.key?(:desired_security_posture_config)
  @desired_service_external_ips_config = args[:desired_service_external_ips_config] if args.key?(:desired_service_external_ips_config)
  @desired_shielded_nodes = args[:desired_shielded_nodes] if args.key?(:desired_shielded_nodes)
  @desired_stack_type = args[:desired_stack_type] if args.key?(:desired_stack_type)
  @desired_user_managed_keys_config = args[:desired_user_managed_keys_config] if args.key?(:desired_user_managed_keys_config)
  @desired_vertical_pod_autoscaling = args[:desired_vertical_pod_autoscaling] if args.key?(:desired_vertical_pod_autoscaling)
  @desired_workload_identity_config = args[:desired_workload_identity_config] if args.key?(:desired_workload_identity_config)
  @enable_k8s_beta_apis = args[:enable_k8s_beta_apis] if args.key?(:enable_k8s_beta_apis)
  @etag = args[:etag] if args.key?(:etag)
  @gke_auto_upgrade_config = args[:gke_auto_upgrade_config] if args.key?(:gke_auto_upgrade_config)
  @removed_additional_pod_ranges_config = args[:removed_additional_pod_ranges_config] if args.key?(:removed_additional_pod_ranges_config)
  @user_managed_keys_config = args[:user_managed_keys_config] if args.key?(:user_managed_keys_config)
end