Class: Google::Apis::ContainerV1::CompleteIpRotationRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

CompleteIPRotationRequest moves the cluster master back into single-IP mode.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CompleteIpRotationRequest

Returns a new instance of CompleteIpRotationRequest.



2709
2710
2711
# File 'lib/google/apis/container_v1/classes.rb', line 2709

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cluster_idString

Deprecated. The name of the cluster. This field has been deprecated and replaced by the name field. Corresponds to the JSON property clusterId

Returns:

  • (String)


2687
2688
2689
# File 'lib/google/apis/container_v1/classes.rb', line 2687

def cluster_id
  @cluster_id
end

#nameString

The name (project, location, cluster name) of the cluster to complete IP rotation. Specified in the format projects/*/locations/*/clusters/*. Corresponds to the JSON property name

Returns:

  • (String)


2693
2694
2695
# File 'lib/google/apis/container_v1/classes.rb', line 2693

def name
  @name
end

#project_idString

Deprecated. The Google Developers Console project ID or project number. This field has been deprecated and replaced by the name field. Corresponds to the JSON property projectId

Returns:

  • (String)


2700
2701
2702
# File 'lib/google/apis/container_v1/classes.rb', line 2700

def project_id
  @project_id
end

#zoneString

Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has been deprecated and replaced by the name field. Corresponds to the JSON property zone

Returns:

  • (String)


2707
2708
2709
# File 'lib/google/apis/container_v1/classes.rb', line 2707

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2714
2715
2716
2717
2718
2719
# File 'lib/google/apis/container_v1/classes.rb', line 2714

def update!(**args)
  @cluster_id = args[:cluster_id] if args.key?(:cluster_id)
  @name = args[:name] if args.key?(:name)
  @project_id = args[:project_id] if args.key?(:project_id)
  @zone = args[:zone] if args.key?(:zone)
end