Class: Google::Apis::ContainerV1::CompleteIpRotationRequest
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1::CompleteIpRotationRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb
Overview
CompleteIPRotationRequest moves the cluster master back into single-IP mode.
Instance Attribute Summary collapse
-
#cluster_id ⇒ String
Deprecated.
-
#name ⇒ String
The name (project, location, cluster name) of the cluster to complete IP rotation.
-
#project_id ⇒ String
Deprecated.
-
#zone ⇒ String
Deprecated.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CompleteIpRotationRequest
constructor
A new instance of CompleteIpRotationRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CompleteIpRotationRequest
Returns a new instance of CompleteIpRotationRequest.
2516 2517 2518 |
# File 'lib/google/apis/container_v1/classes.rb', line 2516 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cluster_id ⇒ String
Deprecated. The name of the cluster. This field has been deprecated and
replaced by the name field.
Corresponds to the JSON property clusterId
2494 2495 2496 |
# File 'lib/google/apis/container_v1/classes.rb', line 2494 def cluster_id @cluster_id end |
#name ⇒ String
The name (project, location, cluster name) of the cluster to complete IP
rotation. Specified in the format projects/*/locations/*/clusters/*.
Corresponds to the JSON property name
2500 2501 2502 |
# File 'lib/google/apis/container_v1/classes.rb', line 2500 def name @name end |
#project_id ⇒ String
Deprecated. The Google Developers Console project ID or project number. This
field has been deprecated and replaced by the name field.
Corresponds to the JSON property projectId
2507 2508 2509 |
# File 'lib/google/apis/container_v1/classes.rb', line 2507 def project_id @project_id end |
#zone ⇒ String
Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has
been deprecated and replaced by the name field.
Corresponds to the JSON property zone
2514 2515 2516 |
# File 'lib/google/apis/container_v1/classes.rb', line 2514 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2521 2522 2523 2524 2525 2526 |
# File 'lib/google/apis/container_v1/classes.rb', line 2521 def update!(**args) @cluster_id = args[:cluster_id] if args.key?(:cluster_id) @name = args[:name] if args.key?(:name) @project_id = args[:project_id] if args.key?(:project_id) @zone = args[:zone] if args.key?(:zone) end |