Class: Google::Apis::ContainerV1::CreateClusterRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

CreateClusterRequest creates a cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CreateClusterRequest

Returns a new instance of CreateClusterRequest.



3004
3005
3006
# File 'lib/google/apis/container_v1/classes.rb', line 3004

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#clusterGoogle::Apis::ContainerV1::Cluster

A Google Kubernetes Engine cluster. Corresponds to the JSON property cluster



2982
2983
2984
# File 'lib/google/apis/container_v1/classes.rb', line 2982

def cluster
  @cluster
end

#parentString

The parent (project and location) where the cluster will be created. Specified in the format projects/*/locations/*. Corresponds to the JSON property parent

Returns:

  • (String)


2988
2989
2990
# File 'lib/google/apis/container_v1/classes.rb', line 2988

def parent
  @parent
end

#project_idString

Deprecated. The Google Developers Console project ID or project number. This field has been deprecated and replaced by the parent field. Corresponds to the JSON property projectId

Returns:

  • (String)


2995
2996
2997
# File 'lib/google/apis/container_v1/classes.rb', line 2995

def project_id
  @project_id
end

#zoneString

Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has been deprecated and replaced by the parent field. Corresponds to the JSON property zone

Returns:

  • (String)


3002
3003
3004
# File 'lib/google/apis/container_v1/classes.rb', line 3002

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3009
3010
3011
3012
3013
3014
# File 'lib/google/apis/container_v1/classes.rb', line 3009

def update!(**args)
  @cluster = args[:cluster] if args.key?(:cluster)
  @parent = args[:parent] if args.key?(:parent)
  @project_id = args[:project_id] if args.key?(:project_id)
  @zone = args[:zone] if args.key?(:zone)
end