Class: Google::Apis::ContainerV1::CreateClusterRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

CreateClusterRequest creates a cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CreateClusterRequest

Returns a new instance of CreateClusterRequest.



2716
2717
2718
# File 'lib/google/apis/container_v1/classes.rb', line 2716

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#clusterGoogle::Apis::ContainerV1::Cluster

A Google Kubernetes Engine cluster. Corresponds to the JSON property cluster



2694
2695
2696
# File 'lib/google/apis/container_v1/classes.rb', line 2694

def cluster
  @cluster
end

#parentString

The parent (project and location) where the cluster will be created. Specified in the format projects/*/locations/*. Corresponds to the JSON property parent

Returns:

  • (String)


2700
2701
2702
# File 'lib/google/apis/container_v1/classes.rb', line 2700

def parent
  @parent
end

#project_idString

Deprecated. The Google Developers Console project ID or project number. This field has been deprecated and replaced by the parent field. Corresponds to the JSON property projectId

Returns:

  • (String)


2707
2708
2709
# File 'lib/google/apis/container_v1/classes.rb', line 2707

def project_id
  @project_id
end

#zoneString

Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has been deprecated and replaced by the parent field. Corresponds to the JSON property zone

Returns:

  • (String)


2714
2715
2716
# File 'lib/google/apis/container_v1/classes.rb', line 2714

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2721
2722
2723
2724
2725
2726
# File 'lib/google/apis/container_v1/classes.rb', line 2721

def update!(**args)
  @cluster = args[:cluster] if args.key?(:cluster)
  @parent = args[:parent] if args.key?(:parent)
  @project_id = args[:project_id] if args.key?(:project_id)
  @zone = args[:zone] if args.key?(:zone)
end