Class: Google::Apis::ContainerV1::CreateNodePoolRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

CreateNodePoolRequest creates a node pool for a cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CreateNodePoolRequest

Returns a new instance of CreateNodePoolRequest.



3057
3058
3059
# File 'lib/google/apis/container_v1/classes.rb', line 3057

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cluster_idString

Deprecated. The name of the cluster. This field has been deprecated and replaced by the parent field. Corresponds to the JSON property clusterId

Returns:

  • (String)


3025
3026
3027
# File 'lib/google/apis/container_v1/classes.rb', line 3025

def cluster_id
  @cluster_id
end

#node_poolGoogle::Apis::ContainerV1::NodePool

NodePool contains the name and configuration for a cluster's node pool. Node pools are a set of nodes (i.e. VM's), with a common configuration and specification, under the control of the cluster master. They may have a set of Kubernetes labels applied to them, which may be used to reference them during pod scheduling. They may also be resized up or down, to accommodate the workload. Corresponds to the JSON property nodePool



3035
3036
3037
# File 'lib/google/apis/container_v1/classes.rb', line 3035

def node_pool
  @node_pool
end

#parentString

The parent (project, location, cluster name) where the node pool will be created. Specified in the format projects/*/locations/*/clusters/*. Corresponds to the JSON property parent

Returns:

  • (String)


3041
3042
3043
# File 'lib/google/apis/container_v1/classes.rb', line 3041

def parent
  @parent
end

#project_idString

Deprecated. The Google Developers Console project ID or project number. This field has been deprecated and replaced by the parent field. Corresponds to the JSON property projectId

Returns:

  • (String)


3048
3049
3050
# File 'lib/google/apis/container_v1/classes.rb', line 3048

def project_id
  @project_id
end

#zoneString

Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has been deprecated and replaced by the parent field. Corresponds to the JSON property zone

Returns:

  • (String)


3055
3056
3057
# File 'lib/google/apis/container_v1/classes.rb', line 3055

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3062
3063
3064
3065
3066
3067
3068
# File 'lib/google/apis/container_v1/classes.rb', line 3062

def update!(**args)
  @cluster_id = args[:cluster_id] if args.key?(:cluster_id)
  @node_pool = args[:node_pool] if args.key?(:node_pool)
  @parent = args[:parent] if args.key?(:parent)
  @project_id = args[:project_id] if args.key?(:project_id)
  @zone = args[:zone] if args.key?(:zone)
end