Class: Google::Apis::ContainerV1::CreateNodePoolRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

CreateNodePoolRequest creates a node pool for a cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CreateNodePoolRequest

Returns a new instance of CreateNodePoolRequest.



2844
2845
2846
# File 'lib/google/apis/container_v1/classes.rb', line 2844

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cluster_idString

Deprecated. The name of the cluster. This field has been deprecated and replaced by the parent field. Corresponds to the JSON property clusterId

Returns:

  • (String)


2812
2813
2814
# File 'lib/google/apis/container_v1/classes.rb', line 2812

def cluster_id
  @cluster_id
end

#node_poolGoogle::Apis::ContainerV1::NodePool

NodePool contains the name and configuration for a cluster's node pool. Node pools are a set of nodes (i.e. VM's), with a common configuration and specification, under the control of the cluster master. They may have a set of Kubernetes labels applied to them, which may be used to reference them during pod scheduling. They may also be resized up or down, to accommodate the workload. Corresponds to the JSON property nodePool



2822
2823
2824
# File 'lib/google/apis/container_v1/classes.rb', line 2822

def node_pool
  @node_pool
end

#parentString

The parent (project, location, cluster name) where the node pool will be created. Specified in the format projects/*/locations/*/clusters/*. Corresponds to the JSON property parent

Returns:

  • (String)


2828
2829
2830
# File 'lib/google/apis/container_v1/classes.rb', line 2828

def parent
  @parent
end

#project_idString

Deprecated. The Google Developers Console project ID or project number. This field has been deprecated and replaced by the parent field. Corresponds to the JSON property projectId

Returns:

  • (String)


2835
2836
2837
# File 'lib/google/apis/container_v1/classes.rb', line 2835

def project_id
  @project_id
end

#zoneString

Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has been deprecated and replaced by the parent field. Corresponds to the JSON property zone

Returns:

  • (String)


2842
2843
2844
# File 'lib/google/apis/container_v1/classes.rb', line 2842

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2849
2850
2851
2852
2853
2854
2855
# File 'lib/google/apis/container_v1/classes.rb', line 2849

def update!(**args)
  @cluster_id = args[:cluster_id] if args.key?(:cluster_id)
  @node_pool = args[:node_pool] if args.key?(:node_pool)
  @parent = args[:parent] if args.key?(:parent)
  @project_id = args[:project_id] if args.key?(:project_id)
  @zone = args[:zone] if args.key?(:zone)
end