Class: Google::Apis::ContainerV1::CustomImageConfig
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1::CustomImageConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb
Overview
CustomImageConfig contains the information r
Instance Attribute Summary collapse
-
#image ⇒ String
The name of the image to use for this node.
-
#image_project ⇒ String
The project containing the image to use for this node.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CustomImageConfig
constructor
A new instance of CustomImageConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CustomImageConfig
Returns a new instance of CustomImageConfig.
3138 3139 3140 |
# File 'lib/google/apis/container_v1/classes.rb', line 3138 def initialize(**args) update!(**args) end |
Instance Attribute Details
#image ⇒ String
The name of the image to use for this node.
Corresponds to the JSON property image
3131 3132 3133 |
# File 'lib/google/apis/container_v1/classes.rb', line 3131 def image @image end |
#image_project ⇒ String
The project containing the image to use for this node.
Corresponds to the JSON property imageProject
3136 3137 3138 |
# File 'lib/google/apis/container_v1/classes.rb', line 3136 def image_project @image_project end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3143 3144 3145 3146 |
# File 'lib/google/apis/container_v1/classes.rb', line 3143 def update!(**args) @image = args[:image] if args.key?(:image) @image_project = args[:image_project] if args.key?(:image_project) end |