Class: Google::Apis::ContainerV1::CustomImageConfig
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1::CustomImageConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb
Overview
CustomImageConfig contains the information r
Instance Attribute Summary collapse
-
#image ⇒ String
The name of the image to use for this node.
-
#image_project ⇒ String
The project containing the image to use for this node.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CustomImageConfig
constructor
A new instance of CustomImageConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CustomImageConfig
Returns a new instance of CustomImageConfig.
3085 3086 3087 |
# File 'lib/google/apis/container_v1/classes.rb', line 3085 def initialize(**args) update!(**args) end |
Instance Attribute Details
#image ⇒ String
The name of the image to use for this node.
Corresponds to the JSON property image
3078 3079 3080 |
# File 'lib/google/apis/container_v1/classes.rb', line 3078 def image @image end |
#image_project ⇒ String
The project containing the image to use for this node.
Corresponds to the JSON property imageProject
3083 3084 3085 |
# File 'lib/google/apis/container_v1/classes.rb', line 3083 def image_project @image_project end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3090 3091 3092 3093 |
# File 'lib/google/apis/container_v1/classes.rb', line 3090 def update!(**args) @image = args[:image] if args.key?(:image) @image_project = args[:image_project] if args.key?(:image_project) end |