Class: Google::Apis::ContainerV1::CustomImageConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

CustomImageConfig contains the information r

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CustomImageConfig

Returns a new instance of CustomImageConfig.



3090
3091
3092
# File 'lib/google/apis/container_v1/classes.rb', line 3090

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#imageString

The name of the image to use for this node. Corresponds to the JSON property image

Returns:

  • (String)


3078
3079
3080
# File 'lib/google/apis/container_v1/classes.rb', line 3078

def image
  @image
end

#image_familyString

The name of the image family to use for this node. Corresponds to the JSON property imageFamily

Returns:

  • (String)


3083
3084
3085
# File 'lib/google/apis/container_v1/classes.rb', line 3083

def image_family
  @image_family
end

#image_projectString

The project containing the image to use for this node. Corresponds to the JSON property imageProject

Returns:

  • (String)


3088
3089
3090
# File 'lib/google/apis/container_v1/classes.rb', line 3088

def image_project
  @image_project
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3095
3096
3097
3098
3099
# File 'lib/google/apis/container_v1/classes.rb', line 3095

def update!(**args)
  @image = args[:image] if args.key?(:image)
  @image_family = args[:image_family] if args.key?(:image_family)
  @image_project = args[:image_project] if args.key?(:image_project)
end