Class: Google::Apis::ContainerV1::DailyMaintenanceWindow
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1::DailyMaintenanceWindow
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb
Overview
Time window specified for daily maintenance operations.
Instance Attribute Summary collapse
-
#duration ⇒ String
Output only.
-
#start_time ⇒ String
Time within the maintenance window to start the maintenance operations.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DailyMaintenanceWindow
constructor
A new instance of DailyMaintenanceWindow.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DailyMaintenanceWindow
Returns a new instance of DailyMaintenanceWindow.
2882 2883 2884 |
# File 'lib/google/apis/container_v1/classes.rb', line 2882 def initialize(**args) update!(**args) end |
Instance Attribute Details
#duration ⇒ String
Output only. Duration of the time window, automatically chosen to be smallest
possible in the given scenario. Duration will be in RFC3339 format "PTnHnMnS".
Corresponds to the JSON property duration
2873 2874 2875 |
# File 'lib/google/apis/container_v1/classes.rb', line 2873 def duration @duration end |
#start_time ⇒ String
Time within the maintenance window to start the maintenance operations. Time
format should be in RFC3339 format "HH:
MM", where HH : [00-23] and MM : [00-59] GMT.
Corresponds to the JSON property startTime
2880 2881 2882 |
# File 'lib/google/apis/container_v1/classes.rb', line 2880 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2887 2888 2889 2890 |
# File 'lib/google/apis/container_v1/classes.rb', line 2887 def update!(**args) @duration = args[:duration] if args.key?(:duration) @start_time = args[:start_time] if args.key?(:start_time) end |