Class: Google::Apis::ContainerV1::DisruptionEvent

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

DisruptionEvent is a notification sent to customers about the disruption event of a resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DisruptionEvent

Returns a new instance of DisruptionEvent.



3050
3051
3052
# File 'lib/google/apis/container_v1/classes.rb', line 3050

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#disruption_typeString

The type of the disruption event. Corresponds to the JSON property disruptionType

Returns:

  • (String)


3029
3030
3031
# File 'lib/google/apis/container_v1/classes.rb', line 3029

def disruption_type
  @disruption_type
end

#pdb_blocked_nodeString

The node whose drain is blocked by PDB. This field is set for both POD_PDB_VIOLATION and POD_NOT_ENOUGH_PDB event. Corresponds to the JSON property pdbBlockedNode

Returns:

  • (String)


3035
3036
3037
# File 'lib/google/apis/container_v1/classes.rb', line 3035

def pdb_blocked_node
  @pdb_blocked_node
end

#pdb_blocked_podArray<Google::Apis::ContainerV1::PdbBlockedPod>

The pods whose evictions are blocked by PDB. This field is set for both POD_PDB_VIOLATION and POD_NOT_ENOUGH_PDB event. Corresponds to the JSON property pdbBlockedPod



3041
3042
3043
# File 'lib/google/apis/container_v1/classes.rb', line 3041

def pdb_blocked_pod
  @pdb_blocked_pod
end

#pdb_violation_timeoutString

The timeout in seconds for which the node drain is blocked by PDB. After this timeout, pods are forcefully evicted. This field is only populated when event_type is POD_PDB_VIOLATION. Corresponds to the JSON property pdbViolationTimeout

Returns:

  • (String)


3048
3049
3050
# File 'lib/google/apis/container_v1/classes.rb', line 3048

def pdb_violation_timeout
  @pdb_violation_timeout
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3055
3056
3057
3058
3059
3060
# File 'lib/google/apis/container_v1/classes.rb', line 3055

def update!(**args)
  @disruption_type = args[:disruption_type] if args.key?(:disruption_type)
  @pdb_blocked_node = args[:pdb_blocked_node] if args.key?(:pdb_blocked_node)
  @pdb_blocked_pod = args[:pdb_blocked_pod] if args.key?(:pdb_blocked_pod)
  @pdb_violation_timeout = args[:pdb_violation_timeout] if args.key?(:pdb_violation_timeout)
end