Class: Google::Apis::ContainerV1::DnsConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

DNSConfig contains the desired set of options for configuring clusterDNS.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DnsConfig

Returns a new instance of DnsConfig.



2807
2808
2809
# File 'lib/google/apis/container_v1/classes.rb', line 2807

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#additive_vpc_scope_dns_domainString

Optional. The domain used in Additive VPC scope. Corresponds to the JSON property additiveVpcScopeDnsDomain

Returns:

  • (String)


2790
2791
2792
# File 'lib/google/apis/container_v1/classes.rb', line 2790

def additive_vpc_scope_dns_domain
  @additive_vpc_scope_dns_domain
end

#cluster_dnsString

cluster_dns indicates which in-cluster DNS provider should be used. Corresponds to the JSON property clusterDns

Returns:

  • (String)


2795
2796
2797
# File 'lib/google/apis/container_v1/classes.rb', line 2795

def cluster_dns
  @cluster_dns
end

#cluster_dns_domainString

cluster_dns_domain is the suffix used for all cluster service records. Corresponds to the JSON property clusterDnsDomain

Returns:

  • (String)


2800
2801
2802
# File 'lib/google/apis/container_v1/classes.rb', line 2800

def cluster_dns_domain
  @cluster_dns_domain
end

#cluster_dns_scopeString

cluster_dns_scope indicates the scope of access to cluster DNS records. Corresponds to the JSON property clusterDnsScope

Returns:

  • (String)


2805
2806
2807
# File 'lib/google/apis/container_v1/classes.rb', line 2805

def cluster_dns_scope
  @cluster_dns_scope
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2812
2813
2814
2815
2816
2817
# File 'lib/google/apis/container_v1/classes.rb', line 2812

def update!(**args)
  @additive_vpc_scope_dns_domain = args[:additive_vpc_scope_dns_domain] if args.key?(:additive_vpc_scope_dns_domain)
  @cluster_dns = args[:cluster_dns] if args.key?(:cluster_dns)
  @cluster_dns_domain = args[:cluster_dns_domain] if args.key?(:cluster_dns_domain)
  @cluster_dns_scope = args[:cluster_dns_scope] if args.key?(:cluster_dns_scope)
end