Class: Google::Apis::ContainerV1::DnsEndpointConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

Describes the configuration of a DNS endpoint.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DnsEndpointConfig

Returns a new instance of DnsEndpointConfig.



2851
2852
2853
# File 'lib/google/apis/container_v1/classes.rb', line 2851

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allow_external_trafficBoolean Also known as: allow_external_traffic?

Controls whether user traffic is allowed over this endpoint. Note that Google- managed services may still use the endpoint even if this is false. Corresponds to the JSON property allowExternalTraffic

Returns:

  • (Boolean)


2828
2829
2830
# File 'lib/google/apis/container_v1/classes.rb', line 2828

def allow_external_traffic
  @allow_external_traffic
end

#enable_k8s_certs_via_dnsBoolean Also known as: enable_k8s_certs_via_dns?

Controls whether the k8s certs auth is allowed via DNS. Corresponds to the JSON property enableK8sCertsViaDns

Returns:

  • (Boolean)


2834
2835
2836
# File 'lib/google/apis/container_v1/classes.rb', line 2834

def enable_k8s_certs_via_dns
  @enable_k8s_certs_via_dns
end

#enable_k8s_tokens_via_dnsBoolean Also known as: enable_k8s_tokens_via_dns?

Controls whether the k8s token auth is allowed via DNS. Corresponds to the JSON property enableK8sTokensViaDns

Returns:

  • (Boolean)


2840
2841
2842
# File 'lib/google/apis/container_v1/classes.rb', line 2840

def enable_k8s_tokens_via_dns
  @enable_k8s_tokens_via_dns
end

#endpointString

Output only. The cluster's DNS endpoint configuration. A DNS format address. This is accessible from the public internet. Ex: uid.us-central1.gke.goog. Always present, but the behavior may change according to the value of DNSEndpointConfig.allow_external_traffic. Corresponds to the JSON property endpoint

Returns:

  • (String)


2849
2850
2851
# File 'lib/google/apis/container_v1/classes.rb', line 2849

def endpoint
  @endpoint
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2856
2857
2858
2859
2860
2861
# File 'lib/google/apis/container_v1/classes.rb', line 2856

def update!(**args)
  @allow_external_traffic = args[:allow_external_traffic] if args.key?(:allow_external_traffic)
  @enable_k8s_certs_via_dns = args[:enable_k8s_certs_via_dns] if args.key?(:enable_k8s_certs_via_dns)
  @enable_k8s_tokens_via_dns = args[:enable_k8s_tokens_via_dns] if args.key?(:enable_k8s_tokens_via_dns)
  @endpoint = args[:endpoint] if args.key?(:endpoint)
end