Class: Google::Apis::ContainerV1::EphemeralStorageLocalSsdConfig
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1::EphemeralStorageLocalSsdConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb
Overview
EphemeralStorageLocalSsdConfig contains configuration for the node ephemeral storage using Local SSDs.
Instance Attribute Summary collapse
-
#data_cache_count ⇒ Fixnum
Number of local SSDs to use for GKE Data Cache.
-
#local_ssd_count ⇒ Fixnum
Number of local SSDs to use to back ephemeral storage.
Instance Method Summary collapse
-
#initialize(**args) ⇒ EphemeralStorageLocalSsdConfig
constructor
A new instance of EphemeralStorageLocalSsdConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EphemeralStorageLocalSsdConfig
Returns a new instance of EphemeralStorageLocalSsdConfig.
3333 3334 3335 |
# File 'lib/google/apis/container_v1/classes.rb', line 3333 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data_cache_count ⇒ Fixnum
Number of local SSDs to use for GKE Data Cache.
Corresponds to the JSON property dataCacheCount
3315 3316 3317 |
# File 'lib/google/apis/container_v1/classes.rb', line 3315 def data_cache_count @data_cache_count end |
#local_ssd_count ⇒ Fixnum
Number of local SSDs to use to back ephemeral storage. Uses NVMe interfaces. A
zero (or unset) value has different meanings depending on machine type being
used: 1. For pre-Gen3 machines, which support flexible numbers of local ssds,
zero (or unset) means to disable using local SSDs as ephemeral storage. The
limit for this value is dependent upon the maximum number of disk available on
a machine per zone. See: https://cloud.google.com/compute/docs/disks/local-ssd
for more information. 2. For Gen3 machines which dictate a specific number of
local ssds, zero (or unset) means to use the default number of local ssds that
goes with that machine type. For example, for a c3-standard-8-lssd machine, 2
local ssds would be provisioned. For c3-standard-8 (which doesn't support
local ssds), 0 will be provisioned. See https://cloud.google.com/compute/docs/
disks/local-ssd#choose_number_local_ssds for more info.
Corresponds to the JSON property localSsdCount
3331 3332 3333 |
# File 'lib/google/apis/container_v1/classes.rb', line 3331 def local_ssd_count @local_ssd_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3338 3339 3340 3341 |
# File 'lib/google/apis/container_v1/classes.rb', line 3338 def update!(**args) @data_cache_count = args[:data_cache_count] if args.key?(:data_cache_count) @local_ssd_count = args[:local_ssd_count] if args.key?(:local_ssd_count) end |