Class: Google::Apis::ContainerV1::EvictionGracePeriod

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

Eviction grace periods are grace periods for each eviction signal.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EvictionGracePeriod

Returns a new instance of EvictionGracePeriod.



3726
3727
3728
# File 'lib/google/apis/container_v1/classes.rb', line 3726

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#imagefs_availableString

Optional. Grace period for eviction due to imagefs available signal. Sample format: "10s". Must be >= 0. See https://kubernetes.io/docs/concepts/ scheduling-eviction/node-pressure-eviction/#eviction-signals Corresponds to the JSON property imagefsAvailable

Returns:

  • (String)


3689
3690
3691
# File 'lib/google/apis/container_v1/classes.rb', line 3689

def imagefs_available
  @imagefs_available
end

#imagefs_inodes_freeString

Optional. Grace period for eviction due to imagefs inodes free signal. Sample format: "10s". Must be >= 0. See https://kubernetes.io/docs/concepts/ scheduling-eviction/node-pressure-eviction/#eviction-signals Corresponds to the JSON property imagefsInodesFree

Returns:

  • (String)


3696
3697
3698
# File 'lib/google/apis/container_v1/classes.rb', line 3696

def imagefs_inodes_free
  @imagefs_inodes_free
end

#memory_availableString

Optional. Grace period for eviction due to memory available signal. Sample format: "10s". Must be >= 0. See https://kubernetes.io/docs/concepts/ scheduling-eviction/node-pressure-eviction/#eviction-signals Corresponds to the JSON property memoryAvailable

Returns:

  • (String)


3703
3704
3705
# File 'lib/google/apis/container_v1/classes.rb', line 3703

def memory_available
  @memory_available
end

#nodefs_availableString

Optional. Grace period for eviction due to nodefs available signal. Sample format: "10s". Must be >= 0. See https://kubernetes.io/docs/concepts/ scheduling-eviction/node-pressure-eviction/#eviction-signals Corresponds to the JSON property nodefsAvailable

Returns:

  • (String)


3710
3711
3712
# File 'lib/google/apis/container_v1/classes.rb', line 3710

def nodefs_available
  @nodefs_available
end

#nodefs_inodes_freeString

Optional. Grace period for eviction due to nodefs inodes free signal. Sample format: "10s". Must be >= 0. See https://kubernetes.io/docs/concepts/ scheduling-eviction/node-pressure-eviction/#eviction-signals Corresponds to the JSON property nodefsInodesFree

Returns:

  • (String)


3717
3718
3719
# File 'lib/google/apis/container_v1/classes.rb', line 3717

def nodefs_inodes_free
  @nodefs_inodes_free
end

#pid_availableString

Optional. Grace period for eviction due to pid available signal. Sample format: "10s". Must be >= 0. See https://kubernetes.io/docs/concepts/scheduling- eviction/node-pressure-eviction/#eviction-signals Corresponds to the JSON property pidAvailable

Returns:

  • (String)


3724
3725
3726
# File 'lib/google/apis/container_v1/classes.rb', line 3724

def pid_available
  @pid_available
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3731
3732
3733
3734
3735
3736
3737
3738
# File 'lib/google/apis/container_v1/classes.rb', line 3731

def update!(**args)
  @imagefs_available = args[:imagefs_available] if args.key?(:imagefs_available)
  @imagefs_inodes_free = args[:imagefs_inodes_free] if args.key?(:imagefs_inodes_free)
  @memory_available = args[:memory_available] if args.key?(:memory_available)
  @nodefs_available = args[:nodefs_available] if args.key?(:nodefs_available)
  @nodefs_inodes_free = args[:nodefs_inodes_free] if args.key?(:nodefs_inodes_free)
  @pid_available = args[:pid_available] if args.key?(:pid_available)
end