Class: Google::Apis::ContainerV1::EvictionGracePeriod

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

Eviction grace periods are grace periods for each eviction signal.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EvictionGracePeriod

Returns a new instance of EvictionGracePeriod.



3390
3391
3392
# File 'lib/google/apis/container_v1/classes.rb', line 3390

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#imagefs_availableString

Optional. Grace period for eviction due to imagefs available signal. Sample format: "10s". Must be >= 0. See https://kubernetes.io/docs/concepts/ scheduling-eviction/node-pressure-eviction/#eviction-signals Corresponds to the JSON property imagefsAvailable

Returns:

  • (String)


3353
3354
3355
# File 'lib/google/apis/container_v1/classes.rb', line 3353

def imagefs_available
  @imagefs_available
end

#imagefs_inodes_freeString

Optional. Grace period for eviction due to imagefs inodes free signal. Sample format: "10s". Must be >= 0. See https://kubernetes.io/docs/concepts/ scheduling-eviction/node-pressure-eviction/#eviction-signals Corresponds to the JSON property imagefsInodesFree

Returns:

  • (String)


3360
3361
3362
# File 'lib/google/apis/container_v1/classes.rb', line 3360

def imagefs_inodes_free
  @imagefs_inodes_free
end

#memory_availableString

Optional. Grace period for eviction due to memory available signal. Sample format: "10s". Must be >= 0. See https://kubernetes.io/docs/concepts/ scheduling-eviction/node-pressure-eviction/#eviction-signals Corresponds to the JSON property memoryAvailable

Returns:

  • (String)


3367
3368
3369
# File 'lib/google/apis/container_v1/classes.rb', line 3367

def memory_available
  @memory_available
end

#nodefs_availableString

Optional. Grace period for eviction due to nodefs available signal. Sample format: "10s". Must be >= 0. See https://kubernetes.io/docs/concepts/ scheduling-eviction/node-pressure-eviction/#eviction-signals Corresponds to the JSON property nodefsAvailable

Returns:

  • (String)


3374
3375
3376
# File 'lib/google/apis/container_v1/classes.rb', line 3374

def nodefs_available
  @nodefs_available
end

#nodefs_inodes_freeString

Optional. Grace period for eviction due to nodefs inodes free signal. Sample format: "10s". Must be >= 0. See https://kubernetes.io/docs/concepts/ scheduling-eviction/node-pressure-eviction/#eviction-signals Corresponds to the JSON property nodefsInodesFree

Returns:

  • (String)


3381
3382
3383
# File 'lib/google/apis/container_v1/classes.rb', line 3381

def nodefs_inodes_free
  @nodefs_inodes_free
end

#pid_availableString

Optional. Grace period for eviction due to pid available signal. Sample format: "10s". Must be >= 0. See https://kubernetes.io/docs/concepts/scheduling- eviction/node-pressure-eviction/#eviction-signals Corresponds to the JSON property pidAvailable

Returns:

  • (String)


3388
3389
3390
# File 'lib/google/apis/container_v1/classes.rb', line 3388

def pid_available
  @pid_available
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3395
3396
3397
3398
3399
3400
3401
3402
# File 'lib/google/apis/container_v1/classes.rb', line 3395

def update!(**args)
  @imagefs_available = args[:imagefs_available] if args.key?(:imagefs_available)
  @imagefs_inodes_free = args[:imagefs_inodes_free] if args.key?(:imagefs_inodes_free)
  @memory_available = args[:memory_available] if args.key?(:memory_available)
  @nodefs_available = args[:nodefs_available] if args.key?(:nodefs_available)
  @nodefs_inodes_free = args[:nodefs_inodes_free] if args.key?(:nodefs_inodes_free)
  @pid_available = args[:pid_available] if args.key?(:pid_available)
end