Class: Google::Apis::ContainerV1::EvictionGracePeriod

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

Eviction grace periods are grace periods for each eviction signal.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EvictionGracePeriod

Returns a new instance of EvictionGracePeriod.



3208
3209
3210
# File 'lib/google/apis/container_v1/classes.rb', line 3208

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#imagefs_availableString

Optional. Grace period for eviction due to imagefs available signal. Sample format: "10s". Must be >= 0. See https://kubernetes.io/docs/concepts/ scheduling-eviction/node-pressure-eviction/#eviction-signals Corresponds to the JSON property imagefsAvailable

Returns:

  • (String)


3171
3172
3173
# File 'lib/google/apis/container_v1/classes.rb', line 3171

def imagefs_available
  @imagefs_available
end

#imagefs_inodes_freeString

Optional. Grace period for eviction due to imagefs inodes free signal. Sample format: "10s". Must be >= 0. See https://kubernetes.io/docs/concepts/ scheduling-eviction/node-pressure-eviction/#eviction-signals Corresponds to the JSON property imagefsInodesFree

Returns:

  • (String)


3178
3179
3180
# File 'lib/google/apis/container_v1/classes.rb', line 3178

def imagefs_inodes_free
  @imagefs_inodes_free
end

#memory_availableString

Optional. Grace period for eviction due to memory available signal. Sample format: "10s". Must be >= 0. See https://kubernetes.io/docs/concepts/ scheduling-eviction/node-pressure-eviction/#eviction-signals Corresponds to the JSON property memoryAvailable

Returns:

  • (String)


3185
3186
3187
# File 'lib/google/apis/container_v1/classes.rb', line 3185

def memory_available
  @memory_available
end

#nodefs_availableString

Optional. Grace period for eviction due to nodefs available signal. Sample format: "10s". Must be >= 0. See https://kubernetes.io/docs/concepts/ scheduling-eviction/node-pressure-eviction/#eviction-signals Corresponds to the JSON property nodefsAvailable

Returns:

  • (String)


3192
3193
3194
# File 'lib/google/apis/container_v1/classes.rb', line 3192

def nodefs_available
  @nodefs_available
end

#nodefs_inodes_freeString

Optional. Grace period for eviction due to nodefs inodes free signal. Sample format: "10s". Must be >= 0. See https://kubernetes.io/docs/concepts/ scheduling-eviction/node-pressure-eviction/#eviction-signals Corresponds to the JSON property nodefsInodesFree

Returns:

  • (String)


3199
3200
3201
# File 'lib/google/apis/container_v1/classes.rb', line 3199

def nodefs_inodes_free
  @nodefs_inodes_free
end

#pid_availableString

Optional. Grace period for eviction due to pid available signal. Sample format: "10s". Must be >= 0. See https://kubernetes.io/docs/concepts/scheduling- eviction/node-pressure-eviction/#eviction-signals Corresponds to the JSON property pidAvailable

Returns:

  • (String)


3206
3207
3208
# File 'lib/google/apis/container_v1/classes.rb', line 3206

def pid_available
  @pid_available
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3213
3214
3215
3216
3217
3218
3219
3220
# File 'lib/google/apis/container_v1/classes.rb', line 3213

def update!(**args)
  @imagefs_available = args[:imagefs_available] if args.key?(:imagefs_available)
  @imagefs_inodes_free = args[:imagefs_inodes_free] if args.key?(:imagefs_inodes_free)
  @memory_available = args[:memory_available] if args.key?(:memory_available)
  @nodefs_available = args[:nodefs_available] if args.key?(:nodefs_available)
  @nodefs_inodes_free = args[:nodefs_inodes_free] if args.key?(:nodefs_inodes_free)
  @pid_available = args[:pid_available] if args.key?(:pid_available)
end