Class: Google::Apis::ContainerV1::EvictionMinimumReclaim
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1::EvictionMinimumReclaim
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb
Overview
Eviction minimum reclaims are the resource amounts of minimum reclaims for each eviction signal.
Instance Attribute Summary collapse
-
#imagefs_available ⇒ String
Optional.
-
#imagefs_inodes_free ⇒ String
Optional.
-
#memory_available ⇒ String
Optional.
-
#nodefs_available ⇒ String
Optional.
-
#nodefs_inodes_free ⇒ String
Optional.
-
#pid_available ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ EvictionMinimumReclaim
constructor
A new instance of EvictionMinimumReclaim.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EvictionMinimumReclaim
Returns a new instance of EvictionMinimumReclaim.
3781 3782 3783 |
# File 'lib/google/apis/container_v1/classes.rb', line 3781 def initialize(**args) update!(**args) end |
Instance Attribute Details
#imagefs_available ⇒ String
Optional. Minimum reclaim for eviction due to imagefs available signal. Only
take percentage value for now. Sample format: "10%". Must be <=10%. See https:/
/kubernetes.io/docs/concepts/scheduling-eviction/node-pressure-eviction/#
eviction-signals
Corresponds to the JSON property imagefsAvailable
3739 3740 3741 |
# File 'lib/google/apis/container_v1/classes.rb', line 3739 def imagefs_available @imagefs_available end |
#imagefs_inodes_free ⇒ String
Optional. Minimum reclaim for eviction due to imagefs inodes free signal. Only
take percentage value for now. Sample format: "10%". Must be <=10%. See https:/
/kubernetes.io/docs/concepts/scheduling-eviction/node-pressure-eviction/#
eviction-signals
Corresponds to the JSON property imagefsInodesFree
3747 3748 3749 |
# File 'lib/google/apis/container_v1/classes.rb', line 3747 def imagefs_inodes_free @imagefs_inodes_free end |
#memory_available ⇒ String
Optional. Minimum reclaim for eviction due to memory available signal. Only
take percentage value for now. Sample format: "10%". Must be <=10%. See https:/
/kubernetes.io/docs/concepts/scheduling-eviction/node-pressure-eviction/#
eviction-signals
Corresponds to the JSON property memoryAvailable
3755 3756 3757 |
# File 'lib/google/apis/container_v1/classes.rb', line 3755 def memory_available @memory_available end |
#nodefs_available ⇒ String
Optional. Minimum reclaim for eviction due to nodefs available signal. Only
take percentage value for now. Sample format: "10%". Must be <=10%. See https:/
/kubernetes.io/docs/concepts/scheduling-eviction/node-pressure-eviction/#
eviction-signals
Corresponds to the JSON property nodefsAvailable
3763 3764 3765 |
# File 'lib/google/apis/container_v1/classes.rb', line 3763 def nodefs_available @nodefs_available end |
#nodefs_inodes_free ⇒ String
Optional. Minimum reclaim for eviction due to nodefs inodes free signal. Only
take percentage value for now. Sample format: "10%". Must be <=10%. See https:/
/kubernetes.io/docs/concepts/scheduling-eviction/node-pressure-eviction/#
eviction-signals
Corresponds to the JSON property nodefsInodesFree
3771 3772 3773 |
# File 'lib/google/apis/container_v1/classes.rb', line 3771 def nodefs_inodes_free @nodefs_inodes_free end |
#pid_available ⇒ String
Optional. Minimum reclaim for eviction due to pid available signal. Only take
percentage value for now. Sample format: "10%". Must be <=10%. See https://
kubernetes.io/docs/concepts/scheduling-eviction/node-pressure-eviction/#
eviction-signals
Corresponds to the JSON property pidAvailable
3779 3780 3781 |
# File 'lib/google/apis/container_v1/classes.rb', line 3779 def pid_available @pid_available end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3786 3787 3788 3789 3790 3791 3792 3793 |
# File 'lib/google/apis/container_v1/classes.rb', line 3786 def update!(**args) @imagefs_available = args[:imagefs_available] if args.key?(:imagefs_available) @imagefs_inodes_free = args[:imagefs_inodes_free] if args.key?(:imagefs_inodes_free) @memory_available = args[:memory_available] if args.key?(:memory_available) @nodefs_available = args[:nodefs_available] if args.key?(:nodefs_available) @nodefs_inodes_free = args[:nodefs_inodes_free] if args.key?(:nodefs_inodes_free) @pid_available = args[:pid_available] if args.key?(:pid_available) end |