Class: Google::Apis::ContainerV1::EvictionMinimumReclaim

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

Eviction minimum reclaims are the resource amounts of minimum reclaims for each eviction signal.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EvictionMinimumReclaim

Returns a new instance of EvictionMinimumReclaim.



3458
3459
3460
# File 'lib/google/apis/container_v1/classes.rb', line 3458

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#imagefs_availableString

Optional. Minimum reclaim for eviction due to imagefs available signal. Only take percentage value for now. Sample format: "10%". Must be <=10%. See https:/ /kubernetes.io/docs/concepts/scheduling-eviction/node-pressure-eviction/# eviction-signals Corresponds to the JSON property imagefsAvailable

Returns:

  • (String)


3416
3417
3418
# File 'lib/google/apis/container_v1/classes.rb', line 3416

def imagefs_available
  @imagefs_available
end

#imagefs_inodes_freeString

Optional. Minimum reclaim for eviction due to imagefs inodes free signal. Only take percentage value for now. Sample format: "10%". Must be <=10%. See https:/ /kubernetes.io/docs/concepts/scheduling-eviction/node-pressure-eviction/# eviction-signals Corresponds to the JSON property imagefsInodesFree

Returns:

  • (String)


3424
3425
3426
# File 'lib/google/apis/container_v1/classes.rb', line 3424

def imagefs_inodes_free
  @imagefs_inodes_free
end

#memory_availableString

Optional. Minimum reclaim for eviction due to memory available signal. Only take percentage value for now. Sample format: "10%". Must be <=10%. See https:/ /kubernetes.io/docs/concepts/scheduling-eviction/node-pressure-eviction/# eviction-signals Corresponds to the JSON property memoryAvailable

Returns:

  • (String)


3432
3433
3434
# File 'lib/google/apis/container_v1/classes.rb', line 3432

def memory_available
  @memory_available
end

#nodefs_availableString

Optional. Minimum reclaim for eviction due to nodefs available signal. Only take percentage value for now. Sample format: "10%". Must be <=10%. See https:/ /kubernetes.io/docs/concepts/scheduling-eviction/node-pressure-eviction/# eviction-signals Corresponds to the JSON property nodefsAvailable

Returns:

  • (String)


3440
3441
3442
# File 'lib/google/apis/container_v1/classes.rb', line 3440

def nodefs_available
  @nodefs_available
end

#nodefs_inodes_freeString

Optional. Minimum reclaim for eviction due to nodefs inodes free signal. Only take percentage value for now. Sample format: "10%". Must be <=10%. See https:/ /kubernetes.io/docs/concepts/scheduling-eviction/node-pressure-eviction/# eviction-signals Corresponds to the JSON property nodefsInodesFree

Returns:

  • (String)


3448
3449
3450
# File 'lib/google/apis/container_v1/classes.rb', line 3448

def nodefs_inodes_free
  @nodefs_inodes_free
end

#pid_availableString

Optional. Minimum reclaim for eviction due to pid available signal. Only take percentage value for now. Sample format: "10%". Must be <=10%. See https:// kubernetes.io/docs/concepts/scheduling-eviction/node-pressure-eviction/# eviction-signals Corresponds to the JSON property pidAvailable

Returns:

  • (String)


3456
3457
3458
# File 'lib/google/apis/container_v1/classes.rb', line 3456

def pid_available
  @pid_available
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3463
3464
3465
3466
3467
3468
3469
3470
# File 'lib/google/apis/container_v1/classes.rb', line 3463

def update!(**args)
  @imagefs_available = args[:imagefs_available] if args.key?(:imagefs_available)
  @imagefs_inodes_free = args[:imagefs_inodes_free] if args.key?(:imagefs_inodes_free)
  @memory_available = args[:memory_available] if args.key?(:memory_available)
  @nodefs_available = args[:nodefs_available] if args.key?(:nodefs_available)
  @nodefs_inodes_free = args[:nodefs_inodes_free] if args.key?(:nodefs_inodes_free)
  @pid_available = args[:pid_available] if args.key?(:pid_available)
end