Class: Google::Apis::ContainerV1::ExclusionUntilEndOfSupport
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1::ExclusionUntilEndOfSupport
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb
Overview
Defines the maintenance exclusion for the node pool.
Instance Attribute Summary collapse
-
#enabled ⇒ Boolean
(also: #enabled?)
Optional.
-
#end_time ⇒ String
Output only.
-
#start_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExclusionUntilEndOfSupport
constructor
A new instance of ExclusionUntilEndOfSupport.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExclusionUntilEndOfSupport
Returns a new instance of ExclusionUntilEndOfSupport.
3915 3916 3917 |
# File 'lib/google/apis/container_v1/classes.rb', line 3915 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enabled ⇒ Boolean Also known as: enabled?
Optional. Indicates whether the exclusion is enabled.
Corresponds to the JSON property enabled
3899 3900 3901 |
# File 'lib/google/apis/container_v1/classes.rb', line 3899 def enabled @enabled end |
#end_time ⇒ String
Output only. The end time of the maintenance exclusion. It is output only. It
is the cluster control plane version's end of support time, or end of extended
support time when the cluster is on extended support channel.
Corresponds to the JSON property endTime
3907 3908 3909 |
# File 'lib/google/apis/container_v1/classes.rb', line 3907 def end_time @end_time end |
#start_time ⇒ String
Output only. The start time of the maintenance exclusion. It is output only.
It is the exclusion creation time.
Corresponds to the JSON property startTime
3913 3914 3915 |
# File 'lib/google/apis/container_v1/classes.rb', line 3913 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3920 3921 3922 3923 3924 |
# File 'lib/google/apis/container_v1/classes.rb', line 3920 def update!(**args) @enabled = args[:enabled] if args.key?(:enabled) @end_time = args[:end_time] if args.key?(:end_time) @start_time = args[:start_time] if args.key?(:start_time) end |