Class: Google::Apis::ContainerV1::ExclusionUntilEndOfSupport

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

Defines the maintenance exclusion for the node pool.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExclusionUntilEndOfSupport

Returns a new instance of ExclusionUntilEndOfSupport.



3902
3903
3904
# File 'lib/google/apis/container_v1/classes.rb', line 3902

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enabledBoolean Also known as: enabled?

Optional. Indicates whether the exclusion is enabled. Corresponds to the JSON property enabled

Returns:

  • (Boolean)


3886
3887
3888
# File 'lib/google/apis/container_v1/classes.rb', line 3886

def enabled
  @enabled
end

#end_timeString

Output only. The end time of the maintenance exclusion. It is output only. It is the cluster control plane version's end of support time, or end of extended support time when the cluster is on extended support channel. Corresponds to the JSON property endTime

Returns:

  • (String)


3894
3895
3896
# File 'lib/google/apis/container_v1/classes.rb', line 3894

def end_time
  @end_time
end

#start_timeString

Output only. The start time of the maintenance exclusion. It is output only. It is the exclusion creation time. Corresponds to the JSON property startTime

Returns:

  • (String)


3900
3901
3902
# File 'lib/google/apis/container_v1/classes.rb', line 3900

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3907
3908
3909
3910
3911
# File 'lib/google/apis/container_v1/classes.rb', line 3907

def update!(**args)
  @enabled = args[:enabled] if args.key?(:enabled)
  @end_time = args[:end_time] if args.key?(:end_time)
  @start_time = args[:start_time] if args.key?(:start_time)
end