Class: Google::Apis::ContainerV1::Filter

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

Allows filtering to one or more specific event types. If event types are present, those and only those event types will be transmitted to the cluster. Other types will be skipped. If no filter is specified, or no event types are present, all event types will be sent

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Filter

Returns a new instance of Filter.



3959
3960
3961
# File 'lib/google/apis/container_v1/classes.rb', line 3959

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#event_typeArray<String>

Event types to allowlist. Corresponds to the JSON property eventType

Returns:

  • (Array<String>)


3957
3958
3959
# File 'lib/google/apis/container_v1/classes.rb', line 3957

def event_type
  @event_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3964
3965
3966
# File 'lib/google/apis/container_v1/classes.rb', line 3964

def update!(**args)
  @event_type = args[:event_type] if args.key?(:event_type)
end