Class: Google::Apis::ContainerV1::Filter
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1::Filter
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb
Overview
Allows filtering to one or more specific event types. If event types are present, those and only those event types will be transmitted to the cluster. Other types will be skipped. If no filter is specified, or no event types are present, all event types will be sent
Instance Attribute Summary collapse
-
#event_type ⇒ Array<String>
Event types to allowlist.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Filter
constructor
A new instance of Filter.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Filter
Returns a new instance of Filter.
3406 3407 3408 |
# File 'lib/google/apis/container_v1/classes.rb', line 3406 def initialize(**args) update!(**args) end |
Instance Attribute Details
#event_type ⇒ Array<String>
Event types to allowlist.
Corresponds to the JSON property eventType
3404 3405 3406 |
# File 'lib/google/apis/container_v1/classes.rb', line 3404 def event_type @event_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3411 3412 3413 |
# File 'lib/google/apis/container_v1/classes.rb', line 3411 def update!(**args) @event_type = args[:event_type] if args.key?(:event_type) end |