Class: Google::Apis::ContainerV1::GetJsonWebKeysResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

GetJSONWebKeysResponse is a valid JSON Web Key Set as specified in rfc 7517

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GetJsonWebKeysResponse

Returns a new instance of GetJsonWebKeysResponse.



3840
3841
3842
# File 'lib/google/apis/container_v1/classes.rb', line 3840

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cache_headerGoogle::Apis::ContainerV1::HttpCacheControlResponseHeader

RFC-2616: cache control support Corresponds to the JSON property cacheHeader



3833
3834
3835
# File 'lib/google/apis/container_v1/classes.rb', line 3833

def cache_header
  @cache_header
end

#keysArray<Google::Apis::ContainerV1::Jwk>

The public component of the keys used by the cluster to sign token requests. Corresponds to the JSON property keys

Returns:



3838
3839
3840
# File 'lib/google/apis/container_v1/classes.rb', line 3838

def keys
  @keys
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3845
3846
3847
3848
# File 'lib/google/apis/container_v1/classes.rb', line 3845

def update!(**args)
  @cache_header = args[:cache_header] if args.key?(:cache_header)
  @keys = args[:keys] if args.key?(:keys)
end