Class: Google::Apis::ContainerV1::HostConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

HostConfig configures the registry host under a given Server.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HostConfig

Returns a new instance of HostConfig.



4418
4419
4420
# File 'lib/google/apis/container_v1/classes.rb', line 4418

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#caArray<Google::Apis::ContainerV1::CertificateConfig>

CA configures the registry host certificate. Corresponds to the JSON property ca



4373
4374
4375
# File 'lib/google/apis/container_v1/classes.rb', line 4373

def ca
  @ca
end

#capabilitiesArray<String>

Capabilities represent the capabilities of the registry host, specifying what operations a host is capable of performing. If not set, containerd enables all capabilities by default. Corresponds to the JSON property capabilities

Returns:

  • (Array<String>)


4380
4381
4382
# File 'lib/google/apis/container_v1/classes.rb', line 4380

def capabilities
  @capabilities
end

#clientArray<Google::Apis::ContainerV1::CertificateConfigPair>

Client configures the registry host client certificate and key. Corresponds to the JSON property client



4385
4386
4387
# File 'lib/google/apis/container_v1/classes.rb', line 4385

def client
  @client
end

#dial_timeoutString

Specifies the maximum duration allowed for a connection attempt to complete. A shorter timeout helps reduce delays when falling back to the original registry if the mirror is unreachable. Maximum allowed value is 180s. If not set, containerd sets default 30s. The value should be a decimal number of seconds with an s suffix. Corresponds to the JSON property dialTimeout

Returns:

  • (String)


4394
4395
4396
# File 'lib/google/apis/container_v1/classes.rb', line 4394

def dial_timeout
  @dial_timeout
end

#headerArray<Google::Apis::ContainerV1::RegistryHeader>

Header configures the registry host headers. Corresponds to the JSON property header



4399
4400
4401
# File 'lib/google/apis/container_v1/classes.rb', line 4399

def header
  @header
end

#hostString

Host configures the registry host/mirror. It supports fully qualified domain names (FQDNs) and IP addresses. Specifying scheme, port or path is supported. Scheme can only be http or https. Wildcards are NOT supported. Examples: - my. customdomain.com - https://my.customdomain.com/path - 10.0.1.2:5000 Corresponds to the JSON property host

Returns:

  • (String)


4407
4408
4409
# File 'lib/google/apis/container_v1/classes.rb', line 4407

def host
  @host
end

#override_pathBoolean Also known as: override_path?

OverridePath is used to indicate the host's API root endpoint is defined in the URL path rather than by the API specification. This may be used with non- compliant OCI registries which are missing the /v2 prefix. If not set, containerd sets default false. Corresponds to the JSON property overridePath

Returns:

  • (Boolean)


4415
4416
4417
# File 'lib/google/apis/container_v1/classes.rb', line 4415

def override_path
  @override_path
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4423
4424
4425
4426
4427
4428
4429
4430
4431
# File 'lib/google/apis/container_v1/classes.rb', line 4423

def update!(**args)
  @ca = args[:ca] if args.key?(:ca)
  @capabilities = args[:capabilities] if args.key?(:capabilities)
  @client = args[:client] if args.key?(:client)
  @dial_timeout = args[:dial_timeout] if args.key?(:dial_timeout)
  @header = args[:header] if args.key?(:header)
  @host = args[:host] if args.key?(:host)
  @override_path = args[:override_path] if args.key?(:override_path)
end