Class: Google::Apis::ContainerV1::HostConfig
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1::HostConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb
Overview
HostConfig configures the registry host under a given Server.
Instance Attribute Summary collapse
-
#ca ⇒ Array<Google::Apis::ContainerV1::CertificateConfig>
CA configures the registry host certificate.
-
#capabilities ⇒ Array<String>
Capabilities represent the capabilities of the registry host, specifying what operations a host is capable of performing.
-
#client ⇒ Array<Google::Apis::ContainerV1::CertificateConfigPair>
Client configures the registry host client certificate and key.
-
#dial_timeout ⇒ String
Specifies the maximum duration allowed for a connection attempt to complete.
-
#header ⇒ Array<Google::Apis::ContainerV1::RegistryHeader>
Header configures the registry host headers.
-
#host ⇒ String
Host configures the registry host/mirror.
-
#override_path ⇒ Boolean
(also: #override_path?)
OverridePath is used to indicate the host's API root endpoint is defined in the URL path rather than by the API specification.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HostConfig
constructor
A new instance of HostConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HostConfig
Returns a new instance of HostConfig.
4046 4047 4048 |
# File 'lib/google/apis/container_v1/classes.rb', line 4046 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ca ⇒ Array<Google::Apis::ContainerV1::CertificateConfig>
CA configures the registry host certificate.
Corresponds to the JSON property ca
4002 4003 4004 |
# File 'lib/google/apis/container_v1/classes.rb', line 4002 def ca @ca end |
#capabilities ⇒ Array<String>
Capabilities represent the capabilities of the registry host, specifying what
operations a host is capable of performing. If not set, containerd enables all
capabilities by default.
Corresponds to the JSON property capabilities
4009 4010 4011 |
# File 'lib/google/apis/container_v1/classes.rb', line 4009 def capabilities @capabilities end |
#client ⇒ Array<Google::Apis::ContainerV1::CertificateConfigPair>
Client configures the registry host client certificate and key.
Corresponds to the JSON property client
4014 4015 4016 |
# File 'lib/google/apis/container_v1/classes.rb', line 4014 def client @client end |
#dial_timeout ⇒ String
Specifies the maximum duration allowed for a connection attempt to complete. A
shorter timeout helps reduce delays when falling back to the original registry
if the mirror is unreachable. Maximum allowed value is 180s. If not set,
containerd sets default 30s. The value should be a decimal number of seconds
with an s suffix.
Corresponds to the JSON property dialTimeout
4023 4024 4025 |
# File 'lib/google/apis/container_v1/classes.rb', line 4023 def dial_timeout @dial_timeout end |
#header ⇒ Array<Google::Apis::ContainerV1::RegistryHeader>
Header configures the registry host headers.
Corresponds to the JSON property header
4028 4029 4030 |
# File 'lib/google/apis/container_v1/classes.rb', line 4028 def header @header end |
#host ⇒ String
Host configures the registry host/mirror. It supports fully qualified domain
names (FQDN) and IP addresses: Specifying port is supported. Wildcards are NOT
supported. Examples: - my.customdomain.com - 10.0.1.2:5000
Corresponds to the JSON property host
4035 4036 4037 |
# File 'lib/google/apis/container_v1/classes.rb', line 4035 def host @host end |
#override_path ⇒ Boolean Also known as: override_path?
OverridePath is used to indicate the host's API root endpoint is defined in
the URL path rather than by the API specification. This may be used with non-
compliant OCI registries which are missing the /v2 prefix. If not set,
containerd sets default false.
Corresponds to the JSON property overridePath
4043 4044 4045 |
# File 'lib/google/apis/container_v1/classes.rb', line 4043 def override_path @override_path end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4051 4052 4053 4054 4055 4056 4057 4058 4059 |
# File 'lib/google/apis/container_v1/classes.rb', line 4051 def update!(**args) @ca = args[:ca] if args.key?(:ca) @capabilities = args[:capabilities] if args.key?(:capabilities) @client = args[:client] if args.key?(:client) @dial_timeout = args[:dial_timeout] if args.key?(:dial_timeout) @header = args[:header] if args.key?(:header) @host = args[:host] if args.key?(:host) @override_path = args[:override_path] if args.key?(:override_path) end |