Class: Google::Apis::ContainerV1::HostConfig
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1::HostConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb
Overview
HostConfig configures the registry host under a given Server.
Instance Attribute Summary collapse
-
#ca ⇒ Array<Google::Apis::ContainerV1::CertificateConfig>
CA configures the registry host certificate.
-
#capabilities ⇒ Array<String>
Capabilities represent the capabilities of the registry host, specifying what operations a host is capable of performing.
-
#client ⇒ Array<Google::Apis::ContainerV1::CertificateConfigPair>
Client configures the registry host client certificate and key.
-
#dial_timeout ⇒ String
Specifies the maximum duration allowed for a connection attempt to complete.
-
#header ⇒ Array<Google::Apis::ContainerV1::RegistryHeader>
Header configures the registry host headers.
-
#host ⇒ String
Host configures the registry host/mirror.
-
#override_path ⇒ Boolean
(also: #override_path?)
OverridePath is used to indicate the host's API root endpoint is defined in the URL path rather than by the API specification.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HostConfig
constructor
A new instance of HostConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HostConfig
Returns a new instance of HostConfig.
3845 3846 3847 |
# File 'lib/google/apis/container_v1/classes.rb', line 3845 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ca ⇒ Array<Google::Apis::ContainerV1::CertificateConfig>
CA configures the registry host certificate.
Corresponds to the JSON property ca
3801 3802 3803 |
# File 'lib/google/apis/container_v1/classes.rb', line 3801 def ca @ca end |
#capabilities ⇒ Array<String>
Capabilities represent the capabilities of the registry host, specifying what
operations a host is capable of performing. If not set, containerd enables all
capabilities by default.
Corresponds to the JSON property capabilities
3808 3809 3810 |
# File 'lib/google/apis/container_v1/classes.rb', line 3808 def capabilities @capabilities end |
#client ⇒ Array<Google::Apis::ContainerV1::CertificateConfigPair>
Client configures the registry host client certificate and key.
Corresponds to the JSON property client
3813 3814 3815 |
# File 'lib/google/apis/container_v1/classes.rb', line 3813 def client @client end |
#dial_timeout ⇒ String
Specifies the maximum duration allowed for a connection attempt to complete. A
shorter timeout helps reduce delays when falling back to the original registry
if the mirror is unreachable. Maximum allowed value is 180s. If not set,
containerd sets default 30s. The value should be a decimal number of seconds
with an s suffix.
Corresponds to the JSON property dialTimeout
3822 3823 3824 |
# File 'lib/google/apis/container_v1/classes.rb', line 3822 def dial_timeout @dial_timeout end |
#header ⇒ Array<Google::Apis::ContainerV1::RegistryHeader>
Header configures the registry host headers.
Corresponds to the JSON property header
3827 3828 3829 |
# File 'lib/google/apis/container_v1/classes.rb', line 3827 def header @header end |
#host ⇒ String
Host configures the registry host/mirror. It supports fully qualified domain
names (FQDN) and IP addresses: Specifying port is supported. Wildcards are NOT
supported. Examples: - my.customdomain.com - 10.0.1.2:5000
Corresponds to the JSON property host
3834 3835 3836 |
# File 'lib/google/apis/container_v1/classes.rb', line 3834 def host @host end |
#override_path ⇒ Boolean Also known as: override_path?
OverridePath is used to indicate the host's API root endpoint is defined in
the URL path rather than by the API specification. This may be used with non-
compliant OCI registries which are missing the /v2 prefix. If not set,
containerd sets default false.
Corresponds to the JSON property overridePath
3842 3843 3844 |
# File 'lib/google/apis/container_v1/classes.rb', line 3842 def override_path @override_path end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3850 3851 3852 3853 3854 3855 3856 3857 3858 |
# File 'lib/google/apis/container_v1/classes.rb', line 3850 def update!(**args) @ca = args[:ca] if args.key?(:ca) @capabilities = args[:capabilities] if args.key?(:capabilities) @client = args[:client] if args.key?(:client) @dial_timeout = args[:dial_timeout] if args.key?(:dial_timeout) @header = args[:header] if args.key?(:header) @host = args[:host] if args.key?(:host) @override_path = args[:override_path] if args.key?(:override_path) end |