Class: Google::Apis::ContainerV1::IpEndpointsConfig
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1::IpEndpointsConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb
Overview
IP endpoints configuration.
Instance Attribute Summary collapse
-
#authorized_networks_config ⇒ Google::Apis::ContainerV1::MasterAuthorizedNetworksConfig
Configuration options for the master authorized networks feature.
-
#enable_public_endpoint ⇒ Boolean
(also: #enable_public_endpoint?)
Controls whether the control plane allows access through a public IP.
-
#enabled ⇒ Boolean
(also: #enabled?)
Controls whether to allow direct IP access.
-
#global_access ⇒ Boolean
(also: #global_access?)
Controls whether the control plane's private endpoint is accessible from sources in other regions.
-
#private_endpoint ⇒ String
Output only.
-
#private_endpoint_subnetwork ⇒ String
Subnet to provision the master's private endpoint during cluster creation.
-
#public_endpoint ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ IpEndpointsConfig
constructor
A new instance of IpEndpointsConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ IpEndpointsConfig
Returns a new instance of IpEndpointsConfig.
4776 4777 4778 |
# File 'lib/google/apis/container_v1/classes.rb', line 4776 def initialize(**args) update!(**args) end |
Instance Attribute Details
#authorized_networks_config ⇒ Google::Apis::ContainerV1::MasterAuthorizedNetworksConfig
Configuration options for the master authorized networks feature. Enabled
master authorized networks will disallow all external traffic to access
Kubernetes master through HTTPS except traffic from the given CIDR blocks,
Google Compute Engine Public IPs and Google Prod IPs.
Corresponds to the JSON property authorizedNetworksConfig
4732 4733 4734 |
# File 'lib/google/apis/container_v1/classes.rb', line 4732 def @authorized_networks_config end |
#enable_public_endpoint ⇒ Boolean Also known as: enable_public_endpoint?
Controls whether the control plane allows access through a public IP. It is
invalid to specify both PrivateClusterConfig.enablePrivateEndpoint and this
field at the same time.
Corresponds to the JSON property enablePublicEndpoint
4739 4740 4741 |
# File 'lib/google/apis/container_v1/classes.rb', line 4739 def enable_public_endpoint @enable_public_endpoint end |
#enabled ⇒ Boolean Also known as: enabled?
Controls whether to allow direct IP access.
Corresponds to the JSON property enabled
4745 4746 4747 |
# File 'lib/google/apis/container_v1/classes.rb', line 4745 def enabled @enabled end |
#global_access ⇒ Boolean Also known as: global_access?
Controls whether the control plane's private endpoint is accessible from
sources in other regions. It is invalid to specify both
PrivateClusterMasterGlobalAccessConfig.enabled and this field at the same time.
Corresponds to the JSON property globalAccess
4753 4754 4755 |
# File 'lib/google/apis/container_v1/classes.rb', line 4753 def global_access @global_access end |
#private_endpoint ⇒ String
Output only. The internal IP address of this cluster's control plane. Only
populated if enabled.
Corresponds to the JSON property privateEndpoint
4760 4761 4762 |
# File 'lib/google/apis/container_v1/classes.rb', line 4760 def private_endpoint @private_endpoint end |
#private_endpoint_subnetwork ⇒ String
Subnet to provision the master's private endpoint during cluster creation.
Specified in projects//regions//subnetworks/* format. It is invalid to
specify both PrivateClusterConfig.privateEndpointSubnetwork and this field at
the same time.
Corresponds to the JSON property privateEndpointSubnetwork
4768 4769 4770 |
# File 'lib/google/apis/container_v1/classes.rb', line 4768 def private_endpoint_subnetwork @private_endpoint_subnetwork end |
#public_endpoint ⇒ String
Output only. The external IP address of this cluster's control plane. Only
populated if enabled.
Corresponds to the JSON property publicEndpoint
4774 4775 4776 |
# File 'lib/google/apis/container_v1/classes.rb', line 4774 def public_endpoint @public_endpoint end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4781 4782 4783 4784 4785 4786 4787 4788 4789 |
# File 'lib/google/apis/container_v1/classes.rb', line 4781 def update!(**args) @authorized_networks_config = args[:authorized_networks_config] if args.key?(:authorized_networks_config) @enable_public_endpoint = args[:enable_public_endpoint] if args.key?(:enable_public_endpoint) @enabled = args[:enabled] if args.key?(:enabled) @global_access = args[:global_access] if args.key?(:global_access) @private_endpoint = args[:private_endpoint] if args.key?(:private_endpoint) @private_endpoint_subnetwork = args[:private_endpoint_subnetwork] if args.key?(:private_endpoint_subnetwork) @public_endpoint = args[:public_endpoint] if args.key?(:public_endpoint) end |