Class: Google::Apis::ContainerV1::IpEndpointsConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

IP endpoints configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IpEndpointsConfig

Returns a new instance of IpEndpointsConfig.



4216
4217
4218
# File 'lib/google/apis/container_v1/classes.rb', line 4216

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#authorized_networks_configGoogle::Apis::ContainerV1::MasterAuthorizedNetworksConfig

Configuration options for the master authorized networks feature. Enabled master authorized networks will disallow all external traffic to access Kubernetes master through HTTPS except traffic from the given CIDR blocks, Google Compute Engine Public IPs and Google Prod IPs. Corresponds to the JSON property authorizedNetworksConfig



4172
4173
4174
# File 'lib/google/apis/container_v1/classes.rb', line 4172

def authorized_networks_config
  @authorized_networks_config
end

#enable_public_endpointBoolean Also known as: enable_public_endpoint?

Controls whether the control plane allows access through a public IP. It is invalid to specify both PrivateClusterConfig.enablePrivateEndpoint and this field at the same time. Corresponds to the JSON property enablePublicEndpoint

Returns:

  • (Boolean)


4179
4180
4181
# File 'lib/google/apis/container_v1/classes.rb', line 4179

def enable_public_endpoint
  @enable_public_endpoint
end

#enabledBoolean Also known as: enabled?

Controls whether to allow direct IP access. Corresponds to the JSON property enabled

Returns:

  • (Boolean)


4185
4186
4187
# File 'lib/google/apis/container_v1/classes.rb', line 4185

def enabled
  @enabled
end

#global_accessBoolean Also known as: global_access?

Controls whether the control plane's private endpoint is accessible from sources in other regions. It is invalid to specify both PrivateClusterMasterGlobalAccessConfig.enabled and this field at the same time. Corresponds to the JSON property globalAccess

Returns:

  • (Boolean)


4193
4194
4195
# File 'lib/google/apis/container_v1/classes.rb', line 4193

def global_access
  @global_access
end

#private_endpointString

Output only. The internal IP address of this cluster's control plane. Only populated if enabled. Corresponds to the JSON property privateEndpoint

Returns:

  • (String)


4200
4201
4202
# File 'lib/google/apis/container_v1/classes.rb', line 4200

def private_endpoint
  @private_endpoint
end

#private_endpoint_subnetworkString

Subnet to provision the master's private endpoint during cluster creation. Specified in projects//regions//subnetworks/* format. It is invalid to specify both PrivateClusterConfig.privateEndpointSubnetwork and this field at the same time. Corresponds to the JSON property privateEndpointSubnetwork

Returns:

  • (String)


4208
4209
4210
# File 'lib/google/apis/container_v1/classes.rb', line 4208

def private_endpoint_subnetwork
  @private_endpoint_subnetwork
end

#public_endpointString

Output only. The external IP address of this cluster's control plane. Only populated if enabled. Corresponds to the JSON property publicEndpoint

Returns:

  • (String)


4214
4215
4216
# File 'lib/google/apis/container_v1/classes.rb', line 4214

def public_endpoint
  @public_endpoint
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4221
4222
4223
4224
4225
4226
4227
4228
4229
# File 'lib/google/apis/container_v1/classes.rb', line 4221

def update!(**args)
  @authorized_networks_config = args[:authorized_networks_config] if args.key?(:authorized_networks_config)
  @enable_public_endpoint = args[:enable_public_endpoint] if args.key?(:enable_public_endpoint)
  @enabled = args[:enabled] if args.key?(:enabled)
  @global_access = args[:global_access] if args.key?(:global_access)
  @private_endpoint = args[:private_endpoint] if args.key?(:private_endpoint)
  @private_endpoint_subnetwork = args[:private_endpoint_subnetwork] if args.key?(:private_endpoint_subnetwork)
  @public_endpoint = args[:public_endpoint] if args.key?(:public_endpoint)
end