Class: Google::Apis::ContainerV1::LegacyAbac

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

Configuration for the legacy Attribute Based Access Control authorization mode.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LegacyAbac

Returns a new instance of LegacyAbac.



5015
5016
5017
# File 'lib/google/apis/container_v1/classes.rb', line 5015

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enabledBoolean Also known as: enabled?

Whether the ABAC authorizer is enabled for this cluster. When enabled, identities in the system, including service accounts, nodes, and controllers, will have statically granted permissions beyond those provided by the RBAC configuration or IAM. Corresponds to the JSON property enabled

Returns:

  • (Boolean)


5012
5013
5014
# File 'lib/google/apis/container_v1/classes.rb', line 5012

def enabled
  @enabled
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5020
5021
5022
# File 'lib/google/apis/container_v1/classes.rb', line 5020

def update!(**args)
  @enabled = args[:enabled] if args.key?(:enabled)
end