Class: Google::Apis::ContainerV1::LinuxNodeConfig
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1::LinuxNodeConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb
Overview
Parameters that can be configured on Linux nodes.
Instance Attribute Summary collapse
-
#cgroup_mode ⇒ String
cgroup_mode specifies the cgroup mode to be used on the node.
-
#hugepages ⇒ Google::Apis::ContainerV1::HugepagesConfig
Hugepages amount in both 2m and 1g size Corresponds to the JSON property
hugepages. -
#node_kernel_module_loading ⇒ Google::Apis::ContainerV1::NodeKernelModuleLoading
Configuration for kernel module loading on nodes.
-
#swap_config ⇒ Google::Apis::ContainerV1::SwapConfig
Configuration for swap memory on a node pool.
-
#sysctls ⇒ Hash<String,String>
The Linux kernel parameters to be applied to the nodes and all pods running on the nodes.
-
#transparent_hugepage_defrag ⇒ String
Optional.
-
#transparent_hugepage_enabled ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LinuxNodeConfig
constructor
A new instance of LinuxNodeConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LinuxNodeConfig
Returns a new instance of LinuxNodeConfig.
4668 4669 4670 |
# File 'lib/google/apis/container_v1/classes.rb', line 4668 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cgroup_mode ⇒ String
cgroup_mode specifies the cgroup mode to be used on the node.
Corresponds to the JSON property cgroupMode
4611 4612 4613 |
# File 'lib/google/apis/container_v1/classes.rb', line 4611 def cgroup_mode @cgroup_mode end |
#hugepages ⇒ Google::Apis::ContainerV1::HugepagesConfig
Hugepages amount in both 2m and 1g size
Corresponds to the JSON property hugepages
4616 4617 4618 |
# File 'lib/google/apis/container_v1/classes.rb', line 4616 def hugepages @hugepages end |
#node_kernel_module_loading ⇒ Google::Apis::ContainerV1::NodeKernelModuleLoading
Configuration for kernel module loading on nodes.
Corresponds to the JSON property nodeKernelModuleLoading
4621 4622 4623 |
# File 'lib/google/apis/container_v1/classes.rb', line 4621 def node_kernel_module_loading @node_kernel_module_loading end |
#swap_config ⇒ Google::Apis::ContainerV1::SwapConfig
Configuration for swap memory on a node pool.
Corresponds to the JSON property swapConfig
4626 4627 4628 |
# File 'lib/google/apis/container_v1/classes.rb', line 4626 def swap_config @swap_config end |
#sysctls ⇒ Hash<String,String>
The Linux kernel parameters to be applied to the nodes and all pods running on
the nodes. The following parameters are supported. net.core.busy_poll net.core.
busy_read net.core.netdev_max_backlog net.core.rmem_max net.core.rmem_default
net.core.wmem_default net.core.wmem_max net.core.optmem_max net.core.somaxconn
net.ipv4.tcp_rmem net.ipv4.tcp_wmem net.ipv4.tcp_tw_reuse net.ipv4.
tcp_mtu_probing net.ipv4.tcp_max_orphans net.ipv4.tcp_max_tw_buckets net.ipv4.
tcp_syn_retries net.ipv4.tcp_ecn net.ipv4.tcp_congestion_control net.netfilter.
nf_conntrack_max net.netfilter.nf_conntrack_buckets net.netfilter.
nf_conntrack_tcp_timeout_close_wait net.netfilter.
nf_conntrack_tcp_timeout_time_wait net.netfilter.
nf_conntrack_tcp_timeout_established net.netfilter.nf_conntrack_acct kernel.
shmmni kernel.shmmax kernel.shmall kernel.perf_event_paranoid kernel.
sched_rt_runtime_us kernel.softlockup_panic kernel.yama.ptrace_scope kernel.
kptr_restrict kernel.dmesg_restrict kernel.sysrq fs.aio-max-nr fs.file-max fs.
inotify.max_user_instances fs.inotify.max_user_watches fs.nr_open vm.
dirty_background_ratio vm.dirty_background_bytes vm.dirty_expire_centisecs vm.
dirty_ratio vm.dirty_bytes vm.dirty_writeback_centisecs vm.max_map_count vm.
overcommit_memory vm.overcommit_ratio vm.vfs_cache_pressure vm.swappiness vm.
watermark_scale_factor vm.min_free_kbytes
Corresponds to the JSON property sysctls
4649 4650 4651 |
# File 'lib/google/apis/container_v1/classes.rb', line 4649 def sysctls @sysctls end |
#transparent_hugepage_defrag ⇒ String
Optional. Defines the transparent hugepage defrag configuration on the node.
VM hugepage allocation can be managed by either limiting defragmentation for
delayed allocation or skipping it entirely for immediate allocation only. See
https://docs.kernel.org/admin-guide/mm/transhuge.html for more details.
Corresponds to the JSON property transparentHugepageDefrag
4657 4658 4659 |
# File 'lib/google/apis/container_v1/classes.rb', line 4657 def transparent_hugepage_defrag @transparent_hugepage_defrag end |
#transparent_hugepage_enabled ⇒ String
Optional. Transparent hugepage support for anonymous memory can be entirely
disabled (mostly for debugging purposes) or only enabled inside MADV_HUGEPAGE
regions (to avoid the risk of consuming more memory resources) or enabled
system wide. See https://docs.kernel.org/admin-guide/mm/transhuge.html for
more details.
Corresponds to the JSON property transparentHugepageEnabled
4666 4667 4668 |
# File 'lib/google/apis/container_v1/classes.rb', line 4666 def transparent_hugepage_enabled @transparent_hugepage_enabled end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4673 4674 4675 4676 4677 4678 4679 4680 4681 |
# File 'lib/google/apis/container_v1/classes.rb', line 4673 def update!(**args) @cgroup_mode = args[:cgroup_mode] if args.key?(:cgroup_mode) @hugepages = args[:hugepages] if args.key?(:hugepages) @node_kernel_module_loading = args[:node_kernel_module_loading] if args.key?(:node_kernel_module_loading) @swap_config = args[:swap_config] if args.key?(:swap_config) @sysctls = args[:sysctls] if args.key?(:sysctls) @transparent_hugepage_defrag = args[:transparent_hugepage_defrag] if args.key?(:transparent_hugepage_defrag) @transparent_hugepage_enabled = args[:transparent_hugepage_enabled] if args.key?(:transparent_hugepage_enabled) end |