Class: Google::Apis::ContainerV1::MaintenancePolicy
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1::MaintenancePolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb
Overview
MaintenancePolicy defines the maintenance policy to be used for the cluster.
Instance Attribute Summary collapse
-
#resource_version ⇒ String
A hash identifying the version of this policy, so that updates to fields of the policy won't accidentally undo intermediate changes (and so that users of the API unaware of some fields won't accidentally remove other fields).
-
#window ⇒ Google::Apis::ContainerV1::MaintenanceWindow
MaintenanceWindow defines the maintenance window to be used for the cluster.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MaintenancePolicy
constructor
A new instance of MaintenancePolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MaintenancePolicy
Returns a new instance of MaintenancePolicy.
4741 4742 4743 |
# File 'lib/google/apis/container_v1/classes.rb', line 4741 def initialize(**args) update!(**args) end |
Instance Attribute Details
#resource_version ⇒ String
A hash identifying the version of this policy, so that updates to fields of
the policy won't accidentally undo intermediate changes (and so that users of
the API unaware of some fields won't accidentally remove other fields). Make a
get() request to the cluster to get the current resource version and include
it with requests to set the policy.
Corresponds to the JSON property resourceVersion
4734 4735 4736 |
# File 'lib/google/apis/container_v1/classes.rb', line 4734 def resource_version @resource_version end |
#window ⇒ Google::Apis::ContainerV1::MaintenanceWindow
MaintenanceWindow defines the maintenance window to be used for the cluster.
Corresponds to the JSON property window
4739 4740 4741 |
# File 'lib/google/apis/container_v1/classes.rb', line 4739 def window @window end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4746 4747 4748 4749 |
# File 'lib/google/apis/container_v1/classes.rb', line 4746 def update!(**args) @resource_version = args[:resource_version] if args.key?(:resource_version) @window = args[:window] if args.key?(:window) end |