Class: Google::Apis::ContainerV1::MasterAuth

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

The authentication information for accessing the master endpoint. Authentication can be done using HTTP basic auth or using client certificates.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MasterAuth

Returns a new instance of MasterAuth.



5557
5558
5559
# File 'lib/google/apis/container_v1/classes.rb', line 5557

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#client_certificateString

Output only. Base64-encoded public certificate used by clients to authenticate to the cluster endpoint. Issued only if client_certificate_config is set. Corresponds to the JSON property clientCertificate

Returns:

  • (String)


5516
5517
5518
# File 'lib/google/apis/container_v1/classes.rb', line 5516

def client_certificate
  @client_certificate
end

#client_certificate_configGoogle::Apis::ContainerV1::ClientCertificateConfig

Configuration for client certificates on the cluster. Corresponds to the JSON property clientCertificateConfig



5521
5522
5523
# File 'lib/google/apis/container_v1/classes.rb', line 5521

def client_certificate_config
  @client_certificate_config
end

#client_keyString

Output only. Base64-encoded private key used by clients to authenticate to the cluster endpoint. Corresponds to the JSON property clientKey

Returns:

  • (String)


5527
5528
5529
# File 'lib/google/apis/container_v1/classes.rb', line 5527

def client_key
  @client_key
end

#cluster_ca_certificateString

Output only. Base64-encoded public certificate that is the root of trust for the cluster. Corresponds to the JSON property clusterCaCertificate

Returns:

  • (String)


5533
5534
5535
# File 'lib/google/apis/container_v1/classes.rb', line 5533

def cluster_ca_certificate
  @cluster_ca_certificate
end

#passwordString

The password to use for HTTP basic authentication to the master endpoint. Because the master endpoint is open to the Internet, you should create a strong password. If a password is provided for cluster creation, username must be non-empty. Warning: basic authentication is deprecated, and will be removed in GKE control plane versions 1.19 and newer. For a list of recommended authentication methods, see: https://cloud.google.com/kubernetes-engine/docs/ how-to/api-server-authentication Corresponds to the JSON property password

Returns:

  • (String)


5544
5545
5546
# File 'lib/google/apis/container_v1/classes.rb', line 5544

def password
  @password
end

#usernameString

The username to use for HTTP basic authentication to the master endpoint. For clusters v1.6.0 and later, basic authentication can be disabled by leaving username unspecified (or setting it to the empty string). Warning: basic authentication is deprecated, and will be removed in GKE control plane versions 1.19 and newer. For a list of recommended authentication methods, see: https://cloud.google.com/kubernetes-engine/docs/how-to/api-server- authentication Corresponds to the JSON property username

Returns:

  • (String)


5555
5556
5557
# File 'lib/google/apis/container_v1/classes.rb', line 5555

def username
  @username
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5562
5563
5564
5565
5566
5567
5568
5569
# File 'lib/google/apis/container_v1/classes.rb', line 5562

def update!(**args)
  @client_certificate = args[:client_certificate] if args.key?(:client_certificate)
  @client_certificate_config = args[:client_certificate_config] if args.key?(:client_certificate_config)
  @client_key = args[:client_key] if args.key?(:client_key)
  @cluster_ca_certificate = args[:cluster_ca_certificate] if args.key?(:cluster_ca_certificate)
  @password = args[:password] if args.key?(:password)
  @username = args[:username] if args.key?(:username)
end