Class: Google::Apis::ContainerV1::MasterAuth

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

The authentication information for accessing the master endpoint. Authentication can be done using HTTP basic auth or using client certificates.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MasterAuth

Returns a new instance of MasterAuth.



4882
4883
4884
# File 'lib/google/apis/container_v1/classes.rb', line 4882

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#client_certificateString

Output only. Base64-encoded public certificate used by clients to authenticate to the cluster endpoint. Issued only if client_certificate_config is set. Corresponds to the JSON property clientCertificate

Returns:

  • (String)


4841
4842
4843
# File 'lib/google/apis/container_v1/classes.rb', line 4841

def client_certificate
  @client_certificate
end

#client_certificate_configGoogle::Apis::ContainerV1::ClientCertificateConfig

Configuration for client certificates on the cluster. Corresponds to the JSON property clientCertificateConfig



4846
4847
4848
# File 'lib/google/apis/container_v1/classes.rb', line 4846

def client_certificate_config
  @client_certificate_config
end

#client_keyString

Output only. Base64-encoded private key used by clients to authenticate to the cluster endpoint. Corresponds to the JSON property clientKey

Returns:

  • (String)


4852
4853
4854
# File 'lib/google/apis/container_v1/classes.rb', line 4852

def client_key
  @client_key
end

#cluster_ca_certificateString

Output only. Base64-encoded public certificate that is the root of trust for the cluster. Corresponds to the JSON property clusterCaCertificate

Returns:

  • (String)


4858
4859
4860
# File 'lib/google/apis/container_v1/classes.rb', line 4858

def cluster_ca_certificate
  @cluster_ca_certificate
end

#passwordString

The password to use for HTTP basic authentication to the master endpoint. Because the master endpoint is open to the Internet, you should create a strong password. If a password is provided for cluster creation, username must be non-empty. Warning: basic authentication is deprecated, and will be removed in GKE control plane versions 1.19 and newer. For a list of recommended authentication methods, see: https://cloud.google.com/kubernetes-engine/docs/ how-to/api-server-authentication Corresponds to the JSON property password

Returns:

  • (String)


4869
4870
4871
# File 'lib/google/apis/container_v1/classes.rb', line 4869

def password
  @password
end

#usernameString

The username to use for HTTP basic authentication to the master endpoint. For clusters v1.6.0 and later, basic authentication can be disabled by leaving username unspecified (or setting it to the empty string). Warning: basic authentication is deprecated, and will be removed in GKE control plane versions 1.19 and newer. For a list of recommended authentication methods, see: https://cloud.google.com/kubernetes-engine/docs/how-to/api-server- authentication Corresponds to the JSON property username

Returns:

  • (String)


4880
4881
4882
# File 'lib/google/apis/container_v1/classes.rb', line 4880

def username
  @username
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4887
4888
4889
4890
4891
4892
4893
4894
# File 'lib/google/apis/container_v1/classes.rb', line 4887

def update!(**args)
  @client_certificate = args[:client_certificate] if args.key?(:client_certificate)
  @client_certificate_config = args[:client_certificate_config] if args.key?(:client_certificate_config)
  @client_key = args[:client_key] if args.key?(:client_key)
  @cluster_ca_certificate = args[:cluster_ca_certificate] if args.key?(:cluster_ca_certificate)
  @password = args[:password] if args.key?(:password)
  @username = args[:username] if args.key?(:username)
end