Class: Google::Apis::ContainerV1::MasterAuthorizedNetworksConfig
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1::MasterAuthorizedNetworksConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb
Overview
Configuration options for the master authorized networks feature. Enabled master authorized networks will disallow all external traffic to access Kubernetes master through HTTPS except traffic from the given CIDR blocks, Google Compute Engine Public IPs and Google Prod IPs.
Instance Attribute Summary collapse
-
#cidr_blocks ⇒ Array<Google::Apis::ContainerV1::CidrBlock>
cidr_blocks define up to 50 external networks that could access Kubernetes master through HTTPS.
-
#enabled ⇒ Boolean
(also: #enabled?)
Whether or not master authorized networks is enabled.
-
#gcp_public_cidrs_access_enabled ⇒ Boolean
(also: #gcp_public_cidrs_access_enabled?)
Whether master is accessible via Google Compute Engine Public IP addresses.
-
#private_endpoint_enforcement_enabled ⇒ Boolean
(also: #private_endpoint_enforcement_enabled?)
Whether master authorized networks is enforced on private endpoint or not.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MasterAuthorizedNetworksConfig
constructor
A new instance of MasterAuthorizedNetworksConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MasterAuthorizedNetworksConfig
Returns a new instance of MasterAuthorizedNetworksConfig.
5616 5617 5618 |
# File 'lib/google/apis/container_v1/classes.rb', line 5616 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cidr_blocks ⇒ Array<Google::Apis::ContainerV1::CidrBlock>
cidr_blocks define up to 50 external networks that could access Kubernetes
master through HTTPS.
Corresponds to the JSON property cidrBlocks
5596 5597 5598 |
# File 'lib/google/apis/container_v1/classes.rb', line 5596 def cidr_blocks @cidr_blocks end |
#enabled ⇒ Boolean Also known as: enabled?
Whether or not master authorized networks is enabled.
Corresponds to the JSON property enabled
5601 5602 5603 |
# File 'lib/google/apis/container_v1/classes.rb', line 5601 def enabled @enabled end |
#gcp_public_cidrs_access_enabled ⇒ Boolean Also known as: gcp_public_cidrs_access_enabled?
Whether master is accessible via Google Compute Engine Public IP addresses.
Corresponds to the JSON property gcpPublicCidrsAccessEnabled
5607 5608 5609 |
# File 'lib/google/apis/container_v1/classes.rb', line 5607 def gcp_public_cidrs_access_enabled @gcp_public_cidrs_access_enabled end |
#private_endpoint_enforcement_enabled ⇒ Boolean Also known as: private_endpoint_enforcement_enabled?
Whether master authorized networks is enforced on private endpoint or not.
Corresponds to the JSON property privateEndpointEnforcementEnabled
5613 5614 5615 |
# File 'lib/google/apis/container_v1/classes.rb', line 5613 def private_endpoint_enforcement_enabled @private_endpoint_enforcement_enabled end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5621 5622 5623 5624 5625 5626 |
# File 'lib/google/apis/container_v1/classes.rb', line 5621 def update!(**args) @cidr_blocks = args[:cidr_blocks] if args.key?(:cidr_blocks) @enabled = args[:enabled] if args.key?(:enabled) @gcp_public_cidrs_access_enabled = args[:gcp_public_cidrs_access_enabled] if args.key?(:gcp_public_cidrs_access_enabled) @private_endpoint_enforcement_enabled = args[:private_endpoint_enforcement_enabled] if args.key?(:private_endpoint_enforcement_enabled) end |