Class: Google::Apis::ContainerV1::MasterAuthorizedNetworksConfig
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1::MasterAuthorizedNetworksConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb
Overview
Configuration options for the master authorized networks feature. Enabled master authorized networks will disallow all external traffic to access Kubernetes master through HTTPS except traffic from the given CIDR blocks, Google Compute Engine Public IPs and Google Prod IPs.
Instance Attribute Summary collapse
-
#cidr_blocks ⇒ Array<Google::Apis::ContainerV1::CidrBlock>
cidr_blocks define up to 50 external networks that could access Kubernetes master through HTTPS.
-
#enabled ⇒ Boolean
(also: #enabled?)
Whether or not master authorized networks is enabled.
-
#gcp_public_cidrs_access_enabled ⇒ Boolean
(also: #gcp_public_cidrs_access_enabled?)
Whether master is accessible via Google Compute Engine Public IP addresses.
-
#private_endpoint_enforcement_enabled ⇒ Boolean
(also: #private_endpoint_enforcement_enabled?)
Whether master authorized networks is enforced on private endpoint or not.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MasterAuthorizedNetworksConfig
constructor
A new instance of MasterAuthorizedNetworksConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MasterAuthorizedNetworksConfig
Returns a new instance of MasterAuthorizedNetworksConfig.
4928 4929 4930 |
# File 'lib/google/apis/container_v1/classes.rb', line 4928 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cidr_blocks ⇒ Array<Google::Apis::ContainerV1::CidrBlock>
cidr_blocks define up to 50 external networks that could access Kubernetes
master through HTTPS.
Corresponds to the JSON property cidrBlocks
4908 4909 4910 |
# File 'lib/google/apis/container_v1/classes.rb', line 4908 def cidr_blocks @cidr_blocks end |
#enabled ⇒ Boolean Also known as: enabled?
Whether or not master authorized networks is enabled.
Corresponds to the JSON property enabled
4913 4914 4915 |
# File 'lib/google/apis/container_v1/classes.rb', line 4913 def enabled @enabled end |
#gcp_public_cidrs_access_enabled ⇒ Boolean Also known as: gcp_public_cidrs_access_enabled?
Whether master is accessible via Google Compute Engine Public IP addresses.
Corresponds to the JSON property gcpPublicCidrsAccessEnabled
4919 4920 4921 |
# File 'lib/google/apis/container_v1/classes.rb', line 4919 def gcp_public_cidrs_access_enabled @gcp_public_cidrs_access_enabled end |
#private_endpoint_enforcement_enabled ⇒ Boolean Also known as: private_endpoint_enforcement_enabled?
Whether master authorized networks is enforced on private endpoint or not.
Corresponds to the JSON property privateEndpointEnforcementEnabled
4925 4926 4927 |
# File 'lib/google/apis/container_v1/classes.rb', line 4925 def private_endpoint_enforcement_enabled @private_endpoint_enforcement_enabled end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4933 4934 4935 4936 4937 4938 |
# File 'lib/google/apis/container_v1/classes.rb', line 4933 def update!(**args) @cidr_blocks = args[:cidr_blocks] if args.key?(:cidr_blocks) @enabled = args[:enabled] if args.key?(:enabled) @gcp_public_cidrs_access_enabled = args[:gcp_public_cidrs_access_enabled] if args.key?(:gcp_public_cidrs_access_enabled) @private_endpoint_enforcement_enabled = args[:private_endpoint_enforcement_enabled] if args.key?(:private_endpoint_enforcement_enabled) end |