Class: Google::Apis::ContainerV1::MeshCertificates

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

Configuration for issuance of mTLS keys and certificates to Kubernetes pods.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MeshCertificates

Returns a new instance of MeshCertificates.



5211
5212
5213
# File 'lib/google/apis/container_v1/classes.rb', line 5211

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enable_certificatesBoolean Also known as: enable_certificates?

enable_certificates controls issuance of workload mTLS certificates. If set, the GKE Workload Identity Certificates controller and node agent will be deployed in the cluster, which can then be configured by creating a WorkloadCertificateConfig Custom Resource. Requires Workload Identity ( workload_pool must be non-empty). Corresponds to the JSON property enableCertificates

Returns:

  • (Boolean)


5208
5209
5210
# File 'lib/google/apis/container_v1/classes.rb', line 5208

def enable_certificates
  @enable_certificates
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5216
5217
5218
# File 'lib/google/apis/container_v1/classes.rb', line 5216

def update!(**args)
  @enable_certificates = args[:enable_certificates] if args.key?(:enable_certificates)
end