Class: Google::Apis::ContainerV1::MonitoringConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

MonitoringConfig is cluster monitoring configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MonitoringConfig

Returns a new instance of MonitoringConfig.



5760
5761
5762
# File 'lib/google/apis/container_v1/classes.rb', line 5760

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advanced_datapath_observability_configGoogle::Apis::ContainerV1::AdvancedDatapathObservabilityConfig

AdvancedDatapathObservabilityConfig specifies configuration of observability features of advanced datapath. Corresponds to the JSON property advancedDatapathObservabilityConfig



5747
5748
5749
# File 'lib/google/apis/container_v1/classes.rb', line 5747

def advanced_datapath_observability_config
  @advanced_datapath_observability_config
end

#component_configGoogle::Apis::ContainerV1::MonitoringComponentConfig

MonitoringComponentConfig is cluster monitoring component configuration. Corresponds to the JSON property componentConfig



5752
5753
5754
# File 'lib/google/apis/container_v1/classes.rb', line 5752

def component_config
  @component_config
end

#managed_prometheus_configGoogle::Apis::ContainerV1::ManagedPrometheusConfig

ManagedPrometheusConfig defines the configuration for Google Cloud Managed Service for Prometheus. Corresponds to the JSON property managedPrometheusConfig



5758
5759
5760
# File 'lib/google/apis/container_v1/classes.rb', line 5758

def managed_prometheus_config
  @managed_prometheus_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5765
5766
5767
5768
5769
# File 'lib/google/apis/container_v1/classes.rb', line 5765

def update!(**args)
  @advanced_datapath_observability_config = args[:advanced_datapath_observability_config] if args.key?(:advanced_datapath_observability_config)
  @component_config = args[:component_config] if args.key?(:component_config)
  @managed_prometheus_config = args[:managed_prometheus_config] if args.key?(:managed_prometheus_config)
end