Class: Google::Apis::ContainerV1::NetworkConfig
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1::NetworkConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb
Overview
NetworkConfig reports the relative names of network & subnetwork.
Instance Attribute Summary collapse
-
#datapath_provider ⇒ String
The desired datapath provider for this cluster.
-
#dataplane_v2_config ⇒ Google::Apis::ContainerV1::DataplaneV2Config
DataplaneV2Config is the configuration for DPv2.
-
#default_enable_private_nodes ⇒ Boolean
(also: #default_enable_private_nodes?)
Controls whether by default nodes have private IP addresses only.
-
#default_snat_status ⇒ Google::Apis::ContainerV1::DefaultSnatStatus
DefaultSnatStatus contains the desired state of whether default sNAT should be disabled on the cluster.
-
#disable_l4_lb_firewall_reconciliation ⇒ Boolean
(also: #disable_l4_lb_firewall_reconciliation?)
Disable L4 load balancer VPC firewalls to enable firewall policies.
-
#dns_config ⇒ Google::Apis::ContainerV1::DnsConfig
DNSConfig contains the desired set of options for configuring clusterDNS.
-
#enable_cilium_clusterwide_network_policy ⇒ Boolean
(also: #enable_cilium_clusterwide_network_policy?)
Whether CiliumClusterwideNetworkPolicy is enabled on this cluster.
-
#enable_fqdn_network_policy ⇒ Boolean
(also: #enable_fqdn_network_policy?)
Whether FQDN Network Policy is enabled on this cluster.
-
#enable_intra_node_visibility ⇒ Boolean
(also: #enable_intra_node_visibility?)
Whether Intra-node visibility is enabled for this cluster.
-
#enable_l4ilb_subsetting ⇒ Boolean
(also: #enable_l4ilb_subsetting?)
Whether L4ILB Subsetting is enabled for this cluster.
-
#enable_multi_networking ⇒ Boolean
(also: #enable_multi_networking?)
Whether multi-networking is enabled for this cluster.
-
#gateway_api_config ⇒ Google::Apis::ContainerV1::GatewayApiConfig
GatewayAPIConfig contains the desired config of Gateway API on this cluster.
-
#in_transit_encryption_config ⇒ String
Specify the details of in-transit encryption.
-
#network ⇒ String
Output only.
-
#network_performance_config ⇒ Google::Apis::ContainerV1::ClusterNetworkPerformanceConfig
Configuration of network bandwidth tiers Corresponds to the JSON property
networkPerformanceConfig. -
#private_ipv6_google_access ⇒ String
The desired state of IPv6 connectivity to Google Services.
-
#service_external_ips_config ⇒ Google::Apis::ContainerV1::ServiceExternalIPsConfig
Config to block services with externalIPs field.
-
#subnetwork ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkConfig
constructor
A new instance of NetworkConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkConfig
Returns a new instance of NetworkConfig.
5898 5899 5900 |
# File 'lib/google/apis/container_v1/classes.rb', line 5898 def initialize(**args) update!(**args) end |
Instance Attribute Details
#datapath_provider ⇒ String
The desired datapath provider for this cluster. By default, uses the IPTables-
based kube-proxy implementation.
Corresponds to the JSON property datapathProvider
5793 5794 5795 |
# File 'lib/google/apis/container_v1/classes.rb', line 5793 def datapath_provider @datapath_provider end |
#dataplane_v2_config ⇒ Google::Apis::ContainerV1::DataplaneV2Config
DataplaneV2Config is the configuration for DPv2.
Corresponds to the JSON property dataplaneV2Config
5798 5799 5800 |
# File 'lib/google/apis/container_v1/classes.rb', line 5798 def dataplane_v2_config @dataplane_v2_config end |
#default_enable_private_nodes ⇒ Boolean Also known as: default_enable_private_nodes?
Controls whether by default nodes have private IP addresses only. It is
invalid to specify both PrivateClusterConfig.enablePrivateNodes and this field
at the same time. To update the default setting, use ClusterUpdate.
desired_default_enable_private_nodes
Corresponds to the JSON property defaultEnablePrivateNodes
5806 5807 5808 |
# File 'lib/google/apis/container_v1/classes.rb', line 5806 def default_enable_private_nodes @default_enable_private_nodes end |
#default_snat_status ⇒ Google::Apis::ContainerV1::DefaultSnatStatus
DefaultSnatStatus contains the desired state of whether default sNAT should be
disabled on the cluster.
Corresponds to the JSON property defaultSnatStatus
5813 5814 5815 |
# File 'lib/google/apis/container_v1/classes.rb', line 5813 def default_snat_status @default_snat_status end |
#disable_l4_lb_firewall_reconciliation ⇒ Boolean Also known as: disable_l4_lb_firewall_reconciliation?
Disable L4 load balancer VPC firewalls to enable firewall policies.
Corresponds to the JSON property disableL4LbFirewallReconciliation
5818 5819 5820 |
# File 'lib/google/apis/container_v1/classes.rb', line 5818 def disable_l4_lb_firewall_reconciliation @disable_l4_lb_firewall_reconciliation end |
#dns_config ⇒ Google::Apis::ContainerV1::DnsConfig
DNSConfig contains the desired set of options for configuring clusterDNS.
Corresponds to the JSON property dnsConfig
5824 5825 5826 |
# File 'lib/google/apis/container_v1/classes.rb', line 5824 def dns_config @dns_config end |
#enable_cilium_clusterwide_network_policy ⇒ Boolean Also known as: enable_cilium_clusterwide_network_policy?
Whether CiliumClusterwideNetworkPolicy is enabled on this cluster.
Corresponds to the JSON property enableCiliumClusterwideNetworkPolicy
5829 5830 5831 |
# File 'lib/google/apis/container_v1/classes.rb', line 5829 def enable_cilium_clusterwide_network_policy @enable_cilium_clusterwide_network_policy end |
#enable_fqdn_network_policy ⇒ Boolean Also known as: enable_fqdn_network_policy?
Whether FQDN Network Policy is enabled on this cluster.
Corresponds to the JSON property enableFqdnNetworkPolicy
5835 5836 5837 |
# File 'lib/google/apis/container_v1/classes.rb', line 5835 def enable_fqdn_network_policy @enable_fqdn_network_policy end |
#enable_intra_node_visibility ⇒ Boolean Also known as: enable_intra_node_visibility?
Whether Intra-node visibility is enabled for this cluster. This makes same
node pod to pod traffic visible for VPC network.
Corresponds to the JSON property enableIntraNodeVisibility
5842 5843 5844 |
# File 'lib/google/apis/container_v1/classes.rb', line 5842 def enable_intra_node_visibility @enable_intra_node_visibility end |
#enable_l4ilb_subsetting ⇒ Boolean Also known as: enable_l4ilb_subsetting?
Whether L4ILB Subsetting is enabled for this cluster.
Corresponds to the JSON property enableL4ilbSubsetting
5848 5849 5850 |
# File 'lib/google/apis/container_v1/classes.rb', line 5848 def enable_l4ilb_subsetting @enable_l4ilb_subsetting end |
#enable_multi_networking ⇒ Boolean Also known as: enable_multi_networking?
Whether multi-networking is enabled for this cluster.
Corresponds to the JSON property enableMultiNetworking
5854 5855 5856 |
# File 'lib/google/apis/container_v1/classes.rb', line 5854 def enable_multi_networking @enable_multi_networking end |
#gateway_api_config ⇒ Google::Apis::ContainerV1::GatewayApiConfig
GatewayAPIConfig contains the desired config of Gateway API on this cluster.
Corresponds to the JSON property gatewayApiConfig
5860 5861 5862 |
# File 'lib/google/apis/container_v1/classes.rb', line 5860 def gateway_api_config @gateway_api_config end |
#in_transit_encryption_config ⇒ String
Specify the details of in-transit encryption. Now named inter-node transparent
encryption.
Corresponds to the JSON property inTransitEncryptionConfig
5866 5867 5868 |
# File 'lib/google/apis/container_v1/classes.rb', line 5866 def in_transit_encryption_config @in_transit_encryption_config end |
#network ⇒ String
Output only. The relative name of the Google Compute Engine network to which the
cluster is connected. Example: projects/my-project/global/networks/my-network
Corresponds to the JSON property network
5873 5874 5875 |
# File 'lib/google/apis/container_v1/classes.rb', line 5873 def network @network end |
#network_performance_config ⇒ Google::Apis::ContainerV1::ClusterNetworkPerformanceConfig
Configuration of network bandwidth tiers
Corresponds to the JSON property networkPerformanceConfig
5878 5879 5880 |
# File 'lib/google/apis/container_v1/classes.rb', line 5878 def network_performance_config @network_performance_config end |
#private_ipv6_google_access ⇒ String
The desired state of IPv6 connectivity to Google Services. By default, no
private IPv6 access to or from Google Services (all access will be via IPv4)
Corresponds to the JSON property privateIpv6GoogleAccess
5884 5885 5886 |
# File 'lib/google/apis/container_v1/classes.rb', line 5884 def private_ipv6_google_access @private_ipv6_google_access end |
#service_external_ips_config ⇒ Google::Apis::ContainerV1::ServiceExternalIPsConfig
Config to block services with externalIPs field.
Corresponds to the JSON property serviceExternalIpsConfig
5889 5890 5891 |
# File 'lib/google/apis/container_v1/classes.rb', line 5889 def service_external_ips_config @service_external_ips_config end |
#subnetwork ⇒ String
Output only. The relative name of the Google Compute Engine subnetwork to which the cluster is connected.
Example: projects/my-project/regions/us-central1/subnetworks/my-subnet
Corresponds to the JSON property subnetwork
5896 5897 5898 |
# File 'lib/google/apis/container_v1/classes.rb', line 5896 def subnetwork @subnetwork end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5903 5904 5905 5906 5907 5908 5909 5910 5911 5912 5913 5914 5915 5916 5917 5918 5919 5920 5921 5922 |
# File 'lib/google/apis/container_v1/classes.rb', line 5903 def update!(**args) @datapath_provider = args[:datapath_provider] if args.key?(:datapath_provider) @dataplane_v2_config = args[:dataplane_v2_config] if args.key?(:dataplane_v2_config) @default_enable_private_nodes = args[:default_enable_private_nodes] if args.key?(:default_enable_private_nodes) @default_snat_status = args[:default_snat_status] if args.key?(:default_snat_status) @disable_l4_lb_firewall_reconciliation = args[:disable_l4_lb_firewall_reconciliation] if args.key?(:disable_l4_lb_firewall_reconciliation) @dns_config = args[:dns_config] if args.key?(:dns_config) @enable_cilium_clusterwide_network_policy = args[:enable_cilium_clusterwide_network_policy] if args.key?(:enable_cilium_clusterwide_network_policy) @enable_fqdn_network_policy = args[:enable_fqdn_network_policy] if args.key?(:enable_fqdn_network_policy) @enable_intra_node_visibility = args[:enable_intra_node_visibility] if args.key?(:enable_intra_node_visibility) @enable_l4ilb_subsetting = args[:enable_l4ilb_subsetting] if args.key?(:enable_l4ilb_subsetting) @enable_multi_networking = args[:enable_multi_networking] if args.key?(:enable_multi_networking) @gateway_api_config = args[:gateway_api_config] if args.key?(:gateway_api_config) @in_transit_encryption_config = args[:in_transit_encryption_config] if args.key?(:in_transit_encryption_config) @network = args[:network] if args.key?(:network) @network_performance_config = args[:network_performance_config] if args.key?(:network_performance_config) @private_ipv6_google_access = args[:private_ipv6_google_access] if args.key?(:private_ipv6_google_access) @service_external_ips_config = args[:service_external_ips_config] if args.key?(:service_external_ips_config) @subnetwork = args[:subnetwork] if args.key?(:subnetwork) end |