Class: Google::Apis::ContainerV1::NetworkConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

NetworkConfig reports the relative names of network & subnetwork.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkConfig

Returns a new instance of NetworkConfig.



5885
5886
5887
# File 'lib/google/apis/container_v1/classes.rb', line 5885

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#datapath_providerString

The desired datapath provider for this cluster. By default, uses the IPTables- based kube-proxy implementation. Corresponds to the JSON property datapathProvider

Returns:

  • (String)


5780
5781
5782
# File 'lib/google/apis/container_v1/classes.rb', line 5780

def datapath_provider
  @datapath_provider
end

#dataplane_v2_configGoogle::Apis::ContainerV1::DataplaneV2Config

DataplaneV2Config is the configuration for DPv2. Corresponds to the JSON property dataplaneV2Config



5785
5786
5787
# File 'lib/google/apis/container_v1/classes.rb', line 5785

def dataplane_v2_config
  @dataplane_v2_config
end

#default_enable_private_nodesBoolean Also known as: default_enable_private_nodes?

Controls whether by default nodes have private IP addresses only. It is invalid to specify both PrivateClusterConfig.enablePrivateNodes and this field at the same time. To update the default setting, use ClusterUpdate. desired_default_enable_private_nodes Corresponds to the JSON property defaultEnablePrivateNodes

Returns:

  • (Boolean)


5793
5794
5795
# File 'lib/google/apis/container_v1/classes.rb', line 5793

def default_enable_private_nodes
  @default_enable_private_nodes
end

#default_snat_statusGoogle::Apis::ContainerV1::DefaultSnatStatus

DefaultSnatStatus contains the desired state of whether default sNAT should be disabled on the cluster. Corresponds to the JSON property defaultSnatStatus



5800
5801
5802
# File 'lib/google/apis/container_v1/classes.rb', line 5800

def default_snat_status
  @default_snat_status
end

#disable_l4_lb_firewall_reconciliationBoolean Also known as: disable_l4_lb_firewall_reconciliation?

Disable L4 load balancer VPC firewalls to enable firewall policies. Corresponds to the JSON property disableL4LbFirewallReconciliation

Returns:

  • (Boolean)


5805
5806
5807
# File 'lib/google/apis/container_v1/classes.rb', line 5805

def disable_l4_lb_firewall_reconciliation
  @disable_l4_lb_firewall_reconciliation
end

#dns_configGoogle::Apis::ContainerV1::DnsConfig

DNSConfig contains the desired set of options for configuring clusterDNS. Corresponds to the JSON property dnsConfig



5811
5812
5813
# File 'lib/google/apis/container_v1/classes.rb', line 5811

def dns_config
  @dns_config
end

#enable_cilium_clusterwide_network_policyBoolean Also known as: enable_cilium_clusterwide_network_policy?

Whether CiliumClusterwideNetworkPolicy is enabled on this cluster. Corresponds to the JSON property enableCiliumClusterwideNetworkPolicy

Returns:

  • (Boolean)


5816
5817
5818
# File 'lib/google/apis/container_v1/classes.rb', line 5816

def enable_cilium_clusterwide_network_policy
  @enable_cilium_clusterwide_network_policy
end

#enable_fqdn_network_policyBoolean Also known as: enable_fqdn_network_policy?

Whether FQDN Network Policy is enabled on this cluster. Corresponds to the JSON property enableFqdnNetworkPolicy

Returns:

  • (Boolean)


5822
5823
5824
# File 'lib/google/apis/container_v1/classes.rb', line 5822

def enable_fqdn_network_policy
  @enable_fqdn_network_policy
end

#enable_intra_node_visibilityBoolean Also known as: enable_intra_node_visibility?

Whether Intra-node visibility is enabled for this cluster. This makes same node pod to pod traffic visible for VPC network. Corresponds to the JSON property enableIntraNodeVisibility

Returns:

  • (Boolean)


5829
5830
5831
# File 'lib/google/apis/container_v1/classes.rb', line 5829

def enable_intra_node_visibility
  @enable_intra_node_visibility
end

#enable_l4ilb_subsettingBoolean Also known as: enable_l4ilb_subsetting?

Whether L4ILB Subsetting is enabled for this cluster. Corresponds to the JSON property enableL4ilbSubsetting

Returns:

  • (Boolean)


5835
5836
5837
# File 'lib/google/apis/container_v1/classes.rb', line 5835

def enable_l4ilb_subsetting
  @enable_l4ilb_subsetting
end

#enable_multi_networkingBoolean Also known as: enable_multi_networking?

Whether multi-networking is enabled for this cluster. Corresponds to the JSON property enableMultiNetworking

Returns:

  • (Boolean)


5841
5842
5843
# File 'lib/google/apis/container_v1/classes.rb', line 5841

def enable_multi_networking
  @enable_multi_networking
end

#gateway_api_configGoogle::Apis::ContainerV1::GatewayApiConfig

GatewayAPIConfig contains the desired config of Gateway API on this cluster. Corresponds to the JSON property gatewayApiConfig



5847
5848
5849
# File 'lib/google/apis/container_v1/classes.rb', line 5847

def gateway_api_config
  @gateway_api_config
end

#in_transit_encryption_configString

Specify the details of in-transit encryption. Now named inter-node transparent encryption. Corresponds to the JSON property inTransitEncryptionConfig

Returns:

  • (String)


5853
5854
5855
# File 'lib/google/apis/container_v1/classes.rb', line 5853

def in_transit_encryption_config
  @in_transit_encryption_config
end

#networkString

Output only. The relative name of the Google Compute Engine network to which the cluster is connected. Example: projects/my-project/global/networks/my-network Corresponds to the JSON property network

Returns:

  • (String)


5860
5861
5862
# File 'lib/google/apis/container_v1/classes.rb', line 5860

def network
  @network
end

#network_performance_configGoogle::Apis::ContainerV1::ClusterNetworkPerformanceConfig

Configuration of network bandwidth tiers Corresponds to the JSON property networkPerformanceConfig



5865
5866
5867
# File 'lib/google/apis/container_v1/classes.rb', line 5865

def network_performance_config
  @network_performance_config
end

#private_ipv6_google_accessString

The desired state of IPv6 connectivity to Google Services. By default, no private IPv6 access to or from Google Services (all access will be via IPv4) Corresponds to the JSON property privateIpv6GoogleAccess

Returns:

  • (String)


5871
5872
5873
# File 'lib/google/apis/container_v1/classes.rb', line 5871

def private_ipv6_google_access
  @private_ipv6_google_access
end

#service_external_ips_configGoogle::Apis::ContainerV1::ServiceExternalIPsConfig

Config to block services with externalIPs field. Corresponds to the JSON property serviceExternalIpsConfig



5876
5877
5878
# File 'lib/google/apis/container_v1/classes.rb', line 5876

def service_external_ips_config
  @service_external_ips_config
end

#subnetworkString

Output only. The relative name of the Google Compute Engine subnetwork to which the cluster is connected. Example: projects/my-project/regions/us-central1/subnetworks/my-subnet Corresponds to the JSON property subnetwork

Returns:

  • (String)


5883
5884
5885
# File 'lib/google/apis/container_v1/classes.rb', line 5883

def subnetwork
  @subnetwork
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5890
5891
5892
5893
5894
5895
5896
5897
5898
5899
5900
5901
5902
5903
5904
5905
5906
5907
5908
5909
# File 'lib/google/apis/container_v1/classes.rb', line 5890

def update!(**args)
  @datapath_provider = args[:datapath_provider] if args.key?(:datapath_provider)
  @dataplane_v2_config = args[:dataplane_v2_config] if args.key?(:dataplane_v2_config)
  @default_enable_private_nodes = args[:default_enable_private_nodes] if args.key?(:default_enable_private_nodes)
  @default_snat_status = args[:default_snat_status] if args.key?(:default_snat_status)
  @disable_l4_lb_firewall_reconciliation = args[:disable_l4_lb_firewall_reconciliation] if args.key?(:disable_l4_lb_firewall_reconciliation)
  @dns_config = args[:dns_config] if args.key?(:dns_config)
  @enable_cilium_clusterwide_network_policy = args[:enable_cilium_clusterwide_network_policy] if args.key?(:enable_cilium_clusterwide_network_policy)
  @enable_fqdn_network_policy = args[:enable_fqdn_network_policy] if args.key?(:enable_fqdn_network_policy)
  @enable_intra_node_visibility = args[:enable_intra_node_visibility] if args.key?(:enable_intra_node_visibility)
  @enable_l4ilb_subsetting = args[:enable_l4ilb_subsetting] if args.key?(:enable_l4ilb_subsetting)
  @enable_multi_networking = args[:enable_multi_networking] if args.key?(:enable_multi_networking)
  @gateway_api_config = args[:gateway_api_config] if args.key?(:gateway_api_config)
  @in_transit_encryption_config = args[:in_transit_encryption_config] if args.key?(:in_transit_encryption_config)
  @network = args[:network] if args.key?(:network)
  @network_performance_config = args[:network_performance_config] if args.key?(:network_performance_config)
  @private_ipv6_google_access = args[:private_ipv6_google_access] if args.key?(:private_ipv6_google_access)
  @service_external_ips_config = args[:service_external_ips_config] if args.key?(:service_external_ips_config)
  @subnetwork = args[:subnetwork] if args.key?(:subnetwork)
end