Class: Google::Apis::ContainerV1::NetworkConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

NetworkConfig reports the relative names of network & subnetwork.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkConfig

Returns a new instance of NetworkConfig.



5419
5420
5421
# File 'lib/google/apis/container_v1/classes.rb', line 5419

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#datapath_providerString

The desired datapath provider for this cluster. By default, uses the IPTables- based kube-proxy implementation. Corresponds to the JSON property datapathProvider

Returns:

  • (String)


5319
5320
5321
# File 'lib/google/apis/container_v1/classes.rb', line 5319

def datapath_provider
  @datapath_provider
end

#default_enable_private_nodesBoolean Also known as: default_enable_private_nodes?

Controls whether by default nodes have private IP addresses only. It is invalid to specify both PrivateClusterConfig.enablePrivateNodes and this field at the same time. To update the default setting, use ClusterUpdate. desired_default_enable_private_nodes Corresponds to the JSON property defaultEnablePrivateNodes

Returns:

  • (Boolean)


5327
5328
5329
# File 'lib/google/apis/container_v1/classes.rb', line 5327

def default_enable_private_nodes
  @default_enable_private_nodes
end

#default_snat_statusGoogle::Apis::ContainerV1::DefaultSnatStatus

DefaultSnatStatus contains the desired state of whether default sNAT should be disabled on the cluster. Corresponds to the JSON property defaultSnatStatus



5334
5335
5336
# File 'lib/google/apis/container_v1/classes.rb', line 5334

def default_snat_status
  @default_snat_status
end

#disable_l4_lb_firewall_reconciliationBoolean Also known as: disable_l4_lb_firewall_reconciliation?

Disable L4 load balancer VPC firewalls to enable firewall policies. Corresponds to the JSON property disableL4LbFirewallReconciliation

Returns:

  • (Boolean)


5339
5340
5341
# File 'lib/google/apis/container_v1/classes.rb', line 5339

def disable_l4_lb_firewall_reconciliation
  @disable_l4_lb_firewall_reconciliation
end

#dns_configGoogle::Apis::ContainerV1::DnsConfig

DNSConfig contains the desired set of options for configuring clusterDNS. Corresponds to the JSON property dnsConfig



5345
5346
5347
# File 'lib/google/apis/container_v1/classes.rb', line 5345

def dns_config
  @dns_config
end

#enable_cilium_clusterwide_network_policyBoolean Also known as: enable_cilium_clusterwide_network_policy?

Whether CiliumClusterwideNetworkPolicy is enabled on this cluster. Corresponds to the JSON property enableCiliumClusterwideNetworkPolicy

Returns:

  • (Boolean)


5350
5351
5352
# File 'lib/google/apis/container_v1/classes.rb', line 5350

def enable_cilium_clusterwide_network_policy
  @enable_cilium_clusterwide_network_policy
end

#enable_fqdn_network_policyBoolean Also known as: enable_fqdn_network_policy?

Whether FQDN Network Policy is enabled on this cluster. Corresponds to the JSON property enableFqdnNetworkPolicy

Returns:

  • (Boolean)


5356
5357
5358
# File 'lib/google/apis/container_v1/classes.rb', line 5356

def enable_fqdn_network_policy
  @enable_fqdn_network_policy
end

#enable_intra_node_visibilityBoolean Also known as: enable_intra_node_visibility?

Whether Intra-node visibility is enabled for this cluster. This makes same node pod to pod traffic visible for VPC network. Corresponds to the JSON property enableIntraNodeVisibility

Returns:

  • (Boolean)


5363
5364
5365
# File 'lib/google/apis/container_v1/classes.rb', line 5363

def enable_intra_node_visibility
  @enable_intra_node_visibility
end

#enable_l4ilb_subsettingBoolean Also known as: enable_l4ilb_subsetting?

Whether L4ILB Subsetting is enabled for this cluster. Corresponds to the JSON property enableL4ilbSubsetting

Returns:

  • (Boolean)


5369
5370
5371
# File 'lib/google/apis/container_v1/classes.rb', line 5369

def enable_l4ilb_subsetting
  @enable_l4ilb_subsetting
end

#enable_multi_networkingBoolean Also known as: enable_multi_networking?

Whether multi-networking is enabled for this cluster. Corresponds to the JSON property enableMultiNetworking

Returns:

  • (Boolean)


5375
5376
5377
# File 'lib/google/apis/container_v1/classes.rb', line 5375

def enable_multi_networking
  @enable_multi_networking
end

#gateway_api_configGoogle::Apis::ContainerV1::GatewayApiConfig

GatewayAPIConfig contains the desired config of Gateway API on this cluster. Corresponds to the JSON property gatewayApiConfig



5381
5382
5383
# File 'lib/google/apis/container_v1/classes.rb', line 5381

def gateway_api_config
  @gateway_api_config
end

#in_transit_encryption_configString

Specify the details of in-transit encryption. Now named inter-node transparent encryption. Corresponds to the JSON property inTransitEncryptionConfig

Returns:

  • (String)


5387
5388
5389
# File 'lib/google/apis/container_v1/classes.rb', line 5387

def in_transit_encryption_config
  @in_transit_encryption_config
end

#networkString

Output only. The relative name of the Google Compute Engine network to which the cluster is connected. Example: projects/my-project/global/networks/my-network Corresponds to the JSON property network

Returns:

  • (String)


5394
5395
5396
# File 'lib/google/apis/container_v1/classes.rb', line 5394

def network
  @network
end

#network_performance_configGoogle::Apis::ContainerV1::ClusterNetworkPerformanceConfig

Configuration of network bandwidth tiers Corresponds to the JSON property networkPerformanceConfig



5399
5400
5401
# File 'lib/google/apis/container_v1/classes.rb', line 5399

def network_performance_config
  @network_performance_config
end

#private_ipv6_google_accessString

The desired state of IPv6 connectivity to Google Services. By default, no private IPv6 access to or from Google Services (all access will be via IPv4) Corresponds to the JSON property privateIpv6GoogleAccess

Returns:

  • (String)


5405
5406
5407
# File 'lib/google/apis/container_v1/classes.rb', line 5405

def private_ipv6_google_access
  @private_ipv6_google_access
end

#service_external_ips_configGoogle::Apis::ContainerV1::ServiceExternalIPsConfig

Config to block services with externalIPs field. Corresponds to the JSON property serviceExternalIpsConfig



5410
5411
5412
# File 'lib/google/apis/container_v1/classes.rb', line 5410

def service_external_ips_config
  @service_external_ips_config
end

#subnetworkString

Output only. The relative name of the Google Compute Engine subnetwork to which the cluster is connected. Example: projects/my-project/regions/us-central1/subnetworks/my-subnet Corresponds to the JSON property subnetwork

Returns:

  • (String)


5417
5418
5419
# File 'lib/google/apis/container_v1/classes.rb', line 5417

def subnetwork
  @subnetwork
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5424
5425
5426
5427
5428
5429
5430
5431
5432
5433
5434
5435
5436
5437
5438
5439
5440
5441
5442
# File 'lib/google/apis/container_v1/classes.rb', line 5424

def update!(**args)
  @datapath_provider = args[:datapath_provider] if args.key?(:datapath_provider)
  @default_enable_private_nodes = args[:default_enable_private_nodes] if args.key?(:default_enable_private_nodes)
  @default_snat_status = args[:default_snat_status] if args.key?(:default_snat_status)
  @disable_l4_lb_firewall_reconciliation = args[:disable_l4_lb_firewall_reconciliation] if args.key?(:disable_l4_lb_firewall_reconciliation)
  @dns_config = args[:dns_config] if args.key?(:dns_config)
  @enable_cilium_clusterwide_network_policy = args[:enable_cilium_clusterwide_network_policy] if args.key?(:enable_cilium_clusterwide_network_policy)
  @enable_fqdn_network_policy = args[:enable_fqdn_network_policy] if args.key?(:enable_fqdn_network_policy)
  @enable_intra_node_visibility = args[:enable_intra_node_visibility] if args.key?(:enable_intra_node_visibility)
  @enable_l4ilb_subsetting = args[:enable_l4ilb_subsetting] if args.key?(:enable_l4ilb_subsetting)
  @enable_multi_networking = args[:enable_multi_networking] if args.key?(:enable_multi_networking)
  @gateway_api_config = args[:gateway_api_config] if args.key?(:gateway_api_config)
  @in_transit_encryption_config = args[:in_transit_encryption_config] if args.key?(:in_transit_encryption_config)
  @network = args[:network] if args.key?(:network)
  @network_performance_config = args[:network_performance_config] if args.key?(:network_performance_config)
  @private_ipv6_google_access = args[:private_ipv6_google_access] if args.key?(:private_ipv6_google_access)
  @service_external_ips_config = args[:service_external_ips_config] if args.key?(:service_external_ips_config)
  @subnetwork = args[:subnetwork] if args.key?(:subnetwork)
end