Class: Google::Apis::ContainerV1::NetworkPolicyConfig
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1::NetworkPolicyConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb
Overview
Configuration for NetworkPolicy. This only tracks whether the addon is enabled or not on the Master, it does not track whether network policy is enabled for the nodes.
Instance Attribute Summary collapse
-
#disabled ⇒ Boolean
(also: #disabled?)
Whether NetworkPolicy is enabled for this cluster.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkPolicyConfig
constructor
A new instance of NetworkPolicyConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkPolicyConfig
Returns a new instance of NetworkPolicyConfig.
5983 5984 5985 |
# File 'lib/google/apis/container_v1/classes.rb', line 5983 def initialize(**args) update!(**args) end |
Instance Attribute Details
#disabled ⇒ Boolean Also known as: disabled?
Whether NetworkPolicy is enabled for this cluster.
Corresponds to the JSON property disabled
5980 5981 5982 |
# File 'lib/google/apis/container_v1/classes.rb', line 5980 def disabled @disabled end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5988 5989 5990 |
# File 'lib/google/apis/container_v1/classes.rb', line 5988 def update!(**args) @disabled = args[:disabled] if args.key?(:disabled) end |