Class: Google::Apis::ContainerV1::NodeConfig
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1::NodeConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb
Overview
Parameters that describe the nodes in a cluster. GKE Autopilot clusters do not
recognize parameters in NodeConfig. Use AutoprovisioningNodePoolDefaults
instead.
Instance Attribute Summary collapse
-
#accelerators ⇒ Array<Google::Apis::ContainerV1::AcceleratorConfig>
A list of hardware accelerators to be attached to each node.
-
#advanced_machine_features ⇒ Google::Apis::ContainerV1::AdvancedMachineFeatures
Specifies options for controlling advanced machine features.
-
#boot_disk ⇒ Google::Apis::ContainerV1::BootDisk
BootDisk specifies the boot disk configuration for node pools.
-
#boot_disk_kms_key ⇒ String
The Customer Managed Encryption Key used to encrypt the boot disk attached to each node in the node pool.
-
#confidential_nodes ⇒ Google::Apis::ContainerV1::ConfidentialNodes
ConfidentialNodes is configuration for the confidential nodes feature, which makes nodes run on confidential VMs.
-
#consolidation_delay ⇒ String
Consolidation delay defines duration after which the Cluster Autoscaler can scale down underutilized nodes.
-
#containerd_config ⇒ Google::Apis::ContainerV1::ContainerdConfig
ContainerdConfig contains configuration to customize containerd.
-
#disk_size_gb ⇒ Fixnum
Size of the disk attached to each node, specified in GB.
-
#disk_type ⇒ String
Type of the disk attached to each node (e.g. 'pd-standard', 'pd-ssd' or 'pd- balanced') If unspecified, the default disk type is 'pd-standard' Corresponds to the JSON property
diskType. -
#effective_cgroup_mode ⇒ String
Output only.
-
#enable_confidential_storage ⇒ Boolean
(also: #enable_confidential_storage?)
Optional.
-
#ephemeral_storage_local_ssd_config ⇒ Google::Apis::ContainerV1::EphemeralStorageLocalSsdConfig
EphemeralStorageLocalSsdConfig contains configuration for the node ephemeral storage using Local SSDs.
-
#fast_socket ⇒ Google::Apis::ContainerV1::FastSocket
Configuration of Fast Socket feature.
-
#flex_start ⇒ Boolean
(also: #flex_start?)
Flex Start flag for enabling Flex Start VM.
-
#gcfs_config ⇒ Google::Apis::ContainerV1::GcfsConfig
GcfsConfig contains configurations of Google Container File System (image streaming).
-
#gpu_direct_config ⇒ Google::Apis::ContainerV1::GpuDirectConfig
GPUDirectConfig specifies the GPU direct strategy on the node pool.
-
#gvnic ⇒ Google::Apis::ContainerV1::VirtualNic
Configuration of gVNIC feature.
-
#image_type ⇒ String
The image type to use for this node.
-
#kubelet_config ⇒ Google::Apis::ContainerV1::NodeKubeletConfig
Node kubelet configs.
-
#labels ⇒ Hash<String,String>
The Kubernetes labels (key/value pairs) to apply to each node.
-
#linux_node_config ⇒ Google::Apis::ContainerV1::LinuxNodeConfig
Parameters that can be configured on Linux nodes.
-
#local_nvme_ssd_block_config ⇒ Google::Apis::ContainerV1::LocalNvmeSsdBlockConfig
LocalNvmeSsdBlockConfig contains configuration for using raw-block local NVMe SSDs Corresponds to the JSON property
localNvmeSsdBlockConfig. -
#local_ssd_count ⇒ Fixnum
The number of local SSD disks to be attached to the node.
-
#local_ssd_encryption_mode ⇒ String
Specifies which method should be used for encrypting the Local SSDs attached to the node.
-
#logging_config ⇒ Google::Apis::ContainerV1::NodePoolLoggingConfig
NodePoolLoggingConfig specifies logging configuration for node pools.
-
#machine_type ⇒ String
The name of a Google Compute Engine machine type If unspecified, the default machine type is
e2- medium. -
#max_run_duration ⇒ String
The maximum duration for the nodes to exist.
-
#metadata ⇒ Hash<String,String>
The metadata key/value pairs assigned to instances in the cluster.
-
#min_cpu_platform ⇒ String
Minimum CPU platform to be used by this instance.
-
#node_group ⇒ String
Setting this field will assign instances of this pool to run on the specified node group.
-
#node_image_config ⇒ Google::Apis::ContainerV1::CustomImageConfig
CustomImageConfig contains the information r Corresponds to the JSON property
nodeImageConfig. -
#oauth_scopes ⇒ Array<String>
The set of Google API scopes to be made available on all of the node VMs under the "default" service account.
-
#preemptible ⇒ Boolean
(also: #preemptible?)
Whether the nodes are created as preemptible VM instances.
-
#reservation_affinity ⇒ Google::Apis::ContainerV1::ReservationAffinity
ReservationAffinity is the configuration of desired reservation which instances could take capacity from.
-
#resource_labels ⇒ Hash<String,String>
The resource labels for the node pool to use to annotate any related Google Compute Engine resources.
-
#resource_manager_tags ⇒ Google::Apis::ContainerV1::ResourceManagerTags
A map of resource manager tag keys and values to be attached to the nodes for managing Compute Engine firewalls using Network Firewall Policies.
-
#sandbox_config ⇒ Google::Apis::ContainerV1::SandboxConfig
SandboxConfig contains configurations of the sandbox to use for the node.
-
#secondary_boot_disk_update_strategy ⇒ Google::Apis::ContainerV1::SecondaryBootDiskUpdateStrategy
SecondaryBootDiskUpdateStrategy is a placeholder which will be extended in the future to define different options for updating secondary boot disks.
-
#secondary_boot_disks ⇒ Array<Google::Apis::ContainerV1::SecondaryBootDisk>
List of secondary boot disks attached to the nodes.
-
#service_account ⇒ String
The Google Cloud Platform Service Account to be used by the node VMs.
-
#shielded_instance_config ⇒ Google::Apis::ContainerV1::ShieldedInstanceConfig
A set of Shielded Instance options.
-
#sole_tenant_config ⇒ Google::Apis::ContainerV1::SoleTenantConfig
SoleTenantConfig contains the NodeAffinities to specify what shared sole tenant node groups should back the node pool.
-
#spot ⇒ Boolean
(also: #spot?)
Spot flag for enabling Spot VM, which is a rebrand of the existing preemptible flag.
-
#storage_pools ⇒ Array<String>
List of Storage Pools where boot disks are provisioned.
-
#tags ⇒ Array<String>
The list of instance tags applied to all nodes.
-
#taint_config ⇒ Google::Apis::ContainerV1::TaintConfig
TaintConfig contains the configuration for the taints of the node pool.
-
#taints ⇒ Array<Google::Apis::ContainerV1::NodeTaint>
List of kubernetes taints to be applied to each node.
-
#windows_node_config ⇒ Google::Apis::ContainerV1::WindowsNodeConfig
Parameters that can be configured on Windows nodes.
-
#workload_metadata_config ⇒ Google::Apis::ContainerV1::WorkloadMetadataConfig
WorkloadMetadataConfig defines the metadata configuration to expose to workloads on the node pool.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NodeConfig
constructor
A new instance of NodeConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NodeConfig
Returns a new instance of NodeConfig.
6392 6393 6394 |
# File 'lib/google/apis/container_v1/classes.rb', line 6392 def initialize(**args) update!(**args) end |
Instance Attribute Details
#accelerators ⇒ Array<Google::Apis::ContainerV1::AcceleratorConfig>
A list of hardware accelerators to be attached to each node. See https://cloud.
google.com/compute/docs/gpus for more information about support for GPUs.
Corresponds to the JSON property accelerators
6062 6063 6064 |
# File 'lib/google/apis/container_v1/classes.rb', line 6062 def accelerators @accelerators end |
#advanced_machine_features ⇒ Google::Apis::ContainerV1::AdvancedMachineFeatures
Specifies options for controlling advanced machine features.
Corresponds to the JSON property advancedMachineFeatures
6067 6068 6069 |
# File 'lib/google/apis/container_v1/classes.rb', line 6067 def advanced_machine_features @advanced_machine_features end |
#boot_disk ⇒ Google::Apis::ContainerV1::BootDisk
BootDisk specifies the boot disk configuration for node pools.
Corresponds to the JSON property bootDisk
6072 6073 6074 |
# File 'lib/google/apis/container_v1/classes.rb', line 6072 def boot_disk @boot_disk end |
#boot_disk_kms_key ⇒ String
The Customer Managed Encryption Key used to encrypt the boot disk attached to
each node in the node pool. This should be of the form projects/[
KEY_PROJECT_ID]/locations/[LOCATION]/keyRings/[RING_NAME]/cryptoKeys/[KEY_NAME]
. For more information about protecting resources with Cloud KMS Keys please
see: https://cloud.google.com/compute/docs/disks/customer-managed-encryption
Corresponds to the JSON property bootDiskKmsKey
6081 6082 6083 |
# File 'lib/google/apis/container_v1/classes.rb', line 6081 def boot_disk_kms_key @boot_disk_kms_key end |
#confidential_nodes ⇒ Google::Apis::ContainerV1::ConfidentialNodes
ConfidentialNodes is configuration for the confidential nodes feature, which
makes nodes run on confidential VMs.
Corresponds to the JSON property confidentialNodes
6087 6088 6089 |
# File 'lib/google/apis/container_v1/classes.rb', line 6087 def confidential_nodes @confidential_nodes end |
#consolidation_delay ⇒ String
Consolidation delay defines duration after which the Cluster Autoscaler can
scale down underutilized nodes. If not set, nodes are scaled down by default
behavior, i.e. according to the chosen autoscaling profile.
Corresponds to the JSON property consolidationDelay
6094 6095 6096 |
# File 'lib/google/apis/container_v1/classes.rb', line 6094 def consolidation_delay @consolidation_delay end |
#containerd_config ⇒ Google::Apis::ContainerV1::ContainerdConfig
ContainerdConfig contains configuration to customize containerd.
Corresponds to the JSON property containerdConfig
6099 6100 6101 |
# File 'lib/google/apis/container_v1/classes.rb', line 6099 def containerd_config @containerd_config end |
#disk_size_gb ⇒ Fixnum
Size of the disk attached to each node, specified in GB. The smallest allowed
disk size is 10GB. If unspecified, the default disk size is 100GB.
Corresponds to the JSON property diskSizeGb
6105 6106 6107 |
# File 'lib/google/apis/container_v1/classes.rb', line 6105 def disk_size_gb @disk_size_gb end |
#disk_type ⇒ String
Type of the disk attached to each node (e.g. 'pd-standard', 'pd-ssd' or 'pd-
balanced') If unspecified, the default disk type is 'pd-standard'
Corresponds to the JSON property diskType
6111 6112 6113 |
# File 'lib/google/apis/container_v1/classes.rb', line 6111 def disk_type @disk_type end |
#effective_cgroup_mode ⇒ String
Output only. effective_cgroup_mode is the cgroup mode actually used by the
node pool. It is determined by the cgroup mode specified in the
LinuxNodeConfig or the default cgroup mode based on the cluster creation
version.
Corresponds to the JSON property effectiveCgroupMode
6119 6120 6121 |
# File 'lib/google/apis/container_v1/classes.rb', line 6119 def effective_cgroup_mode @effective_cgroup_mode end |
#enable_confidential_storage ⇒ Boolean Also known as: enable_confidential_storage?
Optional. Reserved for future use.
Corresponds to the JSON property enableConfidentialStorage
6124 6125 6126 |
# File 'lib/google/apis/container_v1/classes.rb', line 6124 def enable_confidential_storage @enable_confidential_storage end |
#ephemeral_storage_local_ssd_config ⇒ Google::Apis::ContainerV1::EphemeralStorageLocalSsdConfig
EphemeralStorageLocalSsdConfig contains configuration for the node ephemeral
storage using Local SSDs.
Corresponds to the JSON property ephemeralStorageLocalSsdConfig
6131 6132 6133 |
# File 'lib/google/apis/container_v1/classes.rb', line 6131 def ephemeral_storage_local_ssd_config @ephemeral_storage_local_ssd_config end |
#fast_socket ⇒ Google::Apis::ContainerV1::FastSocket
Configuration of Fast Socket feature.
Corresponds to the JSON property fastSocket
6136 6137 6138 |
# File 'lib/google/apis/container_v1/classes.rb', line 6136 def fast_socket @fast_socket end |
#flex_start ⇒ Boolean Also known as: flex_start?
Flex Start flag for enabling Flex Start VM.
Corresponds to the JSON property flexStart
6141 6142 6143 |
# File 'lib/google/apis/container_v1/classes.rb', line 6141 def flex_start @flex_start end |
#gcfs_config ⇒ Google::Apis::ContainerV1::GcfsConfig
GcfsConfig contains configurations of Google Container File System (image
streaming).
Corresponds to the JSON property gcfsConfig
6148 6149 6150 |
# File 'lib/google/apis/container_v1/classes.rb', line 6148 def gcfs_config @gcfs_config end |
#gpu_direct_config ⇒ Google::Apis::ContainerV1::GpuDirectConfig
GPUDirectConfig specifies the GPU direct strategy on the node pool.
Corresponds to the JSON property gpuDirectConfig
6153 6154 6155 |
# File 'lib/google/apis/container_v1/classes.rb', line 6153 def gpu_direct_config @gpu_direct_config end |
#gvnic ⇒ Google::Apis::ContainerV1::VirtualNic
Configuration of gVNIC feature.
Corresponds to the JSON property gvnic
6158 6159 6160 |
# File 'lib/google/apis/container_v1/classes.rb', line 6158 def gvnic @gvnic end |
#image_type ⇒ String
The image type to use for this node. Note that for a given image type, the
latest version of it will be used. Please see https://cloud.google.com/
kubernetes-engine/docs/concepts/node-images for available image types.
Corresponds to the JSON property imageType
6165 6166 6167 |
# File 'lib/google/apis/container_v1/classes.rb', line 6165 def image_type @image_type end |
#kubelet_config ⇒ Google::Apis::ContainerV1::NodeKubeletConfig
Node kubelet configs.
Corresponds to the JSON property kubeletConfig
6170 6171 6172 |
# File 'lib/google/apis/container_v1/classes.rb', line 6170 def kubelet_config @kubelet_config end |
#labels ⇒ Hash<String,String>
The Kubernetes labels (key/value pairs) to apply to each node. The values in
this field are added to the set of default labels Kubernetes applies to nodes.
This field has the following restrictions: * Labels must use a valid
Kubernetes syntax and character set, as defined in https://kubernetes.io/docs/
concepts/overview/working-with-objects/labels/#syntax-and-character-set. *
This field supports up to 1,024 total characters in a single request.
Depending on the Kubernetes version, keys in this field might conflict with
the keys of the default labels, which might change which of your labels are
applied to the nodes. Assume that the behavior is unpredictable and avoid
label key conflicts. For more information about the default labels, see: https:
//kubernetes.io/docs/reference/labels-annotations-taints/
Corresponds to the JSON property labels
6185 6186 6187 |
# File 'lib/google/apis/container_v1/classes.rb', line 6185 def labels @labels end |
#linux_node_config ⇒ Google::Apis::ContainerV1::LinuxNodeConfig
Parameters that can be configured on Linux nodes.
Corresponds to the JSON property linuxNodeConfig
6190 6191 6192 |
# File 'lib/google/apis/container_v1/classes.rb', line 6190 def linux_node_config @linux_node_config end |
#local_nvme_ssd_block_config ⇒ Google::Apis::ContainerV1::LocalNvmeSsdBlockConfig
LocalNvmeSsdBlockConfig contains configuration for using raw-block local NVMe
SSDs
Corresponds to the JSON property localNvmeSsdBlockConfig
6196 6197 6198 |
# File 'lib/google/apis/container_v1/classes.rb', line 6196 def local_nvme_ssd_block_config @local_nvme_ssd_block_config end |
#local_ssd_count ⇒ Fixnum
The number of local SSD disks to be attached to the node. The limit for this
value is dependent upon the maximum number of disks available on a machine per
zone. See: https://cloud.google.com/compute/docs/disks/local-ssd for more
information.
Corresponds to the JSON property localSsdCount
6204 6205 6206 |
# File 'lib/google/apis/container_v1/classes.rb', line 6204 def local_ssd_count @local_ssd_count end |
#local_ssd_encryption_mode ⇒ String
Specifies which method should be used for encrypting the Local SSDs attached
to the node.
Corresponds to the JSON property localSsdEncryptionMode
6210 6211 6212 |
# File 'lib/google/apis/container_v1/classes.rb', line 6210 def local_ssd_encryption_mode @local_ssd_encryption_mode end |
#logging_config ⇒ Google::Apis::ContainerV1::NodePoolLoggingConfig
NodePoolLoggingConfig specifies logging configuration for node pools.
Corresponds to the JSON property loggingConfig
6215 6216 6217 |
# File 'lib/google/apis/container_v1/classes.rb', line 6215 def logging_config @logging_config end |
#machine_type ⇒ String
The name of a Google Compute Engine machine type If unspecified, the default machine type is e2-
medium.
Corresponds to the JSON property machineType
6222 6223 6224 |
# File 'lib/google/apis/container_v1/classes.rb', line 6222 def machine_type @machine_type end |
#max_run_duration ⇒ String
The maximum duration for the nodes to exist. If unspecified, the nodes can
exist indefinitely.
Corresponds to the JSON property maxRunDuration
6228 6229 6230 |
# File 'lib/google/apis/container_v1/classes.rb', line 6228 def max_run_duration @max_run_duration end |
#metadata ⇒ Hash<String,String>
The metadata key/value pairs assigned to instances in the cluster. Keys must
conform to the regexp [a-zA-Z0-9-_]+ and be less than 128 bytes in length.
These are reflected as part of a URL in the metadata server. Additionally, to
avoid ambiguity, keys must not conflict with any other metadata keys for the
project or be one of the reserved keys: - "cluster-location" - "cluster-name" -
"cluster-uid" - "configure-sh" - "containerd-configure-sh" - "enable-os-login"
- "gci-ensure-gke-docker" - "gci-metrics-enabled" - "gci-update-strategy" - "
instance-template" - "kube-env" - "startup-script" - "user-data" - "disable-
address-manager" - "windows-startup-script-ps1" - "common-psm1" - "k8s-node-
setup-psm1" - "install-ssh-psm1" - "user-profile-psm1" Values are free-form
strings, and only have meaning as interpreted by the image running in the
instance. The only restriction placed on them is that each value's size must
be less than or equal to 32 KB. The total size of all keys and values must be
less than 512 KB.
Corresponds to the JSON property
metadata
6246 6247 6248 |
# File 'lib/google/apis/container_v1/classes.rb', line 6246 def @metadata end |
#min_cpu_platform ⇒ String
Minimum CPU platform to be used by this instance. The instance may be
scheduled on the specified or newer CPU platform. Applicable values are the
friendly names of CPU platforms, such as minCpuPlatform: "Intel Haswell" or
minCpuPlatform: "Intel Sandy Bridge". For more information, read how to
specify min CPU platform
Corresponds to the JSON property minCpuPlatform
6256 6257 6258 |
# File 'lib/google/apis/container_v1/classes.rb', line 6256 def min_cpu_platform @min_cpu_platform end |
#node_group ⇒ String
Setting this field will assign instances of this pool to run on the specified
node group. This is useful for running workloads on sole tenant nodes.
Corresponds to the JSON property nodeGroup
6263 6264 6265 |
# File 'lib/google/apis/container_v1/classes.rb', line 6263 def node_group @node_group end |
#node_image_config ⇒ Google::Apis::ContainerV1::CustomImageConfig
CustomImageConfig contains the information r
Corresponds to the JSON property nodeImageConfig
6268 6269 6270 |
# File 'lib/google/apis/container_v1/classes.rb', line 6268 def node_image_config @node_image_config end |
#oauth_scopes ⇒ Array<String>
The set of Google API scopes to be made available on all of the node VMs under
the "default" service account. The following scopes are recommended, but not
required, and by default are not included: * https://www.googleapis.com/auth/
compute is required for mounting persistent storage on your nodes. * https://
www.googleapis.com/auth/devstorage.read_only is required for communicating
with gcr.io (the Artifact Registry). If unspecified, no scopes are added, unless Cloud Logging or
Cloud Monitoring are enabled, in which case their required scopes will be
added.
Corresponds to the JSON property oauthScopes
6281 6282 6283 |
# File 'lib/google/apis/container_v1/classes.rb', line 6281 def oauth_scopes @oauth_scopes end |
#preemptible ⇒ Boolean Also known as: preemptible?
Whether the nodes are created as preemptible VM instances. See: https://cloud.
google.com/compute/docs/instances/preemptible for more information about
preemptible VM instances.
Corresponds to the JSON property preemptible
6288 6289 6290 |
# File 'lib/google/apis/container_v1/classes.rb', line 6288 def preemptible @preemptible end |
#reservation_affinity ⇒ Google::Apis::ContainerV1::ReservationAffinity
ReservationAffinity is the configuration of desired reservation which
instances could take capacity from.
Corresponds to the JSON property reservationAffinity
6296 6297 6298 |
# File 'lib/google/apis/container_v1/classes.rb', line 6296 def reservation_affinity @reservation_affinity end |
#resource_labels ⇒ Hash<String,String>
The resource labels for the node pool to use to annotate any related Google
Compute Engine resources.
Corresponds to the JSON property resourceLabels
6302 6303 6304 |
# File 'lib/google/apis/container_v1/classes.rb', line 6302 def resource_labels @resource_labels end |
#resource_manager_tags ⇒ Google::Apis::ContainerV1::ResourceManagerTags
A map of resource manager tag keys and values to be attached to the nodes for
managing Compute Engine firewalls using Network Firewall Policies. Tags must
be according to specifications in https://cloud.google.com/vpc/docs/tags-
firewalls-overview#specifications. A maximum of 5 tag key-value pairs can be
specified. Existing tags will be replaced with new values.
Corresponds to the JSON property resourceManagerTags
6311 6312 6313 |
# File 'lib/google/apis/container_v1/classes.rb', line 6311 def @resource_manager_tags end |
#sandbox_config ⇒ Google::Apis::ContainerV1::SandboxConfig
SandboxConfig contains configurations of the sandbox to use for the node.
Corresponds to the JSON property sandboxConfig
6316 6317 6318 |
# File 'lib/google/apis/container_v1/classes.rb', line 6316 def sandbox_config @sandbox_config end |
#secondary_boot_disk_update_strategy ⇒ Google::Apis::ContainerV1::SecondaryBootDiskUpdateStrategy
SecondaryBootDiskUpdateStrategy is a placeholder which will be extended in the
future to define different options for updating secondary boot disks.
Corresponds to the JSON property secondaryBootDiskUpdateStrategy
6322 6323 6324 |
# File 'lib/google/apis/container_v1/classes.rb', line 6322 def secondary_boot_disk_update_strategy @secondary_boot_disk_update_strategy end |
#secondary_boot_disks ⇒ Array<Google::Apis::ContainerV1::SecondaryBootDisk>
List of secondary boot disks attached to the nodes.
Corresponds to the JSON property secondaryBootDisks
6327 6328 6329 |
# File 'lib/google/apis/container_v1/classes.rb', line 6327 def secondary_boot_disks @secondary_boot_disks end |
#service_account ⇒ String
The Google Cloud Platform Service Account to be used by the node VMs. Specify
the email address of the Service Account; otherwise, if no Service Account is
specified, the "default" service account is used.
Corresponds to the JSON property serviceAccount
6334 6335 6336 |
# File 'lib/google/apis/container_v1/classes.rb', line 6334 def service_account @service_account end |
#shielded_instance_config ⇒ Google::Apis::ContainerV1::ShieldedInstanceConfig
A set of Shielded Instance options.
Corresponds to the JSON property shieldedInstanceConfig
6339 6340 6341 |
# File 'lib/google/apis/container_v1/classes.rb', line 6339 def shielded_instance_config @shielded_instance_config end |
#sole_tenant_config ⇒ Google::Apis::ContainerV1::SoleTenantConfig
SoleTenantConfig contains the NodeAffinities to specify what shared sole
tenant node groups should back the node pool.
Corresponds to the JSON property soleTenantConfig
6345 6346 6347 |
# File 'lib/google/apis/container_v1/classes.rb', line 6345 def sole_tenant_config @sole_tenant_config end |
#spot ⇒ Boolean Also known as: spot?
Spot flag for enabling Spot VM, which is a rebrand of the existing preemptible
flag.
Corresponds to the JSON property spot
6351 6352 6353 |
# File 'lib/google/apis/container_v1/classes.rb', line 6351 def spot @spot end |
#storage_pools ⇒ Array<String>
List of Storage Pools where boot disks are provisioned.
Corresponds to the JSON property storagePools
6357 6358 6359 |
# File 'lib/google/apis/container_v1/classes.rb', line 6357 def storage_pools @storage_pools end |
#tags ⇒ Array<String>
The list of instance tags applied to all nodes. Tags are used to identify
valid sources or targets for network firewalls and are specified by the client
during cluster or node pool creation. Each tag within the list must comply
with RFC1035.
Corresponds to the JSON property tags
6365 6366 6367 |
# File 'lib/google/apis/container_v1/classes.rb', line 6365 def @tags end |
#taint_config ⇒ Google::Apis::ContainerV1::TaintConfig
TaintConfig contains the configuration for the taints of the node pool.
Corresponds to the JSON property taintConfig
6370 6371 6372 |
# File 'lib/google/apis/container_v1/classes.rb', line 6370 def taint_config @taint_config end |
#taints ⇒ Array<Google::Apis::ContainerV1::NodeTaint>
List of kubernetes taints to be applied to each node. For more information,
including usage and the valid values, see: https://kubernetes.io/docs/concepts/
configuration/taint-and-toleration/
Corresponds to the JSON property taints
6377 6378 6379 |
# File 'lib/google/apis/container_v1/classes.rb', line 6377 def taints @taints end |
#windows_node_config ⇒ Google::Apis::ContainerV1::WindowsNodeConfig
Parameters that can be configured on Windows nodes. Windows Node Config that
define the parameters that will be used to configure the Windows node pool
settings.
Corresponds to the JSON property windowsNodeConfig
6384 6385 6386 |
# File 'lib/google/apis/container_v1/classes.rb', line 6384 def windows_node_config @windows_node_config end |
#workload_metadata_config ⇒ Google::Apis::ContainerV1::WorkloadMetadataConfig
WorkloadMetadataConfig defines the metadata configuration to expose to
workloads on the node pool.
Corresponds to the JSON property workloadMetadataConfig
6390 6391 6392 |
# File 'lib/google/apis/container_v1/classes.rb', line 6390 def @workload_metadata_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6397 6398 6399 6400 6401 6402 6403 6404 6405 6406 6407 6408 6409 6410 6411 6412 6413 6414 6415 6416 6417 6418 6419 6420 6421 6422 6423 6424 6425 6426 6427 6428 6429 6430 6431 6432 6433 6434 6435 6436 6437 6438 6439 6440 6441 6442 6443 6444 6445 6446 6447 |
# File 'lib/google/apis/container_v1/classes.rb', line 6397 def update!(**args) @accelerators = args[:accelerators] if args.key?(:accelerators) @advanced_machine_features = args[:advanced_machine_features] if args.key?(:advanced_machine_features) @boot_disk = args[:boot_disk] if args.key?(:boot_disk) @boot_disk_kms_key = args[:boot_disk_kms_key] if args.key?(:boot_disk_kms_key) @confidential_nodes = args[:confidential_nodes] if args.key?(:confidential_nodes) @consolidation_delay = args[:consolidation_delay] if args.key?(:consolidation_delay) @containerd_config = args[:containerd_config] if args.key?(:containerd_config) @disk_size_gb = args[:disk_size_gb] if args.key?(:disk_size_gb) @disk_type = args[:disk_type] if args.key?(:disk_type) @effective_cgroup_mode = args[:effective_cgroup_mode] if args.key?(:effective_cgroup_mode) @enable_confidential_storage = args[:enable_confidential_storage] if args.key?(:enable_confidential_storage) @ephemeral_storage_local_ssd_config = args[:ephemeral_storage_local_ssd_config] if args.key?(:ephemeral_storage_local_ssd_config) @fast_socket = args[:fast_socket] if args.key?(:fast_socket) @flex_start = args[:flex_start] if args.key?(:flex_start) @gcfs_config = args[:gcfs_config] if args.key?(:gcfs_config) @gpu_direct_config = args[:gpu_direct_config] if args.key?(:gpu_direct_config) @gvnic = args[:gvnic] if args.key?(:gvnic) @image_type = args[:image_type] if args.key?(:image_type) @kubelet_config = args[:kubelet_config] if args.key?(:kubelet_config) @labels = args[:labels] if args.key?(:labels) @linux_node_config = args[:linux_node_config] if args.key?(:linux_node_config) @local_nvme_ssd_block_config = args[:local_nvme_ssd_block_config] if args.key?(:local_nvme_ssd_block_config) @local_ssd_count = args[:local_ssd_count] if args.key?(:local_ssd_count) @local_ssd_encryption_mode = args[:local_ssd_encryption_mode] if args.key?(:local_ssd_encryption_mode) @logging_config = args[:logging_config] if args.key?(:logging_config) @machine_type = args[:machine_type] if args.key?(:machine_type) @max_run_duration = args[:max_run_duration] if args.key?(:max_run_duration) @metadata = args[:metadata] if args.key?(:metadata) @min_cpu_platform = args[:min_cpu_platform] if args.key?(:min_cpu_platform) @node_group = args[:node_group] if args.key?(:node_group) @node_image_config = args[:node_image_config] if args.key?(:node_image_config) @oauth_scopes = args[:oauth_scopes] if args.key?(:oauth_scopes) @preemptible = args[:preemptible] if args.key?(:preemptible) @reservation_affinity = args[:reservation_affinity] if args.key?(:reservation_affinity) @resource_labels = args[:resource_labels] if args.key?(:resource_labels) @resource_manager_tags = args[:resource_manager_tags] if args.key?(:resource_manager_tags) @sandbox_config = args[:sandbox_config] if args.key?(:sandbox_config) @secondary_boot_disk_update_strategy = args[:secondary_boot_disk_update_strategy] if args.key?(:secondary_boot_disk_update_strategy) @secondary_boot_disks = args[:secondary_boot_disks] if args.key?(:secondary_boot_disks) @service_account = args[:service_account] if args.key?(:service_account) @shielded_instance_config = args[:shielded_instance_config] if args.key?(:shielded_instance_config) @sole_tenant_config = args[:sole_tenant_config] if args.key?(:sole_tenant_config) @spot = args[:spot] if args.key?(:spot) @storage_pools = args[:storage_pools] if args.key?(:storage_pools) @tags = args[:tags] if args.key?(:tags) @taint_config = args[:taint_config] if args.key?(:taint_config) @taints = args[:taints] if args.key?(:taints) @windows_node_config = args[:windows_node_config] if args.key?(:windows_node_config) @workload_metadata_config = args[:workload_metadata_config] if args.key?(:workload_metadata_config) end |