Class: Google::Apis::ContainerV1::NodeManagement

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

NodeManagement defines the set of node management services turned on for the node pool.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NodeManagement

Returns a new instance of NodeManagement.



6839
6840
6841
# File 'lib/google/apis/container_v1/classes.rb', line 6839

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auto_repairBoolean Also known as: auto_repair?

A flag that specifies whether the node auto-repair is enabled for the node pool. If enabled, the nodes in this node pool will be monitored and, if they fail health checks too many times, an automatic repair action will be triggered. Corresponds to the JSON property autoRepair

Returns:

  • (Boolean)


6822
6823
6824
# File 'lib/google/apis/container_v1/classes.rb', line 6822

def auto_repair
  @auto_repair
end

#auto_upgradeBoolean Also known as: auto_upgrade?

A flag that specifies whether node auto-upgrade is enabled for the node pool. If enabled, node auto-upgrade helps keep the nodes in your node pool up to date with the latest release version of Kubernetes. Corresponds to the JSON property autoUpgrade

Returns:

  • (Boolean)


6830
6831
6832
# File 'lib/google/apis/container_v1/classes.rb', line 6830

def auto_upgrade
  @auto_upgrade
end

#upgrade_optionsGoogle::Apis::ContainerV1::AutoUpgradeOptions

AutoUpgradeOptions defines the set of options for the user to control how the Auto Upgrades will proceed. Corresponds to the JSON property upgradeOptions



6837
6838
6839
# File 'lib/google/apis/container_v1/classes.rb', line 6837

def upgrade_options
  @upgrade_options
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6844
6845
6846
6847
6848
# File 'lib/google/apis/container_v1/classes.rb', line 6844

def update!(**args)
  @auto_repair = args[:auto_repair] if args.key?(:auto_repair)
  @auto_upgrade = args[:auto_upgrade] if args.key?(:auto_upgrade)
  @upgrade_options = args[:upgrade_options] if args.key?(:upgrade_options)
end