Class: Google::Apis::ContainerV1::NodeNetworkConfig
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1::NodeNetworkConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb
Overview
Parameters for node pool-level network config.
Instance Attribute Summary collapse
-
#additional_node_network_configs ⇒ Array<Google::Apis::ContainerV1::AdditionalNodeNetworkConfig>
We specify the additional node networks for this node pool using this list.
-
#additional_pod_network_configs ⇒ Array<Google::Apis::ContainerV1::AdditionalPodNetworkConfig>
We specify the additional pod networks for this node pool using this list.
-
#create_pod_range ⇒ Boolean
(also: #create_pod_range?)
Input only.
-
#enable_private_nodes ⇒ Boolean
(also: #enable_private_nodes?)
Whether nodes have internal IP addresses only.
-
#network_performance_config ⇒ Google::Apis::ContainerV1::NetworkPerformanceConfig
Configuration of all network bandwidth tiers Corresponds to the JSON property
networkPerformanceConfig. -
#network_tier_config ⇒ Google::Apis::ContainerV1::NetworkTierConfig
NetworkTierConfig contains network tier information.
-
#pod_cidr_overprovision_config ⇒ Google::Apis::ContainerV1::PodCidrOverprovisionConfig
[PRIVATE FIELD] Config for pod CIDR size overprovisioning.
-
#pod_ipv4_cidr_block ⇒ String
The IP address range for pod IPs in this node pool.
-
#pod_ipv4_range_utilization ⇒ Float
Output only.
-
#pod_range ⇒ String
The ID of the secondary range for pod IPs.
-
#subnetwork ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NodeNetworkConfig
constructor
A new instance of NodeNetworkConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NodeNetworkConfig
Returns a new instance of NodeNetworkConfig.
6427 6428 6429 |
# File 'lib/google/apis/container_v1/classes.rb', line 6427 def initialize(**args) update!(**args) end |
Instance Attribute Details
#additional_node_network_configs ⇒ Array<Google::Apis::ContainerV1::AdditionalNodeNetworkConfig>
We specify the additional node networks for this node pool using this list.
Each node network corresponds to an additional interface
Corresponds to the JSON property additionalNodeNetworkConfigs
6345 6346 6347 |
# File 'lib/google/apis/container_v1/classes.rb', line 6345 def additional_node_network_configs @additional_node_network_configs end |
#additional_pod_network_configs ⇒ Array<Google::Apis::ContainerV1::AdditionalPodNetworkConfig>
We specify the additional pod networks for this node pool using this list.
Each pod network corresponds to an additional alias IP range for the node
Corresponds to the JSON property additionalPodNetworkConfigs
6351 6352 6353 |
# File 'lib/google/apis/container_v1/classes.rb', line 6351 def additional_pod_network_configs @additional_pod_network_configs end |
#create_pod_range ⇒ Boolean Also known as: create_pod_range?
Input only. Whether to create a new range for pod IPs in this node pool.
Defaults are provided for pod_range and pod_ipv4_cidr_block if they are
not specified. If neither create_pod_range or pod_range are specified, the
cluster-level default (ip_allocation_policy.cluster_ipv4_cidr_block) is used.
Only applicable if ip_allocation_policy.use_ip_aliases is true. This field
cannot be changed after the node pool has been created.
Corresponds to the JSON property createPodRange
6361 6362 6363 |
# File 'lib/google/apis/container_v1/classes.rb', line 6361 def create_pod_range @create_pod_range end |
#enable_private_nodes ⇒ Boolean Also known as: enable_private_nodes?
Whether nodes have internal IP addresses only. If enable_private_nodes is not
specified, then the value is derived from Cluster.NetworkConfig.
default_enable_private_nodes
Corresponds to the JSON property enablePrivateNodes
6369 6370 6371 |
# File 'lib/google/apis/container_v1/classes.rb', line 6369 def enable_private_nodes @enable_private_nodes end |
#network_performance_config ⇒ Google::Apis::ContainerV1::NetworkPerformanceConfig
Configuration of all network bandwidth tiers
Corresponds to the JSON property networkPerformanceConfig
6375 6376 6377 |
# File 'lib/google/apis/container_v1/classes.rb', line 6375 def network_performance_config @network_performance_config end |
#network_tier_config ⇒ Google::Apis::ContainerV1::NetworkTierConfig
NetworkTierConfig contains network tier information.
Corresponds to the JSON property networkTierConfig
6380 6381 6382 |
# File 'lib/google/apis/container_v1/classes.rb', line 6380 def network_tier_config @network_tier_config end |
#pod_cidr_overprovision_config ⇒ Google::Apis::ContainerV1::PodCidrOverprovisionConfig
[PRIVATE FIELD] Config for pod CIDR size overprovisioning.
Corresponds to the JSON property podCidrOverprovisionConfig
6385 6386 6387 |
# File 'lib/google/apis/container_v1/classes.rb', line 6385 def pod_cidr_overprovision_config @pod_cidr_overprovision_config end |
#pod_ipv4_cidr_block ⇒ String
The IP address range for pod IPs in this node pool. Only applicable if
create_pod_range is true. Set to blank to have a range chosen with the
default size. Set to /netmask (e.g. /14) to have a range chosen with a
specific netmask. Set to a CIDR notation (e.g. 10.96.0.0/14) to pick a
specific range to use. Only applicable if ip_allocation_policy.use_ip_aliases
is true. This field cannot be changed after the node pool has been created.
Corresponds to the JSON property podIpv4CidrBlock
6396 6397 6398 |
# File 'lib/google/apis/container_v1/classes.rb', line 6396 def pod_ipv4_cidr_block @pod_ipv4_cidr_block end |
#pod_ipv4_range_utilization ⇒ Float
Output only. The utilization of the IPv4 range for the pod. The ratio is Usage/
[Total number of IPs in the secondary range], Usage=numNodes*numZones*
podIPsPerNode.
Corresponds to the JSON property podIpv4RangeUtilization
6403 6404 6405 |
# File 'lib/google/apis/container_v1/classes.rb', line 6403 def pod_ipv4_range_utilization @pod_ipv4_range_utilization end |
#pod_range ⇒ String
The ID of the secondary range for pod IPs. If create_pod_range is true, this
ID is used for the new range. If create_pod_range is false, uses an existing
secondary range with this ID. Only applicable if ip_allocation_policy.
use_ip_aliases is true. This field cannot be changed after the node pool has
been created.
Corresponds to the JSON property podRange
6412 6413 6414 |
# File 'lib/google/apis/container_v1/classes.rb', line 6412 def pod_range @pod_range end |
#subnetwork ⇒ String
Optional. The subnetwork name/path for the node pool. Format: projects/
project/regions/region/subnetworks/subnetwork If the cluster is
associated with multiple subnetworks, the subnetwork can be either: - A user
supplied subnetwork name during node pool creation (e.g., my-subnet). The
name must be between 1 and 63 characters long, start with a letter, contain
only letters, numbers, and hyphens, and end with a letter or a number. - A
full subnetwork path during node pool creation, such as projects/gke-project/
regions/us-central1/subnetworks/my-subnet - A subnetwork path picked based on
the IP utilization during node pool creation and is immutable.
Corresponds to the JSON property subnetwork
6425 6426 6427 |
# File 'lib/google/apis/container_v1/classes.rb', line 6425 def subnetwork @subnetwork end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6432 6433 6434 6435 6436 6437 6438 6439 6440 6441 6442 6443 6444 |
# File 'lib/google/apis/container_v1/classes.rb', line 6432 def update!(**args) @additional_node_network_configs = args[:additional_node_network_configs] if args.key?(:additional_node_network_configs) @additional_pod_network_configs = args[:additional_pod_network_configs] if args.key?(:additional_pod_network_configs) @create_pod_range = args[:create_pod_range] if args.key?(:create_pod_range) @enable_private_nodes = args[:enable_private_nodes] if args.key?(:enable_private_nodes) @network_performance_config = args[:network_performance_config] if args.key?(:network_performance_config) @network_tier_config = args[:network_tier_config] if args.key?(:network_tier_config) @pod_cidr_overprovision_config = args[:pod_cidr_overprovision_config] if args.key?(:pod_cidr_overprovision_config) @pod_ipv4_cidr_block = args[:pod_ipv4_cidr_block] if args.key?(:pod_ipv4_cidr_block) @pod_ipv4_range_utilization = args[:pod_ipv4_range_utilization] if args.key?(:pod_ipv4_range_utilization) @pod_range = args[:pod_range] if args.key?(:pod_range) @subnetwork = args[:subnetwork] if args.key?(:subnetwork) end |