Class: Google::Apis::ContainerV1::NodePool

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

NodePool contains the name and configuration for a cluster's node pool. Node pools are a set of nodes (i.e. VM's), with a common configuration and specification, under the control of the cluster master. They may have a set of Kubernetes labels applied to them, which may be used to reference them during pod scheduling. They may also be resized up or down, to accommodate the workload.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NodePool

Returns a new instance of NodePool.



7170
7171
7172
# File 'lib/google/apis/container_v1/classes.rb', line 7170

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#autopilot_configGoogle::Apis::ContainerV1::AutopilotConfig

AutopilotConfig contains configuration of autopilot feature for this node pool. Corresponds to the JSON property autopilotConfig



7001
7002
7003
# File 'lib/google/apis/container_v1/classes.rb', line 7001

def autopilot_config
  @autopilot_config
end

#autoscalingGoogle::Apis::ContainerV1::NodePoolAutoscaling

NodePoolAutoscaling contains information required by cluster autoscaler to adjust the size of the node pool to the current cluster usage. Corresponds to the JSON property autoscaling



7007
7008
7009
# File 'lib/google/apis/container_v1/classes.rb', line 7007

def autoscaling
  @autoscaling
end

#best_effort_provisioningGoogle::Apis::ContainerV1::BestEffortProvisioning

Best effort provisioning. Corresponds to the JSON property bestEffortProvisioning



7012
7013
7014
# File 'lib/google/apis/container_v1/classes.rb', line 7012

def best_effort_provisioning
  @best_effort_provisioning
end

#conditionsArray<Google::Apis::ContainerV1::StatusCondition>

Which conditions caused the current node pool state. Corresponds to the JSON property conditions



7017
7018
7019
# File 'lib/google/apis/container_v1/classes.rb', line 7017

def conditions
  @conditions
end

#configGoogle::Apis::ContainerV1::NodeConfig

Parameters that describe the nodes in a cluster. GKE Autopilot clusters do not recognize parameters in NodeConfig. Use AutoprovisioningNodePoolDefaults instead. Corresponds to the JSON property config



7024
7025
7026
# File 'lib/google/apis/container_v1/classes.rb', line 7024

def config
  @config
end

#etagString

This checksum is computed by the server based on the value of node pool fields, and may be sent on update requests to ensure the client has an up-to-date value before proceeding. Corresponds to the JSON property etag

Returns:

  • (String)


7031
7032
7033
# File 'lib/google/apis/container_v1/classes.rb', line 7031

def etag
  @etag
end

#initial_node_countFixnum

The initial node count for the pool. You must ensure that your Compute Engine resource quota is sufficient for this number of instances. You must also have available firewall and routes quota. Corresponds to the JSON property initialNodeCount

Returns:

  • (Fixnum)


7039
7040
7041
# File 'lib/google/apis/container_v1/classes.rb', line 7039

def initial_node_count
  @initial_node_count
end

#instance_group_urlsArray<String>

Output only. The resource URLs of the managed instance groups associated with this node pool. During the node pool blue-green upgrade operation, the URLs contain both blue and green resources. Corresponds to the JSON property instanceGroupUrls

Returns:

  • (Array<String>)


7047
7048
7049
# File 'lib/google/apis/container_v1/classes.rb', line 7047

def instance_group_urls
  @instance_group_urls
end

#locationsArray<String>

The list of Google Compute Engine zones in which the NodePool's nodes should be located. If this value is unspecified during node pool creation, the Cluster.Locations value will be used, instead. Warning: changing node pool locations will result in nodes being added and/or removed. Corresponds to the JSON property locations

Returns:

  • (Array<String>)


7057
7058
7059
# File 'lib/google/apis/container_v1/classes.rb', line 7057

def locations
  @locations
end

#maintenance_policyGoogle::Apis::ContainerV1::NodePoolMaintenancePolicy

Defines the maintenance policy for the node pool. Corresponds to the JSON property maintenancePolicy



7062
7063
7064
# File 'lib/google/apis/container_v1/classes.rb', line 7062

def maintenance_policy
  @maintenance_policy
end

#managementGoogle::Apis::ContainerV1::NodeManagement

NodeManagement defines the set of node management services turned on for the node pool. Corresponds to the JSON property management



7068
7069
7070
# File 'lib/google/apis/container_v1/classes.rb', line 7068

def management
  @management
end

#max_pods_constraintGoogle::Apis::ContainerV1::MaxPodsConstraint

Constraints applied to pods. Corresponds to the JSON property maxPodsConstraint



7073
7074
7075
# File 'lib/google/apis/container_v1/classes.rb', line 7073

def max_pods_constraint
  @max_pods_constraint
end

#nameString

The name of the node pool. Corresponds to the JSON property name

Returns:

  • (String)


7078
7079
7080
# File 'lib/google/apis/container_v1/classes.rb', line 7078

def name
  @name
end

#network_configGoogle::Apis::ContainerV1::NodeNetworkConfig

Parameters for node pool-level network config. Corresponds to the JSON property networkConfig



7083
7084
7085
# File 'lib/google/apis/container_v1/classes.rb', line 7083

def network_config
  @network_config
end

#node_drain_configGoogle::Apis::ContainerV1::NodeDrainConfig

NodeDrainConfig contains the node drain related configurations for this node pool. Corresponds to the JSON property nodeDrainConfig



7089
7090
7091
# File 'lib/google/apis/container_v1/classes.rb', line 7089

def node_drain_config
  @node_drain_config
end

#placement_policyGoogle::Apis::ContainerV1::PlacementPolicy

PlacementPolicy defines the placement policy used by the node pool. Corresponds to the JSON property placementPolicy



7094
7095
7096
# File 'lib/google/apis/container_v1/classes.rb', line 7094

def placement_policy
  @placement_policy
end

#pod_ipv4_cidr_sizeFixnum

Output only. The pod CIDR block size per node in this node pool. Corresponds to the JSON property podIpv4CidrSize

Returns:

  • (Fixnum)


7099
7100
7101
# File 'lib/google/apis/container_v1/classes.rb', line 7099

def pod_ipv4_cidr_size
  @pod_ipv4_cidr_size
end

#queued_provisioningGoogle::Apis::ContainerV1::QueuedProvisioning

QueuedProvisioning defines the queued provisioning used by the node pool. Corresponds to the JSON property queuedProvisioning



7104
7105
7106
# File 'lib/google/apis/container_v1/classes.rb', line 7104

def queued_provisioning
  @queued_provisioning
end

Output only. Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


7109
7110
7111
# File 'lib/google/apis/container_v1/classes.rb', line 7109

def self_link
  @self_link
end

#statusString

Output only. The status of the nodes in this pool instance. Corresponds to the JSON property status

Returns:

  • (String)


7114
7115
7116
# File 'lib/google/apis/container_v1/classes.rb', line 7114

def status
  @status
end

#status_messageString

Output only. Deprecated. Use conditions instead. Additional information about the current status of this node pool instance, if available. Corresponds to the JSON property statusMessage

Returns:

  • (String)


7120
7121
7122
# File 'lib/google/apis/container_v1/classes.rb', line 7120

def status_message
  @status_message
end

#update_infoGoogle::Apis::ContainerV1::UpdateInfo

UpdateInfo contains resource (instance groups, etc), status and other intermediate information relevant to a node pool upgrade. Corresponds to the JSON property updateInfo



7126
7127
7128
# File 'lib/google/apis/container_v1/classes.rb', line 7126

def update_info
  @update_info
end

#upgrade_settingsGoogle::Apis::ContainerV1::UpgradeSettings

These upgrade settings control the level of parallelism and the level of disruption caused by an upgrade. maxUnavailable controls the number of nodes that can be simultaneously unavailable. maxSurge controls the number of additional nodes that can be added to the node pool temporarily for the time of the upgrade to increase the number of available nodes. (maxUnavailable + maxSurge) determines the level of parallelism (how many nodes are being upgraded at the same time). Note: upgrades inevitably introduce some disruption since workloads need to be moved from old nodes to new, upgraded ones. Even if maxUnavailable=0, this holds true. (Disruption stays within the limits of PodDisruptionBudget, if it is configured.) Consider a hypothetical node pool with 5 nodes having maxSurge=2, maxUnavailable=1. This means the upgrade process upgrades 3 nodes simultaneously. It creates 2 additional ( upgraded) nodes, then it brings down 3 old (not yet upgraded) nodes at the same time. This ensures that there are always at least 4 nodes available. These upgrade settings configure the upgrade strategy for the node pool. Use strategy to switch between the strategies applied to the node pool. If the strategy is ROLLING, use max_surge and max_unavailable to control the level of parallelism and the level of disruption caused by upgrade. 1. maxSurge controls the number of additional nodes that can be added to the node pool temporarily for the time of the upgrade to increase the number of available nodes. 2. maxUnavailable controls the number of nodes that can be simultaneously unavailable. 3. (maxUnavailable + maxSurge) determines the level of parallelism (how many nodes are being upgraded at the same time). If the strategy is BLUE_GREEN, use blue_green_settings to configure the blue- green upgrade related settings. 1. standard_rollout_policy is the default policy. The policy is used to control the way blue pool gets drained. The draining is executed in the batch mode. The batch size could be specified as either percentage of the node pool size or the number of nodes. batch_soak_duration is the soak time after each batch gets drained. 2. node_pool_soak_duration is the soak time after all blue nodes are drained. After this period, the blue pool nodes will be deleted. Corresponds to the JSON property upgradeSettings



7161
7162
7163
# File 'lib/google/apis/container_v1/classes.rb', line 7161

def upgrade_settings
  @upgrade_settings
end

#versionString

The version of Kubernetes running on this NodePool's nodes. If unspecified, it defaults as described here. Corresponds to the JSON property version

Returns:

  • (String)


7168
7169
7170
# File 'lib/google/apis/container_v1/classes.rb', line 7168

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7175
7176
7177
7178
7179
7180
7181
7182
7183
7184
7185
7186
7187
7188
7189
7190
7191
7192
7193
7194
7195
7196
7197
7198
7199
7200
# File 'lib/google/apis/container_v1/classes.rb', line 7175

def update!(**args)
  @autopilot_config = args[:autopilot_config] if args.key?(:autopilot_config)
  @autoscaling = args[:autoscaling] if args.key?(:autoscaling)
  @best_effort_provisioning = args[:best_effort_provisioning] if args.key?(:best_effort_provisioning)
  @conditions = args[:conditions] if args.key?(:conditions)
  @config = args[:config] if args.key?(:config)
  @etag = args[:etag] if args.key?(:etag)
  @initial_node_count = args[:initial_node_count] if args.key?(:initial_node_count)
  @instance_group_urls = args[:instance_group_urls] if args.key?(:instance_group_urls)
  @locations = args[:locations] if args.key?(:locations)
  @maintenance_policy = args[:maintenance_policy] if args.key?(:maintenance_policy)
  @management = args[:management] if args.key?(:management)
  @max_pods_constraint = args[:max_pods_constraint] if args.key?(:max_pods_constraint)
  @name = args[:name] if args.key?(:name)
  @network_config = args[:network_config] if args.key?(:network_config)
  @node_drain_config = args[:node_drain_config] if args.key?(:node_drain_config)
  @placement_policy = args[:placement_policy] if args.key?(:placement_policy)
  @pod_ipv4_cidr_size = args[:pod_ipv4_cidr_size] if args.key?(:pod_ipv4_cidr_size)
  @queued_provisioning = args[:queued_provisioning] if args.key?(:queued_provisioning)
  @self_link = args[:self_link] if args.key?(:self_link)
  @status = args[:status] if args.key?(:status)
  @status_message = args[:status_message] if args.key?(:status_message)
  @update_info = args[:update_info] if args.key?(:update_info)
  @upgrade_settings = args[:upgrade_settings] if args.key?(:upgrade_settings)
  @version = args[:version] if args.key?(:version)
end