Class: Google::Apis::ContainerV1::NodePoolAutoConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

Node pool configs that apply to all auto-provisioned node pools in autopilot clusters and node auto-provisioning enabled clusters.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NodePoolAutoConfig

Returns a new instance of NodePoolAutoConfig.



7233
7234
7235
# File 'lib/google/apis/container_v1/classes.rb', line 7233

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#linux_node_configGoogle::Apis::ContainerV1::LinuxNodeConfig

Parameters that can be configured on Linux nodes. Corresponds to the JSON property linuxNodeConfig



7211
7212
7213
# File 'lib/google/apis/container_v1/classes.rb', line 7211

def linux_node_config
  @linux_node_config
end

#network_tagsGoogle::Apis::ContainerV1::NetworkTags

Collection of Compute Engine network tags that can be applied to a node's underlying VM instance. Corresponds to the JSON property networkTags



7217
7218
7219
# File 'lib/google/apis/container_v1/classes.rb', line 7217

def network_tags
  @network_tags
end

#node_kubelet_configGoogle::Apis::ContainerV1::NodeKubeletConfig

Node kubelet configs. Corresponds to the JSON property nodeKubeletConfig



7222
7223
7224
# File 'lib/google/apis/container_v1/classes.rb', line 7222

def node_kubelet_config
  @node_kubelet_config
end

#resource_manager_tagsGoogle::Apis::ContainerV1::ResourceManagerTags

A map of resource manager tag keys and values to be attached to the nodes for managing Compute Engine firewalls using Network Firewall Policies. Tags must be according to specifications in https://cloud.google.com/vpc/docs/tags- firewalls-overview#specifications. A maximum of 5 tag key-value pairs can be specified. Existing tags will be replaced with new values. Corresponds to the JSON property resourceManagerTags



7231
7232
7233
# File 'lib/google/apis/container_v1/classes.rb', line 7231

def resource_manager_tags
  @resource_manager_tags
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7238
7239
7240
7241
7242
7243
# File 'lib/google/apis/container_v1/classes.rb', line 7238

def update!(**args)
  @linux_node_config = args[:linux_node_config] if args.key?(:linux_node_config)
  @network_tags = args[:network_tags] if args.key?(:network_tags)
  @node_kubelet_config = args[:node_kubelet_config] if args.key?(:node_kubelet_config)
  @resource_manager_tags = args[:resource_manager_tags] if args.key?(:resource_manager_tags)
end