Class: Google::Apis::ContainerV1::NodePoolAutoConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

Node pool configs that apply to all auto-provisioned node pools in autopilot clusters and node auto-provisioning enabled clusters.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NodePoolAutoConfig

Returns a new instance of NodePoolAutoConfig.



7220
7221
7222
# File 'lib/google/apis/container_v1/classes.rb', line 7220

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#linux_node_configGoogle::Apis::ContainerV1::LinuxNodeConfig

Parameters that can be configured on Linux nodes. Corresponds to the JSON property linuxNodeConfig



7198
7199
7200
# File 'lib/google/apis/container_v1/classes.rb', line 7198

def linux_node_config
  @linux_node_config
end

#network_tagsGoogle::Apis::ContainerV1::NetworkTags

Collection of Compute Engine network tags that can be applied to a node's underlying VM instance. Corresponds to the JSON property networkTags



7204
7205
7206
# File 'lib/google/apis/container_v1/classes.rb', line 7204

def network_tags
  @network_tags
end

#node_kubelet_configGoogle::Apis::ContainerV1::NodeKubeletConfig

Node kubelet configs. Corresponds to the JSON property nodeKubeletConfig



7209
7210
7211
# File 'lib/google/apis/container_v1/classes.rb', line 7209

def node_kubelet_config
  @node_kubelet_config
end

#resource_manager_tagsGoogle::Apis::ContainerV1::ResourceManagerTags

A map of resource manager tag keys and values to be attached to the nodes for managing Compute Engine firewalls using Network Firewall Policies. Tags must be according to specifications in https://cloud.google.com/vpc/docs/tags- firewalls-overview#specifications. A maximum of 5 tag key-value pairs can be specified. Existing tags will be replaced with new values. Corresponds to the JSON property resourceManagerTags



7218
7219
7220
# File 'lib/google/apis/container_v1/classes.rb', line 7218

def resource_manager_tags
  @resource_manager_tags
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7225
7226
7227
7228
7229
7230
# File 'lib/google/apis/container_v1/classes.rb', line 7225

def update!(**args)
  @linux_node_config = args[:linux_node_config] if args.key?(:linux_node_config)
  @network_tags = args[:network_tags] if args.key?(:network_tags)
  @node_kubelet_config = args[:node_kubelet_config] if args.key?(:node_kubelet_config)
  @resource_manager_tags = args[:resource_manager_tags] if args.key?(:resource_manager_tags)
end