Class: Google::Apis::ContainerV1::NodePoolAutoConfig
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1::NodePoolAutoConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb
Overview
Node pool configs that apply to all auto-provisioned node pools in autopilot clusters and node auto-provisioning enabled clusters.
Instance Attribute Summary collapse
-
#linux_node_config ⇒ Google::Apis::ContainerV1::LinuxNodeConfig
Parameters that can be configured on Linux nodes.
-
#network_tags ⇒ Google::Apis::ContainerV1::NetworkTags
Collection of Compute Engine network tags that can be applied to a node's underlying VM instance.
-
#node_kubelet_config ⇒ Google::Apis::ContainerV1::NodeKubeletConfig
Node kubelet configs.
-
#resource_manager_tags ⇒ Google::Apis::ContainerV1::ResourceManagerTags
A map of resource manager tag keys and values to be attached to the nodes for managing Compute Engine firewalls using Network Firewall Policies.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NodePoolAutoConfig
constructor
A new instance of NodePoolAutoConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NodePoolAutoConfig
Returns a new instance of NodePoolAutoConfig.
6424 6425 6426 |
# File 'lib/google/apis/container_v1/classes.rb', line 6424 def initialize(**args) update!(**args) end |
Instance Attribute Details
#linux_node_config ⇒ Google::Apis::ContainerV1::LinuxNodeConfig
Parameters that can be configured on Linux nodes.
Corresponds to the JSON property linuxNodeConfig
6402 6403 6404 |
# File 'lib/google/apis/container_v1/classes.rb', line 6402 def linux_node_config @linux_node_config end |
#network_tags ⇒ Google::Apis::ContainerV1::NetworkTags
Collection of Compute Engine network tags that can be applied to a node's
underlying VM instance.
Corresponds to the JSON property networkTags
6408 6409 6410 |
# File 'lib/google/apis/container_v1/classes.rb', line 6408 def @network_tags end |
#node_kubelet_config ⇒ Google::Apis::ContainerV1::NodeKubeletConfig
Node kubelet configs.
Corresponds to the JSON property nodeKubeletConfig
6413 6414 6415 |
# File 'lib/google/apis/container_v1/classes.rb', line 6413 def node_kubelet_config @node_kubelet_config end |
#resource_manager_tags ⇒ Google::Apis::ContainerV1::ResourceManagerTags
A map of resource manager tag keys and values to be attached to the nodes for
managing Compute Engine firewalls using Network Firewall Policies. Tags must
be according to specifications in https://cloud.google.com/vpc/docs/tags-
firewalls-overview#specifications. A maximum of 5 tag key-value pairs can be
specified. Existing tags will be replaced with new values.
Corresponds to the JSON property resourceManagerTags
6422 6423 6424 |
# File 'lib/google/apis/container_v1/classes.rb', line 6422 def @resource_manager_tags end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6429 6430 6431 6432 6433 6434 |
# File 'lib/google/apis/container_v1/classes.rb', line 6429 def update!(**args) @linux_node_config = args[:linux_node_config] if args.key?(:linux_node_config) @network_tags = args[:network_tags] if args.key?(:network_tags) @node_kubelet_config = args[:node_kubelet_config] if args.key?(:node_kubelet_config) @resource_manager_tags = args[:resource_manager_tags] if args.key?(:resource_manager_tags) end |