Class: Google::Apis::ContainerV1::NodePoolAutoscaling
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1::NodePoolAutoscaling
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb
Overview
NodePoolAutoscaling contains information required by cluster autoscaler to adjust the size of the node pool to the current cluster usage.
Instance Attribute Summary collapse
-
#autoprovisioned ⇒ Boolean
(also: #autoprovisioned?)
Can this node pool be deleted automatically.
-
#enabled ⇒ Boolean
(also: #enabled?)
Is autoscaling enabled for this node pool.
-
#location_policy ⇒ String
Location policy used when scaling up a node pool.
-
#max_node_count ⇒ Fixnum
Maximum number of nodes for one location in the node pool.
-
#min_node_count ⇒ Fixnum
Minimum number of nodes for one location in the node pool.
-
#total_max_node_count ⇒ Fixnum
Maximum number of nodes in the node pool.
-
#total_min_node_count ⇒ Fixnum
Minimum number of nodes in the node pool.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NodePoolAutoscaling
constructor
A new instance of NodePoolAutoscaling.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NodePoolAutoscaling
Returns a new instance of NodePoolAutoscaling.
7282 7283 7284 |
# File 'lib/google/apis/container_v1/classes.rb', line 7282 def initialize(**args) update!(**args) end |
Instance Attribute Details
#autoprovisioned ⇒ Boolean Also known as: autoprovisioned?
Can this node pool be deleted automatically.
Corresponds to the JSON property autoprovisioned
7241 7242 7243 |
# File 'lib/google/apis/container_v1/classes.rb', line 7241 def autoprovisioned @autoprovisioned end |
#enabled ⇒ Boolean Also known as: enabled?
Is autoscaling enabled for this node pool.
Corresponds to the JSON property enabled
7247 7248 7249 |
# File 'lib/google/apis/container_v1/classes.rb', line 7247 def enabled @enabled end |
#location_policy ⇒ String
Location policy used when scaling up a node pool.
Corresponds to the JSON property locationPolicy
7253 7254 7255 |
# File 'lib/google/apis/container_v1/classes.rb', line 7253 def location_policy @location_policy end |
#max_node_count ⇒ Fixnum
Maximum number of nodes for one location in the node pool. Must be >=
min_node_count. There has to be enough quota to scale up the cluster.
Corresponds to the JSON property maxNodeCount
7259 7260 7261 |
# File 'lib/google/apis/container_v1/classes.rb', line 7259 def max_node_count @max_node_count end |
#min_node_count ⇒ Fixnum
Minimum number of nodes for one location in the node pool. Must be greater
than or equal to 0 and less than or equal to max_node_count.
Corresponds to the JSON property minNodeCount
7265 7266 7267 |
# File 'lib/google/apis/container_v1/classes.rb', line 7265 def min_node_count @min_node_count end |
#total_max_node_count ⇒ Fixnum
Maximum number of nodes in the node pool. Must be greater than or equal to
total_min_node_count. There has to be enough quota to scale up the cluster.
The total_*_node_count fields are mutually exclusive with the *_node_count
fields.
Corresponds to the JSON property totalMaxNodeCount
7273 7274 7275 |
# File 'lib/google/apis/container_v1/classes.rb', line 7273 def total_max_node_count @total_max_node_count end |
#total_min_node_count ⇒ Fixnum
Minimum number of nodes in the node pool. Must be greater than or equal to 0
and less than or equal to total_max_node_count. The total_*_node_count fields
are mutually exclusive with the *_node_count fields.
Corresponds to the JSON property totalMinNodeCount
7280 7281 7282 |
# File 'lib/google/apis/container_v1/classes.rb', line 7280 def total_min_node_count @total_min_node_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7287 7288 7289 7290 7291 7292 7293 7294 7295 |
# File 'lib/google/apis/container_v1/classes.rb', line 7287 def update!(**args) @autoprovisioned = args[:autoprovisioned] if args.key?(:autoprovisioned) @enabled = args[:enabled] if args.key?(:enabled) @location_policy = args[:location_policy] if args.key?(:location_policy) @max_node_count = args[:max_node_count] if args.key?(:max_node_count) @min_node_count = args[:min_node_count] if args.key?(:min_node_count) @total_max_node_count = args[:total_max_node_count] if args.key?(:total_max_node_count) @total_min_node_count = args[:total_min_node_count] if args.key?(:total_min_node_count) end |