Class: Google::Apis::ContainerV1::NodePoolUpgradeInfo
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1::NodePoolUpgradeInfo
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb
Overview
NodePoolUpgradeInfo contains the upgrade information of a node pool.
Instance Attribute Summary collapse
-
#auto_upgrade_status ⇒ Array<String>
The auto upgrade status.
-
#custom_image_info ⇒ Google::Apis::ContainerV1::CustomImageInfo
Contains the custom image info for a node pool.
-
#end_of_extended_support_timestamp ⇒ String
The node pool's current minor version's end of extended support timestamp.
-
#end_of_standard_support_timestamp ⇒ String
The node pool's current minor version's end of standard support timestamp.
-
#minor_target_version ⇒ String
minor_target_version indicates the target version for minor upgrade.
-
#patch_target_version ⇒ String
patch_target_version indicates the target version for patch upgrade.
-
#paused_reason ⇒ Array<String>
The auto upgrade paused reason.
-
#upgrade_details ⇒ Array<Google::Apis::ContainerV1::UpgradeDetails>
The list of past auto upgrades.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NodePoolUpgradeInfo
constructor
A new instance of NodePoolUpgradeInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NodePoolUpgradeInfo
Returns a new instance of NodePoolUpgradeInfo.
7412 7413 7414 |
# File 'lib/google/apis/container_v1/classes.rb', line 7412 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auto_upgrade_status ⇒ Array<String>
The auto upgrade status.
Corresponds to the JSON property autoUpgradeStatus
7375 7376 7377 |
# File 'lib/google/apis/container_v1/classes.rb', line 7375 def auto_upgrade_status @auto_upgrade_status end |
#custom_image_info ⇒ Google::Apis::ContainerV1::CustomImageInfo
Contains the custom image info for a node pool.
Corresponds to the JSON property customImageInfo
7380 7381 7382 |
# File 'lib/google/apis/container_v1/classes.rb', line 7380 def custom_image_info @custom_image_info end |
#end_of_extended_support_timestamp ⇒ String
The node pool's current minor version's end of extended support timestamp.
Corresponds to the JSON property endOfExtendedSupportTimestamp
7385 7386 7387 |
# File 'lib/google/apis/container_v1/classes.rb', line 7385 def @end_of_extended_support_timestamp end |
#end_of_standard_support_timestamp ⇒ String
The node pool's current minor version's end of standard support timestamp.
Corresponds to the JSON property endOfStandardSupportTimestamp
7390 7391 7392 |
# File 'lib/google/apis/container_v1/classes.rb', line 7390 def @end_of_standard_support_timestamp end |
#minor_target_version ⇒ String
minor_target_version indicates the target version for minor upgrade.
Corresponds to the JSON property minorTargetVersion
7395 7396 7397 |
# File 'lib/google/apis/container_v1/classes.rb', line 7395 def minor_target_version @minor_target_version end |
#patch_target_version ⇒ String
patch_target_version indicates the target version for patch upgrade.
Corresponds to the JSON property patchTargetVersion
7400 7401 7402 |
# File 'lib/google/apis/container_v1/classes.rb', line 7400 def patch_target_version @patch_target_version end |
#paused_reason ⇒ Array<String>
The auto upgrade paused reason.
Corresponds to the JSON property pausedReason
7405 7406 7407 |
# File 'lib/google/apis/container_v1/classes.rb', line 7405 def paused_reason @paused_reason end |
#upgrade_details ⇒ Array<Google::Apis::ContainerV1::UpgradeDetails>
The list of past auto upgrades.
Corresponds to the JSON property upgradeDetails
7410 7411 7412 |
# File 'lib/google/apis/container_v1/classes.rb', line 7410 def upgrade_details @upgrade_details end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7417 7418 7419 7420 7421 7422 7423 7424 7425 7426 |
# File 'lib/google/apis/container_v1/classes.rb', line 7417 def update!(**args) @auto_upgrade_status = args[:auto_upgrade_status] if args.key?(:auto_upgrade_status) @custom_image_info = args[:custom_image_info] if args.key?(:custom_image_info) @end_of_extended_support_timestamp = args[:end_of_extended_support_timestamp] if args.key?(:end_of_extended_support_timestamp) @end_of_standard_support_timestamp = args[:end_of_standard_support_timestamp] if args.key?(:end_of_standard_support_timestamp) @minor_target_version = args[:minor_target_version] if args.key?(:minor_target_version) @patch_target_version = args[:patch_target_version] if args.key?(:patch_target_version) @paused_reason = args[:paused_reason] if args.key?(:paused_reason) @upgrade_details = args[:upgrade_details] if args.key?(:upgrade_details) end |