Class: Google::Apis::ContainerV1::Operation
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1::Operation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb
Overview
This operation resource represents operations that may have happened or are happening on the cluster. All fields are output only.
Instance Attribute Summary collapse
-
#cluster_conditions ⇒ Array<Google::Apis::ContainerV1::StatusCondition>
Which conditions caused the current cluster state.
-
#detail ⇒ String
Output only.
-
#end_time ⇒ String
Output only.
-
#error ⇒ Google::Apis::ContainerV1::Status
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#location ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#nodepool_conditions ⇒ Array<Google::Apis::ContainerV1::StatusCondition>
Which conditions caused the current node pool state.
-
#operation_type ⇒ String
Output only.
-
#progress ⇒ Google::Apis::ContainerV1::OperationProgress
Information about operation (or operation stage) progress.
-
#self_link ⇒ String
Output only.
-
#start_time ⇒ String
Output only.
-
#status ⇒ String
Output only.
-
#status_message ⇒ String
Output only.
-
#target_link ⇒ String
Output only.
-
#zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Operation
constructor
A new instance of Operation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Operation
Returns a new instance of Operation.
7627 7628 7629 |
# File 'lib/google/apis/container_v1/classes.rb', line 7627 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cluster_conditions ⇒ Array<Google::Apis::ContainerV1::StatusCondition>
Which conditions caused the current cluster state. Deprecated. Use field error
instead.
Corresponds to the JSON property clusterConditions
7532 7533 7534 |
# File 'lib/google/apis/container_v1/classes.rb', line 7532 def cluster_conditions @cluster_conditions end |
#detail ⇒ String
Output only. Detailed operation progress, if available.
Corresponds to the JSON property detail
7537 7538 7539 |
# File 'lib/google/apis/container_v1/classes.rb', line 7537 def detail @detail end |
#end_time ⇒ String
Output only. The time the operation completed, in RFC3339 text format.
Corresponds to the JSON property endTime
7543 7544 7545 |
# File 'lib/google/apis/container_v1/classes.rb', line 7543 def end_time @end_time end |
#error ⇒ Google::Apis::ContainerV1::Status
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
7553 7554 7555 |
# File 'lib/google/apis/container_v1/classes.rb', line 7553 def error @error end |
#location ⇒ String
7561 7562 7563 |
# File 'lib/google/apis/container_v1/classes.rb', line 7561 def location @location end |
#name ⇒ String
Output only. The server-assigned ID for the operation.
Corresponds to the JSON property name
7566 7567 7568 |
# File 'lib/google/apis/container_v1/classes.rb', line 7566 def name @name end |
#nodepool_conditions ⇒ Array<Google::Apis::ContainerV1::StatusCondition>
Which conditions caused the current node pool state. Deprecated. Use field
error instead.
Corresponds to the JSON property nodepoolConditions
7572 7573 7574 |
# File 'lib/google/apis/container_v1/classes.rb', line 7572 def nodepool_conditions @nodepool_conditions end |
#operation_type ⇒ String
Output only. The operation type.
Corresponds to the JSON property operationType
7577 7578 7579 |
# File 'lib/google/apis/container_v1/classes.rb', line 7577 def operation_type @operation_type end |
#progress ⇒ Google::Apis::ContainerV1::OperationProgress
Information about operation (or operation stage) progress.
Corresponds to the JSON property progress
7582 7583 7584 |
# File 'lib/google/apis/container_v1/classes.rb', line 7582 def progress @progress end |
#self_link ⇒ String
Output only. Server-defined URI for the operation. Example: https://container.
googleapis.com/v1alpha1/projects/123/locations/us-central1/operations/
operation-123.
Corresponds to the JSON property selfLink
7589 7590 7591 |
# File 'lib/google/apis/container_v1/classes.rb', line 7589 def self_link @self_link end |
#start_time ⇒ String
Output only. The time the operation started, in RFC3339 text format.
Corresponds to the JSON property startTime
7595 7596 7597 |
# File 'lib/google/apis/container_v1/classes.rb', line 7595 def start_time @start_time end |
#status ⇒ String
Output only. The current status of the operation.
Corresponds to the JSON property status
7600 7601 7602 |
# File 'lib/google/apis/container_v1/classes.rb', line 7600 def status @status end |
#status_message ⇒ String
Output only. If an error has occurred, a textual description of the error.
Deprecated. Use the field error instead.
Corresponds to the JSON property statusMessage
7606 7607 7608 |
# File 'lib/google/apis/container_v1/classes.rb', line 7606 def @status_message end |
#target_link ⇒ String
Output only. Server-defined URI for the target of the operation. The format of
this is a URI to the resource being modified (such as a cluster, node pool, or
node). For node pool repairs, there may be multiple nodes being repaired, but
only one will be the target. Examples: - ## https://container.googleapis.com/
v1/projects/123/locations/us-central1/clusters/my-cluster ## https://
container.googleapis.com/v1/projects/123/zones/us-central1-c/clusters/my-
cluster/nodePools/my-np https://container.googleapis.com/v1/projects/123/
zones/us-central1-c/clusters/my-cluster/nodePools/my-np/node/my-node
Corresponds to the JSON property targetLink
7618 7619 7620 |
# File 'lib/google/apis/container_v1/classes.rb', line 7618 def target_link @target_link end |
#zone ⇒ String
Output only. The name of the Google Compute Engine zone in which the operation is taking place. This
field is deprecated, use location instead.
Corresponds to the JSON property zone
7625 7626 7627 |
# File 'lib/google/apis/container_v1/classes.rb', line 7625 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7632 7633 7634 7635 7636 7637 7638 7639 7640 7641 7642 7643 7644 7645 7646 7647 7648 |
# File 'lib/google/apis/container_v1/classes.rb', line 7632 def update!(**args) @cluster_conditions = args[:cluster_conditions] if args.key?(:cluster_conditions) @detail = args[:detail] if args.key?(:detail) @end_time = args[:end_time] if args.key?(:end_time) @error = args[:error] if args.key?(:error) @location = args[:location] if args.key?(:location) @name = args[:name] if args.key?(:name) @nodepool_conditions = args[:nodepool_conditions] if args.key?(:nodepool_conditions) @operation_type = args[:operation_type] if args.key?(:operation_type) @progress = args[:progress] if args.key?(:progress) @self_link = args[:self_link] if args.key?(:self_link) @start_time = args[:start_time] if args.key?(:start_time) @status = args[:status] if args.key?(:status) @status_message = args[:status_message] if args.key?(:status_message) @target_link = args[:target_link] if args.key?(:target_link) @zone = args[:zone] if args.key?(:zone) end |