Class: Google::Apis::ContainerV1::Operation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

This operation resource represents operations that may have happened or are happening on the cluster. All fields are output only.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Operation

Returns a new instance of Operation.



7033
7034
7035
# File 'lib/google/apis/container_v1/classes.rb', line 7033

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cluster_conditionsArray<Google::Apis::ContainerV1::StatusCondition>

Which conditions caused the current cluster state. Deprecated. Use field error instead. Corresponds to the JSON property clusterConditions



6938
6939
6940
# File 'lib/google/apis/container_v1/classes.rb', line 6938

def cluster_conditions
  @cluster_conditions
end

#detailString

Output only. Detailed operation progress, if available. Corresponds to the JSON property detail

Returns:

  • (String)


6943
6944
6945
# File 'lib/google/apis/container_v1/classes.rb', line 6943

def detail
  @detail
end

#end_timeString

Output only. The time the operation completed, in RFC3339 text format. Corresponds to the JSON property endTime

Returns:

  • (String)


6949
6950
6951
# File 'lib/google/apis/container_v1/classes.rb', line 6949

def end_time
  @end_time
end

#errorGoogle::Apis::ContainerV1::Status

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



6959
6960
6961
# File 'lib/google/apis/container_v1/classes.rb', line 6959

def error
  @error
end

#locationString

Output only. The name of the Google Compute Engine zone or region in which the cluster resides. Corresponds to the JSON property location

Returns:

  • (String)


6967
6968
6969
# File 'lib/google/apis/container_v1/classes.rb', line 6967

def location
  @location
end

#nameString

Output only. The server-assigned ID for the operation. Corresponds to the JSON property name

Returns:

  • (String)


6972
6973
6974
# File 'lib/google/apis/container_v1/classes.rb', line 6972

def name
  @name
end

#nodepool_conditionsArray<Google::Apis::ContainerV1::StatusCondition>

Which conditions caused the current node pool state. Deprecated. Use field error instead. Corresponds to the JSON property nodepoolConditions



6978
6979
6980
# File 'lib/google/apis/container_v1/classes.rb', line 6978

def nodepool_conditions
  @nodepool_conditions
end

#operation_typeString

Output only. The operation type. Corresponds to the JSON property operationType

Returns:

  • (String)


6983
6984
6985
# File 'lib/google/apis/container_v1/classes.rb', line 6983

def operation_type
  @operation_type
end

#progressGoogle::Apis::ContainerV1::OperationProgress

Information about operation (or operation stage) progress. Corresponds to the JSON property progress



6988
6989
6990
# File 'lib/google/apis/container_v1/classes.rb', line 6988

def progress
  @progress
end

Output only. Server-defined URI for the operation. Example: https://container. googleapis.com/v1alpha1/projects/123/locations/us-central1/operations/ operation-123. Corresponds to the JSON property selfLink

Returns:

  • (String)


6995
6996
6997
# File 'lib/google/apis/container_v1/classes.rb', line 6995

def self_link
  @self_link
end

#start_timeString

Output only. The time the operation started, in RFC3339 text format. Corresponds to the JSON property startTime

Returns:

  • (String)


7001
7002
7003
# File 'lib/google/apis/container_v1/classes.rb', line 7001

def start_time
  @start_time
end

#statusString

Output only. The current status of the operation. Corresponds to the JSON property status

Returns:

  • (String)


7006
7007
7008
# File 'lib/google/apis/container_v1/classes.rb', line 7006

def status
  @status
end

#status_messageString

Output only. If an error has occurred, a textual description of the error. Deprecated. Use the field error instead. Corresponds to the JSON property statusMessage

Returns:

  • (String)


7012
7013
7014
# File 'lib/google/apis/container_v1/classes.rb', line 7012

def status_message
  @status_message
end

Output only. Server-defined URI for the target of the operation. The format of this is a URI to the resource being modified (such as a cluster, node pool, or node). For node pool repairs, there may be multiple nodes being repaired, but only one will be the target. Examples: - ## https://container.googleapis.com/ v1/projects/123/locations/us-central1/clusters/my-cluster ## https:// container.googleapis.com/v1/projects/123/zones/us-central1-c/clusters/my- cluster/nodePools/my-np https://container.googleapis.com/v1/projects/123/ zones/us-central1-c/clusters/my-cluster/nodePools/my-np/node/my-node Corresponds to the JSON property targetLink

Returns:

  • (String)


7024
7025
7026
# File 'lib/google/apis/container_v1/classes.rb', line 7024

def target_link
  @target_link
end

#zoneString

Output only. The name of the Google Compute Engine zone in which the operation is taking place. This field is deprecated, use location instead. Corresponds to the JSON property zone

Returns:

  • (String)


7031
7032
7033
# File 'lib/google/apis/container_v1/classes.rb', line 7031

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7038
7039
7040
7041
7042
7043
7044
7045
7046
7047
7048
7049
7050
7051
7052
7053
7054
# File 'lib/google/apis/container_v1/classes.rb', line 7038

def update!(**args)
  @cluster_conditions = args[:cluster_conditions] if args.key?(:cluster_conditions)
  @detail = args[:detail] if args.key?(:detail)
  @end_time = args[:end_time] if args.key?(:end_time)
  @error = args[:error] if args.key?(:error)
  @location = args[:location] if args.key?(:location)
  @name = args[:name] if args.key?(:name)
  @nodepool_conditions = args[:nodepool_conditions] if args.key?(:nodepool_conditions)
  @operation_type = args[:operation_type] if args.key?(:operation_type)
  @progress = args[:progress] if args.key?(:progress)
  @self_link = args[:self_link] if args.key?(:self_link)
  @start_time = args[:start_time] if args.key?(:start_time)
  @status = args[:status] if args.key?(:status)
  @status_message = args[:status_message] if args.key?(:status_message)
  @target_link = args[:target_link] if args.key?(:target_link)
  @zone = args[:zone] if args.key?(:zone)
end