Class: Google::Apis::ContainerV1::PlacementPolicy
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1::PlacementPolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb
Overview
PlacementPolicy defines the placement policy used by the node pool.
Instance Attribute Summary collapse
-
#policy_name ⇒ String
If set, refers to the name of a custom resource policy supplied by the user.
-
#tpu_topology ⇒ String
Optional.
-
#type ⇒ String
The type of placement.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PlacementPolicy
constructor
A new instance of PlacementPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PlacementPolicy
Returns a new instance of PlacementPolicy.
7798 7799 7800 |
# File 'lib/google/apis/container_v1/classes.rb', line 7798 def initialize(**args) update!(**args) end |
Instance Attribute Details
#policy_name ⇒ String
If set, refers to the name of a custom resource policy supplied by the user.
The resource policy must be in the same project and region as the node pool.
If not found, InvalidArgument error is returned.
Corresponds to the JSON property policyName
7785 7786 7787 |
# File 'lib/google/apis/container_v1/classes.rb', line 7785 def policy_name @policy_name end |
#tpu_topology ⇒ String
Optional. TPU placement topology for pod slice node pool. https://cloud.google.
com/tpu/docs/types-topologies#tpu_topologies
Corresponds to the JSON property tpuTopology
7791 7792 7793 |
# File 'lib/google/apis/container_v1/classes.rb', line 7791 def tpu_topology @tpu_topology end |
#type ⇒ String
The type of placement.
Corresponds to the JSON property type
7796 7797 7798 |
# File 'lib/google/apis/container_v1/classes.rb', line 7796 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7803 7804 7805 7806 7807 |
# File 'lib/google/apis/container_v1/classes.rb', line 7803 def update!(**args) @policy_name = args[:policy_name] if args.key?(:policy_name) @tpu_topology = args[:tpu_topology] if args.key?(:tpu_topology) @type = args[:type] if args.key?(:type) end |