Class: Google::Apis::ContainerV1::PlacementPolicy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

PlacementPolicy defines the placement policy used by the node pool.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PlacementPolicy

Returns a new instance of PlacementPolicy.



7223
7224
7225
# File 'lib/google/apis/container_v1/classes.rb', line 7223

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#policy_nameString

If set, refers to the name of a custom resource policy supplied by the user. The resource policy must be in the same project and region as the node pool. If not found, InvalidArgument error is returned. Corresponds to the JSON property policyName

Returns:

  • (String)


7210
7211
7212
# File 'lib/google/apis/container_v1/classes.rb', line 7210

def policy_name
  @policy_name
end

#tpu_topologyString

Optional. TPU placement topology for pod slice node pool. https://cloud.google. com/tpu/docs/types-topologies#tpu_topologies Corresponds to the JSON property tpuTopology

Returns:

  • (String)


7216
7217
7218
# File 'lib/google/apis/container_v1/classes.rb', line 7216

def tpu_topology
  @tpu_topology
end

#typeString

The type of placement. Corresponds to the JSON property type

Returns:

  • (String)


7221
7222
7223
# File 'lib/google/apis/container_v1/classes.rb', line 7221

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7228
7229
7230
7231
7232
# File 'lib/google/apis/container_v1/classes.rb', line 7228

def update!(**args)
  @policy_name = args[:policy_name] if args.key?(:policy_name)
  @tpu_topology = args[:tpu_topology] if args.key?(:tpu_topology)
  @type = args[:type] if args.key?(:type)
end