Class: Google::Apis::ContainerV1::PrivateClusterConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

Configuration options for private clusters.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PrivateClusterConfig

Returns a new instance of PrivateClusterConfig.



7933
7934
7935
# File 'lib/google/apis/container_v1/classes.rb', line 7933

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enable_private_endpointBoolean Also known as: enable_private_endpoint?

Whether the master's internal IP address is used as the cluster endpoint. Deprecated: Use ControlPlaneEndpointsConfig.IPEndpointsConfig. enable_public_endpoint instead. Note that the value of enable_public_endpoint is reversed: if enable_private_endpoint is false, then enable_public_endpoint will be true. Corresponds to the JSON property enablePrivateEndpoint

Returns:

  • (Boolean)


7882
7883
7884
# File 'lib/google/apis/container_v1/classes.rb', line 7882

def enable_private_endpoint
  @enable_private_endpoint
end

#enable_private_nodesBoolean Also known as: enable_private_nodes?

Whether nodes have internal IP addresses only. If enabled, all nodes are given only RFC 1918 private addresses and communicate with the master via private networking. Deprecated: Use NetworkConfig.default_enable_private_nodes instead. Corresponds to the JSON property enablePrivateNodes

Returns:

  • (Boolean)


7890
7891
7892
# File 'lib/google/apis/container_v1/classes.rb', line 7890

def enable_private_nodes
  @enable_private_nodes
end

#master_global_access_configGoogle::Apis::ContainerV1::PrivateClusterMasterGlobalAccessConfig

Configuration for controlling master global access settings. Corresponds to the JSON property masterGlobalAccessConfig



7896
7897
7898
# File 'lib/google/apis/container_v1/classes.rb', line 7896

def master_global_access_config
  @master_global_access_config
end

#master_ipv4_cidr_blockString

The IP range in CIDR notation to use for the hosted master network. This range will be used for assigning internal IP addresses to the master or set of masters, as well as the ILB VIP. This range must not overlap with any other ranges in use within the cluster's network. Corresponds to the JSON property masterIpv4CidrBlock

Returns:

  • (String)


7904
7905
7906
# File 'lib/google/apis/container_v1/classes.rb', line 7904

def master_ipv4_cidr_block
  @master_ipv4_cidr_block
end

#peering_nameString

Output only. The peering name in the customer VPC used by this cluster. Corresponds to the JSON property peeringName

Returns:

  • (String)


7909
7910
7911
# File 'lib/google/apis/container_v1/classes.rb', line 7909

def peering_name
  @peering_name
end

#private_endpointString

Output only. The internal IP address of this cluster's master endpoint. Deprecated: Use ControlPlaneEndpointsConfig.IPEndpointsConfig.private_endpoint instead. Corresponds to the JSON property privateEndpoint

Returns:

  • (String)


7916
7917
7918
# File 'lib/google/apis/container_v1/classes.rb', line 7916

def private_endpoint
  @private_endpoint
end

#private_endpoint_subnetworkString

Subnet to provision the master's private endpoint during cluster creation. Specified in projects//regions//subnetworks/* format. Deprecated: Use ControlPlaneEndpointsConfig.IPEndpointsConfig.private_endpoint_subnetwork instead. Corresponds to the JSON property privateEndpointSubnetwork

Returns:

  • (String)


7924
7925
7926
# File 'lib/google/apis/container_v1/classes.rb', line 7924

def private_endpoint_subnetwork
  @private_endpoint_subnetwork
end

#public_endpointString

Output only. The external IP address of this cluster's master endpoint. Deprecated:Use ControlPlaneEndpointsConfig.IPEndpointsConfig.public_endpoint instead. Corresponds to the JSON property publicEndpoint

Returns:

  • (String)


7931
7932
7933
# File 'lib/google/apis/container_v1/classes.rb', line 7931

def public_endpoint
  @public_endpoint
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7938
7939
7940
7941
7942
7943
7944
7945
7946
7947
# File 'lib/google/apis/container_v1/classes.rb', line 7938

def update!(**args)
  @enable_private_endpoint = args[:enable_private_endpoint] if args.key?(:enable_private_endpoint)
  @enable_private_nodes = args[:enable_private_nodes] if args.key?(:enable_private_nodes)
  @master_global_access_config = args[:master_global_access_config] if args.key?(:master_global_access_config)
  @master_ipv4_cidr_block = args[:master_ipv4_cidr_block] if args.key?(:master_ipv4_cidr_block)
  @peering_name = args[:peering_name] if args.key?(:peering_name)
  @private_endpoint = args[:private_endpoint] if args.key?(:private_endpoint)
  @private_endpoint_subnetwork = args[:private_endpoint_subnetwork] if args.key?(:private_endpoint_subnetwork)
  @public_endpoint = args[:public_endpoint] if args.key?(:public_endpoint)
end