Class: Google::Apis::ContainerV1::PubSub
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1::PubSub
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb
Overview
Pub/Sub specific notification config.
Instance Attribute Summary collapse
-
#enabled ⇒ Boolean
(also: #enabled?)
Enable notifications for Pub/Sub.
-
#filter ⇒ Google::Apis::ContainerV1::Filter
Allows filtering to one or more specific event types.
-
#topic ⇒ String
The desired Pub/Sub topic to which notifications will be sent by GKE.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PubSub
constructor
A new instance of PubSub.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PubSub
Returns a new instance of PubSub.
8221 8222 8223 |
# File 'lib/google/apis/container_v1/classes.rb', line 8221 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enabled ⇒ Boolean Also known as: enabled?
Enable notifications for Pub/Sub.
Corresponds to the JSON property enabled
8204 8205 8206 |
# File 'lib/google/apis/container_v1/classes.rb', line 8204 def enabled @enabled end |
#filter ⇒ Google::Apis::ContainerV1::Filter
Allows filtering to one or more specific event types. If event types are
present, those and only those event types will be transmitted to the cluster.
Other types will be skipped. If no filter is specified, or no event types are
present, all event types will be sent
Corresponds to the JSON property filter
8213 8214 8215 |
# File 'lib/google/apis/container_v1/classes.rb', line 8213 def filter @filter end |
#topic ⇒ String
The desired Pub/Sub topic to which notifications will be sent by GKE. Format
is projects/project/topics/topic`.
Corresponds to the JSON propertytopic`
8219 8220 8221 |
# File 'lib/google/apis/container_v1/classes.rb', line 8219 def topic @topic end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8226 8227 8228 8229 8230 |
# File 'lib/google/apis/container_v1/classes.rb', line 8226 def update!(**args) @enabled = args[:enabled] if args.key?(:enabled) @filter = args[:filter] if args.key?(:filter) @topic = args[:topic] if args.key?(:topic) end |