Class: Google::Apis::ContainerV1::PubSub

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

Pub/Sub specific notification config.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PubSub

Returns a new instance of PubSub.



8065
8066
8067
# File 'lib/google/apis/container_v1/classes.rb', line 8065

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enabledBoolean Also known as: enabled?

Enable notifications for Pub/Sub. Corresponds to the JSON property enabled

Returns:

  • (Boolean)


8048
8049
8050
# File 'lib/google/apis/container_v1/classes.rb', line 8048

def enabled
  @enabled
end

#filterGoogle::Apis::ContainerV1::Filter

Allows filtering to one or more specific event types. If event types are present, those and only those event types will be transmitted to the cluster. Other types will be skipped. If no filter is specified, or no event types are present, all event types will be sent Corresponds to the JSON property filter



8057
8058
8059
# File 'lib/google/apis/container_v1/classes.rb', line 8057

def filter
  @filter
end

#topicString

The desired Pub/Sub topic to which notifications will be sent by GKE. Format is projects/project/topics/topic`. Corresponds to the JSON propertytopic`

Returns:

  • (String)


8063
8064
8065
# File 'lib/google/apis/container_v1/classes.rb', line 8063

def topic
  @topic
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8070
8071
8072
8073
8074
# File 'lib/google/apis/container_v1/classes.rb', line 8070

def update!(**args)
  @enabled = args[:enabled] if args.key?(:enabled)
  @filter = args[:filter] if args.key?(:filter)
  @topic = args[:topic] if args.key?(:topic)
end