Class: Google::Apis::ContainerV1::RecurringMaintenanceWindow

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

Represents an arbitrary window of time that recurs. Will replace RecurringTimeWindow.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RecurringMaintenanceWindow

Returns a new instance of RecurringMaintenanceWindow.



8245
8246
8247
# File 'lib/google/apis/container_v1/classes.rb', line 8245

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#delay_untilGoogle::Apis::ContainerV1::Date

Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following: * A full date, with non-zero year, month, and day values. * A month and day, with a zero year (for example, an anniversary). * A year on its own, with a zero month and a zero day. * A year and month, with a zero day (for example, a credit card expiration date). Related types: * google.type. TimeOfDay * google.type.DateTime * google.protobuf.Timestamp Corresponds to the JSON property delayUntil



8221
8222
8223
# File 'lib/google/apis/container_v1/classes.rb', line 8221

def delay_until
  @delay_until
end

#recurrenceString

Required. An RRULE (https://tools.ietf.org/html/rfc5545#section-3.8.5.3) for how this window recurs. For example, to have something repeat every weekday, you'd use: FREQ=WEEKLY;BYDAY=MO,TU,WE,TH,FR To repeat some window daily ( equivalent to the DailyMaintenanceWindow): FREQ=DAILY For the first weekend of every month: FREQ=MONTHLY;BYSETPOS=1;BYDAY=SA,SU The FREQ values of HOURLY, MINUTELY, and SECONDLY are not supported. Corresponds to the JSON property recurrence

Returns:

  • (String)


8231
8232
8233
# File 'lib/google/apis/container_v1/classes.rb', line 8231

def recurrence
  @recurrence
end

#window_durationString

Required. Duration of the window. Corresponds to the JSON property windowDuration

Returns:

  • (String)


8236
8237
8238
# File 'lib/google/apis/container_v1/classes.rb', line 8236

def window_duration
  @window_duration
end

#window_start_timeGoogle::Apis::ContainerV1::TimeOfDay

Represents a time of day. The date and time zone are either not significant or are specified elsewhere. An API may choose to allow leap seconds. Related types are google.type.Date and google.protobuf.Timestamp. Corresponds to the JSON property windowStartTime



8243
8244
8245
# File 'lib/google/apis/container_v1/classes.rb', line 8243

def window_start_time
  @window_start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8250
8251
8252
8253
8254
8255
# File 'lib/google/apis/container_v1/classes.rb', line 8250

def update!(**args)
  @delay_until = args[:delay_until] if args.key?(:delay_until)
  @recurrence = args[:recurrence] if args.key?(:recurrence)
  @window_duration = args[:window_duration] if args.key?(:window_duration)
  @window_start_time = args[:window_start_time] if args.key?(:window_start_time)
end