Class: Google::Apis::ContainerV1::RegistryHostConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

RegistryHostConfig configures the top-level structure for a single containerd registry server's configuration, which represents one hosts.toml file on the node. It will override the same fqdns in PrivateRegistryAccessConfig.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegistryHostConfig

Returns a new instance of RegistryHostConfig.



8343
8344
8345
# File 'lib/google/apis/container_v1/classes.rb', line 8343

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#hostsArray<Google::Apis::ContainerV1::HostConfig>

HostConfig configures a list of host-specific configurations for the server. Each server can have at most 10 host configurations. Corresponds to the JSON property hosts



8332
8333
8334
# File 'lib/google/apis/container_v1/classes.rb', line 8332

def hosts
  @hosts
end

#serverString

Defines the host name of the registry server, which will be used to create configuration file as /etc/containerd/hosts.d//hosts.toml. It supports fully qualified domain names (FQDN) and IP addresses: Specifying port is supported, while scheme and path are NOT supported. Wildcards are NOT supported. Examples:

  • my.customdomain.com - 10.0.1.2:5000 Corresponds to the JSON property server

Returns:

  • (String)


8341
8342
8343
# File 'lib/google/apis/container_v1/classes.rb', line 8341

def server
  @server
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8348
8349
8350
8351
# File 'lib/google/apis/container_v1/classes.rb', line 8348

def update!(**args)
  @hosts = args[:hosts] if args.key?(:hosts)
  @server = args[:server] if args.key?(:server)
end