Class: Google::Apis::ContainerV1::ResourceUsageExportConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

Configuration for exporting cluster resource usages.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourceUsageExportConfig

Returns a new instance of ResourceUsageExportConfig.



7637
7638
7639
# File 'lib/google/apis/container_v1/classes.rb', line 7637

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bigquery_destinationGoogle::Apis::ContainerV1::BigQueryDestination

Parameters for using BigQuery as the destination of resource usage export. Corresponds to the JSON property bigqueryDestination



7623
7624
7625
# File 'lib/google/apis/container_v1/classes.rb', line 7623

def bigquery_destination
  @bigquery_destination
end

#consumption_metering_configGoogle::Apis::ContainerV1::ConsumptionMeteringConfig

Parameters for controlling consumption metering. Corresponds to the JSON property consumptionMeteringConfig



7628
7629
7630
# File 'lib/google/apis/container_v1/classes.rb', line 7628

def consumption_metering_config
  @consumption_metering_config
end

#enable_network_egress_meteringBoolean Also known as: enable_network_egress_metering?

Whether to enable network egress metering for this cluster. If enabled, a daemonset will be created in the cluster to meter network egress traffic. Corresponds to the JSON property enableNetworkEgressMetering

Returns:

  • (Boolean)


7634
7635
7636
# File 'lib/google/apis/container_v1/classes.rb', line 7634

def enable_network_egress_metering
  @enable_network_egress_metering
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7642
7643
7644
7645
7646
# File 'lib/google/apis/container_v1/classes.rb', line 7642

def update!(**args)
  @bigquery_destination = args[:bigquery_destination] if args.key?(:bigquery_destination)
  @consumption_metering_config = args[:consumption_metering_config] if args.key?(:consumption_metering_config)
  @enable_network_egress_metering = args[:enable_network_egress_metering] if args.key?(:enable_network_egress_metering)
end