Class: Google::Apis::ContainerV1::RollbackNodePoolUpgradeRequest
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1::RollbackNodePoolUpgradeRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb
Overview
RollbackNodePoolUpgradeRequest rollbacks the previously Aborted or Failed NodePool upgrade. This will be an no-op if the last upgrade successfully completed.
Instance Attribute Summary collapse
-
#cluster_id ⇒ String
Deprecated.
-
#name ⇒ String
The name (project, location, cluster, node pool id) of the node poll to rollback upgrade.
-
#node_pool_id ⇒ String
Deprecated.
-
#project_id ⇒ String
Deprecated.
-
#respect_pdb ⇒ Boolean
(also: #respect_pdb?)
Option for rollback to ignore the PodDisruptionBudget.
-
#zone ⇒ String
Deprecated.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RollbackNodePoolUpgradeRequest
constructor
A new instance of RollbackNodePoolUpgradeRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RollbackNodePoolUpgradeRequest
Returns a new instance of RollbackNodePoolUpgradeRequest.
8603 8604 8605 |
# File 'lib/google/apis/container_v1/classes.rb', line 8603 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cluster_id ⇒ String
Deprecated. The name of the cluster to rollback. This field has been
deprecated and replaced by the name field.
Corresponds to the JSON property clusterId
8568 8569 8570 |
# File 'lib/google/apis/container_v1/classes.rb', line 8568 def cluster_id @cluster_id end |
#name ⇒ String
The name (project, location, cluster, node pool id) of the node poll to
rollback upgrade. Specified in the format projects/*/locations/*/clusters/*/
nodePools/*.
Corresponds to the JSON property name
8575 8576 8577 |
# File 'lib/google/apis/container_v1/classes.rb', line 8575 def name @name end |
#node_pool_id ⇒ String
Deprecated. The name of the node pool to rollback. This field has been
deprecated and replaced by the name field.
Corresponds to the JSON property nodePoolId
8581 8582 8583 |
# File 'lib/google/apis/container_v1/classes.rb', line 8581 def node_pool_id @node_pool_id end |
#project_id ⇒ String
Deprecated. The Google Developers Console project ID or project number. This
field has been deprecated and replaced by the name field.
Corresponds to the JSON property projectId
8588 8589 8590 |
# File 'lib/google/apis/container_v1/classes.rb', line 8588 def project_id @project_id end |
#respect_pdb ⇒ Boolean Also known as: respect_pdb?
Option for rollback to ignore the PodDisruptionBudget. Default value is false.
Corresponds to the JSON property respectPdb
8593 8594 8595 |
# File 'lib/google/apis/container_v1/classes.rb', line 8593 def respect_pdb @respect_pdb end |
#zone ⇒ String
Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has
been deprecated and replaced by the name field.
Corresponds to the JSON property zone
8601 8602 8603 |
# File 'lib/google/apis/container_v1/classes.rb', line 8601 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8608 8609 8610 8611 8612 8613 8614 8615 |
# File 'lib/google/apis/container_v1/classes.rb', line 8608 def update!(**args) @cluster_id = args[:cluster_id] if args.key?(:cluster_id) @name = args[:name] if args.key?(:name) @node_pool_id = args[:node_pool_id] if args.key?(:node_pool_id) @project_id = args[:project_id] if args.key?(:project_id) @respect_pdb = args[:respect_pdb] if args.key?(:respect_pdb) @zone = args[:zone] if args.key?(:zone) end |