Class: Google::Apis::ContainerV1::RollbackNodePoolUpgradeRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

RollbackNodePoolUpgradeRequest rollbacks the previously Aborted or Failed NodePool upgrade. This will be an no-op if the last upgrade successfully completed.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RollbackNodePoolUpgradeRequest

Returns a new instance of RollbackNodePoolUpgradeRequest.



7694
7695
7696
# File 'lib/google/apis/container_v1/classes.rb', line 7694

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cluster_idString

Deprecated. The name of the cluster to rollback. This field has been deprecated and replaced by the name field. Corresponds to the JSON property clusterId

Returns:

  • (String)


7659
7660
7661
# File 'lib/google/apis/container_v1/classes.rb', line 7659

def cluster_id
  @cluster_id
end

#nameString

The name (project, location, cluster, node pool id) of the node poll to rollback upgrade. Specified in the format projects/*/locations/*/clusters/*/ nodePools/*. Corresponds to the JSON property name

Returns:

  • (String)


7666
7667
7668
# File 'lib/google/apis/container_v1/classes.rb', line 7666

def name
  @name
end

#node_pool_idString

Deprecated. The name of the node pool to rollback. This field has been deprecated and replaced by the name field. Corresponds to the JSON property nodePoolId

Returns:

  • (String)


7672
7673
7674
# File 'lib/google/apis/container_v1/classes.rb', line 7672

def node_pool_id
  @node_pool_id
end

#project_idString

Deprecated. The Google Developers Console project ID or project number. This field has been deprecated and replaced by the name field. Corresponds to the JSON property projectId

Returns:

  • (String)


7679
7680
7681
# File 'lib/google/apis/container_v1/classes.rb', line 7679

def project_id
  @project_id
end

#respect_pdbBoolean Also known as: respect_pdb?

Option for rollback to ignore the PodDisruptionBudget. Default value is false. Corresponds to the JSON property respectPdb

Returns:

  • (Boolean)


7684
7685
7686
# File 'lib/google/apis/container_v1/classes.rb', line 7684

def respect_pdb
  @respect_pdb
end

#zoneString

Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has been deprecated and replaced by the name field. Corresponds to the JSON property zone

Returns:

  • (String)


7692
7693
7694
# File 'lib/google/apis/container_v1/classes.rb', line 7692

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7699
7700
7701
7702
7703
7704
7705
7706
# File 'lib/google/apis/container_v1/classes.rb', line 7699

def update!(**args)
  @cluster_id = args[:cluster_id] if args.key?(:cluster_id)
  @name = args[:name] if args.key?(:name)
  @node_pool_id = args[:node_pool_id] if args.key?(:node_pool_id)
  @project_id = args[:project_id] if args.key?(:project_id)
  @respect_pdb = args[:respect_pdb] if args.key?(:respect_pdb)
  @zone = args[:zone] if args.key?(:zone)
end