Class: Google::Apis::ContainerV1::SetAddonsConfigRequest
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1::SetAddonsConfigRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb
Overview
SetAddonsConfigRequest sets the addons associated with the cluster.
Instance Attribute Summary collapse
-
#addons_config ⇒ Google::Apis::ContainerV1::AddonsConfig
Configuration for the addons that can be automatically spun up in the cluster, enabling additional functionality.
-
#cluster_id ⇒ String
Deprecated.
-
#name ⇒ String
The name (project, location, cluster) of the cluster to set addons.
-
#project_id ⇒ String
Deprecated.
-
#zone ⇒ String
Deprecated.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SetAddonsConfigRequest
constructor
A new instance of SetAddonsConfigRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SetAddonsConfigRequest
Returns a new instance of SetAddonsConfigRequest.
9230 9231 9232 |
# File 'lib/google/apis/container_v1/classes.rb', line 9230 def initialize(**args) update!(**args) end |
Instance Attribute Details
#addons_config ⇒ Google::Apis::ContainerV1::AddonsConfig
Configuration for the addons that can be automatically spun up in the cluster,
enabling additional functionality.
Corresponds to the JSON property addonsConfig
9202 9203 9204 |
# File 'lib/google/apis/container_v1/classes.rb', line 9202 def addons_config @addons_config end |
#cluster_id ⇒ String
Deprecated. The name of the cluster to upgrade. This field has been deprecated
and replaced by the name field.
Corresponds to the JSON property clusterId
9208 9209 9210 |
# File 'lib/google/apis/container_v1/classes.rb', line 9208 def cluster_id @cluster_id end |
#name ⇒ String
The name (project, location, cluster) of the cluster to set addons. Specified
in the format projects/*/locations/*/clusters/*.
Corresponds to the JSON property name
9214 9215 9216 |
# File 'lib/google/apis/container_v1/classes.rb', line 9214 def name @name end |
#project_id ⇒ String
Deprecated. The Google Developers Console project ID or project number. This
field has been deprecated and replaced by the name field.
Corresponds to the JSON property projectId
9221 9222 9223 |
# File 'lib/google/apis/container_v1/classes.rb', line 9221 def project_id @project_id end |
#zone ⇒ String
Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has
been deprecated and replaced by the name field.
Corresponds to the JSON property zone
9228 9229 9230 |
# File 'lib/google/apis/container_v1/classes.rb', line 9228 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9235 9236 9237 9238 9239 9240 9241 |
# File 'lib/google/apis/container_v1/classes.rb', line 9235 def update!(**args) @addons_config = args[:addons_config] if args.key?(:addons_config) @cluster_id = args[:cluster_id] if args.key?(:cluster_id) @name = args[:name] if args.key?(:name) @project_id = args[:project_id] if args.key?(:project_id) @zone = args[:zone] if args.key?(:zone) end |