Class: Google::Apis::ContainerV1::SetAddonsConfigRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

SetAddonsConfigRequest sets the addons associated with the cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SetAddonsConfigRequest

Returns a new instance of SetAddonsConfigRequest.



8996
8997
8998
# File 'lib/google/apis/container_v1/classes.rb', line 8996

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#addons_configGoogle::Apis::ContainerV1::AddonsConfig

Configuration for the addons that can be automatically spun up in the cluster, enabling additional functionality. Corresponds to the JSON property addonsConfig



8968
8969
8970
# File 'lib/google/apis/container_v1/classes.rb', line 8968

def addons_config
  @addons_config
end

#cluster_idString

Deprecated. The name of the cluster to upgrade. This field has been deprecated and replaced by the name field. Corresponds to the JSON property clusterId

Returns:

  • (String)


8974
8975
8976
# File 'lib/google/apis/container_v1/classes.rb', line 8974

def cluster_id
  @cluster_id
end

#nameString

The name (project, location, cluster) of the cluster to set addons. Specified in the format projects/*/locations/*/clusters/*. Corresponds to the JSON property name

Returns:

  • (String)


8980
8981
8982
# File 'lib/google/apis/container_v1/classes.rb', line 8980

def name
  @name
end

#project_idString

Deprecated. The Google Developers Console project ID or project number. This field has been deprecated and replaced by the name field. Corresponds to the JSON property projectId

Returns:

  • (String)


8987
8988
8989
# File 'lib/google/apis/container_v1/classes.rb', line 8987

def project_id
  @project_id
end

#zoneString

Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has been deprecated and replaced by the name field. Corresponds to the JSON property zone

Returns:

  • (String)


8994
8995
8996
# File 'lib/google/apis/container_v1/classes.rb', line 8994

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9001
9002
9003
9004
9005
9006
9007
# File 'lib/google/apis/container_v1/classes.rb', line 9001

def update!(**args)
  @addons_config = args[:addons_config] if args.key?(:addons_config)
  @cluster_id = args[:cluster_id] if args.key?(:cluster_id)
  @name = args[:name] if args.key?(:name)
  @project_id = args[:project_id] if args.key?(:project_id)
  @zone = args[:zone] if args.key?(:zone)
end