Class: Google::Apis::ContainerV1::SetLabelsRequest
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1::SetLabelsRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb
Overview
SetLabelsRequest sets the Google Cloud Platform labels on a Google Container Engine cluster, which will in turn set them for Google Compute Engine resources used by that cluster
Instance Attribute Summary collapse
-
#cluster_id ⇒ String
Deprecated.
-
#label_fingerprint ⇒ String
Required.
-
#name ⇒ String
The name (project, location, cluster name) of the cluster to set labels.
-
#project_id ⇒ String
Deprecated.
-
#resource_labels ⇒ Hash<String,String>
Required.
-
#zone ⇒ String
Deprecated.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SetLabelsRequest
constructor
A new instance of SetLabelsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SetLabelsRequest
Returns a new instance of SetLabelsRequest.
9075 9076 9077 |
# File 'lib/google/apis/container_v1/classes.rb', line 9075 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cluster_id ⇒ String
Deprecated. The name of the cluster. This field has been deprecated and
replaced by the name field.
Corresponds to the JSON property clusterId
9039 9040 9041 |
# File 'lib/google/apis/container_v1/classes.rb', line 9039 def cluster_id @cluster_id end |
#label_fingerprint ⇒ String
Required. The fingerprint of the previous set of labels for this resource,
used to detect conflicts. The fingerprint is initially generated by Kubernetes
Engine and changes after every request to modify or update labels. You must
always provide an up-to-date fingerprint hash when updating or changing labels.
Make a get() request to the resource to get the latest fingerprint.
Corresponds to the JSON property labelFingerprint
9048 9049 9050 |
# File 'lib/google/apis/container_v1/classes.rb', line 9048 def label_fingerprint @label_fingerprint end |
#name ⇒ String
The name (project, location, cluster name) of the cluster to set labels.
Specified in the format projects/*/locations/*/clusters/*.
Corresponds to the JSON property name
9054 9055 9056 |
# File 'lib/google/apis/container_v1/classes.rb', line 9054 def name @name end |
#project_id ⇒ String
Deprecated. The Google Developers Console project ID or project number. This
field has been deprecated and replaced by the name field.
Corresponds to the JSON property projectId
9061 9062 9063 |
# File 'lib/google/apis/container_v1/classes.rb', line 9061 def project_id @project_id end |
#resource_labels ⇒ Hash<String,String>
Required. The labels to set for that cluster.
Corresponds to the JSON property resourceLabels
9066 9067 9068 |
# File 'lib/google/apis/container_v1/classes.rb', line 9066 def resource_labels @resource_labels end |
#zone ⇒ String
Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has
been deprecated and replaced by the name field.
Corresponds to the JSON property zone
9073 9074 9075 |
# File 'lib/google/apis/container_v1/classes.rb', line 9073 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9080 9081 9082 9083 9084 9085 9086 9087 |
# File 'lib/google/apis/container_v1/classes.rb', line 9080 def update!(**args) @cluster_id = args[:cluster_id] if args.key?(:cluster_id) @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint) @name = args[:name] if args.key?(:name) @project_id = args[:project_id] if args.key?(:project_id) @resource_labels = args[:resource_labels] if args.key?(:resource_labels) @zone = args[:zone] if args.key?(:zone) end |