Class: Google::Apis::ContainerV1::SetLabelsRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

SetLabelsRequest sets the Google Cloud Platform labels on a Google Container Engine cluster, which will in turn set them for Google Compute Engine resources used by that cluster

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SetLabelsRequest

Returns a new instance of SetLabelsRequest.



8362
8363
8364
# File 'lib/google/apis/container_v1/classes.rb', line 8362

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cluster_idString

Deprecated. The name of the cluster. This field has been deprecated and replaced by the name field. Corresponds to the JSON property clusterId

Returns:

  • (String)


8326
8327
8328
# File 'lib/google/apis/container_v1/classes.rb', line 8326

def cluster_id
  @cluster_id
end

#label_fingerprintString

Required. The fingerprint of the previous set of labels for this resource, used to detect conflicts. The fingerprint is initially generated by Kubernetes Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash when updating or changing labels. Make a get() request to the resource to get the latest fingerprint. Corresponds to the JSON property labelFingerprint

Returns:

  • (String)


8335
8336
8337
# File 'lib/google/apis/container_v1/classes.rb', line 8335

def label_fingerprint
  @label_fingerprint
end

#nameString

The name (project, location, cluster name) of the cluster to set labels. Specified in the format projects/*/locations/*/clusters/*. Corresponds to the JSON property name

Returns:

  • (String)


8341
8342
8343
# File 'lib/google/apis/container_v1/classes.rb', line 8341

def name
  @name
end

#project_idString

Deprecated. The Google Developers Console project ID or project number. This field has been deprecated and replaced by the name field. Corresponds to the JSON property projectId

Returns:

  • (String)


8348
8349
8350
# File 'lib/google/apis/container_v1/classes.rb', line 8348

def project_id
  @project_id
end

#resource_labelsHash<String,String>

Required. The labels to set for that cluster. Corresponds to the JSON property resourceLabels

Returns:

  • (Hash<String,String>)


8353
8354
8355
# File 'lib/google/apis/container_v1/classes.rb', line 8353

def resource_labels
  @resource_labels
end

#zoneString

Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has been deprecated and replaced by the name field. Corresponds to the JSON property zone

Returns:

  • (String)


8360
8361
8362
# File 'lib/google/apis/container_v1/classes.rb', line 8360

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8367
8368
8369
8370
8371
8372
8373
8374
# File 'lib/google/apis/container_v1/classes.rb', line 8367

def update!(**args)
  @cluster_id = args[:cluster_id] if args.key?(:cluster_id)
  @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint)
  @name = args[:name] if args.key?(:name)
  @project_id = args[:project_id] if args.key?(:project_id)
  @resource_labels = args[:resource_labels] if args.key?(:resource_labels)
  @zone = args[:zone] if args.key?(:zone)
end