Class: Google::Apis::ContainerV1::SetLegacyAbacRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

SetLegacyAbacRequest enables or disables the ABAC authorization mechanism for a cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SetLegacyAbacRequest

Returns a new instance of SetLegacyAbacRequest.



9336
9337
9338
# File 'lib/google/apis/container_v1/classes.rb', line 9336

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cluster_idString

Deprecated. The name of the cluster to update. This field has been deprecated and replaced by the name field. Corresponds to the JSON property clusterId

Returns:

  • (String)


9308
9309
9310
# File 'lib/google/apis/container_v1/classes.rb', line 9308

def cluster_id
  @cluster_id
end

#enabledBoolean Also known as: enabled?

Required. Whether ABAC authorization will be enabled in the cluster. Corresponds to the JSON property enabled

Returns:

  • (Boolean)


9313
9314
9315
# File 'lib/google/apis/container_v1/classes.rb', line 9313

def enabled
  @enabled
end

#nameString

The name (project, location, cluster name) of the cluster to set legacy abac. Specified in the format projects/*/locations/*/clusters/*. Corresponds to the JSON property name

Returns:

  • (String)


9320
9321
9322
# File 'lib/google/apis/container_v1/classes.rb', line 9320

def name
  @name
end

#project_idString

Deprecated. The Google Developers Console project ID or project number. This field has been deprecated and replaced by the name field. Corresponds to the JSON property projectId

Returns:

  • (String)


9327
9328
9329
# File 'lib/google/apis/container_v1/classes.rb', line 9327

def project_id
  @project_id
end

#zoneString

Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has been deprecated and replaced by the name field. Corresponds to the JSON property zone

Returns:

  • (String)


9334
9335
9336
# File 'lib/google/apis/container_v1/classes.rb', line 9334

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9341
9342
9343
9344
9345
9346
9347
# File 'lib/google/apis/container_v1/classes.rb', line 9341

def update!(**args)
  @cluster_id = args[:cluster_id] if args.key?(:cluster_id)
  @enabled = args[:enabled] if args.key?(:enabled)
  @name = args[:name] if args.key?(:name)
  @project_id = args[:project_id] if args.key?(:project_id)
  @zone = args[:zone] if args.key?(:zone)
end