Class: Google::Apis::ContainerV1::SetLegacyAbacRequest
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1::SetLegacyAbacRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb
Overview
SetLegacyAbacRequest enables or disables the ABAC authorization mechanism for a cluster.
Instance Attribute Summary collapse
-
#cluster_id ⇒ String
Deprecated.
-
#enabled ⇒ Boolean
(also: #enabled?)
Required.
-
#name ⇒ String
The name (project, location, cluster name) of the cluster to set legacy abac.
-
#project_id ⇒ String
Deprecated.
-
#zone ⇒ String
Deprecated.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SetLegacyAbacRequest
constructor
A new instance of SetLegacyAbacRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SetLegacyAbacRequest
Returns a new instance of SetLegacyAbacRequest.
9127 9128 9129 |
# File 'lib/google/apis/container_v1/classes.rb', line 9127 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cluster_id ⇒ String
Deprecated. The name of the cluster to update. This field has been deprecated
and replaced by the name field.
Corresponds to the JSON property clusterId
9099 9100 9101 |
# File 'lib/google/apis/container_v1/classes.rb', line 9099 def cluster_id @cluster_id end |
#enabled ⇒ Boolean Also known as: enabled?
Required. Whether ABAC authorization will be enabled in the cluster.
Corresponds to the JSON property enabled
9104 9105 9106 |
# File 'lib/google/apis/container_v1/classes.rb', line 9104 def enabled @enabled end |
#name ⇒ String
The name (project, location, cluster name) of the cluster to set legacy abac.
Specified in the format projects/*/locations/*/clusters/*.
Corresponds to the JSON property name
9111 9112 9113 |
# File 'lib/google/apis/container_v1/classes.rb', line 9111 def name @name end |
#project_id ⇒ String
Deprecated. The Google Developers Console project ID or project number. This
field has been deprecated and replaced by the name field.
Corresponds to the JSON property projectId
9118 9119 9120 |
# File 'lib/google/apis/container_v1/classes.rb', line 9118 def project_id @project_id end |
#zone ⇒ String
Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has
been deprecated and replaced by the name field.
Corresponds to the JSON property zone
9125 9126 9127 |
# File 'lib/google/apis/container_v1/classes.rb', line 9125 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9132 9133 9134 9135 9136 9137 9138 |
# File 'lib/google/apis/container_v1/classes.rb', line 9132 def update!(**args) @cluster_id = args[:cluster_id] if args.key?(:cluster_id) @enabled = args[:enabled] if args.key?(:enabled) @name = args[:name] if args.key?(:name) @project_id = args[:project_id] if args.key?(:project_id) @zone = args[:zone] if args.key?(:zone) end |