Class: Google::Apis::ContainerV1::SetLocationsRequest
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1::SetLocationsRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb
Overview
SetLocationsRequest sets the locations of the cluster.
Instance Attribute Summary collapse
-
#cluster_id ⇒ String
Deprecated.
-
#locations ⇒ Array<String>
Required.
-
#name ⇒ String
The name (project, location, cluster) of the cluster to set locations.
-
#project_id ⇒ String
Deprecated.
-
#zone ⇒ String
Deprecated.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SetLocationsRequest
constructor
A new instance of SetLocationsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SetLocationsRequest
Returns a new instance of SetLocationsRequest.
9390 9391 9392 |
# File 'lib/google/apis/container_v1/classes.rb', line 9390 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cluster_id ⇒ String
Deprecated. The name of the cluster to upgrade. This field has been deprecated
and replaced by the name field.
Corresponds to the JSON property clusterId
9358 9359 9360 |
# File 'lib/google/apis/container_v1/classes.rb', line 9358 def cluster_id @cluster_id end |
#locations ⇒ Array<String>
Required. The desired list of Google Compute Engine zones in which the cluster's nodes should
be located. Changing the locations a cluster is in will result in nodes being
either created or removed from the cluster, depending on whether locations are
being added or removed. This list must always include the cluster's primary
zone.
Corresponds to the JSON property locations
9368 9369 9370 |
# File 'lib/google/apis/container_v1/classes.rb', line 9368 def locations @locations end |
#name ⇒ String
The name (project, location, cluster) of the cluster to set locations.
Specified in the format projects/*/locations/*/clusters/*.
Corresponds to the JSON property name
9374 9375 9376 |
# File 'lib/google/apis/container_v1/classes.rb', line 9374 def name @name end |
#project_id ⇒ String
Deprecated. The Google Developers Console project ID or project number. This
field has been deprecated and replaced by the name field.
Corresponds to the JSON property projectId
9381 9382 9383 |
# File 'lib/google/apis/container_v1/classes.rb', line 9381 def project_id @project_id end |
#zone ⇒ String
Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has
been deprecated and replaced by the name field.
Corresponds to the JSON property zone
9388 9389 9390 |
# File 'lib/google/apis/container_v1/classes.rb', line 9388 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9395 9396 9397 9398 9399 9400 9401 |
# File 'lib/google/apis/container_v1/classes.rb', line 9395 def update!(**args) @cluster_id = args[:cluster_id] if args.key?(:cluster_id) @locations = args[:locations] if args.key?(:locations) @name = args[:name] if args.key?(:name) @project_id = args[:project_id] if args.key?(:project_id) @zone = args[:zone] if args.key?(:zone) end |