Class: Google::Apis::ContainerV1::SetLocationsRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

SetLocationsRequest sets the locations of the cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SetLocationsRequest

Returns a new instance of SetLocationsRequest.



9181
9182
9183
# File 'lib/google/apis/container_v1/classes.rb', line 9181

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cluster_idString

Deprecated. The name of the cluster to upgrade. This field has been deprecated and replaced by the name field. Corresponds to the JSON property clusterId

Returns:

  • (String)


9149
9150
9151
# File 'lib/google/apis/container_v1/classes.rb', line 9149

def cluster_id
  @cluster_id
end

#locationsArray<String>

Required. The desired list of Google Compute Engine zones in which the cluster's nodes should be located. Changing the locations a cluster is in will result in nodes being either created or removed from the cluster, depending on whether locations are being added or removed. This list must always include the cluster's primary zone. Corresponds to the JSON property locations

Returns:

  • (Array<String>)


9159
9160
9161
# File 'lib/google/apis/container_v1/classes.rb', line 9159

def locations
  @locations
end

#nameString

The name (project, location, cluster) of the cluster to set locations. Specified in the format projects/*/locations/*/clusters/*. Corresponds to the JSON property name

Returns:

  • (String)


9165
9166
9167
# File 'lib/google/apis/container_v1/classes.rb', line 9165

def name
  @name
end

#project_idString

Deprecated. The Google Developers Console project ID or project number. This field has been deprecated and replaced by the name field. Corresponds to the JSON property projectId

Returns:

  • (String)


9172
9173
9174
# File 'lib/google/apis/container_v1/classes.rb', line 9172

def project_id
  @project_id
end

#zoneString

Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has been deprecated and replaced by the name field. Corresponds to the JSON property zone

Returns:

  • (String)


9179
9180
9181
# File 'lib/google/apis/container_v1/classes.rb', line 9179

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9186
9187
9188
9189
9190
9191
9192
# File 'lib/google/apis/container_v1/classes.rb', line 9186

def update!(**args)
  @cluster_id = args[:cluster_id] if args.key?(:cluster_id)
  @locations = args[:locations] if args.key?(:locations)
  @name = args[:name] if args.key?(:name)
  @project_id = args[:project_id] if args.key?(:project_id)
  @zone = args[:zone] if args.key?(:zone)
end