Class: Google::Apis::ContainerV1::SetLoggingServiceRequest
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1::SetLoggingServiceRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb
Overview
SetLoggingServiceRequest sets the logging service of a cluster.
Instance Attribute Summary collapse
-
#cluster_id ⇒ String
Deprecated.
-
#logging_service ⇒ String
Required.
-
#name ⇒ String
The name (project, location, cluster) of the cluster to set logging.
-
#project_id ⇒ String
Deprecated.
-
#zone ⇒ String
Deprecated.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SetLoggingServiceRequest
constructor
A new instance of SetLoggingServiceRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SetLoggingServiceRequest
Returns a new instance of SetLoggingServiceRequest.
9217 9218 9219 |
# File 'lib/google/apis/container_v1/classes.rb', line 9217 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cluster_id ⇒ String
Deprecated. The name of the cluster to upgrade. This field has been deprecated
and replaced by the name field.
Corresponds to the JSON property clusterId
9184 9185 9186 |
# File 'lib/google/apis/container_v1/classes.rb', line 9184 def cluster_id @cluster_id end |
#logging_service ⇒ String
Required. The logging service the cluster should use to write logs. Currently
available options: * logging.googleapis.com/kubernetes - The Cloud Logging
service with a Kubernetes-native resource model * logging.googleapis.com -
The legacy Cloud Logging service (no longer available as of GKE 1.15). * none
- no logs will be exported from the cluster. If left as an empty string,
logging.googleapis.com/kuberneteswill be used for GKE 1.14+ orlogging. googleapis.comfor earlier versions. Corresponds to the JSON propertyloggingService
9195 9196 9197 |
# File 'lib/google/apis/container_v1/classes.rb', line 9195 def logging_service @logging_service end |
#name ⇒ String
The name (project, location, cluster) of the cluster to set logging. Specified
in the format projects/*/locations/*/clusters/*.
Corresponds to the JSON property name
9201 9202 9203 |
# File 'lib/google/apis/container_v1/classes.rb', line 9201 def name @name end |
#project_id ⇒ String
Deprecated. The Google Developers Console project ID or project number. This
field has been deprecated and replaced by the name field.
Corresponds to the JSON property projectId
9208 9209 9210 |
# File 'lib/google/apis/container_v1/classes.rb', line 9208 def project_id @project_id end |
#zone ⇒ String
Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has
been deprecated and replaced by the name field.
Corresponds to the JSON property zone
9215 9216 9217 |
# File 'lib/google/apis/container_v1/classes.rb', line 9215 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9222 9223 9224 9225 9226 9227 9228 |
# File 'lib/google/apis/container_v1/classes.rb', line 9222 def update!(**args) @cluster_id = args[:cluster_id] if args.key?(:cluster_id) @logging_service = args[:logging_service] if args.key?(:logging_service) @name = args[:name] if args.key?(:name) @project_id = args[:project_id] if args.key?(:project_id) @zone = args[:zone] if args.key?(:zone) end |