Class: Google::Apis::ContainerV1::SetLoggingServiceRequest
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1::SetLoggingServiceRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb
Overview
SetLoggingServiceRequest sets the logging service of a cluster.
Instance Attribute Summary collapse
-
#cluster_id ⇒ String
Deprecated.
-
#logging_service ⇒ String
Required.
-
#name ⇒ String
The name (project, location, cluster) of the cluster to set logging.
-
#project_id ⇒ String
Deprecated.
-
#zone ⇒ String
Deprecated.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SetLoggingServiceRequest
constructor
A new instance of SetLoggingServiceRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SetLoggingServiceRequest
Returns a new instance of SetLoggingServiceRequest.
8523 8524 8525 |
# File 'lib/google/apis/container_v1/classes.rb', line 8523 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cluster_id ⇒ String
Deprecated. The name of the cluster to upgrade. This field has been deprecated
and replaced by the name field.
Corresponds to the JSON property clusterId
8490 8491 8492 |
# File 'lib/google/apis/container_v1/classes.rb', line 8490 def cluster_id @cluster_id end |
#logging_service ⇒ String
Required. The logging service the cluster should use to write logs. Currently
available options: * logging.googleapis.com/kubernetes - The Cloud Logging
service with a Kubernetes-native resource model * logging.googleapis.com -
The legacy Cloud Logging service (no longer available as of GKE 1.15). * none
- no logs will be exported from the cluster. If left as an empty string,
logging.googleapis.com/kuberneteswill be used for GKE 1.14+ orlogging. googleapis.comfor earlier versions. Corresponds to the JSON propertyloggingService
8501 8502 8503 |
# File 'lib/google/apis/container_v1/classes.rb', line 8501 def logging_service @logging_service end |
#name ⇒ String
The name (project, location, cluster) of the cluster to set logging. Specified
in the format projects/*/locations/*/clusters/*.
Corresponds to the JSON property name
8507 8508 8509 |
# File 'lib/google/apis/container_v1/classes.rb', line 8507 def name @name end |
#project_id ⇒ String
Deprecated. The Google Developers Console project ID or project number. This
field has been deprecated and replaced by the name field.
Corresponds to the JSON property projectId
8514 8515 8516 |
# File 'lib/google/apis/container_v1/classes.rb', line 8514 def project_id @project_id end |
#zone ⇒ String
Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has
been deprecated and replaced by the name field.
Corresponds to the JSON property zone
8521 8522 8523 |
# File 'lib/google/apis/container_v1/classes.rb', line 8521 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8528 8529 8530 8531 8532 8533 8534 |
# File 'lib/google/apis/container_v1/classes.rb', line 8528 def update!(**args) @cluster_id = args[:cluster_id] if args.key?(:cluster_id) @logging_service = args[:logging_service] if args.key?(:logging_service) @name = args[:name] if args.key?(:name) @project_id = args[:project_id] if args.key?(:project_id) @zone = args[:zone] if args.key?(:zone) end |