Class: Google::Apis::ContainerV1::SetMaintenancePolicyRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

SetMaintenancePolicyRequest sets the maintenance policy for a cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SetMaintenancePolicyRequest

Returns a new instance of SetMaintenancePolicyRequest.



8308
8309
8310
# File 'lib/google/apis/container_v1/classes.rb', line 8308

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cluster_idString

Required. The name of the cluster to update. Corresponds to the JSON property clusterId

Returns:

  • (String)


8283
8284
8285
# File 'lib/google/apis/container_v1/classes.rb', line 8283

def cluster_id
  @cluster_id
end

#maintenance_policyGoogle::Apis::ContainerV1::MaintenancePolicy

MaintenancePolicy defines the maintenance policy to be used for the cluster. Corresponds to the JSON property maintenancePolicy



8288
8289
8290
# File 'lib/google/apis/container_v1/classes.rb', line 8288

def maintenance_policy
  @maintenance_policy
end

#nameString

The name (project, location, cluster name) of the cluster to set maintenance policy. Specified in the format projects/*/locations/*/clusters/*. Corresponds to the JSON property name

Returns:

  • (String)


8294
8295
8296
# File 'lib/google/apis/container_v1/classes.rb', line 8294

def name
  @name
end

#project_idString

Required. The Google Developers Console project ID or project number. Corresponds to the JSON property projectId

Returns:

  • (String)


8300
8301
8302
# File 'lib/google/apis/container_v1/classes.rb', line 8300

def project_id
  @project_id
end

#zoneString

Required. The name of the Google Compute Engine zone in which the cluster resides. Corresponds to the JSON property zone

Returns:

  • (String)


8306
8307
8308
# File 'lib/google/apis/container_v1/classes.rb', line 8306

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8313
8314
8315
8316
8317
8318
8319
# File 'lib/google/apis/container_v1/classes.rb', line 8313

def update!(**args)
  @cluster_id = args[:cluster_id] if args.key?(:cluster_id)
  @maintenance_policy = args[:maintenance_policy] if args.key?(:maintenance_policy)
  @name = args[:name] if args.key?(:name)
  @project_id = args[:project_id] if args.key?(:project_id)
  @zone = args[:zone] if args.key?(:zone)
end