Class: Google::Apis::ContainerV1::SetMasterAuthRequest
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1::SetMasterAuthRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb
Overview
SetMasterAuthRequest updates the admin password of a cluster.
Instance Attribute Summary collapse
-
#action ⇒ String
Required.
-
#cluster_id ⇒ String
Deprecated.
-
#name ⇒ String
The name (project, location, cluster) of the cluster to set auth.
-
#project_id ⇒ String
Deprecated.
-
#update ⇒ Google::Apis::ContainerV1::MasterAuth
The authentication information for accessing the master endpoint.
-
#zone ⇒ String
Deprecated.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SetMasterAuthRequest
constructor
A new instance of SetMasterAuthRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SetMasterAuthRequest
Returns a new instance of SetMasterAuthRequest.
9337 9338 9339 |
# File 'lib/google/apis/container_v1/classes.rb', line 9337 def initialize(**args) update!(**args) end |
Instance Attribute Details
#action ⇒ String
Required. The exact form of action to be taken on the master auth.
Corresponds to the JSON property action
9303 9304 9305 |
# File 'lib/google/apis/container_v1/classes.rb', line 9303 def action @action end |
#cluster_id ⇒ String
Deprecated. The name of the cluster to upgrade. This field has been deprecated
and replaced by the name field.
Corresponds to the JSON property clusterId
9309 9310 9311 |
# File 'lib/google/apis/container_v1/classes.rb', line 9309 def cluster_id @cluster_id end |
#name ⇒ String
The name (project, location, cluster) of the cluster to set auth. Specified in
the format projects/*/locations/*/clusters/*.
Corresponds to the JSON property name
9315 9316 9317 |
# File 'lib/google/apis/container_v1/classes.rb', line 9315 def name @name end |
#project_id ⇒ String
Deprecated. The Google Developers Console project ID or project number. This
field has been deprecated and replaced by the name field.
Corresponds to the JSON property projectId
9322 9323 9324 |
# File 'lib/google/apis/container_v1/classes.rb', line 9322 def project_id @project_id end |
#update ⇒ Google::Apis::ContainerV1::MasterAuth
The authentication information for accessing the master endpoint.
Authentication can be done using HTTP basic auth or using client certificates.
Corresponds to the JSON property update
9328 9329 9330 |
# File 'lib/google/apis/container_v1/classes.rb', line 9328 def update @update end |
#zone ⇒ String
Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has
been deprecated and replaced by the name field.
Corresponds to the JSON property zone
9335 9336 9337 |
# File 'lib/google/apis/container_v1/classes.rb', line 9335 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9342 9343 9344 9345 9346 9347 9348 9349 |
# File 'lib/google/apis/container_v1/classes.rb', line 9342 def update!(**args) @action = args[:action] if args.key?(:action) @cluster_id = args[:cluster_id] if args.key?(:cluster_id) @name = args[:name] if args.key?(:name) @project_id = args[:project_id] if args.key?(:project_id) @update = args[:update] if args.key?(:update) @zone = args[:zone] if args.key?(:zone) end |