Class: Google::Apis::ContainerV1::SetMasterAuthRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

SetMasterAuthRequest updates the admin password of a cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SetMasterAuthRequest

Returns a new instance of SetMasterAuthRequest.



9318
9319
9320
# File 'lib/google/apis/container_v1/classes.rb', line 9318

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actionString

Required. The exact form of action to be taken on the master auth. Corresponds to the JSON property action

Returns:

  • (String)


9284
9285
9286
# File 'lib/google/apis/container_v1/classes.rb', line 9284

def action
  @action
end

#cluster_idString

Deprecated. The name of the cluster to upgrade. This field has been deprecated and replaced by the name field. Corresponds to the JSON property clusterId

Returns:

  • (String)


9290
9291
9292
# File 'lib/google/apis/container_v1/classes.rb', line 9290

def cluster_id
  @cluster_id
end

#nameString

The name (project, location, cluster) of the cluster to set auth. Specified in the format projects/*/locations/*/clusters/*. Corresponds to the JSON property name

Returns:

  • (String)


9296
9297
9298
# File 'lib/google/apis/container_v1/classes.rb', line 9296

def name
  @name
end

#project_idString

Deprecated. The Google Developers Console project ID or project number. This field has been deprecated and replaced by the name field. Corresponds to the JSON property projectId

Returns:

  • (String)


9303
9304
9305
# File 'lib/google/apis/container_v1/classes.rb', line 9303

def project_id
  @project_id
end

#updateGoogle::Apis::ContainerV1::MasterAuth

The authentication information for accessing the master endpoint. Authentication can be done using HTTP basic auth or using client certificates. Corresponds to the JSON property update



9309
9310
9311
# File 'lib/google/apis/container_v1/classes.rb', line 9309

def update
  @update
end

#zoneString

Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has been deprecated and replaced by the name field. Corresponds to the JSON property zone

Returns:

  • (String)


9316
9317
9318
# File 'lib/google/apis/container_v1/classes.rb', line 9316

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9323
9324
9325
9326
9327
9328
9329
9330
# File 'lib/google/apis/container_v1/classes.rb', line 9323

def update!(**args)
  @action = args[:action] if args.key?(:action)
  @cluster_id = args[:cluster_id] if args.key?(:cluster_id)
  @name = args[:name] if args.key?(:name)
  @project_id = args[:project_id] if args.key?(:project_id)
  @update = args[:update] if args.key?(:update)
  @zone = args[:zone] if args.key?(:zone)
end