Class: Google::Apis::ContainerV1::SetMasterAuthRequest
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1::SetMasterAuthRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb
Overview
SetMasterAuthRequest updates the admin password of a cluster.
Instance Attribute Summary collapse
-
#action ⇒ String
Required.
-
#cluster_id ⇒ String
Deprecated.
-
#name ⇒ String
The name (project, location, cluster) of the cluster to set auth.
-
#project_id ⇒ String
Deprecated.
-
#update ⇒ Google::Apis::ContainerV1::MasterAuth
The authentication information for accessing the master endpoint.
-
#zone ⇒ String
Deprecated.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SetMasterAuthRequest
constructor
A new instance of SetMasterAuthRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SetMasterAuthRequest
Returns a new instance of SetMasterAuthRequest.
8624 8625 8626 |
# File 'lib/google/apis/container_v1/classes.rb', line 8624 def initialize(**args) update!(**args) end |
Instance Attribute Details
#action ⇒ String
Required. The exact form of action to be taken on the master auth.
Corresponds to the JSON property action
8590 8591 8592 |
# File 'lib/google/apis/container_v1/classes.rb', line 8590 def action @action end |
#cluster_id ⇒ String
Deprecated. The name of the cluster to upgrade. This field has been deprecated
and replaced by the name field.
Corresponds to the JSON property clusterId
8596 8597 8598 |
# File 'lib/google/apis/container_v1/classes.rb', line 8596 def cluster_id @cluster_id end |
#name ⇒ String
The name (project, location, cluster) of the cluster to set auth. Specified in
the format projects/*/locations/*/clusters/*.
Corresponds to the JSON property name
8602 8603 8604 |
# File 'lib/google/apis/container_v1/classes.rb', line 8602 def name @name end |
#project_id ⇒ String
Deprecated. The Google Developers Console project ID or project number. This
field has been deprecated and replaced by the name field.
Corresponds to the JSON property projectId
8609 8610 8611 |
# File 'lib/google/apis/container_v1/classes.rb', line 8609 def project_id @project_id end |
#update ⇒ Google::Apis::ContainerV1::MasterAuth
The authentication information for accessing the master endpoint.
Authentication can be done using HTTP basic auth or using client certificates.
Corresponds to the JSON property update
8615 8616 8617 |
# File 'lib/google/apis/container_v1/classes.rb', line 8615 def update @update end |
#zone ⇒ String
Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has
been deprecated and replaced by the name field.
Corresponds to the JSON property zone
8622 8623 8624 |
# File 'lib/google/apis/container_v1/classes.rb', line 8622 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8629 8630 8631 8632 8633 8634 8635 8636 |
# File 'lib/google/apis/container_v1/classes.rb', line 8629 def update!(**args) @action = args[:action] if args.key?(:action) @cluster_id = args[:cluster_id] if args.key?(:cluster_id) @name = args[:name] if args.key?(:name) @project_id = args[:project_id] if args.key?(:project_id) @update = args[:update] if args.key?(:update) @zone = args[:zone] if args.key?(:zone) end |