Class: Google::Apis::ContainerV1::SetMasterAuthRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

SetMasterAuthRequest updates the admin password of a cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SetMasterAuthRequest

Returns a new instance of SetMasterAuthRequest.



8363
8364
8365
# File 'lib/google/apis/container_v1/classes.rb', line 8363

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actionString

Required. The exact form of action to be taken on the master auth. Corresponds to the JSON property action

Returns:

  • (String)


8329
8330
8331
# File 'lib/google/apis/container_v1/classes.rb', line 8329

def action
  @action
end

#cluster_idString

Deprecated. The name of the cluster to upgrade. This field has been deprecated and replaced by the name field. Corresponds to the JSON property clusterId

Returns:

  • (String)


8335
8336
8337
# File 'lib/google/apis/container_v1/classes.rb', line 8335

def cluster_id
  @cluster_id
end

#nameString

The name (project, location, cluster) of the cluster to set auth. Specified in the format projects/*/locations/*/clusters/*. Corresponds to the JSON property name

Returns:

  • (String)


8341
8342
8343
# File 'lib/google/apis/container_v1/classes.rb', line 8341

def name
  @name
end

#project_idString

Deprecated. The Google Developers Console project ID or project number. This field has been deprecated and replaced by the name field. Corresponds to the JSON property projectId

Returns:

  • (String)


8348
8349
8350
# File 'lib/google/apis/container_v1/classes.rb', line 8348

def project_id
  @project_id
end

#updateGoogle::Apis::ContainerV1::MasterAuth

The authentication information for accessing the master endpoint. Authentication can be done using HTTP basic auth or using client certificates. Corresponds to the JSON property update



8354
8355
8356
# File 'lib/google/apis/container_v1/classes.rb', line 8354

def update
  @update
end

#zoneString

Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has been deprecated and replaced by the name field. Corresponds to the JSON property zone

Returns:

  • (String)


8361
8362
8363
# File 'lib/google/apis/container_v1/classes.rb', line 8361

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8368
8369
8370
8371
8372
8373
8374
8375
# File 'lib/google/apis/container_v1/classes.rb', line 8368

def update!(**args)
  @action = args[:action] if args.key?(:action)
  @cluster_id = args[:cluster_id] if args.key?(:cluster_id)
  @name = args[:name] if args.key?(:name)
  @project_id = args[:project_id] if args.key?(:project_id)
  @update = args[:update] if args.key?(:update)
  @zone = args[:zone] if args.key?(:zone)
end