Class: Google::Apis::ContainerV1::SetMonitoringServiceRequest
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1::SetMonitoringServiceRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb
Overview
SetMonitoringServiceRequest sets the monitoring service of a cluster.
Instance Attribute Summary collapse
-
#cluster_id ⇒ String
Deprecated.
-
#monitoring_service ⇒ String
Required.
-
#name ⇒ String
The name (project, location, cluster) of the cluster to set monitoring.
-
#project_id ⇒ String
Deprecated.
-
#zone ⇒ String
Deprecated.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SetMonitoringServiceRequest
constructor
A new instance of SetMonitoringServiceRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SetMonitoringServiceRequest
Returns a new instance of SetMonitoringServiceRequest.
9608 9609 9610 |
# File 'lib/google/apis/container_v1/classes.rb', line 9608 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cluster_id ⇒ String
Deprecated. The name of the cluster to upgrade. This field has been deprecated
and replaced by the name field.
Corresponds to the JSON property clusterId
9575 9576 9577 |
# File 'lib/google/apis/container_v1/classes.rb', line 9575 def cluster_id @cluster_id end |
#monitoring_service ⇒ String
Required. The monitoring service the cluster should use to write metrics.
Currently available options: * monitoring.googleapis.com/kubernetes - The
Cloud Monitoring service with a Kubernetes-native resource model * monitoring.
googleapis.com - The legacy Cloud Monitoring service (no longer available as
of GKE 1.15). * none - No metrics will be exported from the cluster. If left
as an empty string,monitoring.googleapis.com/kubernetes will be used for GKE
1.14+ or monitoring.googleapis.com for earlier versions.
Corresponds to the JSON property monitoringService
9586 9587 9588 |
# File 'lib/google/apis/container_v1/classes.rb', line 9586 def monitoring_service @monitoring_service end |
#name ⇒ String
The name (project, location, cluster) of the cluster to set monitoring.
Specified in the format projects/*/locations/*/clusters/*.
Corresponds to the JSON property name
9592 9593 9594 |
# File 'lib/google/apis/container_v1/classes.rb', line 9592 def name @name end |
#project_id ⇒ String
Deprecated. The Google Developers Console project ID or project number. This
field has been deprecated and replaced by the name field.
Corresponds to the JSON property projectId
9599 9600 9601 |
# File 'lib/google/apis/container_v1/classes.rb', line 9599 def project_id @project_id end |
#zone ⇒ String
Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has
been deprecated and replaced by the name field.
Corresponds to the JSON property zone
9606 9607 9608 |
# File 'lib/google/apis/container_v1/classes.rb', line 9606 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9613 9614 9615 9616 9617 9618 9619 |
# File 'lib/google/apis/container_v1/classes.rb', line 9613 def update!(**args) @cluster_id = args[:cluster_id] if args.key?(:cluster_id) @monitoring_service = args[:monitoring_service] if args.key?(:monitoring_service) @name = args[:name] if args.key?(:name) @project_id = args[:project_id] if args.key?(:project_id) @zone = args[:zone] if args.key?(:zone) end |