Class: Google::Apis::ContainerV1::SetMonitoringServiceRequest
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1::SetMonitoringServiceRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb
Overview
SetMonitoringServiceRequest sets the monitoring service of a cluster.
Instance Attribute Summary collapse
-
#cluster_id ⇒ String
Deprecated.
-
#monitoring_service ⇒ String
Required.
-
#name ⇒ String
The name (project, location, cluster) of the cluster to set monitoring.
-
#project_id ⇒ String
Deprecated.
-
#zone ⇒ String
Deprecated.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SetMonitoringServiceRequest
constructor
A new instance of SetMonitoringServiceRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SetMonitoringServiceRequest
Returns a new instance of SetMonitoringServiceRequest.
9374 9375 9376 |
# File 'lib/google/apis/container_v1/classes.rb', line 9374 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cluster_id ⇒ String
Deprecated. The name of the cluster to upgrade. This field has been deprecated
and replaced by the name field.
Corresponds to the JSON property clusterId
9341 9342 9343 |
# File 'lib/google/apis/container_v1/classes.rb', line 9341 def cluster_id @cluster_id end |
#monitoring_service ⇒ String
Required. The monitoring service the cluster should use to write metrics.
Currently available options: * monitoring.googleapis.com/kubernetes - The
Cloud Monitoring service with a Kubernetes-native resource model * monitoring.
googleapis.com - The legacy Cloud Monitoring service (no longer available as
of GKE 1.15). * none - No metrics will be exported from the cluster. If left
as an empty string,monitoring.googleapis.com/kubernetes will be used for GKE
1.14+ or monitoring.googleapis.com for earlier versions.
Corresponds to the JSON property monitoringService
9352 9353 9354 |
# File 'lib/google/apis/container_v1/classes.rb', line 9352 def monitoring_service @monitoring_service end |
#name ⇒ String
The name (project, location, cluster) of the cluster to set monitoring.
Specified in the format projects/*/locations/*/clusters/*.
Corresponds to the JSON property name
9358 9359 9360 |
# File 'lib/google/apis/container_v1/classes.rb', line 9358 def name @name end |
#project_id ⇒ String
Deprecated. The Google Developers Console project ID or project number. This
field has been deprecated and replaced by the name field.
Corresponds to the JSON property projectId
9365 9366 9367 |
# File 'lib/google/apis/container_v1/classes.rb', line 9365 def project_id @project_id end |
#zone ⇒ String
Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has
been deprecated and replaced by the name field.
Corresponds to the JSON property zone
9372 9373 9374 |
# File 'lib/google/apis/container_v1/classes.rb', line 9372 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9379 9380 9381 9382 9383 9384 9385 |
# File 'lib/google/apis/container_v1/classes.rb', line 9379 def update!(**args) @cluster_id = args[:cluster_id] if args.key?(:cluster_id) @monitoring_service = args[:monitoring_service] if args.key?(:monitoring_service) @name = args[:name] if args.key?(:name) @project_id = args[:project_id] if args.key?(:project_id) @zone = args[:zone] if args.key?(:zone) end |