Class: Google::Apis::ContainerV1::SetNetworkPolicyRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

SetNetworkPolicyRequest enables/disables network policy for a cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SetNetworkPolicyRequest

Returns a new instance of SetNetworkPolicyRequest.



9424
9425
9426
# File 'lib/google/apis/container_v1/classes.rb', line 9424

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cluster_idString

Deprecated. The name of the cluster. This field has been deprecated and replaced by the name field. Corresponds to the JSON property clusterId

Returns:

  • (String)


9396
9397
9398
# File 'lib/google/apis/container_v1/classes.rb', line 9396

def cluster_id
  @cluster_id
end

#nameString

The name (project, location, cluster name) of the cluster to set networking policy. Specified in the format projects/*/locations/*/clusters/*. Corresponds to the JSON property name

Returns:

  • (String)


9402
9403
9404
# File 'lib/google/apis/container_v1/classes.rb', line 9402

def name
  @name
end

#network_policyGoogle::Apis::ContainerV1::NetworkPolicy

Configuration options for the NetworkPolicy feature. https://kubernetes.io/ docs/concepts/services-networking/networkpolicies/ Corresponds to the JSON property networkPolicy



9408
9409
9410
# File 'lib/google/apis/container_v1/classes.rb', line 9408

def network_policy
  @network_policy
end

#project_idString

Deprecated. The Google Developers Console project ID or project number. This field has been deprecated and replaced by the name field. Corresponds to the JSON property projectId

Returns:

  • (String)


9415
9416
9417
# File 'lib/google/apis/container_v1/classes.rb', line 9415

def project_id
  @project_id
end

#zoneString

Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has been deprecated and replaced by the name field. Corresponds to the JSON property zone

Returns:

  • (String)


9422
9423
9424
# File 'lib/google/apis/container_v1/classes.rb', line 9422

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9429
9430
9431
9432
9433
9434
9435
# File 'lib/google/apis/container_v1/classes.rb', line 9429

def update!(**args)
  @cluster_id = args[:cluster_id] if args.key?(:cluster_id)
  @name = args[:name] if args.key?(:name)
  @network_policy = args[:network_policy] if args.key?(:network_policy)
  @project_id = args[:project_id] if args.key?(:project_id)
  @zone = args[:zone] if args.key?(:zone)
end