Class: Google::Apis::ContainerV1::SetNodePoolAutoscalingRequest
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1::SetNodePoolAutoscalingRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb
Overview
SetNodePoolAutoscalingRequest sets the autoscaler settings of a node pool.
Instance Attribute Summary collapse
-
#autoscaling ⇒ Google::Apis::ContainerV1::NodePoolAutoscaling
NodePoolAutoscaling contains information required by cluster autoscaler to adjust the size of the node pool to the current cluster usage.
-
#cluster_id ⇒ String
Deprecated.
-
#name ⇒ String
The name (project, location, cluster, node pool) of the node pool to set autoscaler settings.
-
#node_pool_id ⇒ String
Deprecated.
-
#project_id ⇒ String
Deprecated.
-
#zone ⇒ String
Deprecated.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SetNodePoolAutoscalingRequest
constructor
A new instance of SetNodePoolAutoscalingRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SetNodePoolAutoscalingRequest
Returns a new instance of SetNodePoolAutoscalingRequest.
9709 9710 9711 |
# File 'lib/google/apis/container_v1/classes.rb', line 9709 def initialize(**args) update!(**args) end |
Instance Attribute Details
#autoscaling ⇒ Google::Apis::ContainerV1::NodePoolAutoscaling
NodePoolAutoscaling contains information required by cluster autoscaler to
adjust the size of the node pool to the current cluster usage.
Corresponds to the JSON property autoscaling
9674 9675 9676 |
# File 'lib/google/apis/container_v1/classes.rb', line 9674 def autoscaling @autoscaling end |
#cluster_id ⇒ String
Deprecated. The name of the cluster to upgrade. This field has been deprecated
and replaced by the name field.
Corresponds to the JSON property clusterId
9680 9681 9682 |
# File 'lib/google/apis/container_v1/classes.rb', line 9680 def cluster_id @cluster_id end |
#name ⇒ String
The name (project, location, cluster, node pool) of the node pool to set
autoscaler settings. Specified in the format projects/*/locations/*/clusters/*
/nodePools/*.
Corresponds to the JSON property name
9687 9688 9689 |
# File 'lib/google/apis/container_v1/classes.rb', line 9687 def name @name end |
#node_pool_id ⇒ String
Deprecated. The name of the node pool to upgrade. This field has been
deprecated and replaced by the name field.
Corresponds to the JSON property nodePoolId
9693 9694 9695 |
# File 'lib/google/apis/container_v1/classes.rb', line 9693 def node_pool_id @node_pool_id end |
#project_id ⇒ String
Deprecated. The Google Developers Console project ID or project number. This
field has been deprecated and replaced by the name field.
Corresponds to the JSON property projectId
9700 9701 9702 |
# File 'lib/google/apis/container_v1/classes.rb', line 9700 def project_id @project_id end |
#zone ⇒ String
Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has
been deprecated and replaced by the name field.
Corresponds to the JSON property zone
9707 9708 9709 |
# File 'lib/google/apis/container_v1/classes.rb', line 9707 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9714 9715 9716 9717 9718 9719 9720 9721 |
# File 'lib/google/apis/container_v1/classes.rb', line 9714 def update!(**args) @autoscaling = args[:autoscaling] if args.key?(:autoscaling) @cluster_id = args[:cluster_id] if args.key?(:cluster_id) @name = args[:name] if args.key?(:name) @node_pool_id = args[:node_pool_id] if args.key?(:node_pool_id) @project_id = args[:project_id] if args.key?(:project_id) @zone = args[:zone] if args.key?(:zone) end |