Class: Google::Apis::ContainerV1::SetNodePoolAutoscalingRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

SetNodePoolAutoscalingRequest sets the autoscaler settings of a node pool.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SetNodePoolAutoscalingRequest

Returns a new instance of SetNodePoolAutoscalingRequest.



9500
9501
9502
# File 'lib/google/apis/container_v1/classes.rb', line 9500

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#autoscalingGoogle::Apis::ContainerV1::NodePoolAutoscaling

NodePoolAutoscaling contains information required by cluster autoscaler to adjust the size of the node pool to the current cluster usage. Corresponds to the JSON property autoscaling



9465
9466
9467
# File 'lib/google/apis/container_v1/classes.rb', line 9465

def autoscaling
  @autoscaling
end

#cluster_idString

Deprecated. The name of the cluster to upgrade. This field has been deprecated and replaced by the name field. Corresponds to the JSON property clusterId

Returns:

  • (String)


9471
9472
9473
# File 'lib/google/apis/container_v1/classes.rb', line 9471

def cluster_id
  @cluster_id
end

#nameString

The name (project, location, cluster, node pool) of the node pool to set autoscaler settings. Specified in the format projects/*/locations/*/clusters/* /nodePools/*. Corresponds to the JSON property name

Returns:

  • (String)


9478
9479
9480
# File 'lib/google/apis/container_v1/classes.rb', line 9478

def name
  @name
end

#node_pool_idString

Deprecated. The name of the node pool to upgrade. This field has been deprecated and replaced by the name field. Corresponds to the JSON property nodePoolId

Returns:

  • (String)


9484
9485
9486
# File 'lib/google/apis/container_v1/classes.rb', line 9484

def node_pool_id
  @node_pool_id
end

#project_idString

Deprecated. The Google Developers Console project ID or project number. This field has been deprecated and replaced by the name field. Corresponds to the JSON property projectId

Returns:

  • (String)


9491
9492
9493
# File 'lib/google/apis/container_v1/classes.rb', line 9491

def project_id
  @project_id
end

#zoneString

Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has been deprecated and replaced by the name field. Corresponds to the JSON property zone

Returns:

  • (String)


9498
9499
9500
# File 'lib/google/apis/container_v1/classes.rb', line 9498

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9505
9506
9507
9508
9509
9510
9511
9512
# File 'lib/google/apis/container_v1/classes.rb', line 9505

def update!(**args)
  @autoscaling = args[:autoscaling] if args.key?(:autoscaling)
  @cluster_id = args[:cluster_id] if args.key?(:cluster_id)
  @name = args[:name] if args.key?(:name)
  @node_pool_id = args[:node_pool_id] if args.key?(:node_pool_id)
  @project_id = args[:project_id] if args.key?(:project_id)
  @zone = args[:zone] if args.key?(:zone)
end