Class: Google::Apis::ContainerV1::SetNodePoolAutoscalingRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

SetNodePoolAutoscalingRequest sets the autoscaler settings of a node pool.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SetNodePoolAutoscalingRequest

Returns a new instance of SetNodePoolAutoscalingRequest.



9481
9482
9483
# File 'lib/google/apis/container_v1/classes.rb', line 9481

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#autoscalingGoogle::Apis::ContainerV1::NodePoolAutoscaling

NodePoolAutoscaling contains information required by cluster autoscaler to adjust the size of the node pool to the current cluster usage. Corresponds to the JSON property autoscaling



9446
9447
9448
# File 'lib/google/apis/container_v1/classes.rb', line 9446

def autoscaling
  @autoscaling
end

#cluster_idString

Deprecated. The name of the cluster to upgrade. This field has been deprecated and replaced by the name field. Corresponds to the JSON property clusterId

Returns:

  • (String)


9452
9453
9454
# File 'lib/google/apis/container_v1/classes.rb', line 9452

def cluster_id
  @cluster_id
end

#nameString

The name (project, location, cluster, node pool) of the node pool to set autoscaler settings. Specified in the format projects/*/locations/*/clusters/* /nodePools/*. Corresponds to the JSON property name

Returns:

  • (String)


9459
9460
9461
# File 'lib/google/apis/container_v1/classes.rb', line 9459

def name
  @name
end

#node_pool_idString

Deprecated. The name of the node pool to upgrade. This field has been deprecated and replaced by the name field. Corresponds to the JSON property nodePoolId

Returns:

  • (String)


9465
9466
9467
# File 'lib/google/apis/container_v1/classes.rb', line 9465

def node_pool_id
  @node_pool_id
end

#project_idString

Deprecated. The Google Developers Console project ID or project number. This field has been deprecated and replaced by the name field. Corresponds to the JSON property projectId

Returns:

  • (String)


9472
9473
9474
# File 'lib/google/apis/container_v1/classes.rb', line 9472

def project_id
  @project_id
end

#zoneString

Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has been deprecated and replaced by the name field. Corresponds to the JSON property zone

Returns:

  • (String)


9479
9480
9481
# File 'lib/google/apis/container_v1/classes.rb', line 9479

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9486
9487
9488
9489
9490
9491
9492
9493
# File 'lib/google/apis/container_v1/classes.rb', line 9486

def update!(**args)
  @autoscaling = args[:autoscaling] if args.key?(:autoscaling)
  @cluster_id = args[:cluster_id] if args.key?(:cluster_id)
  @name = args[:name] if args.key?(:name)
  @node_pool_id = args[:node_pool_id] if args.key?(:node_pool_id)
  @project_id = args[:project_id] if args.key?(:project_id)
  @zone = args[:zone] if args.key?(:zone)
end