Class: Google::Apis::ContainerV1::SetNodePoolManagementRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

SetNodePoolManagementRequest sets the node management properties of a node pool.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SetNodePoolManagementRequest

Returns a new instance of SetNodePoolManagementRequest.



9768
9769
9770
# File 'lib/google/apis/container_v1/classes.rb', line 9768

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cluster_idString

Deprecated. The name of the cluster to update. This field has been deprecated and replaced by the name field. Corresponds to the JSON property clusterId

Returns:

  • (String)


9733
9734
9735
# File 'lib/google/apis/container_v1/classes.rb', line 9733

def cluster_id
  @cluster_id
end

#managementGoogle::Apis::ContainerV1::NodeManagement

NodeManagement defines the set of node management services turned on for the node pool. Corresponds to the JSON property management



9739
9740
9741
# File 'lib/google/apis/container_v1/classes.rb', line 9739

def management
  @management
end

#nameString

The name (project, location, cluster, node pool id) of the node pool to set management properties. Specified in the format projects/*/locations/*/ clusters/*/nodePools/*. Corresponds to the JSON property name

Returns:

  • (String)


9746
9747
9748
# File 'lib/google/apis/container_v1/classes.rb', line 9746

def name
  @name
end

#node_pool_idString

Deprecated. The name of the node pool to update. This field has been deprecated and replaced by the name field. Corresponds to the JSON property nodePoolId

Returns:

  • (String)


9752
9753
9754
# File 'lib/google/apis/container_v1/classes.rb', line 9752

def node_pool_id
  @node_pool_id
end

#project_idString

Deprecated. The Google Developers Console project ID or project number. This field has been deprecated and replaced by the name field. Corresponds to the JSON property projectId

Returns:

  • (String)


9759
9760
9761
# File 'lib/google/apis/container_v1/classes.rb', line 9759

def project_id
  @project_id
end

#zoneString

Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has been deprecated and replaced by the name field. Corresponds to the JSON property zone

Returns:

  • (String)


9766
9767
9768
# File 'lib/google/apis/container_v1/classes.rb', line 9766

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9773
9774
9775
9776
9777
9778
9779
9780
# File 'lib/google/apis/container_v1/classes.rb', line 9773

def update!(**args)
  @cluster_id = args[:cluster_id] if args.key?(:cluster_id)
  @management = args[:management] if args.key?(:management)
  @name = args[:name] if args.key?(:name)
  @node_pool_id = args[:node_pool_id] if args.key?(:node_pool_id)
  @project_id = args[:project_id] if args.key?(:project_id)
  @zone = args[:zone] if args.key?(:zone)
end