Class: Google::Apis::ContainerV1::SetNodePoolManagementRequest
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1::SetNodePoolManagementRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb
Overview
SetNodePoolManagementRequest sets the node management properties of a node pool.
Instance Attribute Summary collapse
-
#cluster_id ⇒ String
Deprecated.
-
#management ⇒ Google::Apis::ContainerV1::NodeManagement
NodeManagement defines the set of node management services turned on for the node pool.
-
#name ⇒ String
The name (project, location, cluster, node pool id) of the node pool to set management properties.
-
#node_pool_id ⇒ String
Deprecated.
-
#project_id ⇒ String
Deprecated.
-
#zone ⇒ String
Deprecated.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SetNodePoolManagementRequest
constructor
A new instance of SetNodePoolManagementRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SetNodePoolManagementRequest
Returns a new instance of SetNodePoolManagementRequest.
9540 9541 9542 |
# File 'lib/google/apis/container_v1/classes.rb', line 9540 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cluster_id ⇒ String
Deprecated. The name of the cluster to update. This field has been deprecated
and replaced by the name field.
Corresponds to the JSON property clusterId
9505 9506 9507 |
# File 'lib/google/apis/container_v1/classes.rb', line 9505 def cluster_id @cluster_id end |
#management ⇒ Google::Apis::ContainerV1::NodeManagement
NodeManagement defines the set of node management services turned on for the
node pool.
Corresponds to the JSON property management
9511 9512 9513 |
# File 'lib/google/apis/container_v1/classes.rb', line 9511 def management @management end |
#name ⇒ String
The name (project, location, cluster, node pool id) of the node pool to set
management properties. Specified in the format projects/*/locations/*/
clusters/*/nodePools/*.
Corresponds to the JSON property name
9518 9519 9520 |
# File 'lib/google/apis/container_v1/classes.rb', line 9518 def name @name end |
#node_pool_id ⇒ String
Deprecated. The name of the node pool to update. This field has been
deprecated and replaced by the name field.
Corresponds to the JSON property nodePoolId
9524 9525 9526 |
# File 'lib/google/apis/container_v1/classes.rb', line 9524 def node_pool_id @node_pool_id end |
#project_id ⇒ String
Deprecated. The Google Developers Console project ID or project number. This
field has been deprecated and replaced by the name field.
Corresponds to the JSON property projectId
9531 9532 9533 |
# File 'lib/google/apis/container_v1/classes.rb', line 9531 def project_id @project_id end |
#zone ⇒ String
Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has
been deprecated and replaced by the name field.
Corresponds to the JSON property zone
9538 9539 9540 |
# File 'lib/google/apis/container_v1/classes.rb', line 9538 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9545 9546 9547 9548 9549 9550 9551 9552 |
# File 'lib/google/apis/container_v1/classes.rb', line 9545 def update!(**args) @cluster_id = args[:cluster_id] if args.key?(:cluster_id) @management = args[:management] if args.key?(:management) @name = args[:name] if args.key?(:name) @node_pool_id = args[:node_pool_id] if args.key?(:node_pool_id) @project_id = args[:project_id] if args.key?(:project_id) @zone = args[:zone] if args.key?(:zone) end |