Class: Google::Apis::ContainerV1::SetNodePoolManagementRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

SetNodePoolManagementRequest sets the node management properties of a node pool.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SetNodePoolManagementRequest

Returns a new instance of SetNodePoolManagementRequest.



8846
8847
8848
# File 'lib/google/apis/container_v1/classes.rb', line 8846

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cluster_idString

Deprecated. The name of the cluster to update. This field has been deprecated and replaced by the name field. Corresponds to the JSON property clusterId

Returns:

  • (String)


8811
8812
8813
# File 'lib/google/apis/container_v1/classes.rb', line 8811

def cluster_id
  @cluster_id
end

#managementGoogle::Apis::ContainerV1::NodeManagement

NodeManagement defines the set of node management services turned on for the node pool. Corresponds to the JSON property management



8817
8818
8819
# File 'lib/google/apis/container_v1/classes.rb', line 8817

def management
  @management
end

#nameString

The name (project, location, cluster, node pool id) of the node pool to set management properties. Specified in the format projects/*/locations/*/ clusters/*/nodePools/*. Corresponds to the JSON property name

Returns:

  • (String)


8824
8825
8826
# File 'lib/google/apis/container_v1/classes.rb', line 8824

def name
  @name
end

#node_pool_idString

Deprecated. The name of the node pool to update. This field has been deprecated and replaced by the name field. Corresponds to the JSON property nodePoolId

Returns:

  • (String)


8830
8831
8832
# File 'lib/google/apis/container_v1/classes.rb', line 8830

def node_pool_id
  @node_pool_id
end

#project_idString

Deprecated. The Google Developers Console project ID or project number. This field has been deprecated and replaced by the name field. Corresponds to the JSON property projectId

Returns:

  • (String)


8837
8838
8839
# File 'lib/google/apis/container_v1/classes.rb', line 8837

def project_id
  @project_id
end

#zoneString

Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has been deprecated and replaced by the name field. Corresponds to the JSON property zone

Returns:

  • (String)


8844
8845
8846
# File 'lib/google/apis/container_v1/classes.rb', line 8844

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8851
8852
8853
8854
8855
8856
8857
8858
# File 'lib/google/apis/container_v1/classes.rb', line 8851

def update!(**args)
  @cluster_id = args[:cluster_id] if args.key?(:cluster_id)
  @management = args[:management] if args.key?(:management)
  @name = args[:name] if args.key?(:name)
  @node_pool_id = args[:node_pool_id] if args.key?(:node_pool_id)
  @project_id = args[:project_id] if args.key?(:project_id)
  @zone = args[:zone] if args.key?(:zone)
end