Class: Google::Apis::ContainerV1::SetNodePoolSizeRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

SetNodePoolSizeRequest sets the size of a node pool.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SetNodePoolSizeRequest

Returns a new instance of SetNodePoolSizeRequest.



9824
9825
9826
# File 'lib/google/apis/container_v1/classes.rb', line 9824

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cluster_idString

Deprecated. The name of the cluster to update. This field has been deprecated and replaced by the name field. Corresponds to the JSON property clusterId

Returns:

  • (String)


9791
9792
9793
# File 'lib/google/apis/container_v1/classes.rb', line 9791

def cluster_id
  @cluster_id
end

#nameString

The name (project, location, cluster, node pool id) of the node pool to set size. Specified in the format projects/*/locations/*/clusters/*/nodePools/*. Corresponds to the JSON property name

Returns:

  • (String)


9797
9798
9799
# File 'lib/google/apis/container_v1/classes.rb', line 9797

def name
  @name
end

#node_countFixnum

Required. The desired node count for the pool. Corresponds to the JSON property nodeCount

Returns:

  • (Fixnum)


9802
9803
9804
# File 'lib/google/apis/container_v1/classes.rb', line 9802

def node_count
  @node_count
end

#node_pool_idString

Deprecated. The name of the node pool to update. This field has been deprecated and replaced by the name field. Corresponds to the JSON property nodePoolId

Returns:

  • (String)


9808
9809
9810
# File 'lib/google/apis/container_v1/classes.rb', line 9808

def node_pool_id
  @node_pool_id
end

#project_idString

Deprecated. The Google Developers Console project ID or project number. This field has been deprecated and replaced by the name field. Corresponds to the JSON property projectId

Returns:

  • (String)


9815
9816
9817
# File 'lib/google/apis/container_v1/classes.rb', line 9815

def project_id
  @project_id
end

#zoneString

Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has been deprecated and replaced by the name field. Corresponds to the JSON property zone

Returns:

  • (String)


9822
9823
9824
# File 'lib/google/apis/container_v1/classes.rb', line 9822

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9829
9830
9831
9832
9833
9834
9835
9836
# File 'lib/google/apis/container_v1/classes.rb', line 9829

def update!(**args)
  @cluster_id = args[:cluster_id] if args.key?(:cluster_id)
  @name = args[:name] if args.key?(:name)
  @node_count = args[:node_count] if args.key?(:node_count)
  @node_pool_id = args[:node_pool_id] if args.key?(:node_pool_id)
  @project_id = args[:project_id] if args.key?(:project_id)
  @zone = args[:zone] if args.key?(:zone)
end