Class: Google::Apis::ContainerV1::SetNodePoolSizeRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

SetNodePoolSizeRequest sets the size of a node pool.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SetNodePoolSizeRequest

Returns a new instance of SetNodePoolSizeRequest.



9615
9616
9617
# File 'lib/google/apis/container_v1/classes.rb', line 9615

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cluster_idString

Deprecated. The name of the cluster to update. This field has been deprecated and replaced by the name field. Corresponds to the JSON property clusterId

Returns:

  • (String)


9582
9583
9584
# File 'lib/google/apis/container_v1/classes.rb', line 9582

def cluster_id
  @cluster_id
end

#nameString

The name (project, location, cluster, node pool id) of the node pool to set size. Specified in the format projects/*/locations/*/clusters/*/nodePools/*. Corresponds to the JSON property name

Returns:

  • (String)


9588
9589
9590
# File 'lib/google/apis/container_v1/classes.rb', line 9588

def name
  @name
end

#node_countFixnum

Required. The desired node count for the pool. Corresponds to the JSON property nodeCount

Returns:

  • (Fixnum)


9593
9594
9595
# File 'lib/google/apis/container_v1/classes.rb', line 9593

def node_count
  @node_count
end

#node_pool_idString

Deprecated. The name of the node pool to update. This field has been deprecated and replaced by the name field. Corresponds to the JSON property nodePoolId

Returns:

  • (String)


9599
9600
9601
# File 'lib/google/apis/container_v1/classes.rb', line 9599

def node_pool_id
  @node_pool_id
end

#project_idString

Deprecated. The Google Developers Console project ID or project number. This field has been deprecated and replaced by the name field. Corresponds to the JSON property projectId

Returns:

  • (String)


9606
9607
9608
# File 'lib/google/apis/container_v1/classes.rb', line 9606

def project_id
  @project_id
end

#zoneString

Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has been deprecated and replaced by the name field. Corresponds to the JSON property zone

Returns:

  • (String)


9613
9614
9615
# File 'lib/google/apis/container_v1/classes.rb', line 9613

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9620
9621
9622
9623
9624
9625
9626
9627
# File 'lib/google/apis/container_v1/classes.rb', line 9620

def update!(**args)
  @cluster_id = args[:cluster_id] if args.key?(:cluster_id)
  @name = args[:name] if args.key?(:name)
  @node_count = args[:node_count] if args.key?(:node_count)
  @node_pool_id = args[:node_pool_id] if args.key?(:node_pool_id)
  @project_id = args[:project_id] if args.key?(:project_id)
  @zone = args[:zone] if args.key?(:zone)
end