Class: Google::Apis::ContainerV1::SetNodePoolSizeRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

SetNodePoolSizeRequest sets the size of a node pool.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SetNodePoolSizeRequest

Returns a new instance of SetNodePoolSizeRequest.



9596
9597
9598
# File 'lib/google/apis/container_v1/classes.rb', line 9596

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cluster_idString

Deprecated. The name of the cluster to update. This field has been deprecated and replaced by the name field. Corresponds to the JSON property clusterId

Returns:

  • (String)


9563
9564
9565
# File 'lib/google/apis/container_v1/classes.rb', line 9563

def cluster_id
  @cluster_id
end

#nameString

The name (project, location, cluster, node pool id) of the node pool to set size. Specified in the format projects/*/locations/*/clusters/*/nodePools/*. Corresponds to the JSON property name

Returns:

  • (String)


9569
9570
9571
# File 'lib/google/apis/container_v1/classes.rb', line 9569

def name
  @name
end

#node_countFixnum

Required. The desired node count for the pool. Corresponds to the JSON property nodeCount

Returns:

  • (Fixnum)


9574
9575
9576
# File 'lib/google/apis/container_v1/classes.rb', line 9574

def node_count
  @node_count
end

#node_pool_idString

Deprecated. The name of the node pool to update. This field has been deprecated and replaced by the name field. Corresponds to the JSON property nodePoolId

Returns:

  • (String)


9580
9581
9582
# File 'lib/google/apis/container_v1/classes.rb', line 9580

def node_pool_id
  @node_pool_id
end

#project_idString

Deprecated. The Google Developers Console project ID or project number. This field has been deprecated and replaced by the name field. Corresponds to the JSON property projectId

Returns:

  • (String)


9587
9588
9589
# File 'lib/google/apis/container_v1/classes.rb', line 9587

def project_id
  @project_id
end

#zoneString

Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has been deprecated and replaced by the name field. Corresponds to the JSON property zone

Returns:

  • (String)


9594
9595
9596
# File 'lib/google/apis/container_v1/classes.rb', line 9594

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9601
9602
9603
9604
9605
9606
9607
9608
# File 'lib/google/apis/container_v1/classes.rb', line 9601

def update!(**args)
  @cluster_id = args[:cluster_id] if args.key?(:cluster_id)
  @name = args[:name] if args.key?(:name)
  @node_count = args[:node_count] if args.key?(:node_count)
  @node_pool_id = args[:node_pool_id] if args.key?(:node_pool_id)
  @project_id = args[:project_id] if args.key?(:project_id)
  @zone = args[:zone] if args.key?(:zone)
end