Class: Google::Apis::ContainerV1::SetNodePoolSizeRequest
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1::SetNodePoolSizeRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb
Overview
SetNodePoolSizeRequest sets the size of a node pool.
Instance Attribute Summary collapse
-
#cluster_id ⇒ String
Deprecated.
-
#name ⇒ String
The name (project, location, cluster, node pool id) of the node pool to set size.
-
#node_count ⇒ Fixnum
Required.
-
#node_pool_id ⇒ String
Deprecated.
-
#project_id ⇒ String
Deprecated.
-
#zone ⇒ String
Deprecated.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SetNodePoolSizeRequest
constructor
A new instance of SetNodePoolSizeRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SetNodePoolSizeRequest
Returns a new instance of SetNodePoolSizeRequest.
8902 8903 8904 |
# File 'lib/google/apis/container_v1/classes.rb', line 8902 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cluster_id ⇒ String
Deprecated. The name of the cluster to update. This field has been deprecated
and replaced by the name field.
Corresponds to the JSON property clusterId
8869 8870 8871 |
# File 'lib/google/apis/container_v1/classes.rb', line 8869 def cluster_id @cluster_id end |
#name ⇒ String
The name (project, location, cluster, node pool id) of the node pool to set
size. Specified in the format projects/*/locations/*/clusters/*/nodePools/*.
Corresponds to the JSON property name
8875 8876 8877 |
# File 'lib/google/apis/container_v1/classes.rb', line 8875 def name @name end |
#node_count ⇒ Fixnum
Required. The desired node count for the pool.
Corresponds to the JSON property nodeCount
8880 8881 8882 |
# File 'lib/google/apis/container_v1/classes.rb', line 8880 def node_count @node_count end |
#node_pool_id ⇒ String
Deprecated. The name of the node pool to update. This field has been
deprecated and replaced by the name field.
Corresponds to the JSON property nodePoolId
8886 8887 8888 |
# File 'lib/google/apis/container_v1/classes.rb', line 8886 def node_pool_id @node_pool_id end |
#project_id ⇒ String
Deprecated. The Google Developers Console project ID or project number. This
field has been deprecated and replaced by the name field.
Corresponds to the JSON property projectId
8893 8894 8895 |
# File 'lib/google/apis/container_v1/classes.rb', line 8893 def project_id @project_id end |
#zone ⇒ String
Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has
been deprecated and replaced by the name field.
Corresponds to the JSON property zone
8900 8901 8902 |
# File 'lib/google/apis/container_v1/classes.rb', line 8900 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8907 8908 8909 8910 8911 8912 8913 8914 |
# File 'lib/google/apis/container_v1/classes.rb', line 8907 def update!(**args) @cluster_id = args[:cluster_id] if args.key?(:cluster_id) @name = args[:name] if args.key?(:name) @node_count = args[:node_count] if args.key?(:node_count) @node_pool_id = args[:node_pool_id] if args.key?(:node_pool_id) @project_id = args[:project_id] if args.key?(:project_id) @zone = args[:zone] if args.key?(:zone) end |