Class: Google::Apis::ContainerV1::SetNodePoolSizeRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

SetNodePoolSizeRequest sets the size of a node pool.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SetNodePoolSizeRequest

Returns a new instance of SetNodePoolSizeRequest.



8641
8642
8643
# File 'lib/google/apis/container_v1/classes.rb', line 8641

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cluster_idString

Deprecated. The name of the cluster to update. This field has been deprecated and replaced by the name field. Corresponds to the JSON property clusterId

Returns:

  • (String)


8608
8609
8610
# File 'lib/google/apis/container_v1/classes.rb', line 8608

def cluster_id
  @cluster_id
end

#nameString

The name (project, location, cluster, node pool id) of the node pool to set size. Specified in the format projects/*/locations/*/clusters/*/nodePools/*. Corresponds to the JSON property name

Returns:

  • (String)


8614
8615
8616
# File 'lib/google/apis/container_v1/classes.rb', line 8614

def name
  @name
end

#node_countFixnum

Required. The desired node count for the pool. Corresponds to the JSON property nodeCount

Returns:

  • (Fixnum)


8619
8620
8621
# File 'lib/google/apis/container_v1/classes.rb', line 8619

def node_count
  @node_count
end

#node_pool_idString

Deprecated. The name of the node pool to update. This field has been deprecated and replaced by the name field. Corresponds to the JSON property nodePoolId

Returns:

  • (String)


8625
8626
8627
# File 'lib/google/apis/container_v1/classes.rb', line 8625

def node_pool_id
  @node_pool_id
end

#project_idString

Deprecated. The Google Developers Console project ID or project number. This field has been deprecated and replaced by the name field. Corresponds to the JSON property projectId

Returns:

  • (String)


8632
8633
8634
# File 'lib/google/apis/container_v1/classes.rb', line 8632

def project_id
  @project_id
end

#zoneString

Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has been deprecated and replaced by the name field. Corresponds to the JSON property zone

Returns:

  • (String)


8639
8640
8641
# File 'lib/google/apis/container_v1/classes.rb', line 8639

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8646
8647
8648
8649
8650
8651
8652
8653
# File 'lib/google/apis/container_v1/classes.rb', line 8646

def update!(**args)
  @cluster_id = args[:cluster_id] if args.key?(:cluster_id)
  @name = args[:name] if args.key?(:name)
  @node_count = args[:node_count] if args.key?(:node_count)
  @node_pool_id = args[:node_pool_id] if args.key?(:node_pool_id)
  @project_id = args[:project_id] if args.key?(:project_id)
  @zone = args[:zone] if args.key?(:zone)
end