Class: Google::Apis::ContainerV1::SlurmOperatorConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

Configuration for the Slurm Operator.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SlurmOperatorConfig

Returns a new instance of SlurmOperatorConfig.



9696
9697
9698
# File 'lib/google/apis/container_v1/classes.rb', line 9696

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enabledBoolean Also known as: enabled?

When enabled, it runs a Slurm Operator that manages the set of compute pods for Slurm Cluster. Corresponds to the JSON property enabled

Returns:

  • (Boolean)


9693
9694
9695
# File 'lib/google/apis/container_v1/classes.rb', line 9693

def enabled
  @enabled
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9701
9702
9703
# File 'lib/google/apis/container_v1/classes.rb', line 9701

def update!(**args)
  @enabled = args[:enabled] if args.key?(:enabled)
end