Class: Google::Apis::ContainerV1::SlurmOperatorConfig
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1::SlurmOperatorConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb
Overview
Configuration for the Slurm Operator.
Instance Attribute Summary collapse
-
#enabled ⇒ Boolean
(also: #enabled?)
When enabled, it runs a Slurm Operator that manages the set of compute pods for Slurm Cluster.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SlurmOperatorConfig
constructor
A new instance of SlurmOperatorConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SlurmOperatorConfig
Returns a new instance of SlurmOperatorConfig.
9696 9697 9698 |
# File 'lib/google/apis/container_v1/classes.rb', line 9696 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enabled ⇒ Boolean Also known as: enabled?
When enabled, it runs a Slurm Operator that manages the set of compute pods
for Slurm Cluster.
Corresponds to the JSON property enabled
9693 9694 9695 |
# File 'lib/google/apis/container_v1/classes.rb', line 9693 def enabled @enabled end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9701 9702 9703 |
# File 'lib/google/apis/container_v1/classes.rb', line 9701 def update!(**args) @enabled = args[:enabled] if args.key?(:enabled) end |