Class: Google::Apis::ContainerV1::StandardRolloutPolicy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

Standard rollout policy is the default policy for blue-green.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StandardRolloutPolicy

Returns a new instance of StandardRolloutPolicy.



9773
9774
9775
# File 'lib/google/apis/container_v1/classes.rb', line 9773

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#batch_node_countFixnum

Number of blue nodes to drain in a batch. Corresponds to the JSON property batchNodeCount

Returns:

  • (Fixnum)


9760
9761
9762
# File 'lib/google/apis/container_v1/classes.rb', line 9760

def batch_node_count
  @batch_node_count
end

#batch_percentageFloat

Percentage of the blue pool nodes to drain in a batch. The range of this field should be (0.0, 1.0]. Corresponds to the JSON property batchPercentage

Returns:

  • (Float)


9766
9767
9768
# File 'lib/google/apis/container_v1/classes.rb', line 9766

def batch_percentage
  @batch_percentage
end

#batch_soak_durationString

Soak time after each batch gets drained. Default to zero. Corresponds to the JSON property batchSoakDuration

Returns:

  • (String)


9771
9772
9773
# File 'lib/google/apis/container_v1/classes.rb', line 9771

def batch_soak_duration
  @batch_soak_duration
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9778
9779
9780
9781
9782
# File 'lib/google/apis/container_v1/classes.rb', line 9778

def update!(**args)
  @batch_node_count = args[:batch_node_count] if args.key?(:batch_node_count)
  @batch_percentage = args[:batch_percentage] if args.key?(:batch_percentage)
  @batch_soak_duration = args[:batch_soak_duration] if args.key?(:batch_soak_duration)
end