Class: Google::Apis::ContainerV1::StartIpRotationRequest
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1::StartIpRotationRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb
Overview
StartIPRotationRequest creates a new IP for the cluster and then performs a node upgrade on each node pool to point to the new IP.
Instance Attribute Summary collapse
-
#cluster_id ⇒ String
Deprecated.
-
#name ⇒ String
The name (project, location, cluster name) of the cluster to start IP rotation.
-
#project_id ⇒ String
Deprecated.
-
#rotate_credentials ⇒ Boolean
(also: #rotate_credentials?)
Whether to rotate credentials during IP rotation.
-
#zone ⇒ String
Deprecated.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StartIpRotationRequest
constructor
A new instance of StartIpRotationRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StartIpRotationRequest
Returns a new instance of StartIpRotationRequest.
10031 10032 10033 |
# File 'lib/google/apis/container_v1/classes.rb', line 10031 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cluster_id ⇒ String
Deprecated. The name of the cluster. This field has been deprecated and
replaced by the name field.
Corresponds to the JSON property clusterId
10003 10004 10005 |
# File 'lib/google/apis/container_v1/classes.rb', line 10003 def cluster_id @cluster_id end |
#name ⇒ String
The name (project, location, cluster name) of the cluster to start IP rotation.
Specified in the format projects/*/locations/*/clusters/*.
Corresponds to the JSON property name
10009 10010 10011 |
# File 'lib/google/apis/container_v1/classes.rb', line 10009 def name @name end |
#project_id ⇒ String
Deprecated. The Google Developers Console project ID or project number. This
field has been deprecated and replaced by the name field.
Corresponds to the JSON property projectId
10016 10017 10018 |
# File 'lib/google/apis/container_v1/classes.rb', line 10016 def project_id @project_id end |
#rotate_credentials ⇒ Boolean Also known as: rotate_credentials?
Whether to rotate credentials during IP rotation.
Corresponds to the JSON property rotateCredentials
10021 10022 10023 |
# File 'lib/google/apis/container_v1/classes.rb', line 10021 def rotate_credentials @rotate_credentials end |
#zone ⇒ String
Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has
been deprecated and replaced by the name field.
Corresponds to the JSON property zone
10029 10030 10031 |
# File 'lib/google/apis/container_v1/classes.rb', line 10029 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10036 10037 10038 10039 10040 10041 10042 |
# File 'lib/google/apis/container_v1/classes.rb', line 10036 def update!(**args) @cluster_id = args[:cluster_id] if args.key?(:cluster_id) @name = args[:name] if args.key?(:name) @project_id = args[:project_id] if args.key?(:project_id) @rotate_credentials = args[:rotate_credentials] if args.key?(:rotate_credentials) @zone = args[:zone] if args.key?(:zone) end |