Class: Google::Apis::ContainerV1::UpdateClusterRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

UpdateClusterRequest updates the settings of a cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UpdateClusterRequest

Returns a new instance of UpdateClusterRequest.



10154
10155
10156
# File 'lib/google/apis/container_v1/classes.rb', line 10154

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cluster_idString

Deprecated. The name of the cluster to upgrade. This field has been deprecated and replaced by the name field. Corresponds to the JSON property clusterId

Returns:

  • (String)


10126
10127
10128
# File 'lib/google/apis/container_v1/classes.rb', line 10126

def cluster_id
  @cluster_id
end

#nameString

The name (project, location, cluster) of the cluster to update. Specified in the format projects/*/locations/*/clusters/*. Corresponds to the JSON property name

Returns:

  • (String)


10132
10133
10134
# File 'lib/google/apis/container_v1/classes.rb', line 10132

def name
  @name
end

#project_idString

Deprecated. The Google Developers Console project ID or project number. This field has been deprecated and replaced by the name field. Corresponds to the JSON property projectId

Returns:

  • (String)


10139
10140
10141
# File 'lib/google/apis/container_v1/classes.rb', line 10139

def project_id
  @project_id
end

#updateGoogle::Apis::ContainerV1::ClusterUpdate

ClusterUpdate describes an update to the cluster. Exactly one update can be applied to a cluster with each request, so at most one field can be provided. Corresponds to the JSON property update



10145
10146
10147
# File 'lib/google/apis/container_v1/classes.rb', line 10145

def update
  @update
end

#zoneString

Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has been deprecated and replaced by the name field. Corresponds to the JSON property zone

Returns:

  • (String)


10152
10153
10154
# File 'lib/google/apis/container_v1/classes.rb', line 10152

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10159
10160
10161
10162
10163
10164
10165
# File 'lib/google/apis/container_v1/classes.rb', line 10159

def update!(**args)
  @cluster_id = args[:cluster_id] if args.key?(:cluster_id)
  @name = args[:name] if args.key?(:name)
  @project_id = args[:project_id] if args.key?(:project_id)
  @update = args[:update] if args.key?(:update)
  @zone = args[:zone] if args.key?(:zone)
end