Class: Google::Apis::ContainerV1::UpdateClusterRequest
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1::UpdateClusterRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb
Overview
UpdateClusterRequest updates the settings of a cluster.
Instance Attribute Summary collapse
-
#cluster_id ⇒ String
Deprecated.
-
#name ⇒ String
The name (project, location, cluster) of the cluster to update.
-
#project_id ⇒ String
Deprecated.
-
#update ⇒ Google::Apis::ContainerV1::ClusterUpdate
ClusterUpdate describes an update to the cluster.
-
#zone ⇒ String
Deprecated.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UpdateClusterRequest
constructor
A new instance of UpdateClusterRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UpdateClusterRequest
Returns a new instance of UpdateClusterRequest.
9348 9349 9350 |
# File 'lib/google/apis/container_v1/classes.rb', line 9348 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cluster_id ⇒ String
Deprecated. The name of the cluster to upgrade. This field has been deprecated
and replaced by the name field.
Corresponds to the JSON property clusterId
9320 9321 9322 |
# File 'lib/google/apis/container_v1/classes.rb', line 9320 def cluster_id @cluster_id end |
#name ⇒ String
The name (project, location, cluster) of the cluster to update. Specified in
the format projects/*/locations/*/clusters/*.
Corresponds to the JSON property name
9326 9327 9328 |
# File 'lib/google/apis/container_v1/classes.rb', line 9326 def name @name end |
#project_id ⇒ String
Deprecated. The Google Developers Console project ID or project number. This
field has been deprecated and replaced by the name field.
Corresponds to the JSON property projectId
9333 9334 9335 |
# File 'lib/google/apis/container_v1/classes.rb', line 9333 def project_id @project_id end |
#update ⇒ Google::Apis::ContainerV1::ClusterUpdate
ClusterUpdate describes an update to the cluster. Exactly one update can be
applied to a cluster with each request, so at most one field can be provided.
Corresponds to the JSON property update
9339 9340 9341 |
# File 'lib/google/apis/container_v1/classes.rb', line 9339 def update @update end |
#zone ⇒ String
Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has
been deprecated and replaced by the name field.
Corresponds to the JSON property zone
9346 9347 9348 |
# File 'lib/google/apis/container_v1/classes.rb', line 9346 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9353 9354 9355 9356 9357 9358 9359 |
# File 'lib/google/apis/container_v1/classes.rb', line 9353 def update!(**args) @cluster_id = args[:cluster_id] if args.key?(:cluster_id) @name = args[:name] if args.key?(:name) @project_id = args[:project_id] if args.key?(:project_id) @update = args[:update] if args.key?(:update) @zone = args[:zone] if args.key?(:zone) end |