Class: Google::Apis::ContainerV1::UpdateMasterRequest
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1::UpdateMasterRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb
Overview
UpdateMasterRequest updates the master of the cluster.
Instance Attribute Summary collapse
-
#cluster_id ⇒ String
Deprecated.
-
#master_version ⇒ String
Required.
-
#name ⇒ String
The name (project, location, cluster) of the cluster to update.
-
#project_id ⇒ String
Deprecated.
-
#zone ⇒ String
Deprecated.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UpdateMasterRequest
constructor
A new instance of UpdateMasterRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UpdateMasterRequest
Returns a new instance of UpdateMasterRequest.
10461 10462 10463 |
# File 'lib/google/apis/container_v1/classes.rb', line 10461 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cluster_id ⇒ String
Deprecated. The name of the cluster to upgrade. This field has been deprecated
and replaced by the name field.
Corresponds to the JSON property clusterId
10428 10429 10430 |
# File 'lib/google/apis/container_v1/classes.rb', line 10428 def cluster_id @cluster_id end |
#master_version ⇒ String
Required. The Kubernetes version to change the master to. Users may specify
either explicit versions offered by Kubernetes Engine or version aliases,
which have the following behavior: - "latest": picks the highest valid
Kubernetes version - "1.X": picks the highest valid patch+gke.N patch in the 1.
X version - "1.X.Y": picks the highest valid gke.N patch in the 1.X.Y version -
"1.X.Y-gke.N": picks an explicit Kubernetes version - "-": picks the default
Kubernetes version
Corresponds to the JSON property masterVersion
10439 10440 10441 |
# File 'lib/google/apis/container_v1/classes.rb', line 10439 def master_version @master_version end |
#name ⇒ String
The name (project, location, cluster) of the cluster to update. Specified in
the format projects/*/locations/*/clusters/*.
Corresponds to the JSON property name
10445 10446 10447 |
# File 'lib/google/apis/container_v1/classes.rb', line 10445 def name @name end |
#project_id ⇒ String
Deprecated. The Google Developers Console project ID or project number. This
field has been deprecated and replaced by the name field.
Corresponds to the JSON property projectId
10452 10453 10454 |
# File 'lib/google/apis/container_v1/classes.rb', line 10452 def project_id @project_id end |
#zone ⇒ String
Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has
been deprecated and replaced by the name field.
Corresponds to the JSON property zone
10459 10460 10461 |
# File 'lib/google/apis/container_v1/classes.rb', line 10459 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10466 10467 10468 10469 10470 10471 10472 |
# File 'lib/google/apis/container_v1/classes.rb', line 10466 def update!(**args) @cluster_id = args[:cluster_id] if args.key?(:cluster_id) @master_version = args[:master_version] if args.key?(:master_version) @name = args[:name] if args.key?(:name) @project_id = args[:project_id] if args.key?(:project_id) @zone = args[:zone] if args.key?(:zone) end |