Class: Google::Apis::ContainerV1::UpdateMasterRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

UpdateMasterRequest updates the master of the cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UpdateMasterRequest

Returns a new instance of UpdateMasterRequest.



9423
9424
9425
# File 'lib/google/apis/container_v1/classes.rb', line 9423

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cluster_idString

Deprecated. The name of the cluster to upgrade. This field has been deprecated and replaced by the name field. Corresponds to the JSON property clusterId

Returns:

  • (String)


9390
9391
9392
# File 'lib/google/apis/container_v1/classes.rb', line 9390

def cluster_id
  @cluster_id
end

#master_versionString

Required. The Kubernetes version to change the master to. Users may specify either explicit versions offered by Kubernetes Engine or version aliases, which have the following behavior: - "latest": picks the highest valid Kubernetes version - "1.X": picks the highest valid patch+gke.N patch in the 1. X version - "1.X.Y": picks the highest valid gke.N patch in the 1.X.Y version - "1.X.Y-gke.N": picks an explicit Kubernetes version - "-": picks the default Kubernetes version Corresponds to the JSON property masterVersion

Returns:

  • (String)


9401
9402
9403
# File 'lib/google/apis/container_v1/classes.rb', line 9401

def master_version
  @master_version
end

#nameString

The name (project, location, cluster) of the cluster to update. Specified in the format projects/*/locations/*/clusters/*. Corresponds to the JSON property name

Returns:

  • (String)


9407
9408
9409
# File 'lib/google/apis/container_v1/classes.rb', line 9407

def name
  @name
end

#project_idString

Deprecated. The Google Developers Console project ID or project number. This field has been deprecated and replaced by the name field. Corresponds to the JSON property projectId

Returns:

  • (String)


9414
9415
9416
# File 'lib/google/apis/container_v1/classes.rb', line 9414

def project_id
  @project_id
end

#zoneString

Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has been deprecated and replaced by the name field. Corresponds to the JSON property zone

Returns:

  • (String)


9421
9422
9423
# File 'lib/google/apis/container_v1/classes.rb', line 9421

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9428
9429
9430
9431
9432
9433
9434
# File 'lib/google/apis/container_v1/classes.rb', line 9428

def update!(**args)
  @cluster_id = args[:cluster_id] if args.key?(:cluster_id)
  @master_version = args[:master_version] if args.key?(:master_version)
  @name = args[:name] if args.key?(:name)
  @project_id = args[:project_id] if args.key?(:project_id)
  @zone = args[:zone] if args.key?(:zone)
end