Class: Google::Apis::ContainerV1::UpdateNodePoolRequest
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1::UpdateNodePoolRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb
Overview
UpdateNodePoolRequests update a node pool's image and/or version.
Instance Attribute Summary collapse
-
#accelerators ⇒ Array<Google::Apis::ContainerV1::AcceleratorConfig>
A list of hardware accelerators to be attached to each node.
-
#boot_disk ⇒ Google::Apis::ContainerV1::BootDisk
BootDisk specifies the boot disk configuration for node pools.
-
#cluster_id ⇒ String
Deprecated.
-
#confidential_nodes ⇒ Google::Apis::ContainerV1::ConfidentialNodes
ConfidentialNodes is configuration for the confidential nodes feature, which makes nodes run on confidential VMs.
-
#consolidation_delay ⇒ String
Consolidation delay defines duration after which the Cluster Autoscaler can scale down underutilized nodes.
-
#containerd_config ⇒ Google::Apis::ContainerV1::ContainerdConfig
ContainerdConfig contains configuration to customize containerd.
-
#disk_size_gb ⇒ Fixnum
Optional.
-
#disk_type ⇒ String
Optional.
-
#etag ⇒ String
The current etag of the node pool.
-
#fast_socket ⇒ Google::Apis::ContainerV1::FastSocket
Configuration of Fast Socket feature.
-
#flex_start ⇒ Boolean
(also: #flex_start?)
Flex Start flag for enabling Flex Start VM.
-
#gcfs_config ⇒ Google::Apis::ContainerV1::GcfsConfig
GcfsConfig contains configurations of Google Container File System (image streaming).
-
#gvnic ⇒ Google::Apis::ContainerV1::VirtualNic
Configuration of gVNIC feature.
-
#image ⇒ String
The desired name of the image name to use for this node.
-
#image_project ⇒ String
The project containing the desired image to use for this node pool.
-
#image_type ⇒ String
Required.
-
#kubelet_config ⇒ Google::Apis::ContainerV1::NodeKubeletConfig
Node kubelet configs.
-
#labels ⇒ Google::Apis::ContainerV1::NodeLabels
Collection of node-level Kubernetes labels.
-
#linux_node_config ⇒ Google::Apis::ContainerV1::LinuxNodeConfig
Parameters that can be configured on Linux nodes.
-
#locations ⇒ Array<String>
The desired list of Google Compute Engine zones in which the node pool's nodes should be located.
-
#logging_config ⇒ Google::Apis::ContainerV1::NodePoolLoggingConfig
NodePoolLoggingConfig specifies logging configuration for node pools.
-
#machine_type ⇒ String
Optional.
-
#max_run_duration ⇒ String
The maximum duration for the nodes to exist.
-
#name ⇒ String
The name (project, location, cluster, node pool) of the node pool to update.
-
#node_drain_config ⇒ Google::Apis::ContainerV1::NodeDrainConfig
NodeDrainConfig contains the node drain related configurations for this node pool.
-
#node_network_config ⇒ Google::Apis::ContainerV1::NodeNetworkConfig
Parameters for node pool-level network config.
-
#node_pool_id ⇒ String
Deprecated.
-
#node_version ⇒ String
Required.
-
#project_id ⇒ String
Deprecated.
-
#queued_provisioning ⇒ Google::Apis::ContainerV1::QueuedProvisioning
QueuedProvisioning defines the queued provisioning used by the node pool.
-
#resource_labels ⇒ Google::Apis::ContainerV1::ResourceLabels
Collection of Resource Manager labels.
-
#resource_manager_tags ⇒ Google::Apis::ContainerV1::ResourceManagerTags
A map of resource manager tag keys and values to be attached to the nodes for managing Compute Engine firewalls using Network Firewall Policies.
-
#storage_pools ⇒ Array<String>
List of Storage Pools where boot disks are provisioned.
-
#tags ⇒ Google::Apis::ContainerV1::NetworkTags
Collection of Compute Engine network tags that can be applied to a node's underlying VM instance.
-
#taint_config ⇒ Google::Apis::ContainerV1::TaintConfig
TaintConfig contains the configuration for the taints of the node pool.
-
#taints ⇒ Google::Apis::ContainerV1::NodeTaints
Collection of Kubernetes node taints.
-
#upgrade_settings ⇒ Google::Apis::ContainerV1::UpgradeSettings
These upgrade settings control the level of parallelism and the level of disruption caused by an upgrade.
-
#windows_node_config ⇒ Google::Apis::ContainerV1::WindowsNodeConfig
Parameters that can be configured on Windows nodes.
-
#workload_metadata_config ⇒ Google::Apis::ContainerV1::WorkloadMetadataConfig
WorkloadMetadataConfig defines the metadata configuration to expose to workloads on the node pool.
-
#zone ⇒ String
Deprecated.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UpdateNodePoolRequest
constructor
A new instance of UpdateNodePoolRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UpdateNodePoolRequest
Returns a new instance of UpdateNodePoolRequest.
10533 10534 10535 |
# File 'lib/google/apis/container_v1/classes.rb', line 10533 def initialize(**args) update!(**args) end |
Instance Attribute Details
#accelerators ⇒ Array<Google::Apis::ContainerV1::AcceleratorConfig>
A list of hardware accelerators to be attached to each node. See https://cloud.
google.com/compute/docs/gpus for more information about support for GPUs.
Corresponds to the JSON property accelerators
10251 10252 10253 |
# File 'lib/google/apis/container_v1/classes.rb', line 10251 def accelerators @accelerators end |
#boot_disk ⇒ Google::Apis::ContainerV1::BootDisk
BootDisk specifies the boot disk configuration for node pools.
Corresponds to the JSON property bootDisk
10256 10257 10258 |
# File 'lib/google/apis/container_v1/classes.rb', line 10256 def boot_disk @boot_disk end |
#cluster_id ⇒ String
Deprecated. The name of the cluster to upgrade. This field has been deprecated
and replaced by the name field.
Corresponds to the JSON property clusterId
10262 10263 10264 |
# File 'lib/google/apis/container_v1/classes.rb', line 10262 def cluster_id @cluster_id end |
#confidential_nodes ⇒ Google::Apis::ContainerV1::ConfidentialNodes
ConfidentialNodes is configuration for the confidential nodes feature, which
makes nodes run on confidential VMs.
Corresponds to the JSON property confidentialNodes
10268 10269 10270 |
# File 'lib/google/apis/container_v1/classes.rb', line 10268 def confidential_nodes @confidential_nodes end |
#consolidation_delay ⇒ String
Consolidation delay defines duration after which the Cluster Autoscaler can
scale down underutilized nodes. If not set, nodes are scaled down by default
behavior, i.e. according to the chosen autoscaling profile.
Corresponds to the JSON property consolidationDelay
10275 10276 10277 |
# File 'lib/google/apis/container_v1/classes.rb', line 10275 def consolidation_delay @consolidation_delay end |
#containerd_config ⇒ Google::Apis::ContainerV1::ContainerdConfig
ContainerdConfig contains configuration to customize containerd.
Corresponds to the JSON property containerdConfig
10280 10281 10282 |
# File 'lib/google/apis/container_v1/classes.rb', line 10280 def containerd_config @containerd_config end |
#disk_size_gb ⇒ Fixnum
Optional. The desired disk size for nodes in the node pool specified in GB.
The smallest allowed disk size is 10GB. Initiates an upgrade operation that
migrates the nodes in the node pool to the specified disk size.
Corresponds to the JSON property diskSizeGb
10287 10288 10289 |
# File 'lib/google/apis/container_v1/classes.rb', line 10287 def disk_size_gb @disk_size_gb end |
#disk_type ⇒ String
Optional. The desired disk type (e.g. 'pd-standard', 'pd-ssd' or 'pd-balanced')
for nodes in the node pool. Initiates an upgrade operation that migrates the
nodes in the node pool to the specified disk type.
Corresponds to the JSON property diskType
10294 10295 10296 |
# File 'lib/google/apis/container_v1/classes.rb', line 10294 def disk_type @disk_type end |
#etag ⇒ String
The current etag of the node pool. If an etag is provided and does not match
the current etag of the node pool, update will be blocked and an ABORTED error
will be returned.
Corresponds to the JSON property etag
10301 10302 10303 |
# File 'lib/google/apis/container_v1/classes.rb', line 10301 def etag @etag end |
#fast_socket ⇒ Google::Apis::ContainerV1::FastSocket
Configuration of Fast Socket feature.
Corresponds to the JSON property fastSocket
10306 10307 10308 |
# File 'lib/google/apis/container_v1/classes.rb', line 10306 def fast_socket @fast_socket end |
#flex_start ⇒ Boolean Also known as: flex_start?
Flex Start flag for enabling Flex Start VM.
Corresponds to the JSON property flexStart
10311 10312 10313 |
# File 'lib/google/apis/container_v1/classes.rb', line 10311 def flex_start @flex_start end |
#gcfs_config ⇒ Google::Apis::ContainerV1::GcfsConfig
GcfsConfig contains configurations of Google Container File System (image
streaming).
Corresponds to the JSON property gcfsConfig
10318 10319 10320 |
# File 'lib/google/apis/container_v1/classes.rb', line 10318 def gcfs_config @gcfs_config end |
#gvnic ⇒ Google::Apis::ContainerV1::VirtualNic
Configuration of gVNIC feature.
Corresponds to the JSON property gvnic
10323 10324 10325 |
# File 'lib/google/apis/container_v1/classes.rb', line 10323 def gvnic @gvnic end |
#image ⇒ String
The desired name of the image name to use for this node. This is used to
create clusters using a custom image.
Corresponds to the JSON property image
10329 10330 10331 |
# File 'lib/google/apis/container_v1/classes.rb', line 10329 def image @image end |
#image_project ⇒ String
The project containing the desired image to use for this node pool. This is
used to create clusters using a custom image.
Corresponds to the JSON property imageProject
10335 10336 10337 |
# File 'lib/google/apis/container_v1/classes.rb', line 10335 def image_project @image_project end |
#image_type ⇒ String
Required. The desired image type for the node pool. Please see https://cloud.
google.com/kubernetes-engine/docs/concepts/node-images for available image
types.
Corresponds to the JSON property imageType
10342 10343 10344 |
# File 'lib/google/apis/container_v1/classes.rb', line 10342 def image_type @image_type end |
#kubelet_config ⇒ Google::Apis::ContainerV1::NodeKubeletConfig
Node kubelet configs.
Corresponds to the JSON property kubeletConfig
10347 10348 10349 |
# File 'lib/google/apis/container_v1/classes.rb', line 10347 def kubelet_config @kubelet_config end |
#labels ⇒ Google::Apis::ContainerV1::NodeLabels
Collection of node-level Kubernetes labels.
Corresponds to the JSON property labels
10353 10354 10355 |
# File 'lib/google/apis/container_v1/classes.rb', line 10353 def labels @labels end |
#linux_node_config ⇒ Google::Apis::ContainerV1::LinuxNodeConfig
Parameters that can be configured on Linux nodes.
Corresponds to the JSON property linuxNodeConfig
10358 10359 10360 |
# File 'lib/google/apis/container_v1/classes.rb', line 10358 def linux_node_config @linux_node_config end |
#locations ⇒ Array<String>
The desired list of Google Compute Engine zones in which the node pool's nodes should be located.
Changing the locations for a node pool will result in nodes being either
created or removed from the node pool, depending on whether locations are
being added or removed. Warning: It is recommended to update node pool
locations in a standalone API call. Do not combine a location update with
changes to other fields (such as tags, labels, taints, etc.) in the same
request. Otherwise, the API performs a structural modification where changes
to other fields will only apply to newly created nodes and will not be applied
to existing nodes in the node pool. To ensure all nodes are updated
consistently, use a separate API call for location changes.
Corresponds to the JSON property locations
10373 10374 10375 |
# File 'lib/google/apis/container_v1/classes.rb', line 10373 def locations @locations end |
#logging_config ⇒ Google::Apis::ContainerV1::NodePoolLoggingConfig
NodePoolLoggingConfig specifies logging configuration for node pools.
Corresponds to the JSON property loggingConfig
10378 10379 10380 |
# File 'lib/google/apis/container_v1/classes.rb', line 10378 def logging_config @logging_config end |
#machine_type ⇒ String
Optional. The desired Google Compute Engine machine type for nodes in the node pool. Initiates
an upgrade operation that migrates the nodes in the node pool to the specified
machine type.
Corresponds to the JSON property machineType
10386 10387 10388 |
# File 'lib/google/apis/container_v1/classes.rb', line 10386 def machine_type @machine_type end |
#max_run_duration ⇒ String
The maximum duration for the nodes to exist. If unspecified, the nodes can
exist indefinitely.
Corresponds to the JSON property maxRunDuration
10392 10393 10394 |
# File 'lib/google/apis/container_v1/classes.rb', line 10392 def max_run_duration @max_run_duration end |
#name ⇒ String
The name (project, location, cluster, node pool) of the node pool to update.
Specified in the format projects/*/locations/*/clusters/*/nodePools/*.
Corresponds to the JSON property name
10398 10399 10400 |
# File 'lib/google/apis/container_v1/classes.rb', line 10398 def name @name end |
#node_drain_config ⇒ Google::Apis::ContainerV1::NodeDrainConfig
NodeDrainConfig contains the node drain related configurations for this node
pool.
Corresponds to the JSON property nodeDrainConfig
10404 10405 10406 |
# File 'lib/google/apis/container_v1/classes.rb', line 10404 def node_drain_config @node_drain_config end |
#node_network_config ⇒ Google::Apis::ContainerV1::NodeNetworkConfig
Parameters for node pool-level network config.
Corresponds to the JSON property nodeNetworkConfig
10409 10410 10411 |
# File 'lib/google/apis/container_v1/classes.rb', line 10409 def node_network_config @node_network_config end |
#node_pool_id ⇒ String
Deprecated. The name of the node pool to upgrade. This field has been
deprecated and replaced by the name field.
Corresponds to the JSON property nodePoolId
10415 10416 10417 |
# File 'lib/google/apis/container_v1/classes.rb', line 10415 def node_pool_id @node_pool_id end |
#node_version ⇒ String
Required. The Kubernetes version to change the nodes to (typically an upgrade).
Users may specify either explicit versions offered by Kubernetes Engine or
version aliases, which have the following behavior: - "latest": picks the
highest valid Kubernetes version - "1.X": picks the highest valid patch+gke.N
patch in the 1.X version - "1.X.Y": picks the highest valid gke.N patch in the
1.X.Y version - "1.X.Y-gke.N": picks an explicit Kubernetes version - "-":
picks the Kubernetes master version
Corresponds to the JSON property nodeVersion
10426 10427 10428 |
# File 'lib/google/apis/container_v1/classes.rb', line 10426 def node_version @node_version end |
#project_id ⇒ String
Deprecated. The Google Developers Console project ID or project number. This
field has been deprecated and replaced by the name field.
Corresponds to the JSON property projectId
10433 10434 10435 |
# File 'lib/google/apis/container_v1/classes.rb', line 10433 def project_id @project_id end |
#queued_provisioning ⇒ Google::Apis::ContainerV1::QueuedProvisioning
QueuedProvisioning defines the queued provisioning used by the node pool.
Corresponds to the JSON property queuedProvisioning
10438 10439 10440 |
# File 'lib/google/apis/container_v1/classes.rb', line 10438 def queued_provisioning @queued_provisioning end |
#resource_labels ⇒ Google::Apis::ContainerV1::ResourceLabels
Collection of Resource Manager labels.
Corresponds to the JSON property resourceLabels
10444 10445 10446 |
# File 'lib/google/apis/container_v1/classes.rb', line 10444 def resource_labels @resource_labels end |
#resource_manager_tags ⇒ Google::Apis::ContainerV1::ResourceManagerTags
A map of resource manager tag keys and values to be attached to the nodes for
managing Compute Engine firewalls using Network Firewall Policies. Tags must
be according to specifications in https://cloud.google.com/vpc/docs/tags-
firewalls-overview#specifications. A maximum of 5 tag key-value pairs can be
specified. Existing tags will be replaced with new values.
Corresponds to the JSON property resourceManagerTags
10453 10454 10455 |
# File 'lib/google/apis/container_v1/classes.rb', line 10453 def @resource_manager_tags end |
#storage_pools ⇒ Array<String>
List of Storage Pools where boot disks are provisioned. Existing Storage Pools
will be replaced with storage-pools.
Corresponds to the JSON property storagePools
10459 10460 10461 |
# File 'lib/google/apis/container_v1/classes.rb', line 10459 def storage_pools @storage_pools end |
#tags ⇒ Google::Apis::ContainerV1::NetworkTags
Collection of Compute Engine network tags that can be applied to a node's
underlying VM instance.
Corresponds to the JSON property tags
10465 10466 10467 |
# File 'lib/google/apis/container_v1/classes.rb', line 10465 def @tags end |
#taint_config ⇒ Google::Apis::ContainerV1::TaintConfig
TaintConfig contains the configuration for the taints of the node pool.
Corresponds to the JSON property taintConfig
10470 10471 10472 |
# File 'lib/google/apis/container_v1/classes.rb', line 10470 def taint_config @taint_config end |
#taints ⇒ Google::Apis::ContainerV1::NodeTaints
Collection of Kubernetes node taints.
Corresponds to the JSON property taints
10476 10477 10478 |
# File 'lib/google/apis/container_v1/classes.rb', line 10476 def taints @taints end |
#upgrade_settings ⇒ Google::Apis::ContainerV1::UpgradeSettings
These upgrade settings control the level of parallelism and the level of
disruption caused by an upgrade. maxUnavailable controls the number of nodes
that can be simultaneously unavailable. maxSurge controls the number of
additional nodes that can be added to the node pool temporarily for the time
of the upgrade to increase the number of available nodes. (maxUnavailable +
maxSurge) determines the level of parallelism (how many nodes are being
upgraded at the same time). Note: upgrades inevitably introduce some
disruption since workloads need to be moved from old nodes to new, upgraded
ones. Even if maxUnavailable=0, this holds true. (Disruption stays within the
limits of PodDisruptionBudget, if it is configured.) Consider a hypothetical
node pool with 5 nodes having maxSurge=2, maxUnavailable=1. This means the
upgrade process upgrades 3 nodes simultaneously. It creates 2 additional (
upgraded) nodes, then it brings down 3 old (not yet upgraded) nodes at the
same time. This ensures that there are always at least 4 nodes available.
These upgrade settings configure the upgrade strategy for the node pool. Use
strategy to switch between the strategies applied to the node pool. If the
strategy is ROLLING, use max_surge and max_unavailable to control the level of
parallelism and the level of disruption caused by upgrade. 1. maxSurge
controls the number of additional nodes that can be added to the node pool
temporarily for the time of the upgrade to increase the number of available
nodes. 2. maxUnavailable controls the number of nodes that can be
simultaneously unavailable. 3. (maxUnavailable + maxSurge) determines the
level of parallelism (how many nodes are being upgraded at the same time). If
the strategy is BLUE_GREEN, use blue_green_settings to configure the blue-
green upgrade related settings. 1. standard_rollout_policy is the default
policy. The policy is used to control the way blue pool gets drained. The
draining is executed in the batch mode. The batch size could be specified as
either percentage of the node pool size or the number of nodes.
batch_soak_duration is the soak time after each batch gets drained. 2.
node_pool_soak_duration is the soak time after all blue nodes are drained.
After this period, the blue pool nodes will be deleted.
Corresponds to the JSON property upgradeSettings
10511 10512 10513 |
# File 'lib/google/apis/container_v1/classes.rb', line 10511 def upgrade_settings @upgrade_settings end |
#windows_node_config ⇒ Google::Apis::ContainerV1::WindowsNodeConfig
Parameters that can be configured on Windows nodes. Windows Node Config that
define the parameters that will be used to configure the Windows node pool
settings.
Corresponds to the JSON property windowsNodeConfig
10518 10519 10520 |
# File 'lib/google/apis/container_v1/classes.rb', line 10518 def windows_node_config @windows_node_config end |
#workload_metadata_config ⇒ Google::Apis::ContainerV1::WorkloadMetadataConfig
WorkloadMetadataConfig defines the metadata configuration to expose to
workloads on the node pool.
Corresponds to the JSON property workloadMetadataConfig
10524 10525 10526 |
# File 'lib/google/apis/container_v1/classes.rb', line 10524 def @workload_metadata_config end |
#zone ⇒ String
Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has
been deprecated and replaced by the name field.
Corresponds to the JSON property zone
10531 10532 10533 |
# File 'lib/google/apis/container_v1/classes.rb', line 10531 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10538 10539 10540 10541 10542 10543 10544 10545 10546 10547 10548 10549 10550 10551 10552 10553 10554 10555 10556 10557 10558 10559 10560 10561 10562 10563 10564 10565 10566 10567 10568 10569 10570 10571 10572 10573 10574 10575 10576 10577 10578 10579 |
# File 'lib/google/apis/container_v1/classes.rb', line 10538 def update!(**args) @accelerators = args[:accelerators] if args.key?(:accelerators) @boot_disk = args[:boot_disk] if args.key?(:boot_disk) @cluster_id = args[:cluster_id] if args.key?(:cluster_id) @confidential_nodes = args[:confidential_nodes] if args.key?(:confidential_nodes) @consolidation_delay = args[:consolidation_delay] if args.key?(:consolidation_delay) @containerd_config = args[:containerd_config] if args.key?(:containerd_config) @disk_size_gb = args[:disk_size_gb] if args.key?(:disk_size_gb) @disk_type = args[:disk_type] if args.key?(:disk_type) @etag = args[:etag] if args.key?(:etag) @fast_socket = args[:fast_socket] if args.key?(:fast_socket) @flex_start = args[:flex_start] if args.key?(:flex_start) @gcfs_config = args[:gcfs_config] if args.key?(:gcfs_config) @gvnic = args[:gvnic] if args.key?(:gvnic) @image = args[:image] if args.key?(:image) @image_project = args[:image_project] if args.key?(:image_project) @image_type = args[:image_type] if args.key?(:image_type) @kubelet_config = args[:kubelet_config] if args.key?(:kubelet_config) @labels = args[:labels] if args.key?(:labels) @linux_node_config = args[:linux_node_config] if args.key?(:linux_node_config) @locations = args[:locations] if args.key?(:locations) @logging_config = args[:logging_config] if args.key?(:logging_config) @machine_type = args[:machine_type] if args.key?(:machine_type) @max_run_duration = args[:max_run_duration] if args.key?(:max_run_duration) @name = args[:name] if args.key?(:name) @node_drain_config = args[:node_drain_config] if args.key?(:node_drain_config) @node_network_config = args[:node_network_config] if args.key?(:node_network_config) @node_pool_id = args[:node_pool_id] if args.key?(:node_pool_id) @node_version = args[:node_version] if args.key?(:node_version) @project_id = args[:project_id] if args.key?(:project_id) @queued_provisioning = args[:queued_provisioning] if args.key?(:queued_provisioning) @resource_labels = args[:resource_labels] if args.key?(:resource_labels) @resource_manager_tags = args[:resource_manager_tags] if args.key?(:resource_manager_tags) @storage_pools = args[:storage_pools] if args.key?(:storage_pools) @tags = args[:tags] if args.key?(:tags) @taint_config = args[:taint_config] if args.key?(:taint_config) @taints = args[:taints] if args.key?(:taints) @upgrade_settings = args[:upgrade_settings] if args.key?(:upgrade_settings) @windows_node_config = args[:windows_node_config] if args.key?(:windows_node_config) @workload_metadata_config = args[:workload_metadata_config] if args.key?(:workload_metadata_config) @zone = args[:zone] if args.key?(:zone) end |