Class: Google::Apis::ContainerV1::UpdateNodePoolRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

UpdateNodePoolRequests update a node pool's image and/or version.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UpdateNodePoolRequest

Returns a new instance of UpdateNodePoolRequest.



9378
9379
9380
# File 'lib/google/apis/container_v1/classes.rb', line 9378

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#acceleratorsArray<Google::Apis::ContainerV1::AcceleratorConfig>

A list of hardware accelerators to be attached to each node. See https://cloud. google.com/compute/docs/gpus for more information about support for GPUs. Corresponds to the JSON property accelerators



9120
9121
9122
# File 'lib/google/apis/container_v1/classes.rb', line 9120

def accelerators
  @accelerators
end

#boot_diskGoogle::Apis::ContainerV1::BootDisk

BootDisk specifies the boot disk configuration for nodepools. Corresponds to the JSON property bootDisk



9125
9126
9127
# File 'lib/google/apis/container_v1/classes.rb', line 9125

def boot_disk
  @boot_disk
end

#cluster_idString

Deprecated. The name of the cluster to upgrade. This field has been deprecated and replaced by the name field. Corresponds to the JSON property clusterId

Returns:

  • (String)


9131
9132
9133
# File 'lib/google/apis/container_v1/classes.rb', line 9131

def cluster_id
  @cluster_id
end

#confidential_nodesGoogle::Apis::ContainerV1::ConfidentialNodes

ConfidentialNodes is configuration for the confidential nodes feature, which makes nodes run on confidential VMs. Corresponds to the JSON property confidentialNodes



9137
9138
9139
# File 'lib/google/apis/container_v1/classes.rb', line 9137

def confidential_nodes
  @confidential_nodes
end

#containerd_configGoogle::Apis::ContainerV1::ContainerdConfig

ContainerdConfig contains configuration to customize containerd. Corresponds to the JSON property containerdConfig



9142
9143
9144
# File 'lib/google/apis/container_v1/classes.rb', line 9142

def containerd_config
  @containerd_config
end

#disk_size_gbFixnum

Optional. The desired disk size for nodes in the node pool specified in GB. The smallest allowed disk size is 10GB. Initiates an upgrade operation that migrates the nodes in the node pool to the specified disk size. Corresponds to the JSON property diskSizeGb

Returns:

  • (Fixnum)


9149
9150
9151
# File 'lib/google/apis/container_v1/classes.rb', line 9149

def disk_size_gb
  @disk_size_gb
end

#disk_typeString

Optional. The desired disk type (e.g. 'pd-standard', 'pd-ssd' or 'pd-balanced') for nodes in the node pool. Initiates an upgrade operation that migrates the nodes in the node pool to the specified disk type. Corresponds to the JSON property diskType

Returns:

  • (String)


9156
9157
9158
# File 'lib/google/apis/container_v1/classes.rb', line 9156

def disk_type
  @disk_type
end

#etagString

The current etag of the node pool. If an etag is provided and does not match the current etag of the node pool, update will be blocked and an ABORTED error will be returned. Corresponds to the JSON property etag

Returns:

  • (String)


9163
9164
9165
# File 'lib/google/apis/container_v1/classes.rb', line 9163

def etag
  @etag
end

#fast_socketGoogle::Apis::ContainerV1::FastSocket

Configuration of Fast Socket feature. Corresponds to the JSON property fastSocket



9168
9169
9170
# File 'lib/google/apis/container_v1/classes.rb', line 9168

def fast_socket
  @fast_socket
end

#flex_startBoolean Also known as: flex_start?

Flex Start flag for enabling Flex Start VM. Corresponds to the JSON property flexStart

Returns:

  • (Boolean)


9173
9174
9175
# File 'lib/google/apis/container_v1/classes.rb', line 9173

def flex_start
  @flex_start
end

#gcfs_configGoogle::Apis::ContainerV1::GcfsConfig

GcfsConfig contains configurations of Google Container File System (image streaming). Corresponds to the JSON property gcfsConfig



9180
9181
9182
# File 'lib/google/apis/container_v1/classes.rb', line 9180

def gcfs_config
  @gcfs_config
end

#gvnicGoogle::Apis::ContainerV1::VirtualNic

Configuration of gVNIC feature. Corresponds to the JSON property gvnic



9185
9186
9187
# File 'lib/google/apis/container_v1/classes.rb', line 9185

def gvnic
  @gvnic
end

#image_typeString

Required. The desired image type for the node pool. Please see https://cloud. google.com/kubernetes-engine/docs/concepts/node-images for available image types. Corresponds to the JSON property imageType

Returns:

  • (String)


9192
9193
9194
# File 'lib/google/apis/container_v1/classes.rb', line 9192

def image_type
  @image_type
end

#kubelet_configGoogle::Apis::ContainerV1::NodeKubeletConfig

Node kubelet configs. Corresponds to the JSON property kubeletConfig



9197
9198
9199
# File 'lib/google/apis/container_v1/classes.rb', line 9197

def kubelet_config
  @kubelet_config
end

#labelsGoogle::Apis::ContainerV1::NodeLabels

Collection of node-level Kubernetes labels. Corresponds to the JSON property labels



9203
9204
9205
# File 'lib/google/apis/container_v1/classes.rb', line 9203

def labels
  @labels
end

#linux_node_configGoogle::Apis::ContainerV1::LinuxNodeConfig

Parameters that can be configured on Linux nodes. Corresponds to the JSON property linuxNodeConfig



9208
9209
9210
# File 'lib/google/apis/container_v1/classes.rb', line 9208

def linux_node_config
  @linux_node_config
end

#locationsArray<String>

The desired list of Google Compute Engine zones in which the node pool's nodes should be located. Changing the locations for a node pool will result in nodes being either created or removed from the node pool, depending on whether locations are being added or removed. Warning: It is recommended to update node pool locations in a standalone API call. Do not combine a location update with changes to other fields (such as tags, labels, taints, etc.) in the same request. Otherwise, the API performs a structural modification where changes to other fields will only apply to newly created nodes and will not be applied to existing nodes in the node pool. To ensure all nodes are updated consistently, use a separate API call for location changes. Corresponds to the JSON property locations

Returns:

  • (Array<String>)


9223
9224
9225
# File 'lib/google/apis/container_v1/classes.rb', line 9223

def locations
  @locations
end

#logging_configGoogle::Apis::ContainerV1::NodePoolLoggingConfig

NodePoolLoggingConfig specifies logging configuration for nodepools. Corresponds to the JSON property loggingConfig



9228
9229
9230
# File 'lib/google/apis/container_v1/classes.rb', line 9228

def logging_config
  @logging_config
end

#machine_typeString

Optional. The desired Google Compute Engine machine type for nodes in the node pool. Initiates an upgrade operation that migrates the nodes in the node pool to the specified machine type. Corresponds to the JSON property machineType

Returns:

  • (String)


9236
9237
9238
# File 'lib/google/apis/container_v1/classes.rb', line 9236

def machine_type
  @machine_type
end

#max_run_durationString

The maximum duration for the nodes to exist. If unspecified, the nodes can exist indefinitely. Corresponds to the JSON property maxRunDuration

Returns:

  • (String)


9242
9243
9244
# File 'lib/google/apis/container_v1/classes.rb', line 9242

def max_run_duration
  @max_run_duration
end

#nameString

The name (project, location, cluster, node pool) of the node pool to update. Specified in the format projects/*/locations/*/clusters/*/nodePools/*. Corresponds to the JSON property name

Returns:

  • (String)


9248
9249
9250
# File 'lib/google/apis/container_v1/classes.rb', line 9248

def name
  @name
end

#node_drain_configGoogle::Apis::ContainerV1::NodeDrainConfig

NodeDrainConfig contains the node drain related configurations for this nodepool. Corresponds to the JSON property nodeDrainConfig



9254
9255
9256
# File 'lib/google/apis/container_v1/classes.rb', line 9254

def node_drain_config
  @node_drain_config
end

#node_network_configGoogle::Apis::ContainerV1::NodeNetworkConfig

Parameters for node pool-level network config. Corresponds to the JSON property nodeNetworkConfig



9259
9260
9261
# File 'lib/google/apis/container_v1/classes.rb', line 9259

def node_network_config
  @node_network_config
end

#node_pool_idString

Deprecated. The name of the node pool to upgrade. This field has been deprecated and replaced by the name field. Corresponds to the JSON property nodePoolId

Returns:

  • (String)


9265
9266
9267
# File 'lib/google/apis/container_v1/classes.rb', line 9265

def node_pool_id
  @node_pool_id
end

#node_versionString

Required. The Kubernetes version to change the nodes to (typically an upgrade). Users may specify either explicit versions offered by Kubernetes Engine or version aliases, which have the following behavior: - "latest": picks the highest valid Kubernetes version - "1.X": picks the highest valid patch+gke.N patch in the 1.X version - "1.X.Y": picks the highest valid gke.N patch in the 1.X.Y version - "1.X.Y-gke.N": picks an explicit Kubernetes version - "-": picks the Kubernetes master version Corresponds to the JSON property nodeVersion

Returns:

  • (String)


9276
9277
9278
# File 'lib/google/apis/container_v1/classes.rb', line 9276

def node_version
  @node_version
end

#project_idString

Deprecated. The Google Developers Console project ID or project number. This field has been deprecated and replaced by the name field. Corresponds to the JSON property projectId

Returns:

  • (String)


9283
9284
9285
# File 'lib/google/apis/container_v1/classes.rb', line 9283

def project_id
  @project_id
end

#queued_provisioningGoogle::Apis::ContainerV1::QueuedProvisioning

QueuedProvisioning defines the queued provisioning used by the node pool. Corresponds to the JSON property queuedProvisioning



9288
9289
9290
# File 'lib/google/apis/container_v1/classes.rb', line 9288

def queued_provisioning
  @queued_provisioning
end

#resource_labelsGoogle::Apis::ContainerV1::ResourceLabels

Collection of Resource Manager labels. Corresponds to the JSON property resourceLabels



9294
9295
9296
# File 'lib/google/apis/container_v1/classes.rb', line 9294

def resource_labels
  @resource_labels
end

#resource_manager_tagsGoogle::Apis::ContainerV1::ResourceManagerTags

A map of resource manager tag keys and values to be attached to the nodes for managing Compute Engine firewalls using Network Firewall Policies. Tags must be according to specifications in https://cloud.google.com/vpc/docs/tags- firewalls-overview#specifications. A maximum of 5 tag key-value pairs can be specified. Existing tags will be replaced with new values. Corresponds to the JSON property resourceManagerTags



9303
9304
9305
# File 'lib/google/apis/container_v1/classes.rb', line 9303

def resource_manager_tags
  @resource_manager_tags
end

#storage_poolsArray<String>

List of Storage Pools where boot disks are provisioned. Existing Storage Pools will be replaced with storage-pools. Corresponds to the JSON property storagePools

Returns:

  • (Array<String>)


9309
9310
9311
# File 'lib/google/apis/container_v1/classes.rb', line 9309

def storage_pools
  @storage_pools
end

#tagsGoogle::Apis::ContainerV1::NetworkTags

Collection of Compute Engine network tags that can be applied to a node's underlying VM instance. Corresponds to the JSON property tags



9315
9316
9317
# File 'lib/google/apis/container_v1/classes.rb', line 9315

def tags
  @tags
end

#taintsGoogle::Apis::ContainerV1::NodeTaints

Collection of Kubernetes node taints. Corresponds to the JSON property taints



9321
9322
9323
# File 'lib/google/apis/container_v1/classes.rb', line 9321

def taints
  @taints
end

#upgrade_settingsGoogle::Apis::ContainerV1::UpgradeSettings

These upgrade settings control the level of parallelism and the level of disruption caused by an upgrade. maxUnavailable controls the number of nodes that can be simultaneously unavailable. maxSurge controls the number of additional nodes that can be added to the node pool temporarily for the time of the upgrade to increase the number of available nodes. (maxUnavailable + maxSurge) determines the level of parallelism (how many nodes are being upgraded at the same time). Note: upgrades inevitably introduce some disruption since workloads need to be moved from old nodes to new, upgraded ones. Even if maxUnavailable=0, this holds true. (Disruption stays within the limits of PodDisruptionBudget, if it is configured.) Consider a hypothetical node pool with 5 nodes having maxSurge=2, maxUnavailable=1. This means the upgrade process upgrades 3 nodes simultaneously. It creates 2 additional ( upgraded) nodes, then it brings down 3 old (not yet upgraded) nodes at the same time. This ensures that there are always at least 4 nodes available. These upgrade settings configure the upgrade strategy for the node pool. Use strategy to switch between the strategies applied to the node pool. If the strategy is ROLLING, use max_surge and max_unavailable to control the level of parallelism and the level of disruption caused by upgrade. 1. maxSurge controls the number of additional nodes that can be added to the node pool temporarily for the time of the upgrade to increase the number of available nodes. 2. maxUnavailable controls the number of nodes that can be simultaneously unavailable. 3. (maxUnavailable + maxSurge) determines the level of parallelism (how many nodes are being upgraded at the same time). If the strategy is BLUE_GREEN, use blue_green_settings to configure the blue- green upgrade related settings. 1. standard_rollout_policy is the default policy. The policy is used to control the way blue pool gets drained. The draining is executed in the batch mode. The batch size could be specified as either percentage of the node pool size or the number of nodes. batch_soak_duration is the soak time after each batch gets drained. 2. node_pool_soak_duration is the soak time after all blue nodes are drained. After this period, the blue pool nodes will be deleted. Corresponds to the JSON property upgradeSettings



9356
9357
9358
# File 'lib/google/apis/container_v1/classes.rb', line 9356

def upgrade_settings
  @upgrade_settings
end

#windows_node_configGoogle::Apis::ContainerV1::WindowsNodeConfig

Parameters that can be configured on Windows nodes. Windows Node Config that define the parameters that will be used to configure the Windows node pool settings. Corresponds to the JSON property windowsNodeConfig



9363
9364
9365
# File 'lib/google/apis/container_v1/classes.rb', line 9363

def windows_node_config
  @windows_node_config
end

#workload_metadata_configGoogle::Apis::ContainerV1::WorkloadMetadataConfig

WorkloadMetadataConfig defines the metadata configuration to expose to workloads on the node pool. Corresponds to the JSON property workloadMetadataConfig



9369
9370
9371
# File 'lib/google/apis/container_v1/classes.rb', line 9369

def 
  @workload_metadata_config
end

#zoneString

Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has been deprecated and replaced by the name field. Corresponds to the JSON property zone

Returns:

  • (String)


9376
9377
9378
# File 'lib/google/apis/container_v1/classes.rb', line 9376

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9383
9384
9385
9386
9387
9388
9389
9390
9391
9392
9393
9394
9395
9396
9397
9398
9399
9400
9401
9402
9403
9404
9405
9406
9407
9408
9409
9410
9411
9412
9413
9414
9415
9416
9417
9418
9419
9420
# File 'lib/google/apis/container_v1/classes.rb', line 9383

def update!(**args)
  @accelerators = args[:accelerators] if args.key?(:accelerators)
  @boot_disk = args[:boot_disk] if args.key?(:boot_disk)
  @cluster_id = args[:cluster_id] if args.key?(:cluster_id)
  @confidential_nodes = args[:confidential_nodes] if args.key?(:confidential_nodes)
  @containerd_config = args[:containerd_config] if args.key?(:containerd_config)
  @disk_size_gb = args[:disk_size_gb] if args.key?(:disk_size_gb)
  @disk_type = args[:disk_type] if args.key?(:disk_type)
  @etag = args[:etag] if args.key?(:etag)
  @fast_socket = args[:fast_socket] if args.key?(:fast_socket)
  @flex_start = args[:flex_start] if args.key?(:flex_start)
  @gcfs_config = args[:gcfs_config] if args.key?(:gcfs_config)
  @gvnic = args[:gvnic] if args.key?(:gvnic)
  @image_type = args[:image_type] if args.key?(:image_type)
  @kubelet_config = args[:kubelet_config] if args.key?(:kubelet_config)
  @labels = args[:labels] if args.key?(:labels)
  @linux_node_config = args[:linux_node_config] if args.key?(:linux_node_config)
  @locations = args[:locations] if args.key?(:locations)
  @logging_config = args[:logging_config] if args.key?(:logging_config)
  @machine_type = args[:machine_type] if args.key?(:machine_type)
  @max_run_duration = args[:max_run_duration] if args.key?(:max_run_duration)
  @name = args[:name] if args.key?(:name)
  @node_drain_config = args[:node_drain_config] if args.key?(:node_drain_config)
  @node_network_config = args[:node_network_config] if args.key?(:node_network_config)
  @node_pool_id = args[:node_pool_id] if args.key?(:node_pool_id)
  @node_version = args[:node_version] if args.key?(:node_version)
  @project_id = args[:project_id] if args.key?(:project_id)
  @queued_provisioning = args[:queued_provisioning] if args.key?(:queued_provisioning)
  @resource_labels = args[:resource_labels] if args.key?(:resource_labels)
  @resource_manager_tags = args[:resource_manager_tags] if args.key?(:resource_manager_tags)
  @storage_pools = args[:storage_pools] if args.key?(:storage_pools)
  @tags = args[:tags] if args.key?(:tags)
  @taints = args[:taints] if args.key?(:taints)
  @upgrade_settings = args[:upgrade_settings] if args.key?(:upgrade_settings)
  @windows_node_config = args[:windows_node_config] if args.key?(:windows_node_config)
  @workload_metadata_config = args[:workload_metadata_config] if args.key?(:workload_metadata_config)
  @zone = args[:zone] if args.key?(:zone)
end