Class: Google::Apis::ContainerV1::UpgradeInfoEvent
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1::UpgradeInfoEvent
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb
Overview
UpgradeInfoEvent is a notification sent to customers about the upgrade information of a resource.
Instance Attribute Summary collapse
-
#current_emulated_version ⇒ String
Output only.
-
#current_version ⇒ String
The current version before the upgrade.
-
#description ⇒ String
A brief description of the event.
-
#disruption_event ⇒ Google::Apis::ContainerV1::DisruptionEvent
DisruptionEvent is a notification sent to customers about the disruption event of a resource.
-
#end_time ⇒ String
The time when the operation ended.
-
#event_type ⇒ String
The type of the event.
-
#extended_support_end_time ⇒ String
The end of extended support timestamp.
-
#operation ⇒ String
The operation associated with this upgrade.
-
#resource ⇒ String
Optional relative path to the resource.
-
#resource_type ⇒ String
The resource type associated with the upgrade.
-
#standard_support_end_time ⇒ String
The end of standard support timestamp.
-
#start_time ⇒ String
The time when the operation was started.
-
#state ⇒ String
Output only.
-
#target_emulated_version ⇒ String
Output only.
-
#target_version ⇒ String
The target version for the upgrade.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UpgradeInfoEvent
constructor
A new instance of UpgradeInfoEvent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UpgradeInfoEvent
Returns a new instance of UpgradeInfoEvent.
11075 11076 11077 |
# File 'lib/google/apis/container_v1/classes.rb', line 11075 def initialize(**args) update!(**args) end |
Instance Attribute Details
#current_emulated_version ⇒ String
Output only. The current emulated version before the upgrade.
Corresponds to the JSON property currentEmulatedVersion
11001 11002 11003 |
# File 'lib/google/apis/container_v1/classes.rb', line 11001 def current_emulated_version @current_emulated_version end |
#current_version ⇒ String
The current version before the upgrade.
Corresponds to the JSON property currentVersion
11006 11007 11008 |
# File 'lib/google/apis/container_v1/classes.rb', line 11006 def current_version @current_version end |
#description ⇒ String
A brief description of the event.
Corresponds to the JSON property description
11011 11012 11013 |
# File 'lib/google/apis/container_v1/classes.rb', line 11011 def description @description end |
#disruption_event ⇒ Google::Apis::ContainerV1::DisruptionEvent
DisruptionEvent is a notification sent to customers about the disruption event
of a resource.
Corresponds to the JSON property disruptionEvent
11017 11018 11019 |
# File 'lib/google/apis/container_v1/classes.rb', line 11017 def disruption_event @disruption_event end |
#end_time ⇒ String
The time when the operation ended.
Corresponds to the JSON property endTime
11022 11023 11024 |
# File 'lib/google/apis/container_v1/classes.rb', line 11022 def end_time @end_time end |
#event_type ⇒ String
The type of the event.
Corresponds to the JSON property eventType
11027 11028 11029 |
# File 'lib/google/apis/container_v1/classes.rb', line 11027 def event_type @event_type end |
#extended_support_end_time ⇒ String
The end of extended support timestamp.
Corresponds to the JSON property extendedSupportEndTime
11032 11033 11034 |
# File 'lib/google/apis/container_v1/classes.rb', line 11032 def extended_support_end_time @extended_support_end_time end |
#operation ⇒ String
The operation associated with this upgrade.
Corresponds to the JSON property operation
11037 11038 11039 |
# File 'lib/google/apis/container_v1/classes.rb', line 11037 def operation @operation end |
#resource ⇒ String
Optional relative path to the resource. For example in node pool upgrades, the
relative path of the node pool.
Corresponds to the JSON property resource
11043 11044 11045 |
# File 'lib/google/apis/container_v1/classes.rb', line 11043 def resource @resource end |
#resource_type ⇒ String
The resource type associated with the upgrade.
Corresponds to the JSON property resourceType
11048 11049 11050 |
# File 'lib/google/apis/container_v1/classes.rb', line 11048 def resource_type @resource_type end |
#standard_support_end_time ⇒ String
The end of standard support timestamp.
Corresponds to the JSON property standardSupportEndTime
11053 11054 11055 |
# File 'lib/google/apis/container_v1/classes.rb', line 11053 def standard_support_end_time @standard_support_end_time end |
#start_time ⇒ String
The time when the operation was started.
Corresponds to the JSON property startTime
11058 11059 11060 |
# File 'lib/google/apis/container_v1/classes.rb', line 11058 def start_time @start_time end |
#state ⇒ String
Output only. The state of the upgrade.
Corresponds to the JSON property state
11063 11064 11065 |
# File 'lib/google/apis/container_v1/classes.rb', line 11063 def state @state end |
#target_emulated_version ⇒ String
Output only. The target emulated version for the upgrade.
Corresponds to the JSON property targetEmulatedVersion
11068 11069 11070 |
# File 'lib/google/apis/container_v1/classes.rb', line 11068 def target_emulated_version @target_emulated_version end |
#target_version ⇒ String
The target version for the upgrade.
Corresponds to the JSON property targetVersion
11073 11074 11075 |
# File 'lib/google/apis/container_v1/classes.rb', line 11073 def target_version @target_version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11080 11081 11082 11083 11084 11085 11086 11087 11088 11089 11090 11091 11092 11093 11094 11095 11096 |
# File 'lib/google/apis/container_v1/classes.rb', line 11080 def update!(**args) @current_emulated_version = args[:current_emulated_version] if args.key?(:current_emulated_version) @current_version = args[:current_version] if args.key?(:current_version) @description = args[:description] if args.key?(:description) @disruption_event = args[:disruption_event] if args.key?(:disruption_event) @end_time = args[:end_time] if args.key?(:end_time) @event_type = args[:event_type] if args.key?(:event_type) @extended_support_end_time = args[:extended_support_end_time] if args.key?(:extended_support_end_time) @operation = args[:operation] if args.key?(:operation) @resource = args[:resource] if args.key?(:resource) @resource_type = args[:resource_type] if args.key?(:resource_type) @standard_support_end_time = args[:standard_support_end_time] if args.key?(:standard_support_end_time) @start_time = args[:start_time] if args.key?(:start_time) @state = args[:state] if args.key?(:state) @target_emulated_version = args[:target_emulated_version] if args.key?(:target_emulated_version) @target_version = args[:target_version] if args.key?(:target_version) end |