Class: Google::Apis::ContainerV1::UpgradeInfoEvent

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

UpgradeInfoEvent is a notification sent to customers about the upgrade information of a resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UpgradeInfoEvent

Returns a new instance of UpgradeInfoEvent.



10822
10823
10824
# File 'lib/google/apis/container_v1/classes.rb', line 10822

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#current_versionString

The current version before the upgrade. Corresponds to the JSON property currentVersion

Returns:

  • (String)


10758
10759
10760
# File 'lib/google/apis/container_v1/classes.rb', line 10758

def current_version
  @current_version
end

#descriptionString

A brief description of the event. Corresponds to the JSON property description

Returns:

  • (String)


10763
10764
10765
# File 'lib/google/apis/container_v1/classes.rb', line 10763

def description
  @description
end

#disruption_eventGoogle::Apis::ContainerV1::DisruptionEvent

DisruptionEvent is a notification sent to customers about the disruption event of a resource. Corresponds to the JSON property disruptionEvent



10769
10770
10771
# File 'lib/google/apis/container_v1/classes.rb', line 10769

def disruption_event
  @disruption_event
end

#end_timeString

The time when the operation ended. Corresponds to the JSON property endTime

Returns:

  • (String)


10774
10775
10776
# File 'lib/google/apis/container_v1/classes.rb', line 10774

def end_time
  @end_time
end

#event_typeString

The type of the event. Corresponds to the JSON property eventType

Returns:

  • (String)


10779
10780
10781
# File 'lib/google/apis/container_v1/classes.rb', line 10779

def event_type
  @event_type
end

#extended_support_end_timeString

The end of extended support timestamp. Corresponds to the JSON property extendedSupportEndTime

Returns:

  • (String)


10784
10785
10786
# File 'lib/google/apis/container_v1/classes.rb', line 10784

def extended_support_end_time
  @extended_support_end_time
end

#operationString

The operation associated with this upgrade. Corresponds to the JSON property operation

Returns:

  • (String)


10789
10790
10791
# File 'lib/google/apis/container_v1/classes.rb', line 10789

def operation
  @operation
end

#resourceString

Optional relative path to the resource. For example in node pool upgrades, the relative path of the node pool. Corresponds to the JSON property resource

Returns:

  • (String)


10795
10796
10797
# File 'lib/google/apis/container_v1/classes.rb', line 10795

def resource
  @resource
end

#resource_typeString

The resource type associated with the upgrade. Corresponds to the JSON property resourceType

Returns:

  • (String)


10800
10801
10802
# File 'lib/google/apis/container_v1/classes.rb', line 10800

def resource_type
  @resource_type
end

#standard_support_end_timeString

The end of standard support timestamp. Corresponds to the JSON property standardSupportEndTime

Returns:

  • (String)


10805
10806
10807
# File 'lib/google/apis/container_v1/classes.rb', line 10805

def standard_support_end_time
  @standard_support_end_time
end

#start_timeString

The time when the operation was started. Corresponds to the JSON property startTime

Returns:

  • (String)


10810
10811
10812
# File 'lib/google/apis/container_v1/classes.rb', line 10810

def start_time
  @start_time
end

#stateString

Output only. The state of the upgrade. Corresponds to the JSON property state

Returns:

  • (String)


10815
10816
10817
# File 'lib/google/apis/container_v1/classes.rb', line 10815

def state
  @state
end

#target_versionString

The target version for the upgrade. Corresponds to the JSON property targetVersion

Returns:

  • (String)


10820
10821
10822
# File 'lib/google/apis/container_v1/classes.rb', line 10820

def target_version
  @target_version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10827
10828
10829
10830
10831
10832
10833
10834
10835
10836
10837
10838
10839
10840
10841
# File 'lib/google/apis/container_v1/classes.rb', line 10827

def update!(**args)
  @current_version = args[:current_version] if args.key?(:current_version)
  @description = args[:description] if args.key?(:description)
  @disruption_event = args[:disruption_event] if args.key?(:disruption_event)
  @end_time = args[:end_time] if args.key?(:end_time)
  @event_type = args[:event_type] if args.key?(:event_type)
  @extended_support_end_time = args[:extended_support_end_time] if args.key?(:extended_support_end_time)
  @operation = args[:operation] if args.key?(:operation)
  @resource = args[:resource] if args.key?(:resource)
  @resource_type = args[:resource_type] if args.key?(:resource_type)
  @standard_support_end_time = args[:standard_support_end_time] if args.key?(:standard_support_end_time)
  @start_time = args[:start_time] if args.key?(:start_time)
  @state = args[:state] if args.key?(:state)
  @target_version = args[:target_version] if args.key?(:target_version)
end