Class: Google::Apis::ContainerV1::UpgradeInfoEvent

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

UpgradeInfoEvent is a notification sent to customers about the upgrade information of a resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UpgradeInfoEvent

Returns a new instance of UpgradeInfoEvent.



10797
10798
10799
# File 'lib/google/apis/container_v1/classes.rb', line 10797

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#current_versionString

The current version before the upgrade. Corresponds to the JSON property currentVersion

Returns:

  • (String)


10733
10734
10735
# File 'lib/google/apis/container_v1/classes.rb', line 10733

def current_version
  @current_version
end

#descriptionString

A brief description of the event. Corresponds to the JSON property description

Returns:

  • (String)


10738
10739
10740
# File 'lib/google/apis/container_v1/classes.rb', line 10738

def description
  @description
end

#disruption_eventGoogle::Apis::ContainerV1::DisruptionEvent

DisruptionEvent is a notification sent to customers about the disruption event of a resource. Corresponds to the JSON property disruptionEvent



10744
10745
10746
# File 'lib/google/apis/container_v1/classes.rb', line 10744

def disruption_event
  @disruption_event
end

#end_timeString

The time when the operation ended. Corresponds to the JSON property endTime

Returns:

  • (String)


10749
10750
10751
# File 'lib/google/apis/container_v1/classes.rb', line 10749

def end_time
  @end_time
end

#event_typeString

The type of the event. Corresponds to the JSON property eventType

Returns:

  • (String)


10754
10755
10756
# File 'lib/google/apis/container_v1/classes.rb', line 10754

def event_type
  @event_type
end

#extended_support_end_timeString

The end of extended support timestamp. Corresponds to the JSON property extendedSupportEndTime

Returns:

  • (String)


10759
10760
10761
# File 'lib/google/apis/container_v1/classes.rb', line 10759

def extended_support_end_time
  @extended_support_end_time
end

#operationString

The operation associated with this upgrade. Corresponds to the JSON property operation

Returns:

  • (String)


10764
10765
10766
# File 'lib/google/apis/container_v1/classes.rb', line 10764

def operation
  @operation
end

#resourceString

Optional relative path to the resource. For example in node pool upgrades, the relative path of the node pool. Corresponds to the JSON property resource

Returns:

  • (String)


10770
10771
10772
# File 'lib/google/apis/container_v1/classes.rb', line 10770

def resource
  @resource
end

#resource_typeString

The resource type associated with the upgrade. Corresponds to the JSON property resourceType

Returns:

  • (String)


10775
10776
10777
# File 'lib/google/apis/container_v1/classes.rb', line 10775

def resource_type
  @resource_type
end

#standard_support_end_timeString

The end of standard support timestamp. Corresponds to the JSON property standardSupportEndTime

Returns:

  • (String)


10780
10781
10782
# File 'lib/google/apis/container_v1/classes.rb', line 10780

def standard_support_end_time
  @standard_support_end_time
end

#start_timeString

The time when the operation was started. Corresponds to the JSON property startTime

Returns:

  • (String)


10785
10786
10787
# File 'lib/google/apis/container_v1/classes.rb', line 10785

def start_time
  @start_time
end

#stateString

Output only. The state of the upgrade. Corresponds to the JSON property state

Returns:

  • (String)


10790
10791
10792
# File 'lib/google/apis/container_v1/classes.rb', line 10790

def state
  @state
end

#target_versionString

The target version for the upgrade. Corresponds to the JSON property targetVersion

Returns:

  • (String)


10795
10796
10797
# File 'lib/google/apis/container_v1/classes.rb', line 10795

def target_version
  @target_version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10802
10803
10804
10805
10806
10807
10808
10809
10810
10811
10812
10813
10814
10815
10816
# File 'lib/google/apis/container_v1/classes.rb', line 10802

def update!(**args)
  @current_version = args[:current_version] if args.key?(:current_version)
  @description = args[:description] if args.key?(:description)
  @disruption_event = args[:disruption_event] if args.key?(:disruption_event)
  @end_time = args[:end_time] if args.key?(:end_time)
  @event_type = args[:event_type] if args.key?(:event_type)
  @extended_support_end_time = args[:extended_support_end_time] if args.key?(:extended_support_end_time)
  @operation = args[:operation] if args.key?(:operation)
  @resource = args[:resource] if args.key?(:resource)
  @resource_type = args[:resource_type] if args.key?(:resource_type)
  @standard_support_end_time = args[:standard_support_end_time] if args.key?(:standard_support_end_time)
  @start_time = args[:start_time] if args.key?(:start_time)
  @state = args[:state] if args.key?(:state)
  @target_version = args[:target_version] if args.key?(:target_version)
end