Class: Google::Apis::ContainerV1::UpgradeInfoEvent
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1::UpgradeInfoEvent
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb
Overview
UpgradeInfoEvent is a notification sent to customers about the upgrade information of a resource.
Instance Attribute Summary collapse
-
#current_version ⇒ String
The current version before the upgrade.
-
#description ⇒ String
A brief description of the event.
-
#disruption_event ⇒ Google::Apis::ContainerV1::DisruptionEvent
DisruptionEvent is a notification sent to customers about the disruption event of a resource.
-
#end_time ⇒ String
The time when the operation ended.
-
#event_type ⇒ String
The type of the event.
-
#extended_support_end_time ⇒ String
The end of extended support timestamp.
-
#operation ⇒ String
The operation associated with this upgrade.
-
#resource ⇒ String
Optional relative path to the resource.
-
#resource_type ⇒ String
The resource type associated with the upgrade.
-
#standard_support_end_time ⇒ String
The end of standard support timestamp.
-
#start_time ⇒ String
The time when the operation was started.
-
#state ⇒ String
Output only.
-
#target_version ⇒ String
The target version for the upgrade.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UpgradeInfoEvent
constructor
A new instance of UpgradeInfoEvent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UpgradeInfoEvent
Returns a new instance of UpgradeInfoEvent.
9971 9972 9973 |
# File 'lib/google/apis/container_v1/classes.rb', line 9971 def initialize(**args) update!(**args) end |
Instance Attribute Details
#current_version ⇒ String
The current version before the upgrade.
Corresponds to the JSON property currentVersion
9907 9908 9909 |
# File 'lib/google/apis/container_v1/classes.rb', line 9907 def current_version @current_version end |
#description ⇒ String
A brief description of the event.
Corresponds to the JSON property description
9912 9913 9914 |
# File 'lib/google/apis/container_v1/classes.rb', line 9912 def description @description end |
#disruption_event ⇒ Google::Apis::ContainerV1::DisruptionEvent
DisruptionEvent is a notification sent to customers about the disruption event
of a resource.
Corresponds to the JSON property disruptionEvent
9918 9919 9920 |
# File 'lib/google/apis/container_v1/classes.rb', line 9918 def disruption_event @disruption_event end |
#end_time ⇒ String
The time when the operation ended.
Corresponds to the JSON property endTime
9923 9924 9925 |
# File 'lib/google/apis/container_v1/classes.rb', line 9923 def end_time @end_time end |
#event_type ⇒ String
The type of the event.
Corresponds to the JSON property eventType
9928 9929 9930 |
# File 'lib/google/apis/container_v1/classes.rb', line 9928 def event_type @event_type end |
#extended_support_end_time ⇒ String
The end of extended support timestamp.
Corresponds to the JSON property extendedSupportEndTime
9933 9934 9935 |
# File 'lib/google/apis/container_v1/classes.rb', line 9933 def extended_support_end_time @extended_support_end_time end |
#operation ⇒ String
The operation associated with this upgrade.
Corresponds to the JSON property operation
9938 9939 9940 |
# File 'lib/google/apis/container_v1/classes.rb', line 9938 def operation @operation end |
#resource ⇒ String
Optional relative path to the resource. For example in node pool upgrades, the
relative path of the node pool.
Corresponds to the JSON property resource
9944 9945 9946 |
# File 'lib/google/apis/container_v1/classes.rb', line 9944 def resource @resource end |
#resource_type ⇒ String
The resource type associated with the upgrade.
Corresponds to the JSON property resourceType
9949 9950 9951 |
# File 'lib/google/apis/container_v1/classes.rb', line 9949 def resource_type @resource_type end |
#standard_support_end_time ⇒ String
The end of standard support timestamp.
Corresponds to the JSON property standardSupportEndTime
9954 9955 9956 |
# File 'lib/google/apis/container_v1/classes.rb', line 9954 def standard_support_end_time @standard_support_end_time end |
#start_time ⇒ String
The time when the operation was started.
Corresponds to the JSON property startTime
9959 9960 9961 |
# File 'lib/google/apis/container_v1/classes.rb', line 9959 def start_time @start_time end |
#state ⇒ String
Output only. The state of the upgrade.
Corresponds to the JSON property state
9964 9965 9966 |
# File 'lib/google/apis/container_v1/classes.rb', line 9964 def state @state end |
#target_version ⇒ String
The target version for the upgrade.
Corresponds to the JSON property targetVersion
9969 9970 9971 |
# File 'lib/google/apis/container_v1/classes.rb', line 9969 def target_version @target_version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9976 9977 9978 9979 9980 9981 9982 9983 9984 9985 9986 9987 9988 9989 9990 |
# File 'lib/google/apis/container_v1/classes.rb', line 9976 def update!(**args) @current_version = args[:current_version] if args.key?(:current_version) @description = args[:description] if args.key?(:description) @disruption_event = args[:disruption_event] if args.key?(:disruption_event) @end_time = args[:end_time] if args.key?(:end_time) @event_type = args[:event_type] if args.key?(:event_type) @extended_support_end_time = args[:extended_support_end_time] if args.key?(:extended_support_end_time) @operation = args[:operation] if args.key?(:operation) @resource = args[:resource] if args.key?(:resource) @resource_type = args[:resource_type] if args.key?(:resource_type) @standard_support_end_time = args[:standard_support_end_time] if args.key?(:standard_support_end_time) @start_time = args[:start_time] if args.key?(:start_time) @state = args[:state] if args.key?(:state) @target_version = args[:target_version] if args.key?(:target_version) end |