Class: Google::Apis::ContainerV1::UpgradeInfoEvent
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1::UpgradeInfoEvent
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb
Overview
UpgradeInfoEvent is a notification sent to customers about the upgrade information of a resource.
Instance Attribute Summary collapse
-
#current_version ⇒ String
The current version before the upgrade.
-
#description ⇒ String
A brief description of the event.
-
#disruption_event ⇒ Google::Apis::ContainerV1::DisruptionEvent
DisruptionEvent is a notification sent to customers about the disruption event of a resource.
-
#end_time ⇒ String
The time when the operation ended.
-
#event_type ⇒ String
The type of the event.
-
#extended_support_end_time ⇒ String
The end of extended support timestamp.
-
#operation ⇒ String
The operation associated with this upgrade.
-
#resource ⇒ String
Optional relative path to the resource.
-
#resource_type ⇒ String
The resource type associated with the upgrade.
-
#standard_support_end_time ⇒ String
The end of standard support timestamp.
-
#start_time ⇒ String
The time when the operation was started.
-
#state ⇒ String
Output only.
-
#target_version ⇒ String
The target version for the upgrade.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UpgradeInfoEvent
constructor
A new instance of UpgradeInfoEvent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UpgradeInfoEvent
Returns a new instance of UpgradeInfoEvent.
9638 9639 9640 |
# File 'lib/google/apis/container_v1/classes.rb', line 9638 def initialize(**args) update!(**args) end |
Instance Attribute Details
#current_version ⇒ String
The current version before the upgrade.
Corresponds to the JSON property currentVersion
9574 9575 9576 |
# File 'lib/google/apis/container_v1/classes.rb', line 9574 def current_version @current_version end |
#description ⇒ String
A brief description of the event.
Corresponds to the JSON property description
9579 9580 9581 |
# File 'lib/google/apis/container_v1/classes.rb', line 9579 def description @description end |
#disruption_event ⇒ Google::Apis::ContainerV1::DisruptionEvent
DisruptionEvent is a notification sent to customers about the disruption event
of a resource.
Corresponds to the JSON property disruptionEvent
9585 9586 9587 |
# File 'lib/google/apis/container_v1/classes.rb', line 9585 def disruption_event @disruption_event end |
#end_time ⇒ String
The time when the operation ended.
Corresponds to the JSON property endTime
9590 9591 9592 |
# File 'lib/google/apis/container_v1/classes.rb', line 9590 def end_time @end_time end |
#event_type ⇒ String
The type of the event.
Corresponds to the JSON property eventType
9595 9596 9597 |
# File 'lib/google/apis/container_v1/classes.rb', line 9595 def event_type @event_type end |
#extended_support_end_time ⇒ String
The end of extended support timestamp.
Corresponds to the JSON property extendedSupportEndTime
9600 9601 9602 |
# File 'lib/google/apis/container_v1/classes.rb', line 9600 def extended_support_end_time @extended_support_end_time end |
#operation ⇒ String
The operation associated with this upgrade.
Corresponds to the JSON property operation
9605 9606 9607 |
# File 'lib/google/apis/container_v1/classes.rb', line 9605 def operation @operation end |
#resource ⇒ String
Optional relative path to the resource. For example in node pool upgrades, the
relative path of the node pool.
Corresponds to the JSON property resource
9611 9612 9613 |
# File 'lib/google/apis/container_v1/classes.rb', line 9611 def resource @resource end |
#resource_type ⇒ String
The resource type associated with the upgrade.
Corresponds to the JSON property resourceType
9616 9617 9618 |
# File 'lib/google/apis/container_v1/classes.rb', line 9616 def resource_type @resource_type end |
#standard_support_end_time ⇒ String
The end of standard support timestamp.
Corresponds to the JSON property standardSupportEndTime
9621 9622 9623 |
# File 'lib/google/apis/container_v1/classes.rb', line 9621 def standard_support_end_time @standard_support_end_time end |
#start_time ⇒ String
The time when the operation was started.
Corresponds to the JSON property startTime
9626 9627 9628 |
# File 'lib/google/apis/container_v1/classes.rb', line 9626 def start_time @start_time end |
#state ⇒ String
Output only. The state of the upgrade.
Corresponds to the JSON property state
9631 9632 9633 |
# File 'lib/google/apis/container_v1/classes.rb', line 9631 def state @state end |
#target_version ⇒ String
The target version for the upgrade.
Corresponds to the JSON property targetVersion
9636 9637 9638 |
# File 'lib/google/apis/container_v1/classes.rb', line 9636 def target_version @target_version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9643 9644 9645 9646 9647 9648 9649 9650 9651 9652 9653 9654 9655 9656 9657 |
# File 'lib/google/apis/container_v1/classes.rb', line 9643 def update!(**args) @current_version = args[:current_version] if args.key?(:current_version) @description = args[:description] if args.key?(:description) @disruption_event = args[:disruption_event] if args.key?(:disruption_event) @end_time = args[:end_time] if args.key?(:end_time) @event_type = args[:event_type] if args.key?(:event_type) @extended_support_end_time = args[:extended_support_end_time] if args.key?(:extended_support_end_time) @operation = args[:operation] if args.key?(:operation) @resource = args[:resource] if args.key?(:resource) @resource_type = args[:resource_type] if args.key?(:resource_type) @standard_support_end_time = args[:standard_support_end_time] if args.key?(:standard_support_end_time) @start_time = args[:start_time] if args.key?(:start_time) @state = args[:state] if args.key?(:state) @target_version = args[:target_version] if args.key?(:target_version) end |