Class: Google::Apis::ContainerV1::UserManagedKeysConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

UserManagedKeysConfig holds the resource address to Keys which are used for signing certs and token that are used for communication within cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UserManagedKeysConfig

Returns a new instance of UserManagedKeysConfig.



11029
11030
11031
# File 'lib/google/apis/container_v1/classes.rb', line 11029

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#aggregation_caString

The Certificate Authority Service caPool to use for the aggregation CA in this cluster. Corresponds to the JSON property aggregationCa

Returns:

  • (String)


10977
10978
10979
# File 'lib/google/apis/container_v1/classes.rb', line 10977

def aggregation_ca
  @aggregation_ca
end

#cluster_caString

The Certificate Authority Service caPool to use for the cluster CA in this cluster. Corresponds to the JSON property clusterCa

Returns:

  • (String)


10983
10984
10985
# File 'lib/google/apis/container_v1/classes.rb', line 10983

def cluster_ca
  @cluster_ca
end

#control_plane_disk_encryption_keyString

The Cloud KMS cryptoKey to use for Confidential Hyperdisk on the control plane nodes. Corresponds to the JSON property controlPlaneDiskEncryptionKey

Returns:

  • (String)


10989
10990
10991
# File 'lib/google/apis/container_v1/classes.rb', line 10989

def control_plane_disk_encryption_key
  @control_plane_disk_encryption_key
end

#control_plane_disk_encryption_key_versionsArray<String>

Output only. All of the versions of the Cloud KMS cryptoKey that are used by Confidential Hyperdisks on the control plane nodes. Corresponds to the JSON property controlPlaneDiskEncryptionKeyVersions

Returns:

  • (Array<String>)


10995
10996
10997
# File 'lib/google/apis/container_v1/classes.rb', line 10995

def control_plane_disk_encryption_key_versions
  @control_plane_disk_encryption_key_versions
end

#etcd_api_caString

Resource path of the Certificate Authority Service caPool to use for the etcd API CA in this cluster. Corresponds to the JSON property etcdApiCa

Returns:

  • (String)


11001
11002
11003
# File 'lib/google/apis/container_v1/classes.rb', line 11001

def etcd_api_ca
  @etcd_api_ca
end

#etcd_peer_caString

Resource path of the Certificate Authority Service caPool to use for the etcd peer CA in this cluster. Corresponds to the JSON property etcdPeerCa

Returns:

  • (String)


11007
11008
11009
# File 'lib/google/apis/container_v1/classes.rb', line 11007

def etcd_peer_ca
  @etcd_peer_ca
end

#gkeops_etcd_backup_encryption_keyString

Resource path of the Cloud KMS cryptoKey to use for encryption of internal etcd backups. Corresponds to the JSON property gkeopsEtcdBackupEncryptionKey

Returns:

  • (String)


11013
11014
11015
# File 'lib/google/apis/container_v1/classes.rb', line 11013

def gkeops_etcd_backup_encryption_key
  @gkeops_etcd_backup_encryption_key
end

#service_account_signing_keysArray<String>

The Cloud KMS cryptoKeyVersions to use for signing service account JWTs issued by this cluster. Format: projects/project/locations/location/keyRings/ keyring/cryptoKeys/cryptoKey/cryptoKeyVersions/cryptoKeyVersion` Corresponds to the JSON propertyserviceAccountSigningKeys`

Returns:

  • (Array<String>)


11020
11021
11022
# File 'lib/google/apis/container_v1/classes.rb', line 11020

def 
  @service_account_signing_keys
end

#service_account_verification_keysArray<String>

The Cloud KMS cryptoKeyVersions to use for verifying service account JWTs issued by this cluster. Format: projects/project/locations/location/ keyRings/keyring/cryptoKeys/cryptoKey/cryptoKeyVersions/cryptoKeyVersion` Corresponds to the JSON propertyserviceAccountVerificationKeys`

Returns:

  • (Array<String>)


11027
11028
11029
# File 'lib/google/apis/container_v1/classes.rb', line 11027

def 
  @service_account_verification_keys
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11034
11035
11036
11037
11038
11039
11040
11041
11042
11043
11044
# File 'lib/google/apis/container_v1/classes.rb', line 11034

def update!(**args)
  @aggregation_ca = args[:aggregation_ca] if args.key?(:aggregation_ca)
  @cluster_ca = args[:cluster_ca] if args.key?(:cluster_ca)
  @control_plane_disk_encryption_key = args[:control_plane_disk_encryption_key] if args.key?(:control_plane_disk_encryption_key)
  @control_plane_disk_encryption_key_versions = args[:control_plane_disk_encryption_key_versions] if args.key?(:control_plane_disk_encryption_key_versions)
  @etcd_api_ca = args[:etcd_api_ca] if args.key?(:etcd_api_ca)
  @etcd_peer_ca = args[:etcd_peer_ca] if args.key?(:etcd_peer_ca)
  @gkeops_etcd_backup_encryption_key = args[:gkeops_etcd_backup_encryption_key] if args.key?(:gkeops_etcd_backup_encryption_key)
  @service_account_signing_keys = args[:service_account_signing_keys] if args.key?(:service_account_signing_keys)
  @service_account_verification_keys = args[:service_account_verification_keys] if args.key?(:service_account_verification_keys)
end