Class: Google::Apis::ContainerV1::WindowsNodeConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb

Overview

Parameters that can be configured on Windows nodes. Windows Node Config that define the parameters that will be used to configure the Windows node pool settings.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WindowsNodeConfig

Returns a new instance of WindowsNodeConfig.



11100
11101
11102
# File 'lib/google/apis/container_v1/classes.rb', line 11100

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#os_versionString

OSVersion specifies the Windows node config to be used on the node. Corresponds to the JSON property osVersion

Returns:

  • (String)


11098
11099
11100
# File 'lib/google/apis/container_v1/classes.rb', line 11098

def os_version
  @os_version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11105
11106
11107
# File 'lib/google/apis/container_v1/classes.rb', line 11105

def update!(**args)
  @os_version = args[:os_version] if args.key?(:os_version)
end