Class: Google::Apis::ContainerV1::WindowsNodeConfig
- Inherits:
-
Object
- Object
- Google::Apis::ContainerV1::WindowsNodeConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/container_v1/classes.rb,
lib/google/apis/container_v1/representations.rb,
lib/google/apis/container_v1/representations.rb
Overview
Parameters that can be configured on Windows nodes. Windows Node Config that define the parameters that will be used to configure the Windows node pool settings.
Instance Attribute Summary collapse
-
#os_version ⇒ String
OSVersion specifies the Windows node config to be used on the node.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WindowsNodeConfig
constructor
A new instance of WindowsNodeConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WindowsNodeConfig
Returns a new instance of WindowsNodeConfig.
9941 9942 9943 |
# File 'lib/google/apis/container_v1/classes.rb', line 9941 def initialize(**args) update!(**args) end |
Instance Attribute Details
#os_version ⇒ String
OSVersion specifies the Windows node config to be used on the node.
Corresponds to the JSON property osVersion
9939 9940 9941 |
# File 'lib/google/apis/container_v1/classes.rb', line 9939 def os_version @os_version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9946 9947 9948 |
# File 'lib/google/apis/container_v1/classes.rb', line 9946 def update!(**args) @os_version = args[:os_version] if args.key?(:os_version) end |